/**
 * BallotData.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.domain.ballot;

import java.util.Set;

import com.smartmatic.waffle.domain.demographics.ElectionData;
import com.smartmatic.waffle.domain.general.GeneralInfo;
import com.smartmatic.waffle.persistence.metadata.MultilingualPropertyAnnotation;
import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamOmitField;

/**
 * JavaBean representing a specific ballot.
 * 
 * A ballot is a gathering of all specific instances of ballot-cards containing
 * specific instances of ballot options. An instance of this class represents a
 * real-world voting ballot (whether voting-machine-screen ballot or physical
 * voting-pad ballot).
 */
@XStreamAlias("ballot")
public class BallotData extends GeneralInfo {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 5278667685412591908L;

	/** The ballot cards. */
	@XStreamAlias("ballot-cards")
	Set<BallotCardData> ballotCards;

	/** The is initialized. */
	@XStreamOmitField
	private boolean isInitialized = false;

	/** The election data parent. */
	@XStreamOmitField
	private ElectionData electionDataParent;

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getVersion()
	 */
	@Override
	public int getVersion() {
		return this.version;
	}

	/**
	 * Getter of <code>help</code> property.
	 * 
	 * @return <code>help</code> property value.
	 * @see #help
	 */
	@Override
	@MultilingualPropertyAnnotation
	public String getHelp() {
		return this.help;
	}

	/**
	 * Getter of <code>abstractKey</code> property.
	 * 
	 * @return <code>abstractKey</code> property value.
	 * @see #abstractKey
	 */
	@Override
	@MultilingualPropertyAnnotation
	public String getAbstractKey() {
		return this.abstractKey;
	}

	/**
	 * Getter of <code>title</code> property.
	 * 
	 * @return <code>title</code> property value.
	 * @see #name
	 */
	@Override
	@MultilingualPropertyAnnotation
	public String getName() {
		return this.name;
	}

	/**
	 * Getter of <code>ballotCards</code> property.
	 * 
	 * @return <code>ballotCards</code> property value.
	 * @see #ballotCards
	 */

	public Set<BallotCardData> getBallotCards() {
		return this.ballotCards;
	}

	/**
	 * Setter of <code>ballotCards</code> property.
	 * 
	 * @param ballotCards
	 *            The <code>ballotCards</code> to set.
	 * @see #ballotCards
	 */
	public void setBallotCards(Set<BallotCardData> ballotCards) {
		this.ballotCards = ballotCards;
	}

	/**
	 * Getter of <code>isInitialized</code> property.
	 * 
	 * @return <code>isInitialized</code> property value.
	 * @see #isInitialized
	 */

	public boolean isInitialized() {
		return this.isInitialized;
	}

	/**
	 * Getter of <code>electionDataParent</code> property.
	 * 
	 * @return <code>electionDataParent</code> property value.
	 * @see #electionDataParent
	 */

	public ElectionData getElectionDataParent() {
		return this.electionDataParent;
	}

	/**
	 * Setter for the <code>electionDataParent</code> attribute.
	 * 
	 * @param electionDataParent
	 *            the electionDataParent to set
	 * @see BallotData#electionDataParent
	 */
	public void setElectionDataParent(ElectionData electionDataParent) {
		this.electionDataParent = electionDataParent;
	}

}
