/**
 * BallotLayoutData.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.domain.contest;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.persistence.UniqueConstraint;

import com.smartmatic.waffle.domain.BaseDataObject;
import com.smartmatic.waffle.domain.bulk.CustomCodeAnnotation;
import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;
import com.thoughtworks.xstream.annotations.XStreamOmitField;

/**
 * JavaBean that represents the eligible option's position in voting device
 * screen.
 */
@XStreamAlias("display-info")
@Entity
@Table(name = "ballot_layout", uniqueConstraints = {
		@UniqueConstraint(columnNames = "ballot_layout_code") })
public class BallotLayoutData extends BaseDataObject {

	/**
	 * The Constant serialVersionUID.
	 */
	@XStreamOmitField
	private static final long serialVersionUID = -1780778070115771757L;

	/**
	 * The ballot layout code.
	 */
	@XStreamOmitField
	private long ballotLayoutCode;

	/**
	 * The ballot layout custom code.
	 */
	@XStreamOmitField
	private String ballotLayoutCustomCode;

	/**
	 * The ballot layout name.
	 */
	@XStreamOmitField
	private String ballotLayoutName;

	/**
	 * Defines the alignment that candidate names should have inside the Ballot.
	 * <p>
	 * Possible values: <code>center, left, right</code>.
	 */
	@XStreamAlias("firstname-alignment")
	@XStreamAsAttribute
	private String cfnAlignment;

	/**
	 * Defines the alignment that candidate last names should have inside the
	 * Ballot.
	 * <p>
	 * Possible values: <code>center, left, right</code>.
	 */
	@XStreamAlias("lastname-alignment")
	@XStreamAsAttribute
	private String clnAlignment;

	/**
	 * The number of columns.
	 */
	@XStreamAlias("number-of-columns")
	@XStreamAsAttribute
	private int numberOfColumns;

	/** Use to configure ballot preview. */
	@XStreamAlias("party-preview")
	@XStreamAsAttribute
	private boolean partyPreview;

	/**
	 * The pivot.
	 */
	@XStreamAlias("value-of-pivot")
	@XStreamAsAttribute
	private int pivot;

	/**
	 * The swing.
	 */
	@XStreamAlias("swing")
	@XStreamAsAttribute
	private String swing;

	/**
	 * Gets the ballot layout code.
	 * 
	 * @return the ballot layout code
	 */
	@Id
	@Column(name = "ballot_layout_code")
	@GeneratedValue(strategy = GenerationType.AUTO, generator = "s_ballot_layout")
	@SequenceGenerator(name = "s_ballot_layout", sequenceName = "s_ballot_layout", allocationSize = 1, initialValue = 1)
	public long getBallotLayoutCode() {
		return this.ballotLayoutCode;
	}

	/**
	 * Gets the ballot layout custom code.
	 * 
	 * @return the ballot layout custom code
	 */
	@CustomCodeAnnotation
	@Column(name = "ballot_layout_custom_code", nullable = false, unique = true, length = 255)
	public String getBallotLayoutCustomCode() {
		return this.ballotLayoutCustomCode;
	}

	/**
	 * Gets the ballot layout name.
	 * 
	 * @return the ballot layout name
	 */
	@Column(name = "ballot_layout_name", nullable = true)
	public String getBallotLayoutName() {
		return this.ballotLayoutName;
	}

	/**
	 * Returns the alignment that candidate names should have inside the Ballot.
	 *
	 * @return {@code String} (Possible values:
	 *         <code>center, left, right</code>)
	 */
	@Column(name = "candidate_name_alignment", nullable = false)
	public String getFirstnameAlignment() {
		return this.cfnAlignment;
	}

	/**
	 * Returns the alignment that candidate last names should have inside the
	 * Ballot.
	 *
	 * @return {@code String} (Possible values:
	 *         <code>center, left, right</code>)
	 */
	@Column(name = "candidate_lastname_alignment", nullable = false)
	public String getLastnameAlignment() {
		return this.clnAlignment;
	}

	/**
	 * Gets the number of columns.
	 * 
	 * @return the number of columns
	 */
	@Column(name = "number_of_columns", nullable = true)
	public int getNumberOfColumns() {
		return this.numberOfColumns;
	}

	/**
	 * Gets the pivot.
	 * 
	 * @return the pivot
	 */
	@Column(name = "value_of_pivot", nullable = true)
	public int getPivot() {
		return this.pivot;
	}

	/**
	 * Gets the value of swing.
	 * 
	 * @return true, if is swing
	 */
	@Column(name = "swing", nullable = true)
	public String getSwing() {
		return this.swing;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.domain.BaseDataObject#getVersion()
	 */
	@Transient
	@Override
	public int getVersion() {
		return 0;
	}

	/**
	 * Get the party preview value.
	 * 
	 * @return the partyPreview
	 */
	@Transient
	public boolean isPartyPreview() {
		return this.partyPreview;
	}

	/**
	 * Sets the ballot layout code.
	 * 
	 * @param ballotLayoutCode
	 *            the new ballot layout code
	 */
	public void setBallotLayoutCode(long ballotLayoutCode) {
		this.ballotLayoutCode = ballotLayoutCode;
	}

	/**
	 * Sets the ballot layout custom code.
	 * 
	 * @param ballotLayoutCustomCode
	 *            the new ballot layout custom code
	 */
	public void setBallotLayoutCustomCode(String ballotLayoutCustomCode) {
		this.ballotLayoutCustomCode = ballotLayoutCustomCode;
	}

	/**
	 * Sets the ballot layout name.
	 * 
	 * @param ballotLayoutName
	 *            the new ballot layout name
	 */
	public void setBallotLayoutName(String ballotLayoutName) {
		this.ballotLayoutName = ballotLayoutName;
	}

	/**
	 * Setups the alignment that candidate names should have inside the Ballot.
	 *
	 * @param alignment
	 *            {@code String} (Possible values:
	 *            <code>center, left, right</code>)
	 */
	public void setFirstnameAlignment(String alignment) {
		this.cfnAlignment = alignment;
	}

	/**
	 * Setups the alignment that candidate last names should have inside the
	 * Ballot.
	 *
	 * @return {@code String} (Possible values:
	 *         <code>center, left, right</code>)
	 */
	public void setLastnameAlignment(String alignment) {
		this.clnAlignment = alignment;
	}

	/**
	 * Sets the number of columns.
	 * 
	 * @param numberOfColumns
	 *            the new number of columns
	 */
	public void setNumberOfColumns(int numberOfColumns) {
		this.numberOfColumns = numberOfColumns;
	}

	/**
	 * Sets the party preview value.
	 * 
	 * @param partyPreview
	 *            the boolean value to set
	 */
	public void setPartyPreview(boolean partyPreview) {
		this.partyPreview = partyPreview;
	}

	/**
	 * Sets the pivot.
	 * 
	 * @param pivot
	 *            the new pivot
	 */
	public void setPivot(int pivot) {
		this.pivot = pivot;
	}

	/**
	 * Sets the swing.
	 * 
	 * @param swing
	 *            the new swing
	 */
	public void setSwing(String swing) {
		this.swing = swing;
	}
}
