/**
 * ContestClassData.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.domain.contest;

import java.util.Map;
import java.util.Set;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.OneToMany;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.persistence.UniqueConstraint;

import com.smartmatic.waffle.domain.bulk.CustomCodeAnnotation;
import com.smartmatic.waffle.domain.general.GeneralInfo;
import com.smartmatic.waffle.domain.i18n.LanguageData;
import com.smartmatic.waffle.lang.annotations.basic.ValidatorListener;
import com.smartmatic.waffle.persistence.metadata.MultilingualPropertyAnnotation;
import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;
import com.thoughtworks.xstream.annotations.XStreamConverter;
import com.thoughtworks.xstream.annotations.XStreamOmitField;
import com.thoughtworks.xstream.converters.enums.EnumConverter;

/**
 * Class that represents the different class of Contest that can be created in a
 * election.
 */
@XStreamAlias("contest-class")
@Entity
@Table(name = "contest_class", uniqueConstraints = { @UniqueConstraint(columnNames = "contest_class_code") })
@ValidatorListener(name = "com.smartmatic.waffle.validator.contest.ContestClassDataValidator")
public class ContestClassData extends GeneralInfo {

	/** The translations list associated with this contest class. */
	@XStreamOmitField
	private Map<LanguageData, String> translationsList;

	/**
	 * Gets the translations list.
	 * 
	 * @return the translations list
	 */
	@Transient
	public Map<LanguageData, String> getTranslationsList() {
		return this.translationsList;
	}

	/**
	 * Sets the translations list.
	 * 
	 * @param translationsList
	 *            the translations list
	 */
	public void setTranslationsList(Map<LanguageData, String> translationsList) {
		this.translationsList = translationsList;
	}

	/** The Constant serialVersionUID. */
	@XStreamOmitField
	private static final long serialVersionUID = 752641698310231504L;

	/** The type. */
	@XStreamAlias("type")
	@XStreamAsAttribute
	@Enumerated(EnumType.ORDINAL)
	Type type;

	/**
	 * The Enum Type.
	 */
	@XStreamConverter(EnumConverter.class)
	public enum Type {

		/** The single. */
		SINGLE,
		/** The list. */
		LIST,
		/** The minority single. */
		MINORITY_SINGLE,
		/** The issue. */
		ISSUE,
		/** The non candidate. */
		NON_CANDIDATE
	}

	/** The requires candidate img. */
	@XStreamOmitField
	boolean requiresCandidateImg;

	/** The document title. */
	@XStreamOmitField
	String documentTitle;

	/** The stand count chief. */
	@XStreamAlias("stand-count-chief")
	@XStreamAsAttribute
	int standCountChief;

	/** The period. */
	@XStreamAlias("period")
	@XStreamAsAttribute
	int period;

	/** The unit. */
	@XStreamAlias("unit")
	@XStreamAsAttribute
	@Enumerated(EnumType.ORDINAL)
	UnitType unit;

	/** The precedence. */
	@XStreamOmitField
	long precedence;

	/**
	 * The Enum UnitType.
	 */
	@XStreamConverter(EnumConverter.class)
	public enum UnitType {

		/** The day. */
		DAY,
		/** The week. */
		WEEK,
		/** The month. */
		MONTH,
		/** The year. */
		YEAR
	}

	/** The election mode. */
	@XStreamAlias("election-mode")
	@XStreamAsAttribute
	@Enumerated(EnumType.ORDINAL)
	ElectionModeType electionMode;

	/**
	 * The Enum ElectionModeType.
	 */
	@XStreamConverter(EnumConverter.class)
	public enum ElectionModeType {

		/** The regular. */
		REGULAR,
		/** The openlist. */
		OPENLIST
	}

	/** The contest class name. */
	@XStreamAlias("name-key")
	@XStreamAsAttribute
	String contestClassName;

	/** The description. */
	@XStreamAlias("description-key")
	@XStreamAsAttribute
	String description;

	/** The contests. */
	@XStreamOmitField
	private Set<ContestData> contests;

	/** The contest class name translate. */
	@XStreamOmitField
	private String contestClassNameTranslate;

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getVersion()
	 */
	@Override
	@Transient
	public int getVersion() {
		return 0;
	}

	/**
	 * Gets the contest class name translate.
	 * 
	 * @return the contestClassNameTranslate
	 */
	@Transient
	public String getContestClassNameTranslate() {
		return this.contestClassNameTranslate;
	}

	/**
	 * Sets the contest class name translate.
	 * 
	 * @param contestClassNameTranslate
	 *            the contestClassNameTranslate to set
	 */
	public void setContestClassNameTranslate(String contestClassNameTranslate) {
		this.contestClassNameTranslate = contestClassNameTranslate;
	}

	/**
	 * Getter of <code>code</code> property.
	 * 
	 * @return <code>code</code> property value.
	 * @see #code
	 */
	@Override
	@Id
	@Column(name = "contest_class_code")
	@GeneratedValue(strategy = GenerationType.AUTO, generator = "s_contest_class")
	@SequenceGenerator(name = "s_contest_class", sequenceName = "s_contest_class", allocationSize = 1, initialValue = 1)
	public long getCode() {
		return this.code;
	}

	/**
	 * Getter of <code>name</code> property.
	 * 
	 * @return <code>name</code> property value.
	 * @see #name
	 */
	@MultilingualPropertyAnnotation
	@Column(name = "contest_class_name", length = 100)
	public String getContestClassName() {
		return this.contestClassName;
	}

	/**
	 * Sets the contest class name.
	 * 
	 * @param contestName
	 *            the contestName to set
	 */
	public void setContestClassName(String contestName) {
		this.contestClassName = contestName;
	}

	/**
	 * Getter of <code>customCode</code> property.
	 * 
	 * @return <code>customCode</code> property value.
	 * @see #customCode
	 */
	@Override
	@CustomCodeAnnotation
	@Column(name = "contest_class_custom_code", nullable = false, unique = true, length = 80)
	public String getCustomCode() {
		return this.customCode;
	}

	/**
	 * Getter of <code>description</code> property.
	 * 
	 * @return <code>description</code> property value.
	 * @see #description
	 */
	@MultilingualPropertyAnnotation
	@Column(name = "contest_class_description", length = 255)
	public String getDescription() {
		return this.description;
	}

	/**
	 * Setter of <code>description</code> property.
	 * 
	 * @param description
	 *            The <code>description</code> to set.
	 * @see #description
	 */
	public void setDescription(String description) {
		this.description = description;
	}

	/**
	 * Getter of <code>type</code> property.
	 * 
	 * @return <code>type</code> property value.
	 * @see #type
	 */
	@Column(name = "class_type")
	public Type getType() {
		return this.type;
	}

	/**
	 * Setter of <code>type</code> property.
	 * 
	 * @param type
	 *            The <code>type</code> to set.
	 * @see #type
	 */
	public void setType(Type type) {
		this.type = type;
	}

	/**
	 * Getter of <code>requiresCandidateImg</code> property.
	 * 
	 * @return <code>requiresCandidateImg</code> property value.
	 * @see #requiresCandidateImg
	 */
	@Column(name = "requires_candidate_image")
	public boolean isRequiresCandidateImg() {
		return this.requiresCandidateImg;
	}

	/**
	 * Setter of <code>requiresCandidateImg</code> property.
	 * 
	 * @param requiresCandidateImg
	 *            The <code>requiresCandidateImg</code> to set.
	 * @see #requiresCandidateImg
	 */
	public void setRequiresCandidateImg(boolean requiresCandidateImg) {
		this.requiresCandidateImg = requiresCandidateImg;
	}

	/**
	 * Getter of <code>documentTitle</code> property.
	 * 
	 * @return <code>documentTitle</code> property value.
	 * @see #documentTitle
	 */
	@MultilingualPropertyAnnotation
	@Column(name = "documents_title", length = 255)
	public String getDocumentTitle() {
		return this.documentTitle;
	}

	/**
	 * Setter of <code>documentTitle</code> property.
	 * 
	 * @param documentTitle
	 *            The <code>documentTitle</code> to set.
	 * @see #documentTitle
	 */
	public void setDocumentTitle(String documentTitle) {
		this.documentTitle = documentTitle;
	}

	/**
	 * Getter of <code>standCountChief</code> property.
	 * 
	 * @return <code>standCountChief</code> property value.
	 * @see #standCountChief
	 */
	@Column(name = "standin_count_per_chief")
	public int getStandCountChief() {
		return this.standCountChief;
	}

	/**
	 * Setter of <code>standCountChief</code> property.
	 * 
	 * @param standCountChief
	 *            The <code>standCountChief</code> to set.
	 * @see #standCountChief
	 */
	public void setStandCountChief(int standCountChief) {
		this.standCountChief = standCountChief;
	}

	/**
	 * Getter of <code>period</code> property.
	 * 
	 * @return <code>period</code> property value.
	 * @see #period
	 */
	@Column(name = "contest_class_period")
	public int getPeriod() {
		return this.period;
	}

	/**
	 * Setter of <code>period</code> property.
	 * 
	 * @param period
	 *            The <code>period</code> to set.
	 * @see #period
	 */
	public void setPeriod(int period) {
		this.period = period;
	}

	/**
	 * Getter of <code>unit</code> property.
	 * 
	 * @return <code>unit</code> property value.
	 * @see #unit
	 */
	@Column(name = "contest_class_unit")
	public UnitType getUnit() {
		return this.unit;
	}

	/**
	 * Setter of <code>unit</code> property.
	 * 
	 * @param unit
	 *            The <code>unit</code> to set.
	 * @see #unit
	 */
	public void setUnit(UnitType unit) {
		this.unit = unit;
	}

	/**
	 * Getter of <code>electionMode</code> property.
	 * 
	 * @return <code>electionMode</code> property value.
	 * @see #electionMode
	 */
	@Column(name = "election_mode")
	public ElectionModeType getElectionMode() {
		return this.electionMode;
	}

	/**
	 * Setter of <code>electionMode</code> property.
	 * 
	 * @param electionMode
	 *            The <code>electionMode</code> to set.
	 * @see #electionMode
	 */
	public void setElectionMode(ElectionModeType electionMode) {
		this.electionMode = electionMode;
	}

	/**
	 * Getter of {@link #precedence} field.
	 * 
	 * @return {@link #precedence} value.
	 */
	@Column(name = "precedence")
	public long getPrecedence() {
		return this.precedence;
	}

	/**
	 * Setter of {@link #precedence} field.
	 * 
	 * @param precedence
	 *            The int to set.
	 */
	public void setPrecedence(long precedence) {
		this.precedence = precedence;
	}

	/**
	 * Gets the contests.
	 * 
	 * @return the contests
	 */
	@OneToMany(mappedBy = "contestClass", targetEntity = ContestData.class)
	public Set<ContestData> getContests() {
		return this.contests;
	}

	/**
	 * Sets the contests.
	 * 
	 * @param contests
	 *            the new contests
	 */
	public void setContests(Set<ContestData> contests) {
		this.contests = contests;
	}

	/**
	 * Hash code.
	 * 
	 * @return the int
	 * @inheritDoc
	 */
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = super.hashCode();
		result = prime * result
				+ ((this.customCode == null) ? 0 : this.customCode.hashCode());
		return result;
	}

	/**
	 * Equals.
	 * 
	 * @param obj
	 *            the obj
	 * @return true, if successful
	 * @inheritDoc
	 */
	@Override
	public boolean equals(Object obj) {
		if (this == obj) {
			return true;
		}
		if (!super.equals(obj)) {
			return false;
		}
		if (getClass() != obj.getClass()) {
			return false;
		}
		ContestClassData other = (ContestClassData) obj;
		if (this.customCode == null) {
			if (other.customCode != null) {
				return false;
			}
		} else if (!this.customCode.equals(other.customCode)) {
			return false;
		}
		return true;
	}

}
