/**
 * ContestData.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.domain.contest;

import java.util.HashSet;
import java.util.List;
import java.util.Set;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.JoinTable;
import javax.persistence.ManyToMany;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.persistence.UniqueConstraint;
import javax.persistence.Version;

import com.smartmatic.waffle.domain.ballot.BallotCardData;
import com.smartmatic.waffle.domain.ballot.BallotOptionData;
import com.smartmatic.waffle.domain.bulk.CustomCodeAnnotation;
import com.smartmatic.waffle.domain.demographics.DistrictData;
import com.smartmatic.waffle.domain.eligibleoption.EligibleOptionData;
import com.smartmatic.waffle.domain.general.GeneralInfo;
import com.smartmatic.waffle.domain.xstream.converters.HibernateCollectionConverter;
import com.smartmatic.waffle.lang.annotations.basic.ValidatorListener;
import com.smartmatic.waffle.persistence.metadata.MultilingualPropertyAnnotation;
import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;
import com.thoughtworks.xstream.annotations.XStreamConverter;
import com.thoughtworks.xstream.annotations.XStreamOmitField;

/**
 * This JavaBean represents a contest to be voted for in an election.
 * 
 * There are different types of contests and different Election Systems related
 * to each of them.
 */
@XStreamAlias("contest")
@Entity
@Table(name = "contest", uniqueConstraints = { @UniqueConstraint(columnNames = "contest_code") })
@ValidatorListener(name = "com.smartmatic.waffle.validator.contest.ContestDataValidator")
public class ContestData extends GeneralInfo {

	/** The Constant serialVersionUID. */
	@XStreamOmitField
	private static final long serialVersionUID = -6327635268812471602L;

	/**
	 * The Enum Type.
	 */
	public enum Type {

		/** The college. */
		COLLEGE,

		/** The language group. */
		LANGUAGE_GROUP
	}

	/**
	 * The Enum CollegeType.
	 */
	public enum CollegeType {

		/** The french college. */
		FRENCH_COLLEGE,

		/** The dutch college. */
		DUTCH_COLLEGE,

		/** The german college. */
		GERMAN_COLLEGE
	}

	/** The question. */
	@XStreamAlias("is-question")
	@XStreamAsAttribute
	boolean question;

	/** The district. */
	@XStreamAlias("district")
	DistrictData district;

	/** The eligible options. */
	@XStreamAlias("eligibles-options")
	@XStreamConverter(HibernateCollectionConverter.class)
	List<EligibleOptionData> eligibleOptions;

	/** The eligible amount. */
	@XStreamAlias("eligible-amount")
	@XStreamAsAttribute
	private int eligibleAmount;

	/** The ballot options. */
	@XStreamOmitField
	private Set<BallotOptionData> ballotOptions;

	/** The is initialized. */
	@XStreamOmitField
	private boolean isInitialized = false;

	/** The ballot card parent. */
	@XStreamOmitField
	private BallotCardData ballotCardParent;

	/** The contest class. */
	@XStreamOmitField
	private ContestClassData contestClass;

	/** The contest class code. */
	@XStreamAlias("contest-class-code")
	@XStreamAsAttribute
	private long contestClassCode;

	/** The type. */
	@XStreamOmitField
	@Enumerated(EnumType.ORDINAL)
	private Type type;

	/** The college type. */
	@XStreamOmitField
	@Enumerated(EnumType.ORDINAL)
	private CollegeType collegeType;

	/** The contest link. */
	@XStreamOmitField
	private ContestData contestLink;

	/** The codi file. */
	@XStreamOmitField
	private String codiFile;

	/** The contest name translate. */
	@XStreamOmitField
	private String contestNameTranslate;

	/** ContestGroupDatas for this contest. */
	@XStreamOmitField
	private Set<ContestGroupData> contestGroupList = new HashSet<ContestGroupData>();

	/** The min votes. */
	@XStreamAlias("min-votes")
	@XStreamAsAttribute
	private long minVotes;

	/** The max votes. */
	@XStreamAlias("max-votes")
	@XStreamAsAttribute
	private long maxVotes;

	/** The college. */
	@XStreamOmitField
	private String college;

	/** The college translate. */
	@XStreamOmitField
	private String collegeTranslate;

	/** The ballot layout. */
	@XStreamAlias("display-info")
	private BallotLayoutData ballotLayout;

	/** The college language rfc. */
	@XStreamOmitField
	private String collegeLanguageRFC;

	/** Use Last level Region as Totalization NIS Code. */
	@XStreamOmitField
	private boolean useLastLevelRegionAsTotNisCode;

	/** Use to configure ballot preview. */
	@XStreamOmitField
	private boolean partyPreview;

	/**
	 * Gets the ballot layout.
	 * 
	 * @return the ballot layout
	 */
	@OneToOne(optional = true, targetEntity = BallotLayoutData.class)
	@JoinColumn(name = "ballot_layout_code", updatable = true)
	public BallotLayoutData getBallotLayout() {
		return this.ballotLayout;
	}

	/**
	 * Sets the ballot layout.
	 * 
	 * @param ballotLayout
	 *            the new ballot layout
	 */
	public void setBallotLayout(BallotLayoutData ballotLayout) {
		this.ballotLayout = ballotLayout;
	}

	/**
	 * Gets the college language rfc.
	 * 
	 * @return the collegeLanguageRFC
	 */
	@Column(name = "college_languagerfc")
	public String getCollegeLanguageRFC() {
		return this.collegeLanguageRFC;
	}

	/**
	 * Sets the college language rfc.
	 * 
	 * @param collegeLanguageRFC
	 *            the collegeLanguageRFC to set
	 */
	public void setCollegeLanguageRFC(String collegeLanguageRFC) {
		this.collegeLanguageRFC = collegeLanguageRFC;
	}

	/**
	 * Gets value of Use last level region as Totalization NIS Code.
	 * 
	 * @return useLastLevelRegionAsTotNisCode
	 */
	@Column(name = "use_last_level_region_as_tot_nis_code", nullable = false)
	public boolean isUseLastLevelRegionAsTotNisCode() {
		return this.useLastLevelRegionAsTotNisCode;
	}

	/**
	 * Sets the value of Use last level region as Totalization NIS Code.
	 * 
	 * @param useLastLevelRegionAsTotNisCode
	 */
	public void setUseLastLevelRegionAsTotNisCode(
			boolean useLastLevelRegionAsTotNisCode) {
		this.useLastLevelRegionAsTotNisCode = useLastLevelRegionAsTotNisCode;
	}

	/**
	 * Gets the codi file.
	 * 
	 * @return the codi file
	 */
	@Column(name = "codi_file", nullable = true)
	public String getCodiFile() {
		return this.codiFile;
	}

	/**
	 * Sets the codi file.
	 * 
	 * @param codiFile
	 *            the new codi file
	 */
	public void setCodiFile(String codiFile) {
		this.codiFile = codiFile;
	}

	/**
	 * Gets the contest link.
	 * 
	 * @return the contest link
	 */
	@ManyToOne(optional = true, targetEntity = ContestData.class)
	@JoinColumn(name = "contest_link", nullable = true)
	public ContestData getContestLink() {
		return this.contestLink;
	}

	/**
	 * Sets the contest link.
	 * 
	 * @param contestLink
	 *            the new contest link
	 */
	public void setContestLink(ContestData contestLink) {
		this.contestLink = contestLink;
	}

	/**
	 * Gets the type.
	 * 
	 * @return the type
	 */
	@Column(name = "type", nullable = true)
	public Type getType() {
		return this.type;
	}

	/**
	 * Sets the type.
	 * 
	 * @param type
	 *            the new type
	 */
	public void setType(Type type) {
		this.type = type;
	}

	/**
	 * Gets the college type.
	 * 
	 * @return the college type
	 */
	@Column(name = "college_type", nullable = true)
	public CollegeType getCollegeType() {
		return this.collegeType;
	}

	/**
	 * Sets the college type.
	 * 
	 * @param collegeType
	 *            the new college type
	 */
	public void setCollegeType(CollegeType collegeType) {
		this.collegeType = collegeType;
	}

	/**
	 * Gets the college.
	 * 
	 * @return the college
	 */
	@MultilingualPropertyAnnotation
	@Column(name = "college", nullable = true)
	public String getCollege() {
		return this.college;
	}

	/**
	 * Sets the college.
	 * 
	 * @param college
	 *            the new college
	 */
	public void setCollege(String college) {
		this.college = college;
	}

	/**
	 * Getter of <code>customCode</code> property.
	 * 
	 * @return <code>customCode</code> property value.
	 * @see #customCode
	 */
	@Override
	@CustomCodeAnnotation
	@Column(name = "contest_custom_code", nullable = false, unique = true, length = 255)
	public String getCustomCode() {
		return this.customCode;
	}

	/**
	 * Getter of <code>minVotes</code> property.
	 * 
	 * @return <code>minVotes</code> property value.
	 * @see #minVotes
	 */
	@Column(name = "max_votes")
	public long getMaxVotes() {
		return this.maxVotes;
	}

	/**
	 * Setter of <code>minVotes</code> property.
	 * 
	 * @param maxVotes
	 *            the new max votes
	 * @see #minVotes
	 */
	public void setMaxVotes(long maxVotes) {
		this.maxVotes = maxVotes;
	}

	/**
	 * Getter of <code>minVotes</code> property.
	 * 
	 * @return <code>minVotes</code> property value.
	 * @see #minVotes
	 */
	@Column(name = "min_votes")
	public long getMinVotes() {
		return this.minVotes;
	}

	/**
	 * Setter of <code>minVotes</code> property.
	 * 
	 * @param minVotes
	 *            The <code>minVotes</code> to set.
	 * @see #minVotes
	 */

	public void setMinVotes(long minVotes) {
		this.minVotes = minVotes;
	}

	/**
	 * Getter of <code>contestClassCode</code> property.
	 * 
	 * @return <code>contestClassCode</code> property value.
	 * @see #contestClassCode
	 */
	@Transient
	public long getContestClassCode() {
		return this.contestClassCode;
	}

	/**
	 * Setter of <code>contestClassCode</code> property.
	 * 
	 * @param contestClassCode
	 *            The <code>contestClassCode</code> to set.
	 * @see #contestClassCode
	 */
	public void setContestClassCode(long contestClassCode) {
		this.contestClassCode = contestClassCode;
	}

	/**
	 * Gets the eligible amount.
	 * 
	 * @return the eligible amount
	 */
	@Column(name = "eligible_amount")
	public int getEligibleAmount() {
		return this.eligibleAmount;
	}

	/**
	 * Sets the eligible amount.
	 * 
	 * @param value
	 *            the new eligible amount
	 */
	public void setEligibleAmount(int value) {
		this.eligibleAmount = value;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getVersion()
	 */
	@Override
	@Transient
	@Version
	public int getVersion() {
		return this.version;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.domain.BaseDataObject#setVersion(int)
	 */
	@Override
	public void setVersion(int version) {
		this.version = version;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getCode()
	 */
	@Override
	@Id
	@Column(name = "contest_code")
	@GeneratedValue(strategy = GenerationType.AUTO, generator = "s_contest")
	@SequenceGenerator(name = "s_contest", sequenceName = "s_contest", allocationSize = 1, initialValue = 1)
	public long getCode() {
		return this.code;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.GeneralInfo#getName()
	 */
	@Override
	@MultilingualPropertyAnnotation
	@Column(name = "contest_name", nullable = false)
	public String getName() {
		return this.name;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#setCode(long)
	 */
	@Override
	public void setCode(long code) {
		this.code = code;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.GeneralInfo#setName(java.lang.
	 * String)
	 */
	@Override
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * Getter of <code>question</code> property.
	 * 
	 * @return <code>question</code> property value.
	 * @see #question
	 */
	@Transient
	public boolean isQuestion() {
		if (this.contestClass.getType().equals(ContestClassData.Type.ISSUE)) {
			this.question = true;
			return this.question;
		}
		this.question = false;
		return this.question;
	}

	/**
	 * Setter of <code>question</code> property.
	 * 
	 * @param question
	 *            The <code>question</code> to set.
	 * @see #question
	 */
	public void setQuestion(boolean question) {
		this.question = question;
	}

	/**
	 * Getter of <code>district</code> property.
	 * 
	 * @return <code>district</code> property value.
	 * @see #district
	 */
	@ManyToOne(optional = false, targetEntity = DistrictData.class)
	@JoinColumn(name = "district_code", referencedColumnName = "district_code")
	public DistrictData getDistrict() {
		return this.district;
	}

	/**
	 * Setter of <code>district</code> property.
	 * 
	 * @param district
	 *            The <code>district</code> to set.
	 * @see #district
	 */
	public void setDistrict(DistrictData district) {
		this.district = district;
	}

	/**
	 * Getter of <code>eligibleOptions</code> property.
	 * 
	 * @return <code>eligibleOptions</code> property value.
	 * @see #eligibleOptions
	 */
	@OneToMany(targetEntity = EligibleOptionData.class, mappedBy = "contest")
	public List<EligibleOptionData> getEligibleOptions() {
		return this.eligibleOptions;
	}

	/**
	 * Getter of <code>contestGroupList</code> property.
	 * 
	 * @return <code>contestGroupList</code> property value.
	 * @see #contestGroupList
	 */
	@ManyToMany()
	@JoinTable(name = "contest_group_contest", inverseJoinColumns = @JoinColumn(name = "contest_group_code", referencedColumnName = "contest_group_code"), joinColumns = @JoinColumn(name = "contest_code", referencedColumnName = "contest_code"))
	public Set<ContestGroupData> getContestGroupList() {
		return this.contestGroupList;
	}

	/**
	 * Setter of <code>contestGroupList</code> property.
	 * 
	 * @param contestGroupList
	 *            The <code>contestGroupList</code> to set.
	 * @see #contestGroupList
	 */
	public void setContestGroupList(Set<ContestGroupData> contestGroupList) {
		this.contestGroupList = contestGroupList;
	}

	/**
	 * Setter of <code>eligibleOptions</code> property.
	 * 
	 * @param eligibleOptions
	 *            The <code>eligibleOptions</code> to set.
	 * @see #eligibleOptions
	 */
	public void setEligibleOptions(List<EligibleOptionData> eligibleOptions) {
		this.eligibleOptions = eligibleOptions;
	}

	/**
	 * Getter of <code>isInitialized</code> property.
	 * 
	 * @return <code>isInitialized</code> property value.
	 * @see #isInitialized
	 */
	@Transient
	public boolean isInitialized() {
		return this.isInitialized;
	}

	/**
	 * Getter of <code>ballotCardParent</code> property.
	 * 
	 * @return <code>ballotCardParent</code> property value.
	 * @see #ballotCardParent
	 */
	@Transient
	public BallotCardData getBallotCardParent() {
		return this.ballotCardParent;
	}

	/**
	 * Getter of <code>contestClass</code> property.
	 * 
	 * @return <code>contestClass</code> property value.
	 * @see #contestClass
	 */
	@ManyToOne(optional = false, targetEntity = ContestClassData.class)
	@JoinColumn(name = "contest_class_code", nullable = false, updatable = true)
	public ContestClassData getContestClass() {
		return this.contestClass;
	}

	/**
	 * Setter for the isInitialized attribute.
	 * 
	 * @param isInitialized
	 *            the isInitialized to set
	 */
	public void setInitialized(boolean isInitialized) {
		this.isInitialized = isInitialized;
	}

	/**
	 * Setter for the ballotCardParent attribute.
	 * 
	 * @param ballotCardParent
	 *            the ballotCardParent to set
	 */
	public void setBallotCardParent(BallotCardData ballotCardParent) {
		this.ballotCardParent = ballotCardParent;
	}

	/**
	 * Setter for the contestClass attribute.
	 * 
	 * @param contestClass
	 *            the contestClass to set
	 */
	public void setContestClass(ContestClassData contestClass) {
		this.contestClass = contestClass;

		this.setContestClassCode(contestClass.getCode());
	}

	/**
	 * Gets the ballot options.
	 * 
	 * @return the ballot options
	 */
	@Transient
	public Set<BallotOptionData> getBallotOptions() {
		if (this.ballotOptions == null) {
			this.ballotOptions = new HashSet<BallotOptionData>();
		}
		if (this.getEligibleOptions() != null) {
			for (EligibleOptionData eligible : this.getEligibleOptions()) {
				if (eligible != null) {
					for (BallotOptionData ballotOption : eligible
							.getBallotOptions()) {
						if (ballotOption != null
								&& !this.ballotOptions.contains(ballotOption)) {
							this.ballotOptions.add(ballotOption);
						}
					}
				}
			}
		}
		return this.ballotOptions;
	}

	/**
	 * Gets the college translate.
	 * 
	 * @return the collegeTranslate
	 */
	@Transient
	public String getCollegeTranslate() {
		return this.collegeTranslate;
	}

	/**
	 * Sets the college translate.
	 * 
	 * @param collegeTranslate
	 *            the collegeTranslate to set
	 */
	public void setCollegeTranslate(String collegeTranslate) {
		this.collegeTranslate = collegeTranslate;
	}

	/**
	 * Gets the contest name translate.
	 * 
	 * @return the contestNameTranslate
	 */
	@Transient
	public String getContestNameTranslate() {
		return this.contestNameTranslate;
	}

	/**
	 * Sets the contest name translate.
	 * 
	 * @param contestNameTranslate
	 *            the contestNameTranslate to set
	 */
	public void setContestNameTranslate(String contestNameTranslate) {
		this.contestNameTranslate = contestNameTranslate;
	}

	/**
	 * Get the party preview value.
	 * 
	 * @return the partyPreview
	 */
	@Column(name = "party_preview", nullable = false)
	public boolean isPartyPreview() {
		return this.partyPreview;
	}

	/**
	 * Sets the party preview value.
	 * 
	 * @param partyPreview
	 *            the boolean value to set
	 */
	public void setPartyPreview(boolean partyPreview) {
		this.partyPreview = partyPreview;
	}

	/**
	 * Hash code.
	 * 
	 * @return the int
	 * @inheritDoc
	 */
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = super.hashCode();
		result = prime * result
				+ ((this.customCode == null) ? 0 : this.customCode.hashCode());
		return result;
	}

	/**
	 * Equals.
	 * 
	 * @param obj
	 *            the obj
	 * @return true, if successful
	 * @inheritDoc
	 */
	@Override
	public boolean equals(Object obj) {
		if (this == obj) {
			return true;
		}
		if (!super.equals(obj)) {
			return false;
		}
		if (getClass() != obj.getClass()) {
			return false;
		}
		ContestData other = (ContestData) obj;
		if (this.customCode == null) {
			if (other.customCode != null) {
				return false;
			}
		} else if (!this.customCode.equals(other.customCode)) {
			return false;
		}
		return true;
	}

}
