/**
 * ProgrammingUnitData.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.domain.demographics;

import java.util.Set;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.JoinTable;
import javax.persistence.ManyToMany;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;

import com.smartmatic.waffle.domain.bulk.CustomCodeAnnotation;
import com.smartmatic.waffle.domain.general.GeneralInfo;

/**
 * Define a group of different regions that shares common information, for
 * generate ballot configuration files for a voting machine given a specific
 * region.
 */
@Entity
@Table(name = "programming_unit", uniqueConstraints = { @UniqueConstraint(columnNames = "programming_unit_custom_code") })
public class ProgrammingUnitData extends GeneralInfo {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = -6724510085570945369L;

	/** The programming unit name. */
	private String programmingUnitName;

	/** The programming unit description. */
	private String programmingUnitDescription;

	/** The protection key. */
	private String protectionKey;

	/** The regions. */
	private Set<RegionData> regions;

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getCode()
	 */
	@Override
	@Id
	@Column(name = "programming_unit_code")
	@GeneratedValue(strategy = GenerationType.AUTO, generator = "s_programming_unit")
	@SequenceGenerator(name = "s_programming_unit", sequenceName = "s_programming_unit", allocationSize = 1, initialValue = 1)
	public long getCode() {
		return this.code;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#setCode(long)
	 */
	@Override
	public void setCode(long code) {
		this.code = code;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getCustomCode()
	 */
	@Override
	@CustomCodeAnnotation
	@Column(name = "programming_unit_custom_code", nullable = false)
	public String getCustomCode() {
		return this.customCode;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#setCustomCode(
	 * java.lang.String)
	 */
	@Override
	public void setCustomCode(String customCode) {
		this.customCode = customCode;
	}

	/**
	 * Gets the programming unit name.
	 * 
	 * @return the programmingUnitName
	 */
	@Column(name = "programming_unit_name", nullable = false)
	public String getProgrammingUnitName() {
		return this.programmingUnitName;
	}

	/**
	 * Sets the programming unit name.
	 * 
	 * @param programmingUnitName
	 *            the programmingUnitName to set
	 */
	public void setProgrammingUnitName(String programmingUnitName) {
		this.programmingUnitName = programmingUnitName;
	}

	/**
	 * Gets the programming unit description.
	 * 
	 * @return the programmingUnitDescription
	 */
	@Column(name = "programming_unit_description")
	public String getProgrammingUnitDescription() {
		return this.programmingUnitDescription;
	}

	/**
	 * Sets the programming unit description.
	 * 
	 * @param programmingUnitDescription
	 *            the programmingUnitDescription to set
	 */
	public void setProgrammingUnitDescription(String programmingUnitDescription) {
		this.programmingUnitDescription = programmingUnitDescription;
	}

	/**
	 * Gets the protection key.
	 * 
	 * @return the protectionKey
	 */
	@Column(name = "protection_key")
	public String getProtectionKey() {
		return this.protectionKey;
	}

	/**
	 * Sets the protection key.
	 * 
	 * @param protectionKey
	 *            the protectionKey to set
	 */
	public void setProtectionKey(String protectionKey) {
		this.protectionKey = protectionKey;
	}

	/**
	 * Gets the regions.
	 * 
	 * @return the regions
	 */
	@ManyToMany(targetEntity = RegionData.class)
	@JoinTable(name = "region_programming_unit", joinColumns = @JoinColumn(name = "programming_unit_code", referencedColumnName = "programming_unit_code"), inverseJoinColumns = @JoinColumn(name = "region_code", referencedColumnName = "region_code"))
	public Set<RegionData> getRegions() {
		return this.regions;
	}

	/**
	 * Sets the regions.
	 * 
	 * @param regions
	 *            the regions to set
	 */
	public void setRegions(Set<RegionData> regions) {
		this.regions = regions;
	}

	/**
	 * Hash code.
	 * 
	 * @return the int
	 * @inheritDoc
	 */
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = super.hashCode();
		result = prime * result
				+ ((this.customCode == null) ? 0 : this.customCode.hashCode());
		return result;
	}

	/**
	 * Equals.
	 * 
	 * @param obj
	 *            the obj
	 * @return true, if successful
	 * @inheritDoc
	 */
	@Override
	public boolean equals(Object obj) {
		if (this == obj) {
			return true;
		}
		if (!super.equals(obj)) {
			return false;
		}
		if (getClass() != obj.getClass()) {
			return false;
		}
		ProgrammingUnitData other = (ProgrammingUnitData) obj;
		if (this.customCode == null) {
			if (other.customCode != null) {
				return false;
			}
		} else if (!this.customCode.equals(other.customCode)) {
			return false;
		}
		return true;
	}

}
