/**
 * ParameterData.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.domain.general;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;

import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;

import com.thoughtworks.xstream.annotations.XStreamAlias;

/**
 * This class represents a group of parameters used for the application.
 */
@XStreamAlias("parameter")
@Entity
@Table(name = "parameter")
public class ParameterData extends GeneralInfo {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 3175593880086896280L;

	/** The parameter key. */
	private String parameterKey;

	/** The parameter value. */
	private String parameterValue;

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getCode()
	 */
	@Override
	@Id
	@Column(name = "parameter_code")
	@GeneratedValue(strategy = GenerationType.AUTO, generator = "s_parameter")
	@SequenceGenerator(name = "s_parameter", sequenceName = "s_parameter", allocationSize = 1)
	public long getCode() {
		return this.code;
	}

	/**
	 * Sets the code.
	 * 
	 * @param code
	 *            the new code
	 */
	public void setCode(Long code) {
		this.code = code;
	}

	/**
	 * Gets the parameter key.
	 * 
	 * @return the parameter key
	 */
	@Column(name = "parameter_key", nullable = false)
	public String getParameterKey() {
		return this.parameterKey;
	}

	/**
	 * Sets the parameter key.
	 * 
	 * @param key
	 *            the new parameter key
	 */
	public void setParameterKey(String key) {
		this.parameterKey = key;
	}

	/**
	 * Gets the parameter value.
	 * 
	 * @return the parameter value
	 */
	@Column(name = "parameter_value", nullable = false)
	public String getParameterValue() {
		return this.parameterValue;
	}

	/**
	 * Sets the parameter value.
	 * 
	 * @param value
	 *            the new parameter value
	 */
	public void setParameterValue(String value) {
		this.parameterValue = value;
	}

	/**
	 * Equals.
	 * 
	 * @param o
	 *            the o
	 * @return true, if successful
	 * @inheritDoc
	 */
	@Override
	public boolean equals(Object o) {
		if (o instanceof ParameterData) {
			ParameterData a = (ParameterData) o;
			return new EqualsBuilder().append(this.code, a.code)
					.append(this.parameterKey, a.parameterKey)
					.append(this.parameterValue, a.parameterValue).isEquals();
		}
		return false;
	}

	/**
	 * Hash code.
	 * 
	 * @return the int
	 * @inheritDoc
	 */
	@Override
	public int hashCode() {
		return new HashCodeBuilder().append(this.code)
				.append(this.parameterKey).append(this.parameterValue)
				.toHashCode();
	}

}
