/**
 * UserData.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.domain.user;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.persistence.UniqueConstraint;
import javax.persistence.Version;

import com.smartmatic.waffle.domain.authority.ElectoralAuthorityData;
import com.smartmatic.waffle.domain.bulk.CustomCodeAnnotation;
import com.smartmatic.waffle.domain.general.GeneralInfo;
import com.smartmatic.waffle.domain.security.ProfileData;

/**
 * Class that represents an user. It contains status and security information
 */
@Entity
@Table(name = "security_user", uniqueConstraints = {
		@UniqueConstraint(columnNames = "user_custom_code"),
		@UniqueConstraint(columnNames = "user_login") })
public class UserData extends GeneralInfo implements IUser {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 1L;

	/** The login. */
	private String login;

	/** The password. */
	private String password;

	/** The secret key. */
	private String secretKey;

	/** The profile. */
	private ProfileData profile;

	/** The electoral authority. */
	private ElectoralAuthorityData electoralAuthority;

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getCode()
	 */
	@Override
	@Id
	@Column(name = "user_code")
	@GeneratedValue(strategy = GenerationType.AUTO, generator = "s_user")
	@SequenceGenerator(name = "s_user", sequenceName = "s_user", allocationSize = 1, initialValue = 1)
	public long getCode() {
		return this.code;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#setCode(long)
	 */
	@Override
	public void setCode(long code) {
		this.code = code;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getCustomCode()
	 */
	@Override
	@CustomCodeAnnotation
	@Column(name = "user_custom_code", nullable = false)
	public String getCustomCode() {
		return this.customCode;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#setCustomCode(
	 * java.lang.String)
	 */
	@Override
	public void setCustomCode(String customCode) {
		this.customCode = customCode;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.domain.user.IUser#getLogin()
	 */
	@Override
	@Column(name = "user_login", nullable = true)
	public String getLogin() {
		return this.login;
	}

	/**
	 * Sets the login.
	 * 
	 * @param login
	 *            the new login
	 */
	public void setLogin(String login) {
		this.login = login;
	}

	/**
	 * Gets the password.
	 * 
	 * @return the password
	 */
	@Column(name = "password", nullable = true)
	public String getPassword() {
		return this.password;
	}

	/**
	 * Sets the password.
	 * 
	 * @param password
	 *            the new password
	 */
	public void setPassword(String password) {
		this.password = password;
	}

	/**
	 * Gets the secret key.
	 * 
	 * @return the secret key
	 */
	@Column(name = "secret_key", nullable = true)
	public String getSecretKey() {
		return this.secretKey;
	}

	/**
	 * Sets the secret key.
	 * 
	 * @param secretKey
	 *            the new secret key
	 */
	public void setSecretKey(String secretKey) {
		this.secretKey = secretKey;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getVersion()
	 */
	@Override
	@Version
	@Transient
	public int getVersion() {
		return this.version;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.domain.user.IUser#isAdmin()
	 */
	@Override
	@Transient
	public boolean isAdmin() {
		return false;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.domain.BaseDataObject#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object anObject) {
		if (anObject instanceof UserData) {
			UserData otherUser = (UserData) anObject;
			return otherUser.code == this.code;
		}
		return false;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.domain.BaseDataObject#hashCode()
	 */
	@Override
	public int hashCode() {
		return (int) this.code;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.GeneralInfo#getName()
	 */
	@Column(name = "user_name", nullable = true)
	@Override
	public String getName() {
		return super.getName();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.GeneralInfo#setName(java.lang.
	 * String)
	 */
	@Override
	public void setName(String name) {
		super.setName(name);
	}

	/**
	 * Gets the profile.
	 * 
	 * @return the profile
	 */
	@ManyToOne()
	@JoinColumn(name = "profile_code", nullable = true, updatable = true)
	public ProfileData getProfile() {
		return this.profile;
	}

	/**
	 * Sets the profile.
	 * 
	 * @param profile
	 *            the new profile
	 */
	public void setProfile(ProfileData profile) {
		this.profile = profile;

		return;
	}

	/**
	 * Gets the electoral authority.
	 * 
	 * @return the electoral authority
	 */
	@ManyToOne(optional = true, targetEntity = ElectoralAuthorityData.class)
	@JoinColumn(name = "electoral_authority_code", nullable = true, updatable = true)
	public ElectoralAuthorityData getElectoralAuthority() {
		return this.electoralAuthority;
	}

	/**
	 * Sets the electoral authority.
	 * 
	 * @param electoralAuthority
	 *            the new electoral authority
	 */
	public void setElectoralAuthority(ElectoralAuthorityData electoralAuthority) {
		this.electoralAuthority = electoralAuthority;
	}

}
