/**
 * IBulkService.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.bulk.service.spec;

import javax.ejb.Remote;

import com.smartmatic.waffle.domain.user.IUser;
import com.smartmatic.waffle.ecm.bulk.service.lang.BulkLoadException;
import com.smartmatic.waffle.ecm.data.transfer.objects.BulkResultDTO;
import com.smartmatic.waffle.ecm.data.transfer.type.BulkStoreMode;

/**
 * Interface that defines the basic functionality required implemented by the
 * BulkServiceImpl bean.
 * 
 * @author Ithamar Torres (itorres@smartmatic.com)
 */
@Remote
public interface IBulkService {

	/**
	 * Holds the name of the bean that implements this interface.
	 * 
	 * @author Ithamar Torres (itorres@smartmatic.com)
	 */
	public static final String SERVICE_NAME = "com.smartmatic.waffle.ecm.bulk.service.spec.IBulkService";

	/**
	 * Method that allows to store a collection of objects.
	 * 
	 * @param xmlData
	 *            the xml that contains all the information to store
	 * @param user
	 *            the user who is performing the operation. who requires execute
	 *            the operation
	 * 
	 * @param bulkStoreMode
	 *            the bulk store mode
	 * 
	 * @return DTO object with the result of store the data in the database
	 * 
	 * @throws BulkLoadException
	 *             if the xml is not well-formed
	 */
	public BulkResultDTO bulkLoad(byte[] xmlData, IUser user,
			BulkStoreMode bulkStoreMode) throws BulkLoadException;

	/**
	 * Method that allows to store a collection of objects.
	 * 
	 * @param xmlData
	 *            the xml that contains all the information to store
	 * @param zip
	 *            the zip File with the binary files
	 * @param user
	 *            the user who is performing the operation
	 * @param bulkStoreMode
	 *            the bulk store mode
	 * 
	 * @return DTO object with the result of store the data in the database
	 * 
	 * @throws BulkLoadException
	 *             if the xml is not well-formed or some other problem has
	 *             occurred executing bulk upload
	 */
	public BulkResultDTO bulkLoad(byte[] xmlData, byte[] zip, IUser user,
			BulkStoreMode bulkStoreMode) throws BulkLoadException;

}