/**
 * BulkErrorHandler.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.bulk.service.util;

import org.xml.sax.ErrorHandler;
import org.xml.sax.SAXException;
import org.xml.sax.SAXParseException;

import com.smartmatic.waffle.messages.ApplicationMessages;

/**
 * Class responsible for obtaining and formatting the errors encountered during
 * the validation of the xml's used in the bulk data loading module.
 * 
 * @author Ithamar Torres (itorres@smartmatic.com)
 */
public class BulkErrorHandler implements ErrorHandler {

	/**
	 * Object used to store all the error messages generated in a validation
	 * process. All the errors reported during the validation are stored and
	 * reported to the caller of this class when the process is finished.
	 */

	private StringBuffer errorReport = new StringBuffer();

	/**
	 * Gets Object used to store all the error messages generated in a
	 * validation process.
	 * 
	 * @return Object used to store all the error messages generated in a
	 *         validation process
	 */
	public StringBuffer getErrorReport() {
		return this.errorReport;
	}

	/**
	 * @inheritDoc
	 */
	@Override
	public void error(SAXParseException exception) throws SAXException {
		this.errorReport.append(exception.getMessage());
	}

	/**
	 * @inheritDoc
	 */
	@Override
	public void fatalError(SAXParseException exception) throws SAXException {
		this.errorReport
				.append(ApplicationMessages
						.getTextFormatter()
						.getText(
								"com.smartmatic.waffle.ecm.bulk.service.impl.BulkErrorHandler.FATAL_ERROR",
								exception.getMessage(),
								Integer.toString(exception.getLineNumber())));
	}

	/**
	 * @inheritDoc
	 */
	@Override
	public void warning(SAXParseException exception) throws SAXException {
	}

}
