package com.smartmatic.waffle.ecm.bulk.service.impl;

import static org.junit.Assert.assertNotNull;

import java.io.File;
import java.io.IOException;
import java.util.HashSet;
import java.util.Set;
import java.util.zip.ZipFile;

import org.apache.commons.io.FileUtils;
import org.dom4j.DocumentException;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.powermock.modules.junit4.PowerMockRunner;

import com.smartmatic.waffle.domain.user.IUser;
import com.smartmatic.waffle.ecm.bulk.service.lang.BulkLoadException;
import com.smartmatic.waffle.ecm.data.transfer.objects.BulkResultDTO;
import com.smartmatic.waffle.ecm.data.transfer.type.BulkStoreMode;

/**
 * Class used to write unit tests for BulkServiceImpl.
 */
@RunWith(PowerMockRunner.class)
public class BulkServiceImplTest {

	@Test
	public void bulkLoadDataUserModeTest() throws Exception {
		File inputFile = new File("test/resources/Language.xml");
		byte[] inputFileByte = FileUtils.readFileToByteArray(inputFile);

		BulkServiceImpl bulkServiceLocal = new BulkServiceImpl() {
			@Override
			public BulkResultDTO bulkLoadExecute(byte[] xmlData,
					ZipFile zipFile, IUser user, BulkStoreMode bulkStoreMode)
					throws BulkLoadException {
				return new BulkResultDTO();
			}
		};

		BulkResultDTO bulkResult = bulkServiceLocal.bulkLoad(inputFileByte,
				null, BulkStoreMode.PERSIST);

		assertNotNull(bulkResult);
	}

	@Test(expected = BulkLoadException.class)
	public void bulkLoadDataZipNullUserModeTest() throws Exception {
		File inputFile = new File("test/resources/Language.xml");
		byte[] inputFileByte = FileUtils.readFileToByteArray(inputFile);

		BulkServiceImpl bulkServiceLocal = new BulkServiceImpl();

		BulkResultDTO bulkResult = bulkServiceLocal.bulkLoad(inputFileByte,
				null, null, BulkStoreMode.PERSIST);
	}

	@Test
	public void bulkLoadDataZipUserModeTest() throws Exception {
		File inputFile = new File("test/resources/Language.xml");
		byte[] inputFileByte = FileUtils.readFileToByteArray(inputFile);

		File zipFile = new File("test/resources/file.zip");
		byte[] inputZipFileByte = FileUtils.readFileToByteArray(zipFile);

		BulkServiceImpl bulkServiceLocal = new BulkServiceImpl() {
			@Override
			public void extractVoiceFile(byte[] xmlData, ZipFile zip)
					throws BulkLoadException, DocumentException, IOException {

			}

			@Override
			public BulkResultDTO bulkLoadExecute(byte[] xmlData,
					ZipFile zipFile, IUser user, BulkStoreMode bulkStoreMode)
					throws BulkLoadException {
				return new BulkResultDTO();
			}
		};

		BulkResultDTO bulkResult = bulkServiceLocal.bulkLoad(inputFileByte,
				inputZipFileByte, null, BulkStoreMode.PERSIST);

		assertNotNull(bulkResult.getIncorrectCount());
	}

	@Test
	public void extractValidateConfiguredFilesNullTest() throws Exception {
		Set<String> configuredFiles = null;

		File zipFile = new File("test/resources/file.zip");

		BulkServiceImpl bulkServiceLocal = new BulkServiceImpl();
		bulkServiceLocal.validateConfiguredFiles(configuredFiles, zipFile);

	}

	@Test(expected = BulkLoadException.class)
	public void extractValidateConfiguredFilesTest() throws Exception {
		Set<String> configuredFiles = new HashSet<String>();
		configuredFiles.add("1.txt");
		configuredFiles.add("test.txt");

		File zipFile = new File("test/resources/file2.zip");

		BulkServiceImpl bulkServiceLocal = new BulkServiceImpl();
		bulkServiceLocal.validateConfiguredFiles(configuredFiles, zipFile);

	}

	@Test(expected = BulkLoadException.class)
	public void extractValidateConfiguredFilesEmptyZipTest() throws Exception {
		Set<String> configuredFiles = new HashSet<String>();
		configuredFiles.add("1.txt");
		configuredFiles.add("test.txt");

		File zipFile = new File("test/resources/file3.zip");

		BulkServiceImpl bulkServiceLocal = new BulkServiceImpl();
		bulkServiceLocal.validateConfiguredFiles(configuredFiles, zipFile);

	}
}
