/*
 * ECMClientSideConstants.java
 * 
 * 1.0 (01/09/2010)
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 * 
 * This software is the confidential and propietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client;

/***
 * Class to handle constants values and configuration values of client side.
 * 
 * 
 */
public class ECMClientSideConstants {

	/**
	 * Parameter key to know if system date and time is already set up.
	 */
	public static final String PARAMETER_KEY_DATETIME_SET = "ECM_DATETIME_SET";

	/***
	 * Query to be executed in bulk load XML files to find the customCode
	 * properties
	 */
	public static final String BULK_XPATH_QUERY = ECMServiceProvider
			.getServerPropertyAsString("bulk.xpath.query");

	/***
	 * Property to indicate the size of pages in generation test data
	 */
	public static final int SIZE_PAGES_IN_GENERATION_TEST_DATA = Integer
			.valueOf(ECMServiceProvider
					.getServerPropertyAsString("size.pages.in.generation.test.data"));

	/***
	 * Location of the PNG images of the voting machine in the Screenshots USB
	 */
	public static final String PATH_IN_DRIVE_FOR_SCREEN_SHOT = ECMServiceProvider
			.getServerPropertyAsString("path.in.drive.for.screen.shot");

	/***
	 * Temporary path in the local hardrive where the PDFs generated by the
	 * system are stored
	 */
	public static final String TEMP_PATH_IN_FILE_SYSTEM_FOR_SCREEN_SHOT = ECMServiceProvider
			.getServerPropertyAsString("temp.path.in.file.system.for.screen.shot");

	/***
	 * Temporary path in the local hardrive where the PNG images of the voting
	 * machine are stored
	 */
	public static final String TEMP_PATH_IN_FILE_SYSTEM_FOR_SCREEN_SHOT_IMG = ECMServiceProvider
			.getServerPropertyAsString("temp.path.in.file.system.for.screen.shot.img");

	/***
	 * Name of the container of final PDFs of screenshots
	 */
	public static final String SCREEN_SHOT_FILE = ECMServiceProvider
			.getServerPropertyAsString("screen.shot.file");

	/***
	 * Folder where electoral authorities configuration files will be stored in
	 * the Master USB
	 */
	public static final String INSTALLATION_FOLDER_PATH = ECMServiceProvider
			.getServerPropertyAsString("installation.folder.relative.root.path.dest");

	/***
	 * The property is used to indicate whether after date of certificates must
	 * be validated. Expected values: true or false
	 */
	public static final boolean VALIDATE_CERTIFICATE_EXPIRED_DATE = ECMServiceProvider
			.getServerPropertyAsBoolean("validate.certificate.expired.date");

	/***
	 * The property is used to indicate whether the before date of certificates
	 * must be validated. Expected values: true or false
	 */
	public static final boolean VALIDATE_CERTIFICATE_DATE = ECMServiceProvider
			.getServerPropertyAsBoolean("validate.certificate.validity_date");

	/***
	 * Number of elements per groups used in the gathering of information during
	 * the Screenshots generation process
	 */
	public static final int PAGE_SIZE_SEARCH_CONTEST_FOR_SCREEN_GENERATOR = Integer
			.parseInt(ECMServiceProvider
					.getServerPropertyAsString("page.size.search.contest.for.screen.generator"));

	/***
	 * Property to indicate if the folders and files into the .tar.gz of
	 * Screenshots must be validated prior to the upload of the image. Expected
	 * values: true or false
	 */
	public static final boolean VALIDATE_FOLDERS_ISO_VOTING_MACHINE = ECMServiceProvider
			.getServerPropertyAsBoolean("validate.folders.iso.voting.machine");

	/***
	 * Property to indicate if the folders and files into the .tar.gz of
	 * Screenshot must be checked. Expected values: true or false
	 */
	public static final boolean VALIDATE_FOLDERS_ISO_SCREENSHOT = ECMServiceProvider
			.getServerPropertyAsBoolean("validate.folders.iso.screenshot");

	// ////////////////////////////////////////////////////////////////////////////
	/*
	 * section of properties for module of generation of master usb.
	 */
	// ////////////////////////////////////////////////////////////////////////////

	/**
	 * White list characters for president passphrase generation
	 */
	public static final String WHITELIST_CHARACTERS = ECMServiceProvider
			.getServerPropertyAsString("president.key.whitelist.characters");

	/***
	 * Property used to indicate the algorithm used to encrypt the files
	 * generated by ECM. Expected values: CBC, ECB
	 */
	public static final String ENCRYPTION_ALGORITHM = ECMServiceProvider
			.getServerPropertyAsString("encryption.algorithm");

	/***
	 * Property used to indicate to the system if the XML files must be
	 * generated encrypted. Expected values: true or false
	 */
	public static final boolean GENERATE_XML_ENCRYPTED = ECMServiceProvider
			.getServerPropertyAsBoolean("generate.xml.encrypted");

	/***
	 * Property used to indicate to the system if the XML files must be
	 * generated signed. Expected values: true or false
	 */
	public static final boolean GENERATE_XML_SIGNED = ECMServiceProvider
			.getServerPropertyAsBoolean("generate.xml.signed");
	/***
	 * Size of the vector used in CBC encryption mode
	 */
	public static final int LENGTH_KEY = Integer.parseInt(ECMServiceProvider
			.getServerPropertyAsString("length.of.vector.for.cbc.encryption"));

	/***
	 * Temporary folder used to store information during the process of
	 * exporting keys
	 */
	public static final String TMP_EXPORT_KEY_LOCATION = ECMServiceProvider
			.getServerPropertyAsString("tmp.export.key.location");

	/***
	 * Property used to indicate if the usb generation must be performed using
	 * the programming unit entity. Expected values: true or false
	 */
	public static final boolean GENERATE_FILES_USING_PROGRAMMING_UNIT = ECMServiceProvider
			.getServerPropertyAsBoolean("generate.files.using.program.unit");

	/***
	 * Path where the logos of the parties must be saved in the Master USB
	 */
	public static final String PATH_PARTIES_IMAGES_FOLDER = ECMServiceProvider
			.getServerPropertyAsString("path.parties.images.folder");

	/***
	 * Path where the voices must be saved in the Master USB
	 */
	public static final String PATH_VOICES_FOLDER = ECMServiceProvider
			.getServerPropertyAsString("path.voices.folder");

	/***
	 * Name of the certicate exported to the Master USB. This certificate will
	 * be used by the PM to encrypr Results CODI files
	 */
	public static final String CERT_TO_ENCRYPT_FILE_NAME = ECMServiceProvider
			.getServerPropertyAsString("cert.to.encrypt.file.name");

	/***
	 * Property used to indicate to the system if the installation_folder must
	 * be generated encrypted. Expected values: true or false
	 */
	public static final boolean GENERATE_INSTALLATION_FOLDER_ENCRYPTED = ECMServiceProvider
			.getServerPropertyAsBoolean("generate.installation.folder.encrypted");

	/***
	 * Property used to indicate to the system if the installation_folder must
	 * be generated signed. Expected values: true or false
	 */
	public static final boolean GENERATE_INSTALLATION_FOLDER_SIGNED = ECMServiceProvider
			.getServerPropertyAsBoolean("generate.installation.folder.signed");

	/***
	 * Property used to indicate to the system if the election.xml file must be
	 * generated compresssed. Expected values: true or false
	 */
	public static final boolean GENERATE_ELECTION_COMPRESS = ECMServiceProvider
			.getServerPropertyAsBoolean("generate.election.compress");

	/***
	 * Level of compression of the election.xml file. Values goes from 1 to 10
	 */
	public static final String LEVEL_COMPRESS_TO_ELECTION = ECMServiceProvider
			.getServerPropertyAsString("level.compress.to.election");

	/**
	 * Name of the file that must be decompressed in order to decrypt it
	 */
	public static final String FILE_NAME_INFLATE = ECMServiceProvider
			.getServerPropertyAsString("file.name.inflate");

	/***
	 * Folder which contains the codi_files needed for the Master USB generation
	 * process. Used in the application server of Distributed Environment
	 */
	public static final String TEMPORARY_PATH_FOR_FILE_GENERATION = ECMServiceProvider
			.getServerPropertyAsString("temporary.path.for.file.generation");

	/***
	 * Property used to indicate the system if a temporary SAESLocal folder must
	 * be saved locally. Expected values: true or false
	 */
	public static final boolean WRITE_FILES_IN_DRIVE = ECMServiceProvider
			.getServerPropertyAsBoolean("write.files.in.drive");

	/***
	 * Maximum number of eligible option displayed per page in the Edit eligible
	 * option functionality
	 */
	public static final String NUMBER_OF_PAGES_FOR_SEARCH_ELIGIBLE_OPTION = ECMServiceProvider
			.getServerPropertyAsString("number.of.pages.for.search.eligible.option");
	/***
	 * Block unused tabs. When false the only blocked tab will be the exit tab
	 */
	public static final boolean BLOCK_PANEL_TABS = ECMServiceProvider
			.getServerPropertyAsBoolean("block.panel.tabs");

	/***
	 * Property to indicate whether voting device report is available. Expected
	 * values: true or false
	 */
	public static final boolean GENERATE_TOTALIZATION_DEVICE = ECMServiceProvider
			.getServerPropertyAsBoolean("generate.totalization.device");

	// ////////////////////////////////////////////////////////////////////////////
	/*
	 * section of properties for module of report generation.
	 */
	// ////////////////////////////////////////////////////////////////////////////

	/***
	 * Property to indicate whether reports generated by ECM must show several
	 * languages in one page, or the reports generated must show one language in
	 * each page. Expected values: true or false
	 */
	public static final boolean REPORTS_WITH_MULTI_LANGUAGES = ECMServiceProvider
			.getServerPropertyAsBoolean("reports.with.multi.languages");

	/***
	 * Property to indicate whether the posibility to print the report for the
	 * president of the totalization bureau is available. Expected values: true
	 * or false
	 */
	public static final boolean AVAILABLE_TOTALISATION_REPORT = ECMServiceProvider
			.getServerPropertyAsBoolean("available.totalisation.report");

	/***
	 * Property to indicate whether the possibility to print the report for the
	 * president of the totalization bureau is available. Expected values: true
	 * or false
	 */
	public static final boolean AVAILABLE_VOTING_DEVICE_REPORT = ECMServiceProvider
			.getServerPropertyAsBoolean("available.voting.device.report");

	/***
	 * Property to indicate whether the possibility to print the report for
	 * recount password is available. Expected values: true or false
	 */
	public static final boolean AVAILABLE_RECOUNT_REPORT = ECMServiceProvider
			.getServerPropertyAsBoolean("available.recount.report");
	// ////////////////////////////////////////////////////////////////////////////
	/*
	 * section of properties for module of eligible option editor
	 */
	// ////////////////////////////////////////////////////////////////////////////

	/***
	 * ASCII codes for Eligible Option Editor
	 */
	public static final String ASCII_KEYS_FOR_ELIGIBLE_OPTION_EDITOR = ECMServiceProvider
			.getServerPropertyAsString("ascii.keys.for.eligible.option.editor");

	/***
	 * Type of check of the ASCII codes, true to check valid characters, false
	 * to check invalid characters
	 */
	public static final boolean CHECK_VALID_CHARACTERS = ECMServiceProvider
			.getServerPropertyAsBoolean("check.valid.characters");

	/***
	 * Property to indicate if an space must be added to the field when the
	 * add.space.to.candidate.name.empty.fields candidate name is empty.
	 * Expected values: true or false
	 */
	public static final boolean ADD_SPACE_TO_CANDIDATE_NAME_EMPTY_FIELDS = ECMServiceProvider
			.getServerPropertyAsBoolean("add.space.to.candidate.name.empty.fields");

	// ////////////////////////////////////////////////////////////////////////////
	/*
	 * section of properties for general purpose.
	 */
	// ////////////////////////////////////////////////////////////////////////////

	/***
	 * Property to activate /deactivate the printer watcher feature. Expected
	 * values: true or false
	 */
	public static boolean USE_PRINTER_WATCHER = ECMServiceProvider
			.getServerPropertyAsBoolean("use.printer.watcher");

	/***
	 * IP address of the Database Server
	 */
	public static final String MASTER_DB_IP_ADDRESS = ECMServiceProvider
			.getServerPropertyAsString("master.db.ip.address");

	/***
	 * Port of the connection test to the Database Server
	 */
	public static final int MASTER_DB_PORT = Integer
			.parseInt(ECMServiceProvider
					.getServerPropertyAsString("master.db.port"));

	/***
	 * IP address of the Application Server
	 */
	public static final String SERVER_IP_ADDRESS = ECMServiceProvider
			.getServerPropertyAsString("server.ip.address");

	/***
	 * Port of the connection test to the Application Server
	 */
	public static final int SERVER_PORT = Integer.parseInt(ECMServiceProvider
			.getServerPropertyAsString("server.port"));

	/***
	 * Property used to activate / deactivate the battery watcher feature
	 */
	public static final boolean USE_BATTERY_WATCHER = ECMServiceProvider
			.getServerPropertyAsBoolean("use.battery.watcher");

	/***
	 * Critical battery charge (in percentage), used to activate the Low Battery
	 * alarm. Expected values: 0 to 100
	 */
	public static final int CRITICAL_POWER_PERCENT_VALUE = Integer
			.valueOf(ECMServiceProvider
					.getServerPropertyAsString("critical.power.percent.value"));

	/***
	 * Property used to indicate if the Low Battery alarm must be activated at
	 * the Critical battery charge
	 */
	public static final boolean PLAY_BATTERY_ALERT_BEEP = ECMServiceProvider
			.getServerPropertyAsBoolean("play.battery.alert.beep");

	/***
	 * Property to indicate whether downloading of pv templates is available or
	 * not. Expected values: true or false
	 */
	public static final boolean AVAILABLE_DOWNLOADING_PV_TEMPLATES = ECMServiceProvider
			.getServerPropertyAsBoolean("available.downloading.pv.templates");

	/***
	 * Property to indicate if only one asymmetric key should be generated.
	 * Expected values: true or false
	 */
	public static final boolean GENERATE_ONLY_ONE_ASYMMETRIC_KEY = ECMServiceProvider
			.getServerPropertyAsBoolean("generate.only.one.asymmetric.key");

	/***
	 * Property used to indicate if a validation of integrity of files must be
	 * performed after each generation. Expected values: true or false
	 */
	public static final boolean CHECK_GENERATION_FILE_INTEGRITY = ECMServiceProvider
			.getServerPropertyAsBoolean("check.generation.files.integrity");

	/***
	 * Property to indicate whether signature for voting device is generated or
	 * not. Expected values: true or false
	 */
	public static final boolean GENERATE_SIGNATURE_FOR_VOTING_DEVICE = ECMServiceProvider
			.getServerPropertyAsBoolean("generate.signature.for.voting.device");

	/***
	 * Property to indicate if generation temporary folder should be deleted.
	 * Expected values: true or false
	 */
	public static final boolean DELETE_GENERATION_TEMPORARY_FOLDER = ECMServiceProvider
			.getServerPropertyAsBoolean("delete.generation.temporary.folder");

	/***
	 * Property used to indicate if the number of plugged USBs must be validated
	 * prior each generation. Expected values: true or false
	 */
	public static final boolean VALIDATE_DRIVES_CONNECTED_AMOUNT = ECMServiceProvider
			.getServerPropertyAsBoolean("validate.drive.conected.amount");

	/***
	 * Property to indicate the number of attempts to file recovery
	 */
	public static final int ATTEMPTS_TO_FILE_RECOVERY = Integer
			.valueOf(ECMServiceProvider
					.getServerPropertyAsString("attempts.to.file.recovery"));

	/***
	 * Property to indicate the maximum to sign
	 */
	public static final int MAX_LEVEL_TO_SIGN = Integer
			.valueOf(ECMServiceProvider
					.getServerPropertyAsString("max.level.to.sign"));

	/**
	 * Property used to indicate the number of character allowed to edit the
	 * eligible option name.
	 */
	public static final int MAX_CHARACTERS_ELIGIBLE_OPTION_NAME = Integer
			.valueOf(ECMServiceProvider
					.getServerPropertyAsString("maximum.characters.allowed.eligibleoption.name"));

	/**
	 * Property used to indicate the number of character allowed to edit the
	 * eligible option last name.
	 */
	public static final int MAX_CHARACTERS_ELIGIBLE_OPTION_LASTNAME = Integer
			.valueOf(ECMServiceProvider
					.getServerPropertyAsString("maximum.characters.allowed.eligibleoption.lastname"));

	/**
	 * Property used to indicate the number of character allowed to edit name of
	 * party of each eligible option.
	 */
	public static final int MAX_CHARACTERS_ELIGIBLE_OPTION_PARTYNAME = Integer
			.valueOf(ECMServiceProvider
					.getServerPropertyAsString("maximum.characters.allowed.eligibleoption.partyname"));

	/**
	 * Property used to set the regular expression to select images in selection
	 * PDF.
	 */
	public static final String REGEX_FOR_SCREENSHOT_SELECTION_IMAGES = ECMServiceProvider
			.getServerPropertyAsString("regex.for.screenshot.selection.images");

	/**
	 * Property used to set the separator for languages report pdf
	 */
	public static final String SCREENSHOT_REPORT_LANGUAGES_SEPARATOR = ECMServiceProvider
			.getServerPropertyAsString("screenshot.report.pdf.languages.separator");

	/**
	 * Property used to indicate to the system if the pdf files for screenshot
	 * report must be generated signed. Expected values: true or false
	 */
	public static final boolean SIGN_SCREENSHOT_REPORT_PDF = ECMServiceProvider
			.getServerPropertyAsBoolean("sign.screenshot.report.pdf");

	/**
	 * Full date format managed by the app.
	 */
	public static final String DATE_PATTERN = ECMServiceProvider
			.getServerPropertyAsString("general.date.pattern");

	/**
	 * Date format without time managed by the app.
	 */
	public static final String DATE_DATE_PATTERN = ECMServiceProvider
			.getServerPropertyAsString("general.date.date.pattern");

	/**
	 * Time format without date managed by the app.
	 */
	public static final String DATE_TIME_PATTERN = ECMServiceProvider
			.getServerPropertyAsString("general.date.time.pattern");

	/**
	 * The date long format managed by the app.
	 */
	public static final String DATE_DATE_LONG_PATTERN = ECMServiceProvider
			.getServerPropertyAsString("general.date.date.long.pattern");

	/***
	 * Property to indicate if is mandatory change the date
	 */
	public static final Boolean CHANGE_DATE_AVAILABLE = ECMServiceProvider
			.getServerPropertyAsBoolean("change.date.available");

	/***
	 * Property to indicate if the change of date will be available
	 */
	public static final Boolean CHANGE_TIME_AVAILABLE = ECMServiceProvider
			.getServerPropertyAsBoolean("change.time.available");

	/***
	 * Property to indicate if the change of date will be available
	 */
	public static final Boolean CHANGE_DATE_MANDATORY = ECMServiceProvider
			.getServerPropertyAsBoolean("change.date.mandatory");

	/**
	 * Property used to set the footer separator for languages report pdf
	 */
	public static final String SCREENSHOT_FOOTER_LANGUAGES_SEPARATOR = ECMServiceProvider
			.getServerPropertyAsString("screenshot.footer.pdf.languages.separator");

	/**
	 * Property used to find client side log folder
	 */
	public static final String CLIENT_SIDE_LOG_FILES_PATH = ECMServiceProvider
			.getServerPropertyAsString("client.side.log.files.path");

	/**
	 * Property in MB to indicate maximum size allowed to export log files.
	 */
	public static final long MAX_SIZE_TO_EXPORT_LOG = Long
			.parseLong(ECMServiceProvider
					.getServerPropertyAsString("max.size.to.export.log"));

	/**
	 * Property used to indicate the default path of the filechooser to save
	 * files.
	 */
	public static final String DEFAULT_FILECHOOSER_PATH = ECMServiceProvider
			.getServerPropertyAsString("default.filechooser.path");

	/**
	 * Property used to indicate if the files to be uploaded should be signed.
	 * True to enable the signature validation, false to disable
	 */
	public static final boolean VALIDATE_FILES_TO_UPLOAD_SIGNATURE = ECMServiceProvider
			.getServerPropertyAsBoolean("validate.files.to.upload.signature");

	/**
	 * Maximum length in bytes allowed for bulk data load files
	 */
	public static final long MAX_LENGTH_ALLOWED_FOR_FILES_TO_UPLOAD = Long
			.parseLong(ECMServiceProvider
					.getServerPropertyAsString("max.length.allowed.for.files.to.upload"));

	/***
	 * Property to indicate the path folders and files that must be into the
	 * .tar.gz of Voting Machine.<br>
	 * Each folder or file must be separated by [:]
	 */
	public static final String REQUIRED_FOLDERS_ISO_VOTING_MACHINE = ECMServiceProvider
			.getECMProperty("required.folders.iso.voting.machine");

	/***
	 * Required folders and files in an Screenshots image file to be valid
	 */
	public static final String REQUIRED_FOLDERS_ISO_SCREENSHOT = ECMServiceProvider
			.getECMProperty("required.folders.iso.screenshot");

	/**
	 * The zip name for voices files.
	 */
	public static final String VOICES_ZIP_NAME = ECMServiceProvider
			.getServerPropertyAsString("voices.zip.name");

	/**
	 * The directory name of eml files on official memory
	 */
	public static final String EML_FILES_DIR = ECMServiceProvider
			.getServerPropertyAsString("eml.files.folder");

}
