/**
 * DecryptException.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.lang;

import com.smartmatic.waffle.ecm.core.lang.ECMBaseException;
import com.smartmatic.waffle.ecm.core.lang.IECMExceptionInfo;

/**
 * Class to handle any exception that may occur executing a Decryption
 * operation.
 */
public class DecryptException extends ECMBaseException {

	/**
	 * Holds the version of the class. It is used by the serialization engine to
	 * determine when a class its equivalent to another
	 */
	private static final long serialVersionUID = 1962224267534632834L;

	/**
	 * Enum that contains all the possible reasons because the DecryptException
	 * can be thrown.
	 */
	public enum DecryptExceptionInfo implements IECMExceptionInfo {
		ELECTION_FILE_NOT_FOUND("election.file.not.found",
				"Election file not found"), VOTING_DEVICE_FILE_NOT_FOUND(
				"voting.device.file.not.found", "Voting device file not found"), STRING_RESOURCES_FILE_NOT_FOUND(
				"string.resources.file.not.found",
				"String resources file not found"), PROBLEM_GETTING_SYMMETRIC_KEY(
				"problem.getting.symmetric.key",
				"A problem occurred trying to get the symmetric key to decipher the PBE "), INVALID_PASSPHRASE(
				"invalid.passphrase",
				"The passphrase introduced by the user is invalid"), PROBLEM_DECIPHERING_FILE(
				"problem.deciphering.file",
				"A problem occurred deciphering the file ");
		;

		/**
		 * Variable to hold the exception message.
		 */
		private String exceptionMessage;

		/**
		 * Variable to hold the bundle key to show a user understandable
		 * message.
		 */
		private String bundleKey;

		/**
		 * Gets the variable to hold the exception message.
		 * 
		 * @return the variable to hold the exception message
		 * @inheritDoc
		 */
		@Override
		public String getExceptionMessage() {
			return this.exceptionMessage;
		}

		/**
		 * Gets the variable to hold the bundle key to show a user
		 * understandable message.
		 * 
		 * @return the variable to hold the bundle key to show a user
		 *         understandable message
		 * @inheritDoc
		 */
		@Override
		public String getBundleKey() {
			return this.bundleKey;
		}

		/**
		 * Constructor.
		 * 
		 * @param bundleKey
		 *            Resource bundle's key message
		 */
		private DecryptExceptionInfo(String bundleKey) {
			this.bundleKey = bundleKey;
		}

		/**
		 * Constructor.
		 * 
		 * @param bundleKey
		 *            Resource bundle's key message
		 * @param exceptionMessage
		 *            Exception message
		 */
		private DecryptExceptionInfo(String bundleKey, String exceptionMessage) {
			this.bundleKey = bundleKey;
			this.exceptionMessage = exceptionMessage;
		}
	}

	/**
	 * Instantiates an DecryptException.
	 * 
	 * @param throwable
	 *            a nested exception
	 * 
	 * @param exceptionInfo
	 *            an enumeration value regarding the cause of the exception
	 */
	public DecryptException(Throwable throwable,
			DecryptExceptionInfo exceptionInfo) {
		super(throwable, exceptionInfo);
	}

	/**
	 * Instantiates an DecryptException.
	 * 
	 * @param throwable
	 *            a nested exception
	 * @param exceptionInfo
	 *            an enumeration value regarding the cause of the exception
	 * @param exceptionMessage
	 *            Exception message of nested exception
	 */
	public DecryptException(Throwable throwable,
			DecryptExceptionInfo exceptionInfo, String exceptionMessage) {
		super(throwable, exceptionInfo, exceptionMessage);
	}

	/**
	 * Instantiates an DecryptException.
	 * 
	 * @param exceptionInfo
	 *            an enumeration value regarding the cause of the exception
	 */
	public DecryptException(DecryptExceptionInfo exceptionInfo) {
		super(exceptionInfo);
	}

	/*
	 * @inheritDoc
	 */
	@Override
	public String getBundleKey() {
		return this.getClass().getSimpleName() + "."
				+ this.exceptionInfo.getBundleKey();
	}
}
