/**
 * BulkUploadEMLFilesController.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.ui;

import java.util.List;

import com.smartmatic.waffle.ecm.client.ui.common.AwtOperationType;
import com.smartmatic.waffle.ecm.client.ui.common.IAwtOperationListener;
import com.smartmatic.waffle.ecm.client.worker.BulkUploadEMLFilesWorker;
import com.smartmatic.waffle.ecm.data.transfer.objects.FileToUploadDTO;

/**
 * Controller class that creates and starts the worker thread to execute the
 * bulk upload process of EML files.
 */
public class BulkUploadEMLFilesController implements IAwtOperationListener {

	/**
	 * Instantiates a new BulkUploadEMLFilesController.
	 * 
	 * @param bulkUploadEMLFilesPanel
	 *            BulkUploadCodiFilesPanel instance
	 * @param emlFilesToUpĺoadList
	 *            Input list with files to load
	 * @param resourceFileContent
	 *            byte array with the resources file
	 */
	public BulkUploadEMLFilesController(
			BulkUploadEMLFilesPanel bulkUploadEMLFilesPanel,
			List<FileToUploadDTO> emlFilesToUpĺoadList,
			byte[] resourceFileContent) {

		this.bulkUploadEMLFilesPanel = bulkUploadEMLFilesPanel;
		this.emlFilesToUpĺoadList = emlFilesToUpĺoadList;
		this.resourceFileContent = resourceFileContent;
	}

	/**
	 * Method that starts the worker that does the real backend functionality
	 * work.
	 */
	public void startWorker() {

		this.bulkUploadEMLFilesWorker = new BulkUploadEMLFilesWorker(
				this.emlFilesToUpĺoadList, this.resourceFileContent);

		this.bulkUploadEMLFilesWorker.addListener(this);

		Thread bulkUploadEMLFilesWorkerThread = new Thread(
				this.bulkUploadEMLFilesWorker, "bulkUploadEMLFilesWorkerThread");

		bulkUploadEMLFilesWorkerThread.start();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.smartmatic.waffle.ecm.client.ui.common.IAwtOperationListener#awtOperation
	 * (com.smartmatic.waffle.ecm.client.ui.common.AwtOperationType)
	 */
	@Override
	public void awtOperation(AwtOperationType awtOperationType) {

		switch (awtOperationType) {
		case UPDATE_COMPONENTS: {

			int currentlyProcessingFileIndex = this.bulkUploadEMLFilesWorker
					.getNumberOfProcessedFiles() + 1;

			String fileBeingProcessingName = this.bulkUploadEMLFilesWorker
					.getFileBeingProcessing().getFileToUploadDetailDTO()
					.getFileInfo().getName();

			this.bulkUploadEMLFilesPanel.updateStatusDuringBulkUploadOperation(
					currentlyProcessingFileIndex,
					this.emlFilesToUpĺoadList.size(), fileBeingProcessingName);
		}

			break;

		case UPDATE_PROGRESS_BAR: {
			int amountOfProcessedFiles = this.bulkUploadEMLFilesWorker
					.getNumberOfProcessedFiles();

			this.bulkUploadEMLFilesPanel
					.updateProgressBar(amountOfProcessedFiles);
		}
			break;

		case SHOW_RESULT_MESSAGE: {
			this.bulkUploadEMLFilesPanel
					.finishBulkUploadProcess(this.bulkUploadEMLFilesWorker
							.getFileUploadedDetailList());

		}
			break;

		case SHOW_ERROR_MESSAGE: {
			this.bulkUploadEMLFilesPanel
					.showUnexpectedErrorMessageExecutingBulkUpload(this.bulkUploadEMLFilesWorker
							.getFileBeingProcessing());
		}
			break;
		}

	}

	/** BulkUploadEMLFilesPanel instance. */
	private BulkUploadEMLFilesPanel bulkUploadEMLFilesPanel;

	/** Input list with files to load. */
	private List<FileToUploadDTO> emlFilesToUpĺoadList;

	/** Hold the byte array with the resources file. */
	private byte[] resourceFileContent;

	/** BulkUploadEMLFilesWorker instance. */
	private BulkUploadEMLFilesWorker bulkUploadEMLFilesWorker;
}
