/**
 * BulkUploadSmttFilesPanel.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.ui;

import java.io.File;
import java.io.IOException;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.swing.JFileChooser;
import javax.swing.table.DefaultTableModel;
import javax.swing.tree.DefaultMutableTreeNode;

import org.apache.commons.io.FileUtils;
import org.apache.commons.lang.StringUtils;

import com.smartmatic.waffle.ecm.client.ECMClientSideConstants;
import com.smartmatic.waffle.ecm.client.ui.BulkUploadFileFilter.FilterType;
import com.smartmatic.waffle.ecm.client.util.ClientCommon;
import com.smartmatic.waffle.ecm.client.util.SignatureException;
import com.smartmatic.waffle.ecm.data.transfer.objects.EntityRecordsQuantitiesDTO;
import com.smartmatic.waffle.ecm.data.transfer.objects.FileToUploadDTO;
import com.smartmatic.waffle.ecm.data.transfer.objects.FileToUploadDetailDTO;
import com.smartmatic.waffle.ecm.data.transfer.objects.UploadedFileDetailDTO;
import com.smartmatic.waffle.ecm.data.transfer.type.SmttFileType;
import com.smartmatic.waffle.ecm.service.lang.BulkDataLoadException;
import com.smartmatic.waffle.ecm.service.lang.BulkDataLoadException.BulkDataLoadExceptionOperationExceptionInfo;
import com.smartmatic.waffle.ecm.ui.util.ECMOptionPane;
import com.smartmatic.waffle.log.SMTTLogger;

/**
 * The Class is used to load and draw all the necessary components for the Bulk
 * Upload Panel.
 */
public class BulkUploadSmttFilesPanel extends BulkUploadAbstractPanel {

	/**
	 * The object's serialization code.
	 */
	private static final long serialVersionUID = 5603236550597792978L;

	/**
	 * File chooser filter.
	 */
	private BulkUploadFileFilter bulkUploadFileFilter;

	/**
	 * For log messages purpose.
	 */
	private static SMTTLogger logger = SMTTLogger
			.getLogger(BulkUploadSmttFilesPanel.class);

	/**
	 * Sets the BulkUploadCodiFilesPanel.
	 * 
	 * @param panel
	 *            the new panel
	 */
	public void setBulkUploadCodiFilesPanel(
			BulkUploadEMLFilesPanel bulkUploadCodiFilesPanel) {
		this.bulkUploadCodiFilesPanel = bulkUploadCodiFilesPanel;
	}

	/**
	 * Sets the data validation certificate
	 * 
	 * @param dataValidationCertificate
	 *            the certificate to validate files to upload signature
	 */
	public void setDataValidationCertificate(
			X509Certificate dataValidationCertificate) {
		this.dataValidationCertificate = dataValidationCertificate;
	}

	/**
	 * Instantiates a new BulkUploadSmttFilesPanel.
	 */
	public BulkUploadSmttFilesPanel() {
		initComponents();

		this.bulkUploadFileFilter = new BulkUploadFileFilter(
				this.resourceBundle
						.getString("Application.max_size_filter_desc"),
				FilterType.FILES_TO_UPLOAD);

		loadFileTypesTranslations();

		this.firstExecution = true;

		startUpdateLoadedNumberOfEachEntity();
	}


    /**
     * Shows a dialog box detailing why the process could not end successfully.
     *
     * @param ex
     *      the problem found while executing the bulk load process
     * @param filename
     *      the file that was being processed when the failure took place
     *      (can be {@code null})
     */
    public void showErrorMessageFor(BulkDataLoadException ex, String filename) {
        final String prefix;        // Message Key prefix

        Map<String, String> ctxt;   // Exception's contextual data
        String eMsg;                // eMsg
        String ss;                  // ss: searchString
        String suffix;              // Message Key suffix

        ctxt = new HashMap<String, String>( ex.getContext() );
        ctxt.put("file_name", filename);

        prefix = "BulkUploadSmttFilesPanel.message.";
        suffix = ex.getInfo().getBundleKey();
        eMsg   = this.resourceBundle.getString(prefix + suffix);

        for (Map.Entry<String, String> entry : ctxt.entrySet()) {
            ss   = String.format("${%s}", entry.getKey());
            eMsg = StringUtils.replace(eMsg, ss, entry.getValue());
        }
        this.showErrorMessageExecutingBulkUpload(eMsg);
    }


	/**
	 * Shows the message error for unexpected errors.
	 * 
	 * @param smttFileToUploadDTO
	 *            file name where the error occurred to report it
	 */
	public void showUnexpectedErrorMessageExecutingBulkUpload(
			String smttFileToUploadDTO) {

		String errorMessage = this.resourceBundle
				.getString("BulkUploadSmttFilesPanel.message.bulk.upload.error");

		errorMessage = StringUtils.replace(errorMessage, "${file_name}",
				smttFileToUploadDTO);

		showErrorMessageExecutingBulkUpload(errorMessage);
	}

	/**
	 * Shows the message error for missing required fields errors.
	 * 
	 * @param smttFileToUploadDTO
	 *            file where the error occurred to report it
	 */
	public void showMissingRequiredFieldErrorMessageExecutingBulkUpload(
			String smttFileToUploadDTO) {

		String errorMessage = this.resourceBundle
				.getString("BulkUploadSmttFilesPanel.message.bulk.upload.missing.required.fields.error");

		errorMessage = StringUtils.replace(errorMessage, "${file_name}",
				smttFileToUploadDTO);

		showErrorMessageExecutingBulkUpload(errorMessage);
	}

	/**
	 * Show the error message for bulk upload action.
	 * 
	 * @param errorMessage
	 *            The error to show.
	 */
	private void showErrorMessageExecutingBulkUpload(String errorMessage) {

		ECMOptionPane.showMessageDialog(this, errorMessage,
				this.resourceBundle.getString("ErrorMessage.title"),
				ECMOptionPane.ERROR_MESSAGE, ECMOptionPane.ERROR_DIALOG);

		startUpdateLoadedNumberOfEachEntity();

		this.clearFilesToUploadTableButton.setEnabled(false);
		this.chooseFilesToUploadButton.setEnabled(true);
		this.closeButton.setEnabled(true);
		this.statusLabel.setText(StringUtils.EMPTY);
		this.updateProgressBar(0);
		if (this.isSomeEntityLoaded) {
			this.clearDataBaseButton.setEnabled(true);
		}
		this.bulkUploadCodiFilesPanel.preventCloseOfBulkUploadDialog(false);
		resetFormToSelectOtherFiles();
	}

	/**
	 * Shows the message error for badly configured audio voting error.
	 * 
	 */
	public void showErrorMessageBadlyConfiguredAudioVoting() {

		String errorMessage = this.resourceBundle
				.getString("BulkUploadSmttFilesPanel.message.audio.voting.config.error");

		ECMOptionPane.showMessageDialog(this, errorMessage,
				this.resourceBundle.getString("ErrorMessage.title"),
				ECMOptionPane.ERROR_MESSAGE, ECMOptionPane.ERROR_DIALOG);

		startUpdateLoadedNumberOfEachEntity();

		this.clearFilesToUploadTableButton.setEnabled(false);
		this.chooseFilesToUploadButton.setEnabled(true);
		this.closeButton.setEnabled(true);
		this.statusLabel.setText(StringUtils.EMPTY);
		this.updateProgressBar(0);
		if (this.isSomeEntityLoaded) {
			this.clearDataBaseButton.setEnabled(true);
		}
		this.bulkUploadCodiFilesPanel.preventCloseOfBulkUploadDialog(false);
		resetFormToSelectOtherFiles();
	}

	/**
	 * Updates the GUI components and displays the result tree after bulk upload
	 * process finished.
	 * 
	 * @param fileUploadedDetailList
	 *            list with the result of bulk upload
	 */
	public void finishBulkUploadProcess(
			List<UploadedFileDetailDTO> fileUploadedDetailList) {

		this.panelProgressBar.setValue(this.panelProgressBar.getMaximum());

		this.bulkUploadCodiFilesPanel.preventCloseOfBulkUploadDialog(false);

		if (fileUploadedDetailList != null) {
			startUpdateLoadedNumberOfEachEntity();
			if (showResult(this.uploadedFilesResultTree, this.rootTreeNode,
					this.paneWithFilesToUploadTable,
					this.paneWithFilesUploadedResult, fileUploadedDetailList)) {

				this.statusLabel.setText(this.resourceBundle
						.getString("BulkUploadSmttFilesPanel.finish.message"));

				ECMOptionPane.showMessageDialog(this, this.resourceBundle
						.getString("BulkUploadSmttFilesPanel.message.success"),
						this.resourceBundle.getString("NormalMessage.title"),
						ECMOptionPane.INFORMATION_MESSAGE,
						ECMOptionPane.INFORMATION_DIALOG);

				this.clearFilesToUploadTableButton.setEnabled(true);
				this.updateEntitiesStatusTableButton.setEnabled(true);
				this.downloadTraslationsTamplateButton.setEnabled(true);
				this.chooseFilesToUploadButton.setEnabled(true);
				this.closeButton.setEnabled(true);
				this.clearDataBaseButton.setEnabled(true);
				this.panelProgressBar.setValue(0);
				this.statusLabel.setText(StringUtils.EMPTY);
			} else {

				ECMOptionPane
						.showMessageDialog(
								this,
								this.resourceBundle
										.getString("BulkUploadSmttFilesPanel.message.warning"),
								this.resourceBundle
										.getString("ErrorMessage.title"),
								ECMOptionPane.ERROR_MESSAGE,
								ECMOptionPane.ERROR_DIALOG);

				if (this.isSomeEntityLoaded) {
					this.clearDataBaseButton.setEnabled(true);
				}
				this.updateEntitiesStatusTableButton.setEnabled(true);
				this.clearFilesToUploadTableButton.setEnabled(true);
				this.closeButton.setEnabled(true);
				this.panelProgressBar.setValue(0);
				this.statusLabel.setText(StringUtils.EMPTY);
			}
		}
	}

	/**
	 * Method to update the status message with the actual file processing while
	 * bulk upload process for this file is executing
	 * 
	 * @param filesProcessed
	 *            files processed
	 * @param filesAmount
	 *            amount of files to process
	 * @param nameFile
	 *            string with the file name
	 */
	public void updateStatusDuringBulkUploadOperation(int filesProcessed,
			int filesAmount, String nameFile) {
		this.isSomeEntityLoaded = true;
		this.statusLabel.setText(String.valueOf(filesProcessed) + "/"
				+ String.valueOf(filesAmount) + "     (" + nameFile + ")");
	}

	/**
	 * Updates the GUI components after translations file downloading process
	 * finished.
	 */
	public void finishTranslationsFileDownloadProcess() {
		this.panelProgressBar.setValue(0);
		this.statusLabel.setText(StringUtils.EMPTY);
		this.updateEntitiesStatusTableButton.setEnabled(true);
		this.downloadTraslationsTamplateButton.setEnabled(true);
		this.chooseFilesToUploadButton.setEnabled(true);
		this.closeButton.setEnabled(true);
		this.clearDataBaseButton.setEnabled(true);

		this.bulkUploadCodiFilesPanel.preventCloseOfBulkUploadDialog(false);
	}

	/**
	 * Updates the GUI components after database records removal process
	 * finished.
	 * 
	 * @param someErrorHasOccurred
	 *            true if some error occurred in the process to show different
	 *            component for each case
	 */
	@Override
	public void finishDatabaseClearingProcess(boolean someErrorHasOccurred) {

		this.panelProgressBar.setValue(0);

		this.statusLabel.setText(StringUtils.EMPTY);

		startUpdateLoadedNumberOfEachEntity();

		if (someErrorHasOccurred) {
			this.clearDataBaseButton.setEnabled(true);
			this.closeButton.setEnabled(true);
			resetFormToSelectOtherFiles();
		} else {
			this.chooseFilesToUploadButton.setEnabled(true);
			this.closeButton.setEnabled(true);
			resetFormToSelectOtherFiles();
		}

		this.bulkUploadCodiFilesPanel.preventCloseOfBulkUploadDialog(false);
	}

	/**
	 * Method to update the status message while database records removal
	 * process is executing
	 * 
	 * @param bundleKey
	 *            bundle key used to find the translation of the message
	 */
	@Override
	public void updateStatusMessage(String bundleKey) {
		if (bundleKey.equals(StringUtils.EMPTY)) {
			this.statusLabel.setText(StringUtils.EMPTY);
		} else {
			this.statusLabel.setText(this.resourceBundle.getString(bundleKey));
		}
	}

	/**
	 * Enables the GUI buttons and refreshes the loaded number of each entity
	 * table after counting the loaded entities.
	 * 
	 * @param entityRecordsQuantitiesList
	 *            List with loaded entities to be printed in the table
	 * 
	 * @param isSmttDataIsLoaded
	 *            True if all database tables related with smartmatic files are
	 *            loaded
	 * 
	 * @param isSomeEntityLoaded
	 *            True if some entities related with smartmatic files are loaded
	 */
	public void finishUpdateLoadedNumberOfEachEntity(
			List<EntityRecordsQuantitiesDTO> entityRecordsQuantitiesList,
			boolean isSmttDataIsLoaded, boolean isSomeEntityLoaded) {

		if (this.firstExecution && isSomeEntityLoaded) {
			this.clearDataBaseButton.setEnabled(true);
			if (isSmttDataIsLoaded) {
				this.downloadTraslationsTamplateButton.setEnabled(true);
			}
			this.firstExecution = false;
		} else {
			this.firstExecution = false;
		}

		this.isSmttDataIsLoaded = isSmttDataIsLoaded;
		this.isSomeEntityLoaded = isSomeEntityLoaded;

		if (this.loadedNumberOfEachEntityTable != null) {
			DefaultTableModel tableModelTmp = (DefaultTableModel) this.loadedNumberOfEachEntityTable
					.getModel();
			tableModelTmp.getDataVector().removeAllElements();
			this.loadedNumberOfEachEntityTable.repaint();
		}

		DefaultTableModel loadedNumberOfEachEntityDefaultTableModel = (DefaultTableModel) this.loadedNumberOfEachEntityTable
				.getModel();

		if (entityRecordsQuantitiesList != null) {
			for (EntityRecordsQuantitiesDTO indexResult : entityRecordsQuantitiesList) {
				loadedNumberOfEachEntityDefaultTableModel.addRow(new String[] {
						indexResult.getSmttFileType().getTranslatedName(),
						String.valueOf(indexResult.getRecordsQuantities()) });
			}
		}
	}

	/**
	 * Method called by some controllers to show error or information messages.
	 * 
	 * @param bundleKey
	 *            bundle key to find the translation message
	 * @param messageType
	 *            type of message to show
	 */
	@Override
	public void showMessage(String bundleKey, int messageType) {
		if (messageType == ECMOptionPane.ERROR_MESSAGE) {
			ECMOptionPane.showMessageDialog(this,
					this.resourceBundle.getString(bundleKey),
					this.resourceBundle.getString("ErrorMessage.title"),
					ECMOptionPane.ERROR_MESSAGE, ECMOptionPane.ERROR_DIALOG);

			this.bulkUploadCodiFilesPanel.preventCloseOfBulkUploadDialog(false);
		} else if (messageType == ECMOptionPane.INFORMATION_MESSAGE) {
			ECMOptionPane
					.showMessageDialog(
							this,
							this.resourceBundle
									.getString("BulkUploadSmttFilesPanel.generate.translations.message.success"),
							this.resourceBundle
									.getString("NormalMessage.title"),
							ECMOptionPane.INFORMATION_MESSAGE,
							ECMOptionPane.INFORMATION_DIALOG);
		}
	}

	/**
	 * Sets the progress bar's maximum value
	 * 
	 * @param maximum
	 *            maximum progress bar's value
	 */
	public void setProgressBarMaximum(int maximum) {
		this.panelProgressBar.setMaximum(maximum);
	}

	/**
	 * Sets the progress bar's current value
	 * 
	 * @param progress
	 *            value to update the progress bar
	 */
	@Override
	public void updateProgressBar(int progress) {
		this.panelProgressBar.setValue(progress);

	}

	/**
	 * Sets the progress bar's maximum value
	 * 
	 * @param progress
	 *            value to update the progress bar
	 */
	@Override
	void setProgressBarMaximumValue(int maxValue) {
		this.panelProgressBar.setMaximum(maxValue);
	}

	/**
	 * Checks if is smtt data is loaded.
	 * 
	 * @return true, if is smtt data is loaded
	 */
	public boolean isSmttDataIsLoaded() {
		return this.isSmttDataIsLoaded;
	}

	/**
	 * Refresh loaded number of each entity.
	 */
	private void startUpdateLoadedNumberOfEachEntity() {
		BulkUploadUpdateLoadedNumberOfEachEntityController bulkUploadStatusQueriesController = new BulkUploadUpdateLoadedNumberOfEachEntityController(
				this);
		bulkUploadStatusQueriesController.startWorker();
	}

	/**
	 * Loads the translations for the smartmatic files type
	 */
	private void loadFileTypesTranslations() {
		SmttFileType[] filesTypes = SmttFileType.values();

		for (int i = 0; i < filesTypes.length; i++) {
			filesTypes[i]
					.setTranslatedName(this.resourceBundle
							.getString("com.smartmatic.waffle.ecm.data.transfer.type.SmttFileType."
									+ filesTypes[i].toString()));
		}
	}

	/**
	 * Enables or disables the panel's buttons.
	 * 
	 * @param value
	 *            True to set the buttons as enabled, false to disable it.
	 */
	private void setAllPanelButtonsEnable(boolean value) {
		this.clearFilesToUploadTableButton.setEnabled(value);
		this.updateEntitiesStatusTableButton.setEnabled(value);
		this.downloadTraslationsTamplateButton.setEnabled(value);
		this.chooseFilesToUploadButton.setEnabled(value);
		this.closeButton.setEnabled(value);
		this.uploadFilesButton.setEnabled(value);
		this.clearDataBaseButton.setEnabled(value);
	}

	/**
	 * Prepare GUI components for bulk upload execution
	 */
	private void startBulkUploadProcess(
			List<FileToUploadDTO> smttFilesToUpĺoadList,
			byte[] resourcesFileContent) {

		this.bulkUploadCodiFilesPanel.preventCloseOfBulkUploadDialog(true);

		this.updateEntitiesStatusTableButton.setEnabled(true);
		this.clearFilesToUploadTableButton.setEnabled(false);
		this.downloadTraslationsTamplateButton.setEnabled(false);
		this.chooseFilesToUploadButton.setEnabled(false);
		this.closeButton.setEnabled(false);
		this.uploadFilesButton.setEnabled(false);
		this.clearDataBaseButton.setEnabled(false);
		this.panelProgressBar.setStringPainted(true);
		this.filesToUploadTable.setEnabled(false);

		BulkUploadSmttFilesController bulkUploadSmttFilesController = new BulkUploadSmttFilesController(
				this, smttFilesToUpĺoadList, resourcesFileContent);

		bulkUploadSmttFilesController.startWorker();
	}

	/**
	 * Prepare GUI components for the downloading of the translation template
	 * file
	 */
	private void startTranslationsFileDownloadProcess(File fileSelected) {

		this.bulkUploadCodiFilesPanel.preventCloseOfBulkUploadDialog(true);

		BulkUploadDownloadTranslationsTemplateController bulkUploadDownloadTranslationsTemplateController = new BulkUploadDownloadTranslationsTemplateController(
				this, fileSelected);

		bulkUploadDownloadTranslationsTemplateController.startDownloadProcess();

		this.statusLabel
				.setText(this.resourceBundle
						.getString("BulkUploadSmttFilesPanel.message.downloading_translations"));

		setAllPanelButtonsEnable(false);
	}

	/**
	 * Reads each file header to determine which smartmatic file type it is
	 * 
	 * @param fileToRead
	 *            file to read
	 * 
	 * @return the smartmatic file type corresponding with the file
	 * 
	 * @throws BulkDataLoadException
	 *             if it is an invalid file type or some error occur opening the
	 *             file to determine which type of file it is
	 */
	private SmttFileType getSmttFileType(File fileToRead)
			throws BulkDataLoadException {
		try {

			String line = FileUtils.readLines(fileToRead).iterator().next();

			try {
				SmttFileType smttFileType = SmttFileType
						.stringToSmttFileType(line.trim());

				return smttFileType;
			} catch (IllegalArgumentException e) {
				throw new BulkDataLoadException(
						BulkDataLoadExceptionOperationExceptionInfo.SMTT_FILE_TYPE_NOT_FOUND);
			}
		} catch (BulkDataLoadException e) {
			this.fileWithProblems = fileToRead;
			throw e;
		} catch (Exception e) {
			this.fileWithProblems = fileToRead;
			throw new BulkDataLoadException(
					e,
					BulkDataLoadExceptionOperationExceptionInfo.UNEXPECTED_ERROR_GETTING_SMTT_FILE_TYPE,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Remove items from files to upload table.
	 */
	private void clearFilesToUploadTable() {
		if (this.filesToUploadTable != null) {
			DefaultTableModel tableModelTmp = (DefaultTableModel) this.filesToUploadTable
					.getModel();
			tableModelTmp.getDataVector().removeAllElements();
			this.filesToUploadTable.repaint();
		}
	}

	/**
	 * Clear current items from files to upload table.
	 */
	private void resetFormToSelectOtherFiles() {
		clearFilesToUploadTable();
		this.paneWithFilesUploadedResult.setVisible(false);
		this.paneWithFilesToUploadTable.setVisible(true);
		this.statusLabel.setText(StringUtils.EMPTY);
		this.panelProgressBar.setValue(0);
		updateUI();
		repaint();
	}

	/**
	 * Gets Smtt File type
	 * 
	 * @param fileToUpload
	 *            File to evaluate.
	 * @return SmttFileType
	 * @throws BulkDataLoadException
	 */
	private SmttFileType getFileType(File fileToUpload)
			throws BulkDataLoadException {
		SmttFileType fileType = null;

		boolean isResourcesFile = validateIfIsResourcesFile(fileToUpload);

		if (isResourcesFile) {
			this.resourcesFileReference = fileToUpload;
			fileType = SmttFileType.RESOURCE;
		} else {
			fileType = getSmttFileType(fileToUpload);
		}

		return fileType;
	}

	/**
	 * Fill the map with the valid files to bulk upload.
	 * 
	 * @param selectedFiles
	 *            files selected by the user
	 */
	private void startValidatingFilesToUpload(List<File> selectedFiles) {
		try {

			DefaultTableModel defaultTableModel = (DefaultTableModel) this.filesToUploadTable
					.getModel();

			boolean enableButtons = true;

			if (ECMClientSideConstants.VALIDATE_FILES_TO_UPLOAD_SIGNATURE) {
				validateSignature(selectedFiles);
			}

			this.validFilesToUploadMap = new HashMap<SmttFileType, File>();

			for (File fileToUpload : selectedFiles) {

				SmttFileType fileType = getFileType(fileToUpload);

				if (this.validFilesToUploadMap.containsKey(fileType)) {

					String errorMessage = this.resourceBundle
							.getString("BulkUploadSmttFilesPanel.error.repeated.file.detected.message");

					errorMessage = StringUtils.replace(errorMessage,
							"${file_type}", fileType.getTranslatedName());

					ECMOptionPane
							.showMessageDialog(this, errorMessage,
									this.resourceBundle
											.getString("ErrorMessage.title"),
									ECMOptionPane.ERROR_MESSAGE,
									ECMOptionPane.ERROR_DIALOG);

					cleanFilesToUploadTableActionPerformed();

					enableButtons = false;

					break;
				} else {
					this.validFilesToUploadMap.put(fileType, fileToUpload);

					defaultTableModel
							.addRow(new Object[] {
									fileType.getTranslatedName(),
									fileToUpload.getName(),
									this.resourceBundle
											.getString("BulkUploadSmttFilesPanel.jTable2.valid.file") });
				}
			}

			if (this.validFilesToUploadMap.isEmpty()) {
				enableButtons = false;

				ECMOptionPane
						.showMessageDialog(
								this,
								this.resourceBundle
										.getString("BulkUploadSmttFilesPanel.error.at.least.one.smartmatic.file.is.required"),
								this.resourceBundle
										.getString("ErrorMessage.title"),
								ECMOptionPane.ERROR_MESSAGE,
								ECMOptionPane.ERROR_DIALOG);

				cleanFilesToUploadTableActionPerformed();
			}

			if (enableButtons) {
				this.uploadFilesButton.setEnabled(true);
				this.clearFilesToUploadTableButton.setEnabled(true);
				this.panelProgressBar.setMaximum(this.validFilesToUploadMap
						.size());
			} else {
				this.uploadFilesButton.setEnabled(false);
				this.clearFilesToUploadTableButton.setEnabled(false);
			}

		} catch (BulkDataLoadException e) {
			logger.error(e, "Error during data bulkload");

			String bundle = "BulkUploadSmttFilesPanel." + e.getBundleKey()
					+ ".message";

			String message = this.resourceBundle.getString(bundle);

			if (this.fileWithProblems != null) {
				message = StringUtils.replace(message, "${file_name}",
						this.fileWithProblems.getName());
			}

			ECMOptionPane.showMessageDialog(this, message,
					this.resourceBundle.getString("ErrorMessage.title"),
					ECMOptionPane.ERROR_MESSAGE, ECMOptionPane.ERROR_DIALOG);

			cleanFilesToUploadTableActionPerformed();
		} catch (SignatureException e) {

			logger.error(e, "Error validating Signature");
			String key = "BulkUploadSmttFilesPanel.BulkDataLoadException.signature.file.does.not.match.with.the.certificate.message";

			ECMOptionPane.showMessageDialog(this,
					this.resourceBundle.getString(key),
					this.resourceBundle.getString("ErrorMessage.title"),
					ECMOptionPane.ERROR_MESSAGE, ECMOptionPane.ERROR_DIALOG);

		}
	}

	/**
	 * Method triggered on click event performed by the user to search in the
	 * filesystem the file to upload.
	 */
	private void searchFilesToUploadActionPerformed() {

		ClientCommon.initFileChooserLocation(this.fileChooser);

		this.fileChooser.setFileFilter(this.bulkUploadFileFilter);

		if (this.fileChooser.showOpenDialog(this) == 0) {
			ClientCommon.saveFileChooserLocationPreference(this.fileChooser
					.getCurrentDirectory().getAbsolutePath());

			if (this.paneWithFilesUploadedResult.isVisible()) {
				resetFormToSelectOtherFiles();
				this.uploadedFilesResultTree.removeAll();
				this.statusLabel.setText(StringUtils.EMPTY);
			}

			List<File> selectedFileList = Arrays.asList(this.fileChooser
					.getSelectedFiles());

			if (selectedFileList != null) {

				startValidatingFilesToUpload(selectedFileList);
			}
		}
		this.mainPanel.repaint();
	}

	/**
	 * Method triggered on click event performed by the user to update the
	 * amount of loaded entities in database
	 */
	private void updateLoadedNumberOfEachEntityActionPerformed() {
		startUpdateLoadedNumberOfEachEntity();
	}

	/**
	 * Method triggered on click event performed by the user to remove all
	 * smartmatic files' table records
	 */
	private void clearDataBaseActionPerformed() {

		int result = ECMOptionPane.showConfirmDialog(this, this.resourceBundle
				.getString("BulkUploadSmttFilesPanel.message.clean.database"),
				this.resourceBundle.getString("ConfirmationMessage.title"),
				ECMOptionPane.YES_NO_OPTION, ECMOptionPane.CONFIRM_DIALOG);

		if (result == 0) {
			this.bulkUploadCodiFilesPanel.preventCloseOfBulkUploadDialog(true);

			this.panelProgressBar.setMaximum(100);

			setAllPanelButtonsEnable(false);

			startDatabaseClearingProcess(this, false);
		}
	}

	/**
	 * Method triggered on click event performed by the user to download the
	 * translation template
	 */
	private void downloadTranslationTemplateActionPerformed() {

		int option = ECMOptionPane
				.showConfirmDialog(
						this,
						this.resourceBundle
								.getString("BulkUploadSmttFilesPanel.translations.download.confirm.message"), //$NON-NLS-1$
						this.resourceBundle
								.getString("ConfirmationMessage.title"), //$NON-NLS-1$
						ECMOptionPane.YES_NO_OPTION,
						ECMOptionPane.CONFIRM_DIALOG);

		if (option == ECMOptionPane.YES_OPTION) {

			resetFormToSelectOtherFiles();

			ClientCommon.initFileChooserLocation(this.fileChooser);
			this.fileChooser.setMultiSelectionEnabled(false);

			this.fileChooser.resetChoosableFileFilters();

			this.fileChooser.setSelectedFile(new File(this.resourceBundle
					.getString("FileName.Untitle.Document")));

			if (this.fileChooser.showSaveDialog(this) == JFileChooser.APPROVE_OPTION) {

				File selected = this.fileChooser.getSelectedFile();

				if (selected.getParentFile().exists()
						&& selected.getParentFile().canWrite()) {

					ClientCommon.saveFileChooserLocationPreference(selected
							.getParentFile().getAbsolutePath());

					startTranslationsFileDownloadProcess(selected);
				} else {
					showMessage(
							"BulkUploadSmttFilesPanel.error.FILE_MUST_BE_CORRECTED",
							ECMOptionPane.ERROR_MESSAGE);
				}
			}
			this.fileChooser.setMultiSelectionEnabled(true);
		}
	}

	/**
	 * Method triggered on click event performed by the user to start the bulk
	 * load process.
	 */
	private void executeBulkUploadActionPerformed() {

		int result = ECMOptionPane.showConfirmDialog(this, this.resourceBundle
				.getString("BulkUploadSmttFilesPanel.message.BulkUpload"),
				this.resourceBundle.getString("ConfirmationMessage.title"),
				ECMOptionPane.YES_NO_OPTION, ECMOptionPane.CONFIRM_DIALOG);

		byte[] resourcesFileContent = null;

		if (result == 0) {
			try {

				List<FileToUploadDTO> smttFilesToUpĺoadList = new ArrayList<FileToUploadDTO>();

				for (SmttFileType smttFileType : SmttFileType.bulkloadOrder()) {

					if (this.validFilesToUploadMap.containsKey(smttFileType)
							&& smttFileType != SmttFileType.RESOURCE) {

						File fileToUpload = this.validFilesToUploadMap
								.get(smttFileType);

						FileToUploadDTO smttFileToUploadDTO = new FileToUploadDTO();

						FileToUploadDetailDTO fileToUploadDetailDTO = new FileToUploadDetailDTO();

						byte[] fileToUploadContent = FileUtils
								.readFileToByteArray(fileToUpload);

						fileToUploadDetailDTO
								.setFileContent(fileToUploadContent);

						fileToUploadDetailDTO.setFileInfo(fileToUpload);

						smttFileToUploadDTO
								.setFileToUploadDetailDTO(fileToUploadDetailDTO);

						smttFileToUploadDTO.setSmttFileType(smttFileType);

						smttFilesToUpĺoadList.add(smttFileToUploadDTO);
					}
				}

				if (this.resourcesFileReference != null) {
					resourcesFileContent = FileUtils
							.readFileToByteArray(this.resourcesFileReference);
				}

				startBulkUploadProcess(smttFilesToUpĺoadList,
						resourcesFileContent);

			} catch (IOException e) {
				logger.error(e, StringUtils.defaultString(e.getMessage()));
				ECMOptionPane
						.showMessageDialog(
								this,
								this.resourceBundle
										.getString("BulkUploadSmttFilesPanel.error.UNEXPECTED_PROBLEM"),
								this.resourceBundle
										.getString("ErrorMessage.title"),
								ECMOptionPane.ERROR_MESSAGE,
								ECMOptionPane.ERROR_DIALOG);
			}

		}
	}

	/**
	 * Method triggered on click event performed by the user to clean the files
	 * to upload table
	 */
	private void cleanFilesToUploadTableActionPerformed() {
		resetFormToSelectOtherFiles();
		this.uploadFilesButton.setEnabled(false);
		this.clearFilesToUploadTableButton.setEnabled(false);
		this.chooseFilesToUploadButton.setEnabled(true);
		if (this.isSomeEntityLoaded) {
			this.clearDataBaseButton.setEnabled(true);
		}
		this.statusLabel.setText(StringUtils.EMPTY);
		this.validFilesToUploadMap = null;
		startUpdateLoadedNumberOfEachEntity();
	}

	/**
	 * Method triggered on click event performed by the user to close the panel
	 */
	private void closePanelActionPerformed() {// GEN-FIRST:event_closePannel
		this.bulkUploadCodiFilesPanel.closeSmttFilesUploadPanel();
	}

	/**
	 * This method is called from within the constructor to initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is always
	 * regenerated by the Form Editor.
	 */
	// desc="Generated Code">//GEN-BEGIN:initComponents
	@SuppressWarnings("serial")
	private void initComponents() {

		this.fileChooser = new javax.swing.JFileChooser();
		this.mainPanel = new javax.swing.JPanel();
		this.chooseFilesToUploadButton = new javax.swing.JButton();
		this.uploadFilesButton = new javax.swing.JButton();
		this.clearFilesToUploadTableButton = new javax.swing.JButton();
		this.clearDataBaseButton = new javax.swing.JButton();
		this.paneWithEntitiesUploadedTable = new javax.swing.JScrollPane();
		this.loadedNumberOfEachEntityTable = new javax.swing.JTable();
		this.updateEntitiesStatusTableButton = new javax.swing.JButton();
		this.panelProgressBar = new javax.swing.JProgressBar();
		this.statusLabel = new javax.swing.JLabel();
		this.downloadTraslationsTamplateButton = new javax.swing.JButton();
		this.closeButton = new javax.swing.JButton();
		this.paneWithFilesUploadedResult = new javax.swing.JScrollPane();
		this.uploadedFilesResultTree = new javax.swing.JTree();
		this.paneWithFilesToUploadTable = new javax.swing.JScrollPane();
		this.filesToUploadTable = new javax.swing.JTable();

		this.fileChooser.setDialogType(javax.swing.JFileChooser.CUSTOM_DIALOG);
		this.fileChooser.setMultiSelectionEnabled(true);
		this.fileChooser.setName("jFileChooser1"); // NOI18N

		setBorder(javax.swing.BorderFactory
				.createBevelBorder(javax.swing.border.BevelBorder.RAISED));
		setMinimumSize(new java.awt.Dimension(0, 0));
		setOpaque(false);
		setPreferredSize(new java.awt.Dimension(800, 600));

		this.mainPanel.setBorder(javax.swing.BorderFactory
				.createTitledBorder(""));
		this.mainPanel.setName("panelStaticBulkDataLoad"); // NOI18N
		this.mainPanel.setPreferredSize(new java.awt.Dimension(780, 543));

		java.util.ResourceBundle bundle = java.util.ResourceBundle
				.getBundle("com/smartmatic/waffle/ecm/client/resources/ECMApp"); // NOI18N
		this.chooseFilesToUploadButton.setText(bundle
				.getString("BulkUploadSmttFilesPanel.button.choose")); // NOI18N
		this.chooseFilesToUploadButton.setName("buttonChooseStaticFiles"); // NOI18N
		this.chooseFilesToUploadButton
				.addActionListener(new java.awt.event.ActionListener() {
					@Override
					public void actionPerformed(java.awt.event.ActionEvent evt) {
						searchFilesToUploadActionPerformed();
					}
				});

		this.uploadFilesButton.setText(bundle
				.getString("BulkUploadSmttFilesPanel.button.upload")); // NOI18N
		this.uploadFilesButton.setEnabled(false);
		this.uploadFilesButton.setMaximumSize(new java.awt.Dimension(109, 30));
		this.uploadFilesButton.setMinimumSize(new java.awt.Dimension(109, 30));
		this.uploadFilesButton.setName("buttonExecuteUpload"); // NOI18N
		this.uploadFilesButton
				.setPreferredSize(new java.awt.Dimension(109, 30));
		this.uploadFilesButton
				.addActionListener(new java.awt.event.ActionListener() {
					@Override
					public void actionPerformed(java.awt.event.ActionEvent evt) {
						executeBulkUploadActionPerformed();
					}
				});

		this.clearFilesToUploadTableButton.setText(bundle
				.getString("BulkUploadSmttFilesPanel.button.clean")); // NOI18N
		this.clearFilesToUploadTableButton.setEnabled(false);
		this.clearFilesToUploadTableButton
				.setMaximumSize(new java.awt.Dimension(109, 30));
		this.clearFilesToUploadTableButton
				.setMinimumSize(new java.awt.Dimension(109, 30));
		this.clearFilesToUploadTableButton.setName("buttonResetTable"); // NOI18N
		this.clearFilesToUploadTableButton
				.setPreferredSize(new java.awt.Dimension(109, 30));
		this.clearFilesToUploadTableButton
				.addActionListener(new java.awt.event.ActionListener() {
					@Override
					public void actionPerformed(java.awt.event.ActionEvent evt) {
						cleanFilesToUploadTableActionPerformed();
					}
				});

		this.clearDataBaseButton.setText(bundle
				.getString("BulkUploadSmttFilesPanel.button.clean.database")); // NOI18N
		this.clearDataBaseButton
				.setMaximumSize(new java.awt.Dimension(109, 30));
		this.clearDataBaseButton
				.setMinimumSize(new java.awt.Dimension(109, 30));
		this.clearDataBaseButton.setName("buttonCleanAllData"); // NOI18N
		this.clearDataBaseButton.setPreferredSize(new java.awt.Dimension(109,
				30));
		this.clearDataBaseButton
				.addActionListener(new java.awt.event.ActionListener() {
					@Override
					public void actionPerformed(java.awt.event.ActionEvent evt) {
						clearDataBaseActionPerformed();
					}
				});
		this.clearDataBaseButton.setEnabled(false);

		this.paneWithEntitiesUploadedTable
				.setName("scrollPaneDataCounterTable"); // NOI18N

		this.loadedNumberOfEachEntityTable
				.setModel(new javax.swing.table.DefaultTableModel(
						new Object[][] {

						}, new String[] { "Entity", "Count" }) {
					boolean[] canEdit = new boolean[] { false, false };

					@Override
					public boolean isCellEditable(int rowIndex, int columnIndex) {
						return this.canEdit[columnIndex];
					}
				});
		this.loadedNumberOfEachEntityTable.setName("tableDataCounter"); // NOI18N
		this.loadedNumberOfEachEntityTable.getTableHeader()
				.setReorderingAllowed(false);
		this.paneWithEntitiesUploadedTable
				.setViewportView(this.loadedNumberOfEachEntityTable);
		this.loadedNumberOfEachEntityTable
				.getColumnModel()
				.getColumn(0)
				.setHeaderValue(
						bundle.getString("BulkUploadSmttFilesPanel.jTable2.columnModel.title0")); // NOI18N
		this.loadedNumberOfEachEntityTable
				.getColumnModel()
				.getColumn(1)
				.setHeaderValue(
						bundle.getString("BulkUploadSmttFilesPanel.jTable2.columnModel.title1")); // NOI18N

		this.updateEntitiesStatusTableButton.setText(bundle
				.getString("BulkUploadSmttFilesPanel.jButton2.text")); // NOI18N
		this.updateEntitiesStatusTableButton
				.setName("buttonRefreshDataCounterTable"); // NOI18N
		this.updateEntitiesStatusTableButton.setOpaque(true);
		this.updateEntitiesStatusTableButton
				.addActionListener(new java.awt.event.ActionListener() {
					@Override
					public void actionPerformed(java.awt.event.ActionEvent evt) {
						updateLoadedNumberOfEachEntityActionPerformed();
					}
				});
		this.updateEntitiesStatusTableButton.setEnabled(false);
		this.panelProgressBar.setName("jProgressBar1"); // NOI18N

		this.statusLabel.setName("jLabel2"); // NOI18N

		this.downloadTraslationsTamplateButton.setText(bundle
				.getString("BulkUploadSmttFilesPanel.jButton3.text")); // NOI18N
		this.downloadTraslationsTamplateButton
				.setName("buttonExportTranslation"); // NOI18N
		this.downloadTraslationsTamplateButton
				.addActionListener(new java.awt.event.ActionListener() {
					@Override
					public void actionPerformed(java.awt.event.ActionEvent evt) {
						downloadTranslationTemplateActionPerformed();
					}
				});
		this.downloadTraslationsTamplateButton.setEnabled(false);

		this.closeButton.setText(bundle
				.getString("BulkUploadSmttFilesPanel.jButton4.text")); // NOI18N
		this.closeButton.setName("buttonClose"); // NOI18N
		this.closeButton.addActionListener(new java.awt.event.ActionListener() {
			@Override
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				closePanelActionPerformed();
			}
		});

		this.paneWithFilesUploadedResult.setMaximumSize(new java.awt.Dimension(
				800, 32767));
		this.paneWithFilesUploadedResult.setName("scrollPaneResults"); // NOI18N
		this.paneWithFilesUploadedResult
				.setPreferredSize(new java.awt.Dimension(780, 290));

		this.uploadedFilesResultTree.setAutoscrolls(true);
		this.uploadedFilesResultTree.setMaximumSize(new java.awt.Dimension(
				2147483647, 0));
		this.uploadedFilesResultTree.setName("treeUploadResult"); // NOI18N
		this.paneWithFilesUploadedResult
				.setViewportView(this.uploadedFilesResultTree);
		this.paneWithFilesUploadedResult.setVisible(false);

		this.paneWithFilesToUploadTable.setName("scrollPaneUploadedFilesTable"); // NOI18N

		this.filesToUploadTable
				.setModel(new javax.swing.table.DefaultTableModel(
						new Object[][] {

						}, new String[] { "Tipo de archivo",
								"Nombre de archivo", "Signature Validation" }) {
					boolean[] canEdit = new boolean[] { false, false, false };

					@Override
					public boolean isCellEditable(int rowIndex, int columnIndex) {
						return this.canEdit[columnIndex];
					}
				});
		this.filesToUploadTable.setMaximumSize(new java.awt.Dimension(780,
				32767));
		this.filesToUploadTable
				.setMinimumSize(new java.awt.Dimension(760, 100));
		this.filesToUploadTable.setName("tableUploadedFiles"); // NOI18N
		this.filesToUploadTable.getTableHeader().setReorderingAllowed(false);
		this.paneWithFilesToUploadTable
				.setViewportView(this.filesToUploadTable);
		this.filesToUploadTable
				.getColumnModel()
				.getColumn(0)
				.setHeaderValue(
						bundle.getString("BulkUploadSmttFilesPanel.table.column0")); // NOI18N
		this.filesToUploadTable
				.getColumnModel()
				.getColumn(1)
				.setHeaderValue(
						bundle.getString("BulkUploadSmttFilesPanel.table.column1")); // NOI18N
		this.filesToUploadTable
				.getColumnModel()
				.getColumn(2)
				.setHeaderValue(
						bundle.getString("BulkUploadSmttFilesPanel.jTable2.columnModel.title4")); // NOI18N

		javax.swing.GroupLayout jPanel1Layout = new javax.swing.GroupLayout(
				this.mainPanel);
		this.mainPanel.setLayout(jPanel1Layout);
		jPanel1Layout
				.setHorizontalGroup(jPanel1Layout
						.createParallelGroup(
								javax.swing.GroupLayout.Alignment.LEADING)
						.addGroup(
								jPanel1Layout
										.createSequentialGroup()
										.addGroup(
												jPanel1Layout
														.createParallelGroup(
																javax.swing.GroupLayout.Alignment.TRAILING,
																false)
														.addComponent(
																this.updateEntitiesStatusTableButton,
																javax.swing.GroupLayout.DEFAULT_SIZE,
																javax.swing.GroupLayout.DEFAULT_SIZE,
																Short.MAX_VALUE)
														.addComponent(
																this.chooseFilesToUploadButton,
																javax.swing.GroupLayout.PREFERRED_SIZE,
																292,
																javax.swing.GroupLayout.PREFERRED_SIZE))
										.addGap(18, 18, 18)
										.addComponent(
												this.paneWithEntitiesUploadedTable,
												javax.swing.GroupLayout.DEFAULT_SIZE,
												450, Short.MAX_VALUE))
						.addGroup(
								jPanel1Layout
										.createSequentialGroup()
										.addGap(207, 207, 207)
										.addComponent(
												this.closeButton,
												javax.swing.GroupLayout.DEFAULT_SIZE,
												328, Short.MAX_VALUE)
										.addGap(225, 225, 225))
						.addGroup(
								jPanel1Layout
										.createSequentialGroup()
										.addComponent(
												this.clearDataBaseButton,
												javax.swing.GroupLayout.DEFAULT_SIZE,
												291, Short.MAX_VALUE)
										.addPreferredGap(
												javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
										.addComponent(
												this.downloadTraslationsTamplateButton,
												javax.swing.GroupLayout.DEFAULT_SIZE,
												130, Short.MAX_VALUE)
										.addGap(12, 12, 12)
										.addComponent(
												this.uploadFilesButton,
												javax.swing.GroupLayout.DEFAULT_SIZE,
												140, Short.MAX_VALUE)
										.addPreferredGap(
												javax.swing.LayoutStyle.ComponentPlacement.RELATED)
										.addComponent(
												this.clearFilesToUploadTableButton,
												javax.swing.GroupLayout.PREFERRED_SIZE,
												169,
												javax.swing.GroupLayout.PREFERRED_SIZE))
						.addGroup(
								javax.swing.GroupLayout.Alignment.TRAILING,
								jPanel1Layout
										.createSequentialGroup()
										.addContainerGap()
										.addComponent(
												this.statusLabel,
												javax.swing.GroupLayout.DEFAULT_SIZE,
												736, Short.MAX_VALUE)
										.addContainerGap())
						.addGroup(
								jPanel1Layout
										.createSequentialGroup()
										.addContainerGap()
										.addComponent(
												this.panelProgressBar,
												javax.swing.GroupLayout.DEFAULT_SIZE,
												736, Short.MAX_VALUE)
										.addContainerGap())
						.addComponent(this.paneWithFilesToUploadTable,
								javax.swing.GroupLayout.DEFAULT_SIZE, 760,
								Short.MAX_VALUE)
						.addComponent(this.paneWithFilesUploadedResult,
								javax.swing.GroupLayout.DEFAULT_SIZE, 760,
								Short.MAX_VALUE));
		jPanel1Layout
				.setVerticalGroup(jPanel1Layout
						.createParallelGroup(
								javax.swing.GroupLayout.Alignment.LEADING)
						.addGroup(
								jPanel1Layout
										.createSequentialGroup()
										.addGroup(
												jPanel1Layout
														.createParallelGroup(
																javax.swing.GroupLayout.Alignment.LEADING)
														.addGroup(
																jPanel1Layout
																		.createSequentialGroup()
																		.addContainerGap()
																		.addComponent(
																				this.chooseFilesToUploadButton)
																		.addPreferredGap(
																				javax.swing.LayoutStyle.ComponentPlacement.RELATED)
																		.addComponent(
																				this.updateEntitiesStatusTableButton))
														.addComponent(
																this.paneWithEntitiesUploadedTable,
																javax.swing.GroupLayout.PREFERRED_SIZE,
																89,
																javax.swing.GroupLayout.PREFERRED_SIZE))
										.addGap(18, 18, 18)
										.addComponent(
												this.paneWithFilesToUploadTable,
												javax.swing.GroupLayout.DEFAULT_SIZE,
												119, Short.MAX_VALUE)
										.addPreferredGap(
												javax.swing.LayoutStyle.ComponentPlacement.RELATED)
										.addComponent(
												this.paneWithFilesUploadedResult,
												javax.swing.GroupLayout.DEFAULT_SIZE,
												147, Short.MAX_VALUE)
										.addGap(18, 18, 18)
										.addComponent(
												this.panelProgressBar,
												javax.swing.GroupLayout.PREFERRED_SIZE,
												javax.swing.GroupLayout.DEFAULT_SIZE,
												javax.swing.GroupLayout.PREFERRED_SIZE)
										.addPreferredGap(
												javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
										.addComponent(
												this.statusLabel,
												javax.swing.GroupLayout.PREFERRED_SIZE,
												18,
												javax.swing.GroupLayout.PREFERRED_SIZE)
										.addPreferredGap(
												javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
										.addGroup(
												jPanel1Layout
														.createParallelGroup(
																javax.swing.GroupLayout.Alignment.TRAILING)
														.addGroup(
																jPanel1Layout
																		.createParallelGroup(
																				javax.swing.GroupLayout.Alignment.BASELINE)
																		.addComponent(
																				this.clearFilesToUploadTableButton,
																				javax.swing.GroupLayout.PREFERRED_SIZE,
																				javax.swing.GroupLayout.DEFAULT_SIZE,
																				javax.swing.GroupLayout.PREFERRED_SIZE)
																		.addComponent(
																				this.uploadFilesButton,
																				javax.swing.GroupLayout.PREFERRED_SIZE,
																				javax.swing.GroupLayout.DEFAULT_SIZE,
																				javax.swing.GroupLayout.PREFERRED_SIZE)
																		.addComponent(
																				this.clearDataBaseButton,
																				javax.swing.GroupLayout.PREFERRED_SIZE,
																				javax.swing.GroupLayout.DEFAULT_SIZE,
																				javax.swing.GroupLayout.PREFERRED_SIZE))
														.addComponent(
																this.downloadTraslationsTamplateButton))
										.addPreferredGap(
												javax.swing.LayoutStyle.ComponentPlacement.RELATED)
										.addComponent(this.closeButton)
										.addGap(6, 6, 6)));

		jPanel1Layout.linkSize(javax.swing.SwingConstants.VERTICAL,
				new java.awt.Component[] { this.uploadFilesButton,
						this.clearFilesToUploadTableButton });

		this.paneWithFilesToUploadTable.getAccessibleContext()
				.setAccessibleParent(this.paneWithFilesToUploadTable);

		javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
		setLayout(layout);
		layout.setHorizontalGroup(layout.createParallelGroup(
				javax.swing.GroupLayout.Alignment.LEADING).addGroup(
				layout.createSequentialGroup()
						.addContainerGap()
						.addComponent(this.mainPanel,
								javax.swing.GroupLayout.DEFAULT_SIZE, 772,
								Short.MAX_VALUE).addContainerGap()));
		layout.setVerticalGroup(layout.createParallelGroup(
				javax.swing.GroupLayout.Alignment.LEADING).addGroup(
				layout.createSequentialGroup()
						.addContainerGap()
						.addComponent(this.mainPanel,
								javax.swing.GroupLayout.PREFERRED_SIZE, 543,
								javax.swing.GroupLayout.PREFERRED_SIZE)
						.addContainerGap(41, Short.MAX_VALUE)));
		this.rootTreeNode = new DefaultMutableTreeNode(
				this.resourceBundle
						.getString("BulkUploadSmttFilesPanel.node.root"));

		javax.swing.tree.DefaultTreeModel model = new javax.swing.tree.DefaultTreeModel(
				this.rootTreeNode);
		this.uploadedFilesResultTree.setModel(model);
		this.uploadedFilesResultTree.setCellRenderer(new TreeRenderer());
	}// </editor-fold>//GEN-END:initComponents

	private javax.swing.JButton chooseFilesToUploadButton;

	private javax.swing.JButton clearDataBaseButton;

	private javax.swing.JButton updateEntitiesStatusTableButton;

	private javax.swing.JButton uploadFilesButton;

	private javax.swing.JButton clearFilesToUploadTableButton;

	private javax.swing.JButton downloadTraslationsTamplateButton;

	private javax.swing.JButton closeButton;

	private javax.swing.JFileChooser fileChooser;

	private javax.swing.JLabel statusLabel;

	private javax.swing.JPanel mainPanel;

	private javax.swing.JProgressBar panelProgressBar;

	private javax.swing.JTable filesToUploadTable;

	private javax.swing.JTable loadedNumberOfEachEntityTable;

	private javax.swing.JTree uploadedFilesResultTree;

	private javax.swing.JScrollPane paneWithFilesUploadedResult;

	private javax.swing.JScrollPane paneWithFilesToUploadTable;

	private javax.swing.JScrollPane paneWithEntitiesUploadedTable;

	private DefaultMutableTreeNode rootTreeNode;

	private Map<SmttFileType, File> validFilesToUploadMap;

	private BulkUploadEMLFilesPanel bulkUploadCodiFilesPanel;

	private boolean firstExecution;

	private boolean isSomeEntityLoaded;

	private boolean isSmttDataIsLoaded;
}
