/**
 * CellButtonRenderer.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.ui;

import java.awt.Component;

import javax.swing.JButton;
import javax.swing.JTable;
import javax.swing.UIManager;
import javax.swing.table.TableCellRenderer;

/**
 * Class that specifies how to render a cell button for the table in the
 * <code>RegionLevelNavigationWidget</code>.
 * 
 * @author Mario Bislick (mario.bislick@smartmatic.com)
 */
public class EligibleOptionCellButtonRenderer extends JButton implements
		TableCellRenderer {

	private static final long serialVersionUID = -9220726245779095864L;

	private String buttonText = null;

	/**
	 * Instantiates a new cell button renderer.
	 * 
	 * @param text
	 *            the text
	 */
	public EligibleOptionCellButtonRenderer(String text) {
		setOpaque(true);
		this.buttonText = text;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * javax.swing.table.TableCellRenderer#getTableCellRendererComponent(javax
	 * .swing.JTable, java.lang.Object, boolean, boolean, int, int)
	 */
	@Override
	public Component getTableCellRendererComponent(JTable table, Object value,
			boolean isSelected, boolean hasFocus, int row, int column) {
		if (isSelected) {
			setForeground(table.getSelectionForeground());
			setBackground(table.getSelectionBackground());
		} else {
			setForeground(table.getForeground());
			setBackground(UIManager.getColor("Button.background"));
		}
		if (this.buttonText == null) {
			setText((value == null) ? "" : value.toString());
		} else {
			setText(this.buttonText);
		}
		return this;
	}
}