/**
 * EligibleOptionCellEditor.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.ui;

import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ResourceBundle;

import javax.swing.AbstractCellEditor;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JPanel;
import javax.swing.JTable;
import javax.swing.table.TableCellEditor;

import com.smartmatic.waffle.domain.eligibleoption.EligibleOptionData;

/**
 * Controller class for the edit button in the Eligible option editor.
 */
public class EligibleOptionCellEditor extends AbstractCellEditor implements
		TableCellEditor, ActionListener {

	/**
	 * Creates a new Eligible Option Cell Editor, linking with its parent
	 * eligibleOptionEditorPanel, and editable property.
	 */
	public EligibleOptionCellEditor(
			EligibleOptionEditorPanel eligibleOptionEditorPanel,
			boolean isCandidateSelected) {

		this.eligibleOptionEditorPanel = eligibleOptionEditorPanel;

		this.resourceBundle = java.util.ResourceBundle
				.getBundle("com/smartmatic/waffle/ecm/client/resources/ECMApp");

		this.editButton = new JButton();
		this.editButton.setText("Edit");
		this.editButton.setActionCommand(EDIT);
		this.editButton.addActionListener(this);
		this.editButton.setBorderPainted(false);
		this.isCandidateSelected = isCandidateSelected;

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	@Override
	public void actionPerformed(ActionEvent e) {
		String title;
		if (EDIT.equals(e.getActionCommand())) {

			this.eligibleOptionData = this.eligibleOptionEditorPanel
					.getEligibleOptionDataAtRow(this.rowToEdit);
			this.dialogPanel = new JDialog();

			if (this.isCandidateSelected) {
				title = "EligibleOptionCandidateEditorDialog.title";
				this.EligibleOptionEditorDialog = new EligibleOptionCandidateEditorDialog(
						this.eligibleOptionData,
						this.eligibleOptionEditorPanel, this.rowToEdit);
				this.dialogPanel.setName("dialogCandidateEditor");
			} else {
				this.EligibleOptionEditorDialog = new EligibleOptionPartyEditorDialog(
						this.eligibleOptionData,
						this.eligibleOptionEditorPanel, this.rowToEdit);
				title = "EligibleOptionPartyEditorDialog.title";
				this.dialogPanel.setName("dialogListEditor");
			}

			//
			this.getCellEditorValue();

			this.dialogPanel.setTitle(this.resourceBundle.getString(title));
			this.dialogPanel.add(this.EligibleOptionEditorDialog);
			this.dialogPanel.setResizable(false);
			this.dialogPanel.setAlwaysOnTop(true);
			this.dialogPanel.setModal(true);
			this.dialogPanel.pack();
			this.dialogPanel
					.setLocationRelativeTo(this.eligibleOptionEditorPanel);
			this.dialogPanel.setVisible(true);

			// Make the renderer reappear.
			fireEditingStopped();

		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.CellEditor#getCellEditorValue()
	 */
	@Override
	public Object getCellEditorValue() {
		return this.eligibleOptionData;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * javax.swing.table.TableCellEditor#getTableCellEditorComponent(javax.swing
	 * .JTable, java.lang.Object, boolean, int, int)
	 */
	@Override
	public Component getTableCellEditorComponent(JTable table, Object value,
			boolean isSelected, int rowToEdit, int column) {
		this.rowToEdit = rowToEdit;
		this.eligibleOptionData = this.eligibleOptionEditorPanel
				.getEligibleOptionDataAtRow(rowToEdit);
		this.editButton
				.setText(this.resourceBundle
						.getString("EligibleOptionCandidateEditorDialog.candidatesTable.modifying.text"));
		return this.editButton;
	}

	private static final long serialVersionUID = 6658477586186716128L;

	private static final String EDIT = "edit";

	private EligibleOptionData eligibleOptionData;

	private EligibleOptionEditorPanel eligibleOptionEditorPanel;

	private JPanel EligibleOptionEditorDialog;

	private ResourceBundle resourceBundle;

	private int rowToEdit;

	private JButton editButton;

	private JDialog dialogPanel;

	private boolean isCandidateSelected;
}