/**
 * EligibleOptionPartyEditorDialog.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */

package com.smartmatic.waffle.ecm.client.ui;

import java.awt.Component;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.util.Calendar;
import java.util.ResourceBundle;

import javax.swing.JDialog;

import com.smartmatic.waffle.domain.eligibleoption.EligibleOptionData;
import com.smartmatic.waffle.ecm.client.ECMClientSideConstants;
import com.smartmatic.waffle.ecm.client.ui.controller.EligibleOptionEditorLogger;
import com.smartmatic.waffle.ecm.ui.util.ECMOptionPane;
import com.smartmatic.waffle.ecm.ui.util.UnicodeTextField;

/**
 * The Class is used to load and draw all the necessary components for the EO
 * Party Editor Dialog.
 */
public class EligibleOptionPartyEditorDialog extends javax.swing.JPanel {

	/**
	 * Creates new EligibleOptionPartyEditorDialog form.
	 * 
	 * @param eligibleOptionToEdit
	 *            the eligible option to edit
	 * @param eligibleOptionEditorPanel
	 *            the eligibleOptionEditorPanel
	 * @param rowToEdit
	 *            the rowToEdit
	 */
	public EligibleOptionPartyEditorDialog(
			EligibleOptionData eligibleOptionToEdit,
			EligibleOptionEditorPanel eligibleOptionEditorPanel, int rowToEdit) {
		initComponents();

		this.eligibleOptionToEdit = eligibleOptionToEdit;
		this.eligibleOptionEditorPanel = eligibleOptionEditorPanel;
		this.rowToEdit = rowToEdit;
		this.resourceBundle = java.util.ResourceBundle
				.getBundle("com/smartmatic/waffle/ecm/client/resources/ECMApp"); // NOI18N
		initValues();
	}

	/**
	 * Method to return the eligible option object to edit.
	 * 
	 * @return the eligible option object.
	 */
	public EligibleOptionData getEligibleOption() {
		return this.eligibleOptionToEdit;
	}

	/**
	 * Shows an error message to the user.
	 */
	public void showErrorMessage() {
		ECMOptionPane
				.showMessageDialog(
						this,
						this.resourceBundle
								.getString("EligibleOptionEditorPanel.updateEligibleOption.error.message"),
						this.resourceBundle.getString("ErrorMessage.title"),
						ECMOptionPane.ERROR_MESSAGE, ECMOptionPane.ERROR_DIALOG);
	}

	/**
	 * Inits the dialog fields.
	 */
	private void initValues() {
		if (!this.eligibleOptionToEdit.getBallotName().isEmpty()) {
			this.ballotNameText.setText(this.eligibleOptionToEdit
					.getBallotName());
		} else {
			this.ballotNameText.setText("-");
		}

		this.contestInfoLabel.setText("<html>"
				+ this.eligibleOptionToEdit.getContest().getName() + "</html>");

		String collegeName = this.eligibleOptionToEdit.getContest()
				.getCollege();

		if (collegeName != null) {
			this.collegeInfoLabel.setText("<html>" + collegeName + "</html>");
		}

		// This panel must have the same name as the EligibleOptionEditorDialog
		// to be QFTest-able
		this.eligibleOptionEditorPanel.setName("panelEligibleOptionEditor");
	}

	/**
	 * Enable/Disable the update button.
	 * 
	 * @param enable
	 *            true for enable or false to disable
	 */
	private void enableUpdateButton(boolean enable) {
		this.updateButton.setEnabled(enable);
	}

	/**
	 * Start the process to update the new party name in database.
	 */
	private void updatePartyActionPerformed() {
		String newBallotName = this.ballotNameText.getText();
		String oldBallotName = this.eligibleOptionToEdit.getBallotName();
		if ((newBallotName != null) && (!newBallotName.isEmpty())) {
			int opt = ECMOptionPane
					.showConfirmDialog(
							this,
							this.resourceBundle
									.getString("EligibleOptionCandidateEditorDialog.updateConfirmationDialog.message"),
							this.resourceBundle
									.getString("ConfirmationMessage.title"),
							ECMOptionPane.YES_NO_OPTION,
							ECMOptionPane.CONFIRM_DIALOG);
			if (opt == ECMOptionPane.OK_OPTION) {

				this.eligibleOptionToEdit.setBallotName(newBallotName);

				UpdateEligibleOptionController updateEligibleOptionController = new UpdateEligibleOptionController(
						this);
				updateEligibleOptionController.startWorker();

				this.eligibleOptionEditorPanel.updateRow(this.rowToEdit,
						this.eligibleOptionToEdit, false);

				EligibleOptionEditorLogger.printMessageTologger(System
						.getProperty("line.separator")
						+ "Updating list name"
						+ System.getProperty("line.separator")

						+ "ID: "
						+ this.eligibleOptionToEdit.getCustomCode()
						+ System.getProperty("line.separator")
						+ "Old value: "
						+ oldBallotName
						+ System.getProperty("line.separator")
						+ "New value: "
						+ newBallotName
						+ System.getProperty("line.separator")

						+ "Updating date: " + Calendar.getInstance().getTime());

				cancelActionPerformed();

			}
		} else {
			ECMOptionPane
					.showMessageDialog(
							this,
							this.resourceBundle
									.getString("EligibleOptionEditorPanel.updateEligibleOption.party.empty.message"),
							this.resourceBundle.getString("ErrorMessage.title"),
							ECMOptionPane.ERROR_MESSAGE,
							ECMOptionPane.ERROR_DIALOG);
		}

	}

	/**
	 * Omits the change and closes the panel
	 */
	private void cancelActionPerformed() {
		Component parent = this.getParent();
		while (!parent.getClass().equals(JDialog.class)) {
			parent = parent.getParent();
		}

		parent.setVisible(false);
	}

	/**
	 * This method is called from within the constructor to initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is always
	 * regenerated by the Form Editor.
	 */
	private void initComponents() {

		this.ballotNameText = new UnicodeTextField(
				ECMClientSideConstants.MAX_CHARACTERS_ELIGIBLE_OPTION_PARTYNAME);
		this.cancelButton = new javax.swing.JButton();
		this.updateButton = new javax.swing.JButton();
		this.nameLabel = new javax.swing.JLabel();
		this.collegeLabel = new javax.swing.JLabel();
		this.contestLabel = new javax.swing.JLabel();
		this.collegeInfoLabel = new javax.swing.JLabel();
		this.contestInfoLabel = new javax.swing.JLabel();

		java.util.ResourceBundle resourceBundle = java.util.ResourceBundle
				.getBundle("com/smartmatic/waffle/ecm/client/resources/ECMApp"); // NOI18N

		this.ballotNameText.setName("textFieldPartyName");

		this.ballotNameText.addKeyListener(new KeyListener() {

			@Override
			public void keyTyped(KeyEvent e) {
				UnicodeTextField unicodeTextField = (UnicodeTextField) e
						.getSource();

				enableUpdateButton(unicodeTextField.isReadyToSave());
			}

			@Override
			public void keyPressed(KeyEvent e) {

			}

			@Override
			public void keyReleased(KeyEvent e) {
				UnicodeTextField unicodeTextField = (UnicodeTextField) e
						.getSource();

				enableUpdateButton(unicodeTextField.isReadyToSave());
			}
		});
		this.cancelButton
				.setText(resourceBundle
						.getString("EligibleOptionPartyEditorDialog.cancelButton.text")); // NOI18N
		this.cancelButton
				.setActionCommand(resourceBundle
						.getString("EligibleOptionPartyEditorDialog.cancelButton.actionCommand")); // NOI18N
		this.cancelButton
				.addActionListener(new java.awt.event.ActionListener() {
					@Override
					public void actionPerformed(java.awt.event.ActionEvent evt) {
						cancelActionPerformed();
					}
				});
		this.cancelButton.setName("buttonCancelParty");

		this.updateButton.setText(resourceBundle
				.getString("EligibleOptionPartyEditorDialog.update.text")); // NOI18N
		this.updateButton
				.addActionListener(new java.awt.event.ActionListener() {
					@Override
					public void actionPerformed(java.awt.event.ActionEvent evt) {
						updatePartyActionPerformed();
					}
				});

		this.updateButton.setName("buttonUpdateParty");

		this.nameLabel.setText(resourceBundle
				.getString("EligibleOptionPartyEditorDialog.jLabel1.text")); // NOI18N
		this.nameLabel.setName("labelName");

		this.collegeLabel
				.setText(resourceBundle
						.getString("EligibleOptionPartyEditorDialog.collegeTitle.text")); // NOI18N
		this.collegeLabel.setName("labelCollege");

		this.contestLabel
				.setText(resourceBundle
						.getString("EligibleOptionPartyEditorDialog.contestTitle.text")); // NOI18N
		this.contestLabel.setName("labelContest");

		javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
		this.setLayout(layout);
		layout.setHorizontalGroup(layout
				.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addGroup(
						layout.createSequentialGroup()
								.addGap(23, 23, 23)
								.addGroup(
										layout.createParallelGroup(
												javax.swing.GroupLayout.Alignment.TRAILING,
												false)
												.addGroup(
														javax.swing.GroupLayout.Alignment.LEADING,
														layout.createSequentialGroup()
																.addGroup(
																		layout.createParallelGroup(
																				javax.swing.GroupLayout.Alignment.LEADING,
																				false)
																				.addComponent(
																						this.collegeLabel,
																						javax.swing.GroupLayout.PREFERRED_SIZE,
																						75,
																						javax.swing.GroupLayout.PREFERRED_SIZE)
																				.addComponent(
																						this.contestLabel,
																						javax.swing.GroupLayout.PREFERRED_SIZE,
																						75,
																						javax.swing.GroupLayout.PREFERRED_SIZE)
																				.addComponent(
																						this.nameLabel))
																.addPreferredGap(
																		javax.swing.LayoutStyle.ComponentPlacement.RELATED)
																.addGroup(
																		layout.createParallelGroup(
																				javax.swing.GroupLayout.Alignment.LEADING)
																				.addComponent(
																						this.collegeInfoLabel,
																						javax.swing.GroupLayout.PREFERRED_SIZE,
																						350,
																						javax.swing.GroupLayout.PREFERRED_SIZE)
																				.addComponent(
																						this.contestInfoLabel,
																						javax.swing.GroupLayout.PREFERRED_SIZE,
																						350,
																						javax.swing.GroupLayout.PREFERRED_SIZE)
																				.addComponent(
																						this.ballotNameText,
																						javax.swing.GroupLayout.PREFERRED_SIZE,
																						350,
																						javax.swing.GroupLayout.PREFERRED_SIZE)
																				.addGroup(
																						javax.swing.GroupLayout.Alignment.TRAILING,
																						layout.createSequentialGroup()
																								.addComponent(
																										this.updateButton)
																								.addPreferredGap(
																										javax.swing.LayoutStyle.ComponentPlacement.RELATED)
																								.addComponent(
																										this.cancelButton)))))
								.addContainerGap(13, Short.MAX_VALUE)));
		layout.setVerticalGroup(layout
				.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addGroup(
						layout.createSequentialGroup()
								.addGap(18, 18, 18)
								.addGroup(
										layout.createParallelGroup(
												javax.swing.GroupLayout.Alignment.BASELINE)
												.addComponent(this.contestLabel)
												.addComponent(
														this.contestInfoLabel,
														0, 30, Short.MAX_VALUE))
								.addPreferredGap(
										javax.swing.LayoutStyle.ComponentPlacement.RELATED)
								.addGroup(
										layout.createParallelGroup(
												javax.swing.GroupLayout.Alignment.BASELINE)
												.addComponent(this.collegeLabel)
												.addComponent(
														this.collegeInfoLabel,
														0, 30, Short.MAX_VALUE))
								.addPreferredGap(
										javax.swing.LayoutStyle.ComponentPlacement.RELATED)
								.addGroup(
										layout.createParallelGroup(
												javax.swing.GroupLayout.Alignment.BASELINE)
												.addComponent(this.nameLabel)
												.addComponent(
														this.ballotNameText,
														javax.swing.GroupLayout.PREFERRED_SIZE,
														javax.swing.GroupLayout.DEFAULT_SIZE,
														javax.swing.GroupLayout.PREFERRED_SIZE))
								.addPreferredGap(
										javax.swing.LayoutStyle.ComponentPlacement.RELATED)
								.addGap(18, 18, 18)
								.addGroup(
										layout.createParallelGroup(
												javax.swing.GroupLayout.Alignment.BASELINE)
												.addComponent(this.cancelButton)
												.addComponent(this.updateButton))
								.addContainerGap(15, Short.MAX_VALUE)));
	}

	private static final long serialVersionUID = -6815649944474754191L;

	private EligibleOptionData eligibleOptionToEdit;

	private ResourceBundle resourceBundle;

	private int rowToEdit;

	private EligibleOptionEditorPanel eligibleOptionEditorPanel;

	private javax.swing.JLabel collegeInfoLabel;

	private javax.swing.JLabel contestInfoLabel;

	private javax.swing.JLabel nameLabel;

	private UnicodeTextField ballotNameText;

	private javax.swing.JButton updateButton;

	private javax.swing.JButton cancelButton;

	private javax.swing.JLabel collegeLabel;

	private javax.swing.JLabel contestLabel;

}
