/**
 * GUIGenerationInterface.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */

package com.smartmatic.waffle.ecm.client.ui;

import java.util.List;
import java.util.ResourceBundle;

import javax.xml.datatype.Duration;

/**
 * Define an interface to modify common GUI components between screens.
 */
public interface GUIGenerationInterface {

	/***
	 * Method to define a functionality to show a message to user when there is
	 * an error during usb generation process.
	 * 
	 * @param messageError
	 *            -Error message to show to user.
	 */
	void showErrorMessage(String messageError);

	/**
	 * Shows message of many devices connected
	 */
	void showMessageManyDevicesConnected();

	/**
	 * Shows confirmation dialog
	 * 
	 * @param mountedPath
	 *            full path where memory is mounted
	 * @return
	 */
	int showConfirmDialogStartGeneration(String mountedPath);

	/**
	 * Start generation process on UI
	 */
	void preparePanelToProcess();

	/**
	 * Especifies if it is necesary to generate an init key during the process
	 * 
	 * @return
	 */
	boolean getGenerateNewInitKey();

	/**
	 * Method to define a functionality must be executed when the usb generation
	 * has finished.
	 * 
	 * @param duration
	 *            Duration of the process
	 */
	void finishProcess(Duration duration);

	/**
	 * Method to define the visibility of pendrive's Ok label.
	 * 
	 * @param value
	 *            true for visible otherwise false
	 */
	void setPendriveOkLabelVisible(boolean value);

	/***
	 * Method to define a functionality to make visible or not the progress bar.
	 * 
	 * @param value
	 *            -value to indicate if progress bar will be visible or not.
	 */
	void setMainProgressBarVisible(boolean value);

	/**
	 * Method to get the visibility status of the main progress bar.
	 * 
	 * @return a boolean indicating the status.
	 */
	boolean isMainProgressBarVisible();

	/**
	 * Method to set the document image label visibility.
	 * 
	 * @param value
	 *            the new document image label visible
	 */
	void setDocumentImageLabelVisible(boolean value);

	/**
	 * Method to get the visibility status of the document's image label.
	 * 
	 * @return a boolean indicating the status
	 */
	boolean isDocumentImageLabelVisible();

	/**
	 * Method to set the message of the status process label.
	 * 
	 * @param processed
	 *            the number of items processed
	 * @param toProcess
	 *            the total number of items to be processed
	 */
	void setLabelStatusProcessingContests(int processed, int toProcess);

	/**
	 * Method to show or hide the label status process.
	 * 
	 * @param value
	 *            a boolean
	 */
	void showLabelStatusProccess(boolean value);

	/**
	 * Method to set the message of the status process label.
	 * 
	 * @param message
	 *            the message to set on label
	 */
	void setLabelStatusProcess(String message);

	/**
	 * Method to return the a list of selected objects.
	 * 
	 * @return the list of objects
	 */
	List<Object> getSelectedObjects();

	/**
	 * Method to set the value of the progress bar.
	 * 
	 * @param value
	 *            the new progress bar value
	 */
	void setProgressBarValue(int value);

	/**
	 * Method to set the bad icon into the pendrive label.
	 */
	void setVerificationIconInPendriveOkLabel();

	/**
	 * Method to set the copy OS icon into the pendrive label.
	 */
	void setCopyOsIconInPendriveOkLabel();

	/**
	 * Method to set the sync and unmount icon into the pendrive label.
	 */
	void setSyncAndUnmountIconInPendriveOkLabel();

	/***
	 * Method to define a functionality to show to user the getting contest info
	 * icon.
	 */
	void setPrepareContestIconInPendriveOkLabel();

	/**
	 * Gets resources bundle.
	 * 
	 * @return Resources bundle.
	 */
	ResourceBundle getBundle();
}
