/**
 * ImagesUploadController.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.ui;

import java.io.File;

import org.apache.commons.lang.StringUtils;

import com.smartmatic.waffle.ecm.client.ui.common.AwtOperationType;
import com.smartmatic.waffle.ecm.client.ui.common.IAwtOperationListener;
import com.smartmatic.waffle.ecm.client.worker.ImagesUploadWorker;

/**
 * Controller class that creates and starts the worker thread to upload the
 * Voting Device OS Image.
 */
public class ImagesUploadController implements IAwtOperationListener {

	/** ImagesUploadPanel reference. */
	private ImagesUploadPanel imagesUploadPanel;

	/** ImagesUploadWorker reference. */
	private ImagesUploadWorker imagesUploadWorker;

	/** Source file to upload. */
	private File srcFile;

	/** Destination file where the image will be uploaded. */
	private File destFile;

	/** ImagesUploadGUIComponents reference. */
	private ImagesUploadGUIComponents imagesUploadGUIComponents;

	/**
	 * Instantiates a new ImagesUploadController.
	 * 
	 * @param imagesUploadPanel
	 *            ImagesUploadPanel reference
	 * @param srcImagePath
	 *            Path to source file to upload.
	 * @param destImageFile
	 *            Destination file where the image will be uploaded
	 * @param imagesUploadGUIComponents
	 *            ImagesUploadGUIComponents reference.
	 */
	public ImagesUploadController(ImagesUploadPanel imagesUploadPanel,
			String srcImagePath, File destImageFile,
			ImagesUploadGUIComponents imagesUploadGUIComponents) {
		this.imagesUploadPanel = imagesUploadPanel;
		this.imagesUploadGUIComponents = imagesUploadGUIComponents;
		this.srcFile = new File(srcImagePath);
		this.destFile = destImageFile;
	}

	/**
	 * Method that starts the worker that does the real backend functionality
	 * work.
	 */
	public void startWorker() {

		this.imagesUploadWorker = new ImagesUploadWorker(this.srcFile,
				this.destFile);

		this.imagesUploadWorker.addListener(this);

		Thread imagesUploadWorkerThread = new Thread(this.imagesUploadWorker,
				"ImagesUploadWorker");

		imagesUploadWorkerThread.start();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.smartmatic.waffle.ecm.client.ui.common.IAwtOperationListener#awtOperation
	 * (com.smartmatic.waffle.ecm.client.ui.common.AwtOperationType)
	 */
	@Override
	public void awtOperation(AwtOperationType awtOperationType) {

		switch (awtOperationType) {

		case UPDATE_PROGRESS_BAR: {
			this.imagesUploadPanel.updateProgressBar(
					this.imagesUploadWorker.getProgressBarValue(),
					this.imagesUploadGUIComponents);
		}
			break;

		case UPDATE_COMPONENTS:
			this.imagesUploadPanel
					.updateComponentsAfterUpload(this.imagesUploadGUIComponents);
			break;

		case SHOW_ERROR_MESSAGE:
			if (this.destFile.exists()) {
				this.destFile.delete();
			}
			this.imagesUploadGUIComponents.getjImageTextFieldImage().setText(
					StringUtils.EMPTY);
			this.imagesUploadPanel.showGenericErrorMessage();
			break;
		}

	}

}
