/**
 * KeyGenerationPanel.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */

package com.smartmatic.waffle.ecm.client.ui;

import java.io.File;
import java.util.HashSet;
import java.util.ResourceBundle;

import javax.swing.JFileChooser;
import javax.swing.filechooser.FileFilter;

import com.smartmatic.waffle.domain.security.FunctionalityDefinitionEnum;
import com.smartmatic.waffle.ecm.client.ECMClientSideConstants;
import com.smartmatic.waffle.ecm.client.ECMServiceProvider;
import com.smartmatic.waffle.ecm.client.util.ClientCommon;
import com.smartmatic.waffle.ecm.ui.util.ECMOptionPane;
import com.smartmatic.waffle.log.SMTTLogger;

/**
 * This panel is the front-end for KeyGeneration functionality.
 */
public class KeyGenerationPanel extends javax.swing.JPanel {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 1L;

	/**
	 * For logging purposes.
	 */
	private static SMTTLogger logger = SMTTLogger
			.getLogger(KeyGenerationPanel.class);

	/** Localized resource bundle. */
	ResourceBundle langBundle = ResourceBundle
			.getBundle("com/smartmatic/waffle/ecm/client/resources/ECMApp");

	/** Localized resource bundle containing the application errors. */
	ResourceBundle errorsBundle = ResourceBundle
			.getBundle("com/smartmatic/waffle/ecm/client/resources/ECMErrors");

	/** The max size allowed in bytes. */
	private long maxLength = ECMClientSideConstants.MAX_LENGTH_ALLOWED_FOR_FILES_TO_UPLOAD;

	/**
	 * FunctionalityDefinitionEnum to define the tab to set focus.
	 */
	final FunctionalityDefinitionEnum functionalityDefinitionEnum = FunctionalityDefinitionEnum.KEY_GENERATION;

	/**
	 * Creates a new KeyGenerationPanel instance.
	 */
	public KeyGenerationPanel() {

		initComponents();
		this.mainProgressBar.setStringPainted(true);
		adjustComponentSizes();
		setFileChooserFilter();

	}

	/**
	 * Shows a pop-up with information about the amount of time that the key
	 * generation task took to successfully complete the process.
	 * 
	 * @param hour
	 *            Amount of hours spend executing the task
	 * @param minute
	 *            Amount of minutes spend executing the task
	 * @param second
	 *            Amount of seconds spend executing the task
	 * @param rest
	 *            Amount of milliseconds spend executing the task
	 */
	public void showResultMessage(long hour, long minute, long second, long rest) {

		ECMServiceProvider.focusTab(this.functionalityDefinitionEnum);

		ECMOptionPane
				.showMessageDialog(
						this,
						this.langBundle
								.getString("FileGenerationPanel.message.success")
								+ " "
								+ hour
								+ " "
								+ this.langBundle
										.getString("FileGenerationPanel.time.hour")
								+ " "
								+ minute
								+ " "
								+ this.langBundle
										.getString("FileGenerationPanel.time.minute")
								+ " "
								+ second
								+ " "
								+ this.langBundle
										.getString("FileGenerationPanel.time.second")
								+ " "
								+ rest
								+ " "
								+ this.langBundle
										.getString("FileGenerationPanel.time.milisecond"),
						this.langBundle.getString("NormalMessage.title"),
						ECMOptionPane.INFORMATION_MESSAGE,
						ECMOptionPane.INFORMATION_DIALOG);
	}

	/**
	 * Updates the progress bar to a given value.
	 * 
	 * @param value
	 *            New value of the progress bar to be set
	 */
	public void updateProgressBar(int value) {
		this.mainProgressBar.setValue(value);
	}

	/**
	 * Updates the progress bar to a given value.
	 * 
	 * @param value
	 *            New value of the progress bar to be set
	 */
	public void setMaxProgressBar(int value) {
		this.mainProgressBar.setMaximum(value);
	}

	/**
	 * Shows an information message to the user.
	 * 
	 * @param errorBundleKey
	 *            The error bundle key to fetch the message.
	 */
	public void showMessage(String bundleKey) {
		ECMServiceProvider.focusTab(this.functionalityDefinitionEnum);

		ECMOptionPane.showMessageDialog(this,
				this.langBundle.getString(bundleKey),
				this.langBundle.getString("NormalMessage.title"),
				ECMOptionPane.INFORMATION_MESSAGE,
				ECMOptionPane.INFORMATION_DIALOG);
	}

	/**
	 * Shows an error message to the user.
	 * 
	 * @param errorBundleKey
	 *            The error bundle key to fetch the message.
	 */
	public void showErrorMessage(String errorBundleKey) {
		ECMServiceProvider.focusTab(this.functionalityDefinitionEnum);

		ECMOptionPane.showMessageDialog(this,
				this.errorsBundle.getString(errorBundleKey),
				this.langBundle.getString("ErrorMessage.title"),
				ECMOptionPane.ERROR_MESSAGE, ECMOptionPane.ERROR_DIALOG);
	}

	/**
	 * Enables or disables the functionalities tabs and workflow buttons.
	 * 
	 * @param value
	 *            true to set the button as enabled, false to disable it.
	 */
	public void enableTabsAndWorkflowButton(boolean value) {
		HashSet<FunctionalityDefinitionEnum> funcs = new HashSet<FunctionalityDefinitionEnum>();
		funcs.add(FunctionalityDefinitionEnum.SCREENSHOT_GENERATION);
		funcs.add(FunctionalityDefinitionEnum.KEY_GENERATION);

		ECMServiceProvider.blockOtherTabsByFunctionality(funcs, !value);
	}

	/**
	 * Enables or disables the key generation button.
	 * 
	 * @param value
	 *            True to set the button as enabled, false to disable it.
	 */
	public void enableButton(boolean value) {
		this.securityComponentsGenerationButton.setEnabled(value);
		this.exportSecurityComponentsButton.setEnabled(value);
	}

	/**
	 * Enables or disables the exporter keys button.
	 * 
	 * @param value
	 *            True to set the button as enabled, false to disable it.
	 */
	public void setExporterKeysEnable(boolean value) {
		this.exportSecurityComponentsButton.setEnabled(value);
	}

	/**
	 * Adjust the size of the progress bar and the key generation button
	 * according to the panel's size.
	 */
	private void adjustComponentSizes() {
		this.mainProgressBar.setSize(WIDTH - 10,
				this.mainProgressBar.getHeight());
		int button_x = (WIDTH / 2)
				- this.securityComponentsGenerationButton.getWidth();
		this.securityComponentsGenerationButton.setLocation(button_x,
				this.securityComponentsGenerationButton.getY());

	}

	/**
	 * Sets the file chooser filter.
	 */
	private void setFileChooserFilter() {
		this.exportFileChooser.setFileFilter(new FileFilter() {

			@Override
			public boolean accept(File file) {
				// Get the length of file
				long file_length = file.length();

				if (file_length >= KeyGenerationPanel.this.maxLength) {
					return false;
				}
				return true;
			}

			@Override
			public String getDescription() {
				return KeyGenerationPanel.this.langBundle
						.getString("Application.max_size_filter_desc");
			}

		});
	}

	/**
	 * Sets the progress bar to its maximum value.
	 */
	public void setProgressBarMaximized() {
		this.mainProgressBar.setMaximum(100);
		this.mainProgressBar.setValue(this.mainProgressBar.getMaximum());
	}

	/**
	 * This method is called from within the constructor to initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is always
	 * regenerated by the Form Editor.
	 */
	private void initComponents() {

		this.exportFileChooser = new javax.swing.JFileChooser();
		this.mainProgressBar = new javax.swing.JProgressBar();
		this.securityComponentsGenerationButton = new javax.swing.JButton();
		this.mainLayeredPane = new javax.swing.JLayeredPane();
		this.securityComponentsGenerationImage = new javax.swing.JLabel();
		this.panelTitleLabel = new javax.swing.JLabel();
		this.descriptionLabel = new javax.swing.JLabel();
		this.bannerBackgroundLabel = new javax.swing.JLabel();
		this.exportSecurityComponentsButton = new javax.swing.JButton();

		this.exportFileChooser.setName("fileChooserExportedKey"); // NOI18N

		File defautFile = new File(
				this.langBundle.getString("Exported.keys.file.name"));

		ClientCommon
				.initFileChooserLocation(this.exportFileChooser, defautFile);

		setPreferredSize(new java.awt.Dimension(704, 374));

		this.mainProgressBar.setName("progressBarMain"); // NOI18N
		this.mainProgressBar.setPreferredSize(new java.awt.Dimension(680, 20));
		this.mainProgressBar.setStringPainted(true);

		java.util.ResourceBundle bundle = java.util.ResourceBundle
				.getBundle("com/smartmatic/waffle/ecm/client/resources/ECMApp"); // NOI18N

		this.securityComponentsGenerationButton.setText(bundle
				.getString("KeyGenerationPanel.key_generation_button.text")); // NOI18N
		this.securityComponentsGenerationButton.setName("buttonKeyGeneration"); // NOI18N
		this.securityComponentsGenerationButton
				.addActionListener(new java.awt.event.ActionListener() {
					@Override
					public void actionPerformed(java.awt.event.ActionEvent evt) {
						generateSecurityComponents(evt);
					}
				});

		this.mainLayeredPane.setName("layeredPaneFunctionalityInfo"); // NOI18N

		this.securityComponentsGenerationImage
				.setIcon(new javax.swing.ImageIcon(
						getClass()
								.getResource(
										"/com/smartmatic/waffle/ecm/client/resources/key_generation.png"))); // NOI18N
		this.securityComponentsGenerationImage
				.setName("labelFunctionalityIcon"); // NOI18N
		this.securityComponentsGenerationImage.setBounds(20, 10, 120, 90);
		this.mainLayeredPane.add(this.securityComponentsGenerationImage,
				javax.swing.JLayeredPane.DEFAULT_LAYER);

		this.panelTitleLabel.setFont(new java.awt.Font("DejaVu Sans", 1, 14));
		this.panelTitleLabel.setText(bundle
				.getString("KeyGenerationPanel.title_jlabel.text")); // NOI18N
		this.panelTitleLabel.setName("labelFunctionalityTitle"); // NOI18N
		this.panelTitleLabel.setBounds(160, 20, 256, 17);
		this.mainLayeredPane.add(this.panelTitleLabel,
				javax.swing.JLayeredPane.DEFAULT_LAYER);

		this.descriptionLabel.setFont(new java.awt.Font("DejaVu Sans", 0, 11));
		this.descriptionLabel.setText(bundle
				.getString("KeyGenerationPanel.jLabel3.text")); // NOI18N
		this.descriptionLabel.setName("labelFunctionalityDescription"); // NOI18N
		this.descriptionLabel.setBounds(200, 40, 364, 14);
		this.mainLayeredPane.add(this.descriptionLabel,
				javax.swing.JLayeredPane.DEFAULT_LAYER);

		this.bannerBackgroundLabel
				.setIcon(new javax.swing.ImageIcon(
						getClass()
								.getResource(
										"/com/smartmatic/waffle/ecm/client/resources/barra titulo subtitulo.jpg"))); // NOI18N

		this.bannerBackgroundLabel
				.setName("labelFunctionalityBannerBackBround"); // NOI18N
		this.bannerBackgroundLabel.setPreferredSize(new java.awt.Dimension(
				1440, 120));
		this.bannerBackgroundLabel.setBounds(0, 0, 1440, 120);
		this.mainLayeredPane.add(this.bannerBackgroundLabel,
				javax.swing.JLayeredPane.DEFAULT_LAYER);

		this.exportSecurityComponentsButton.setText(bundle
				.getString("KeyGenerationPanel.exporterKeys.text")); // NOI18N
		this.exportSecurityComponentsButton.setName("buttonExporterKeys"); // NOI18N
		this.exportSecurityComponentsButton
				.addActionListener(new java.awt.event.ActionListener() {
					@Override
					public void actionPerformed(java.awt.event.ActionEvent evt) {
						exportKeys(evt);
					}
				});

		javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
		this.setLayout(layout);
		layout.setHorizontalGroup(layout
				.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addComponent(this.mainLayeredPane,
						javax.swing.GroupLayout.DEFAULT_SIZE, 704,
						Short.MAX_VALUE)
				.addGroup(
						layout.createSequentialGroup()
								.addGap(54, 54, 54)
								.addGroup(
										layout.createParallelGroup(
												javax.swing.GroupLayout.Alignment.LEADING)
												.addGroup(
														layout.createSequentialGroup()
																.addPreferredGap(
																		javax.swing.LayoutStyle.ComponentPlacement.RELATED,
																		103,
																		javax.swing.GroupLayout.PREFERRED_SIZE))
												.addGroup(
														javax.swing.GroupLayout.Alignment.TRAILING,
														layout.createParallelGroup(
																javax.swing.GroupLayout.Alignment.TRAILING)
																.addGroup(
																		layout.createSequentialGroup()
																				.addComponent(
																						this.securityComponentsGenerationButton,
																						javax.swing.GroupLayout.PREFERRED_SIZE,
																						281,
																						javax.swing.GroupLayout.PREFERRED_SIZE)
																				.addPreferredGap(
																						javax.swing.LayoutStyle.ComponentPlacement.RELATED,
																						34,
																						Short.MAX_VALUE)
																				.addComponent(
																						this.exportSecurityComponentsButton,
																						javax.swing.GroupLayout.PREFERRED_SIZE,
																						275,
																						javax.swing.GroupLayout.PREFERRED_SIZE))
																.addComponent(
																		this.mainProgressBar,
																		javax.swing.GroupLayout.DEFAULT_SIZE,
																		590,
																		Short.MAX_VALUE)))
								.addGap(60, 60, 60)));
		layout.setVerticalGroup(layout
				.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addGroup(
						layout.createSequentialGroup()
								.addComponent(this.mainLayeredPane,
										javax.swing.GroupLayout.PREFERRED_SIZE,
										124,
										javax.swing.GroupLayout.PREFERRED_SIZE)
								.addGap(161, 161, 161)
								.addComponent(this.mainProgressBar,
										javax.swing.GroupLayout.PREFERRED_SIZE,
										javax.swing.GroupLayout.DEFAULT_SIZE,
										javax.swing.GroupLayout.PREFERRED_SIZE)
								.addPreferredGap(
										javax.swing.LayoutStyle.ComponentPlacement.RELATED)
								.addGap(35, 35, 35)
								.addGroup(
										layout.createParallelGroup(
												javax.swing.GroupLayout.Alignment.BASELINE)
												.addComponent(
														this.exportSecurityComponentsButton,
														javax.swing.GroupLayout.PREFERRED_SIZE,
														65,
														javax.swing.GroupLayout.PREFERRED_SIZE)
												.addComponent(
														this.securityComponentsGenerationButton,
														javax.swing.GroupLayout.DEFAULT_SIZE,
														65, Short.MAX_VALUE))
								.addGap(194, 194, 194)));
	}// </editor-fold>//GEN-END:initComponents

	/**
	 * Generates the encryption keys.
	 * 
	 * @param evt
	 *            the evt
	 */
	private void generateSecurityComponents(java.awt.event.ActionEvent evt) {

		try {

			if (ECMServiceProvider.checkIfSecurityComponentsAreGenerated()) {

				int result = ECMOptionPane
						.showConfirmDialog(
								this,
								this.langBundle
										.getString("KeyGenerationPanel.key.allready.generated"),
								this.langBundle
										.getString("WarningMessage.title"),
								ECMOptionPane.YES_NO_OPTION,
								ECMOptionPane.WARNING_MESSAGE,
								ECMOptionPane.CONFIRM_DIALOG);

				if (result == 0) {

					SecurityComponentsGenerationController generator = new SecurityComponentsGenerationController(
							this);
					generator.startWorker();
				}
			} else {

				SecurityComponentsGenerationController generator = new SecurityComponentsGenerationController(
						this);
				generator.startWorker();
			}
		} catch (Exception e) {
			logger.error(e, e.getMessage());
		}
	}

	/**
	 * Export keys.
	 * 
	 * @param evt
	 *            the evt
	 */
	private void exportKeys(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_exportKeys

		try {

			if (ECMServiceProvider.checkIfSecurityComponentsAreGenerated()) {

				this.mainProgressBar.setValue(0);

				ECMServiceProvider.focusTab(this.functionalityDefinitionEnum);

				if (this.exportFileChooser.showSaveDialog(this) == 0) {

					ClientCommon
							.saveFileChooserLocationPreference(this.exportFileChooser
									.getCurrentDirectory().getAbsolutePath());

					File destFile = this.exportFileChooser.getSelectedFile();

					if (!destFile.getParentFile().canWrite()) {
						updateProgressBar(0);
						ECMOptionPane
								.showMessageDialog(
										this,
										this.langBundle
												.getString("KeyGenerationPanel.message.permission.error"),
										this.langBundle
												.getString("ErrorMessage.title"),
										ECMOptionPane.ERROR_MESSAGE,
										ECMOptionPane.ERROR_DIALOG);
					} else {
						if (destFile != null) {

							SecurityComponentsExportController securityComponentsExportController = new SecurityComponentsExportController(
									this, destFile);

							securityComponentsExportController.startWorker();
						}
					}
				}
				this.exportFileChooser
						.setFileSelectionMode(JFileChooser.FILES_ONLY);

			} else {
				updateProgressBar(0);
				ECMOptionPane
						.showMessageDialog(
								this,
								this.langBundle
										.getString("KeyGenerationPanel.message.notAllCertificates.error"),
								this.langBundle.getString("ErrorMessage.title"),
								ECMOptionPane.ERROR_MESSAGE,
								ECMOptionPane.ERROR_DIALOG);
			}
		} catch (Exception e) {
			logger.error(e, e.getMessage());
			updateProgressBar(0);
			ECMOptionPane.showMessageDialog(this, this.langBundle
					.getString("KeyGenerationPanel.message.error"),
					this.langBundle.getString("ErrorMessage.title"),
					ECMOptionPane.ERROR_MESSAGE, ECMOptionPane.ERROR_DIALOG);
		}
	}// GEN-LAST:event_exportVotingDeviceKeys

	// Variables declaration - do not modify//GEN-BEGIN:variables

	/** The banner background label. */
	private javax.swing.JLabel bannerBackgroundLabel;

	/** The export security components button. */
	private javax.swing.JButton exportSecurityComponentsButton;

	/** The export security components file chooser. */
	private javax.swing.JFileChooser exportFileChooser;

	/** The description label. */
	private javax.swing.JLabel descriptionLabel;

	/** The main layered pane. */
	private javax.swing.JLayeredPane mainLayeredPane;

	/** The main progress bar. */
	private javax.swing.JProgressBar mainProgressBar;

	/** The security components generation button. */
	private javax.swing.JButton securityComponentsGenerationButton;

	/** The security components generation image. */
	private javax.swing.JLabel securityComponentsGenerationImage;

	/** The panel title label. */
	private javax.swing.JLabel panelTitleLabel;

	// End of variables declaration//GEN-END:variables

}
