/**
 * ParameterConfigurationPanel.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */

package com.smartmatic.waffle.ecm.client.ui;

import java.awt.event.MouseEvent;
import java.util.HashSet;
import java.util.List;
import java.util.ResourceBundle;

import javax.swing.JTable;
import javax.swing.table.DefaultTableModel;

import org.jdesktop.application.Action;

import com.smartmatic.waffle.domain.general.ParameterData;
import com.smartmatic.waffle.domain.security.FunctionalityDefinitionEnum;
import com.smartmatic.waffle.ecm.client.ECMServiceProvider;
import com.smartmatic.waffle.ecm.client.ui.controller.ParameterConfigurationPanelController;
import com.smartmatic.waffle.ecm.service.lang.XmlGenerationException;
import com.smartmatic.waffle.ecm.ui.util.ECMOptionPane;
import com.smartmatic.waffle.log.SMTTLogger;

/**
 * The Class is used to load and draw all the necessary components for the
 * Parameter Configuration Panel.
 */
public class ParameterConfigurationPanel extends javax.swing.JPanel {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 1L;

	/** The bundle. */
	private ResourceBundle bundle;

	/** The parameters. */
	private List<ParameterData> parameters;

	/** The logger. */
	private static SMTTLogger logger = SMTTLogger
			.getLogger(ParameterConfigurationPanel.class);

	/**
	 * Creates new form ParameterConfigurationPanel.
	 */
	public ParameterConfigurationPanel() {
		this.bundle = java.util.ResourceBundle
				.getBundle("com/smartmatic/waffle/ecm/client/resources/ECMApp");
		initComponents();
		fillParameterTable();
	}

	/**
	 * Fills the table with all of the parameter's info organized each one in a
	 * different row. Each row contains the name of the parameter and its value
	 * in separated columns
	 */
	private void fillParameterTable() {
		try {
			this.parameters = ParameterConfigurationPanelController
					.getParameters();

			DefaultTableModel aux = (DefaultTableModel) this.parameterTable1
					.getModel();

			for (ParameterData parameterData : this.parameters) {
				aux.addRow(new String[] {
						this.bundle
								.getString("ParameterConfigurationPanel.parameter."
										+ parameterData.getParameterKey()),
						parameterData.getParameterValue() });
			}

			this.parameterTable1.repaint();
		} catch (XmlGenerationException e) {
			logger.error(e.getMessage());
			trasformErrorMessage(e.getMessage());
		}
	}

	/**
	 * Removes unwanted content from a given error message.
	 * 
	 * @param message
	 *            Error message to be processed
	 */
	private synchronized void trasformErrorMessage(String message) {
		showErrorMessage(message.split("\\$")[1]);
	}

	/**
	 * Shows a pop-up window with an error message.
	 * 
	 * @param messageError
	 *            Message to be displayed in the pop-up
	 */
	private synchronized void showErrorMessage(String messageError) {
		ECMOptionPane.showMessageDialog(this,
				this.bundle.getString(messageError),
				this.bundle.getString("ErrorMessage.title"),
				ECMOptionPane.ERROR_MESSAGE, ECMOptionPane.ERROR_DIALOG);
	}

	/**
	 * Shows a pop-up with a given information message.
	 * 
	 * @param message
	 *            Information to be displayed in the pop-up
	 */
	private synchronized void showMessage(String message) {
		ECMOptionPane.showMessageDialog(this, this.bundle.getString(message),
				this.bundle.getString("NormalMessage.title"),
				ECMOptionPane.INFORMATION_MESSAGE,
				ECMOptionPane.INFORMATION_DIALOG);
	}

	/**
	 * This method is called from within the constructor to initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is always
	 * regenerated by the Form Editor.
	 */
	@SuppressWarnings("unchecked")
	// <editor-fold defaultstate="collapsed"
	// desc="Generated Code">//GEN-BEGIN:initComponents
	private void initComponents() {

		this.jLayeredPane1 = new javax.swing.JLayeredPane();
		this.title_jlabel = new javax.swing.JLabel();
		this.commentLabel = new javax.swing.JLabel();
		this.parameter_configuration_image = new javax.swing.JLabel();
		this.banner_bg = new javax.swing.JLabel();
		this.jScrollPane1 = new javax.swing.JScrollPane();
		this.parameterTable1 = new javax.swing.JTable();
		this.updateButton1 = new javax.swing.JButton();

		this.jLayeredPane1.setName("jLayeredPane1"); // NOI18N
		this.jLayeredPane1.setPreferredSize(new java.awt.Dimension(1440, 124));

		this.title_jlabel.setFont(new java.awt.Font("DejaVu Sans", 1, 14));
		final java.util.ResourceBundle bundle = java.util.ResourceBundle
				.getBundle("com/smartmatic/waffle/ecm/client/resources/ECMApp"); // NOI18N
		this.title_jlabel.setText(bundle
				.getString("ParameterConfigurationPanel.title_jlabel.text")); // NOI18N
		this.title_jlabel.setName("title_jlabel"); // NOI18N
		this.title_jlabel.setBounds(170, 20, 830, 17);
		this.jLayeredPane1.add(this.title_jlabel,
				javax.swing.JLayeredPane.DEFAULT_LAYER);

		this.commentLabel.setFont(new java.awt.Font("DejaVu Sans", 0, 11));
		this.commentLabel.setText(bundle
				.getString("ParameterConfigurationPanel.commentLabel.text")); // NOI18N
		this.commentLabel.setName("commentLabel"); // NOI18N
		this.commentLabel.setBounds(200, 40, 800, 14);
		this.jLayeredPane1.add(this.commentLabel,
				javax.swing.JLayeredPane.DEFAULT_LAYER);

		this.parameter_configuration_image
				.setIcon(new javax.swing.ImageIcon(
						getClass()
								.getResource(
										"/com/smartmatic/waffle/ecm/client/resources/parameters_configuration.png"))); // NOI18N
		this.parameter_configuration_image
				.setName("parameter_configuration_image"); // NOI18N
		this.parameter_configuration_image.setBounds(20, 10, 120, 90);
		this.jLayeredPane1.add(this.parameter_configuration_image,
				javax.swing.JLayeredPane.DEFAULT_LAYER);

		this.banner_bg
				.setIcon(new javax.swing.ImageIcon(
						getClass()
								.getResource(
										"/com/smartmatic/waffle/ecm/client/resources/barra titulo subtitulo.jpg"))); // NOI18N
		this.banner_bg.setName("banner_bg"); // NOI18N
		this.banner_bg.setPreferredSize(new java.awt.Dimension(1440, 120));
		this.banner_bg.setBounds(0, 0, 1440, 120);
		this.jLayeredPane1.add(this.banner_bg,
				javax.swing.JLayeredPane.DEFAULT_LAYER);

		this.jScrollPane1.setName("jScrollPane1"); // NOI18N

		this.parameterTable1 = new JTable() {

			// Implement table cell tool tips.
			@Override
			public String getToolTipText(MouseEvent e) {

				String tip = null;
				java.awt.Point p = e.getPoint();
				// int rowIndex = rowAtPoint(p);
				int colIndex = columnAtPoint(p);
				int realColumnIndex = convertColumnIndexToModel(colIndex);

				if (0 != realColumnIndex) { // Sport column
					tip = bundle
							.getString("ParameterConfigurationPanel.table.parameter.value.tooltip");
				}
				if (0 == realColumnIndex) {
					tip = bundle
							.getString("ParameterConfigurationPanel.table.parameter.name.tooltip");
				}
				return tip;
			}

		};

		this.parameterTable1.setModel(new javax.swing.table.DefaultTableModel(
				new Object[][] {

				}, new String[] { "Parametro", "Valor" }) {
			/**
		 *
		 */
			private static final long serialVersionUID = 1L;
			boolean[] canEdit = new boolean[] { false, true };

			@Override
			public boolean isCellEditable(int rowIndex, int columnIndex) {
				return this.canEdit[columnIndex];
			}
		});
		this.parameterTable1.setName("parameterTable1"); // NOI18N
		this.jScrollPane1.setViewportView(this.parameterTable1);
		this.parameterTable1.getColumnModel().getColumn(0).setResizable(false);
		this.parameterTable1
				.getColumnModel()
				.getColumn(0)
				.setHeaderValue(
						bundle.getString("ParameterConfigurationPanel.table.parameter")); // NOI18N
		this.parameterTable1.getColumnModel().getColumn(1).setResizable(false);
		this.parameterTable1
				.getColumnModel()
				.getColumn(1)
				.setHeaderValue(
						this.bundle
								.getString("ParameterConfigurationPanel.table.value")); // NOI18N

		javax.swing.ActionMap actionMap = org.jdesktop.application.Application
				.getInstance().getContext()
				.getActionMap(ParameterConfigurationPanel.class, this);
		this.updateButton1.setAction(actionMap.get("updateButtonClick")); // NOI18N
		this.updateButton1.setText(bundle
				.getString("ParameterConfigurationPanel.updateBotton1")); // NOI18N
		this.updateButton1.setName("updateButton1"); // NOI18N

		javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
		this.setLayout(layout);
		layout.setHorizontalGroup(layout
				.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addGroup(
						layout.createSequentialGroup()
								.addContainerGap()
								.addComponent(this.jScrollPane1,
										javax.swing.GroupLayout.DEFAULT_SIZE,
										1416, Short.MAX_VALUE)
								.addContainerGap())
				.addComponent(this.jLayeredPane1,
						javax.swing.GroupLayout.PREFERRED_SIZE,
						javax.swing.GroupLayout.DEFAULT_SIZE,
						javax.swing.GroupLayout.PREFERRED_SIZE)
				.addGroup(
						javax.swing.GroupLayout.Alignment.TRAILING,
						layout.createSequentialGroup()
								.addContainerGap(675, Short.MAX_VALUE)
								.addComponent(this.updateButton1,
										javax.swing.GroupLayout.PREFERRED_SIZE,
										98,
										javax.swing.GroupLayout.PREFERRED_SIZE)
								.addGap(667, 667, 667)));
		layout.setVerticalGroup(layout.createParallelGroup(
				javax.swing.GroupLayout.Alignment.LEADING).addGroup(
				layout.createSequentialGroup()
						.addComponent(this.jLayeredPane1,
								javax.swing.GroupLayout.PREFERRED_SIZE,
								javax.swing.GroupLayout.DEFAULT_SIZE,
								javax.swing.GroupLayout.PREFERRED_SIZE)
						.addGap(18, 18, 18)
						.addComponent(this.jScrollPane1,
								javax.swing.GroupLayout.PREFERRED_SIZE, 321,
								javax.swing.GroupLayout.PREFERRED_SIZE)
						.addGap(18, 18, 18)
						.addComponent(this.updateButton1,
								javax.swing.GroupLayout.PREFERRED_SIZE, 41,
								javax.swing.GroupLayout.PREFERRED_SIZE)
						.addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE,
								Short.MAX_VALUE)));
	}// </editor-fold>//GEN-END:initComponents

	/**
	 * Action executed after clicking the update button.
	 */
	@Action
	public void updateButtonClick() {
		boolean updated = false;
		HashSet<FunctionalityDefinitionEnum> funcs = new HashSet<FunctionalityDefinitionEnum>();
		funcs.add(FunctionalityDefinitionEnum.PARAMETER_CONFIGURATION);
		ECMServiceProvider.blockOtherTabsByFunctionality(funcs, true);

		try {
			int index = 0;
			for (ParameterData parameterData : this.parameters) {
				int value = Integer.parseInt(this.parameterTable1.getValueAt(
						index, 1).toString());

				if (value != Integer
						.parseInt(parameterData.getParameterValue())) {
					parameterData.setParameterValue(String.valueOf(value));

					ParameterConfigurationPanelController
							.updateParameter(parameterData);
					updated = true;
				}
				index++;
			}
			if (updated) {
				showMessage("ParameterConfigurationPanel.parameter.updated");
			}
		} catch (XmlGenerationException e) {
			logger.error(e.getMessage());
			trasformErrorMessage(e.getMessage());
		} catch (NumberFormatException e) {
			logger.error(e.getCause(), e.getMessage());
			ECMOptionPane
					.showMessageDialog(
							this,
							this.bundle
									.getString("ParameterConfigurationPanel.parameter.notnumericvalue"),
							this.bundle.getString("ErrorMessage.title"),
							ECMOptionPane.ERROR_MESSAGE,
							ECMOptionPane.ERROR_DIALOG);

			showErrorMessage(this.bundle
					.getString("ParameterConfigurationPanel.parameter.notnumericvalue"));

		} catch (Exception e) {
			logger.error(e.getCause(), e.getMessage());
			showErrorMessage(this.bundle
					.getString("ErrorMessage.GENERIC_ERROR"));
		} finally {
			ECMServiceProvider.blockOtherTabsByFunctionality(funcs, false);
		}
	}

	// Variables declaration - do not modify//GEN-BEGIN:variables
	/** The banner_bg. */
	private javax.swing.JLabel banner_bg;

	/** The comment label. */
	private javax.swing.JLabel commentLabel;

	/** The j layered pane1. */
	private javax.swing.JLayeredPane jLayeredPane1;

	/** The j scroll pane1. */
	private javax.swing.JScrollPane jScrollPane1;

	/** The parameter table1. */
	private javax.swing.JTable parameterTable1;

	/** The parameter_configuration_image. */
	private javax.swing.JLabel parameter_configuration_image;

	/** The title_jlabel. */
	private javax.swing.JLabel title_jlabel;

	/** The update button1. */
	private javax.swing.JButton updateButton1;
	// End of variables declaration//GEN-END:variables

}
