/**
 * ReportGenerationPanel.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.ui;

import java.awt.Component;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.ResourceBundle;
import java.util.Set;

import javax.swing.DefaultComboBoxModel;
import javax.swing.JOptionPane;
import javax.swing.JProgressBar;
import javax.swing.SwingConstants;

import com.smartmatic.waffle.domain.i18n.LanguageData;
import com.smartmatic.waffle.domain.security.FunctionalityDefinitionEnum;
import com.smartmatic.waffle.ecm.client.ECMClientSideConstants;
import com.smartmatic.waffle.ecm.client.ECMServiceProvider;
import com.smartmatic.waffle.ecm.client.lang.ConnectionException;
import com.smartmatic.waffle.ecm.client.providers.RegionBrowserHierarchyProvider;
import com.smartmatic.waffle.ecm.client.ui.controller.IRefreshRegionWidget;
import com.smartmatic.waffle.ecm.core.printer.IPrinterStatusQuery;
import com.smartmatic.waffle.ecm.core.printer.IPrinterStatusQuery.StatusPrinter;
import com.smartmatic.waffle.ecm.core.printer.PrinterWatcher;
import com.smartmatic.waffle.ecm.data.transfer.objects.BrowserHierarchyDTO;
import com.smartmatic.waffle.ecm.data.transfer.type.ReportGenerationType;
import com.smartmatic.waffle.ecm.service.lang.DemographyException;
import com.smartmatic.waffle.ecm.ui.controls.Browser.BrowserHierarchy;
import com.smartmatic.waffle.ecm.ui.core.i18n.controller.LanguageController;
import com.smartmatic.waffle.ecm.ui.menu.GeneralMenuDialog;
import com.smartmatic.waffle.ecm.ui.util.ECMOptionPane;
import com.smartmatic.waffle.log.SMTTLogger;

/**
 * The Class is used to load and draw all the necessary components for the
 * Report Generation Panel.
 */
public class ReportGenerationPanel extends javax.swing.JPanel implements
		IRefreshRegionWidget {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 1L;

	/** The region navigator widget. */
	private BrowserHierarchy regionNavigator = null;

	/** The logger. */
	private static SMTTLogger logger = SMTTLogger
			.getLogger(ReportGenerationPanel.class);

	/** The provider. */
	private RegionBrowserHierarchyProvider provider;

	ReportGenerationType selectedReport;

	private ResourceBundle bundle = java.util.ResourceBundle
			.getBundle("com/smartmatic/waffle/ecm/client/resources/ECMApp");

	/**
	 * Creates new ReportGenerationPanel.
	 */
	public ReportGenerationPanel() {
		LanguageData language = LanguageController.getInstance()
				.getSelectedLanguage();

		try {
			this.provider = new RegionBrowserHierarchyProvider(
					ECMServiceProvider.getAvailableRegionsForWidget(), true,
					language);
		} catch (DemographyException e) {
			logger.error(e, e.getMessage());
			return;
		} catch (ConnectionException e) {
			logger.error(e, e.getMessage());
			return;
		}

		String titleName = this.bundle
				.getString("RegionLevelNavigatorWidget.regionTable.header.regionColumn")
				+ " | "
				+ this.bundle
						.getString("RegionLevelNavigatorWidget.regionTable.header.categoryColumn");

		this.regionNavigator = new BrowserHierarchy(this.provider, true,
				titleName);
		initComponents();
	}

	/**
	 * Print plugged check.
	 * 
	 * @param parent
	 *            the parent
	 * @param retryMessage
	 *            the retry message
	 * @param continueMessage
	 *            the continue message
	 * @param title
	 *            the title
	 * @param messageByStatus
	 *            the message by status
	 * @return the int
	 * @throws IOException
	 */
	public boolean checkPrinterPlugged() {

		try {

			if (Boolean.getBoolean("simulated_printing")) {
				return true;
			}

			PrinterWatcher printerWatcher = PrinterWatcher.getInstance();

			HashMap<StatusPrinter, String> messageByStatus = buildMessageToTroubleshootingPrinting();

			String message = messageByStatus.get(printerWatcher
					.getPrinterStatus().getPrinterStatus());

			while (message != null) {

				Component parent = GeneralMenuDialog.getInstance();
				String retryMessage = this.bundle
						.getString("general.answer.retry");
				String cancelMessage = this.bundle
						.getString("PrintingDialogView.cancelButton.name");
				String title = this.bundle.getString("question.title.text");

				String[] optionsKey = { cancelMessage, retryMessage };

				int result = JOptionPane.showOptionDialog(parent, message,
						title, JOptionPane.YES_NO_OPTION,
						JOptionPane.QUESTION_MESSAGE, null, optionsKey, null);

				if (result == 0) {
					return false;
				}

				message = messageByStatus.get(printerWatcher.getPrinterStatus()
						.getPrinterStatus());
			}

		} catch (IOException e) {
			logger.error(e.getMessage(), e);
			return false;
		}

		return true;
	}

	/**
	 * Shows a pop-up with information about the status of the report generation
	 * process after it finished succesfully. Also, it sets the progress bar to
	 * a determinate state and with its maximum value
	 */
	public void finishProcess() {
		setIndeterminateProgressBar(false);
		this.mainProgressBar.setValue(100);
		ECMOptionPane.showMessageDialog(this, this.bundle
				.getString("ReportGenerationPanel.show.report.finish.message"),
				this.bundle.getString("NormalMessage.title"),
				ECMOptionPane.INFORMATION_MESSAGE,
				ECMOptionPane.INFORMATION_DIALOG);

	}

	/**
	 * Sets the panel's progress bar as indeterminate.
	 */
	public void stopProgressBar() {
		setIndeterminateProgressBar(false);
	}

	/**
	 * Sets the panel's progress bar as indeterminate.
	 * 
	 * @param indeterminate
	 *            true to indeterminate otherwise false
	 */
	public void setIndeterminateProgressBar(boolean indeterminate) {
		if (indeterminate) {
			this.mainProgressBar.setValue(0);
		}
		this.mainProgressBar.setIndeterminate(indeterminate);
		this.mainProgressBar.setStringPainted(!indeterminate);
	}

	/**
	 * Shows a pop-up with information about the status of the report generation
	 * process after it finished with an error. Also, it sets the progress bar
	 * to a determinate state and with its maximum value
	 * 
	 * @param keyError
	 *            Error message to be displayed in the pop-up window
	 */
	public void finishProcess(String keyError) {
		setIndeterminateProgressBar(false);
		this.mainProgressBar.setValue(100);
		ECMOptionPane.showMessageDialog(this, this.bundle.getString(keyError),
				this.bundle.getString("WarningMessage.title"),
				ECMOptionPane.WARNING_MESSAGE, ECMOptionPane.WARNING_DIALOG);

	}

	/**
	 * Changes the value of the status label to display information about the
	 * region being processed and the general progress of the task.
	 * 
	 * @param currentNumber
	 *            Number of regions processed so far
	 * @param nameRegion
	 *            Name of the current region being processed
	 * @param countRegions
	 *            Total number of regions to be processed
	 */
	public void refreshStatus(int currentNumber, String nameRegion,
			int countRegions) {
		this.statusLabel.setText(String.valueOf(currentNumber) + "/"
				+ String.valueOf(countRegions) + "     (" + nameRegion + ")");
	}

	/**
	 * Refresh status.
	 * 
	 * @param currentNumber
	 *            the current number
	 * @param countRegions
	 *            the count regions
	 * @author Mario Bislick (mario.bislick@smartmatic.com)
	 */
	public void refreshStatus(int currentNumber, int countRegions) {
		this.statusLabel.setText(String.valueOf(currentNumber) + "/"
				+ String.valueOf(countRegions));
	}

	/**
	 * Refresh status.
	 * 
	 * @param status
	 *            the status
	 * @author Mario Bislick (mario.bislick@smartmatic.com)
	 */
	public void refreshStatus(String status) {
		this.statusLabel.setText(status);
	}

	/**
	 * Gets the list of selected regions from the table, ignoring those
	 * unselected but with at least one polling place selected.
	 * 
	 * @return List of selected regions
	 * @author Mario Bislick (mario.bislick@smartmatic.com)
	 */
	public Set<BrowserHierarchyDTO> getSelectedObject() {
		return this.regionNavigator.getSelectedObject();
	}

	/**
	 * Blocks or unblocks the panel's buttons.
	 * 
	 * @param block
	 *            true to block otherwise false
	 */
	public void blockButtons(boolean block) {
		this.generationButton.setEnabled(!block);
		this.reportTypeComboBox.setEnabled(!block);
	}

	/**
	 * Blocks or unblocks tabs others than the current report generation
	 * 
	 * @param block
	 *            true to block otherwise false
	 */
	public void blockTabs(boolean block) {
		HashSet<FunctionalityDefinitionEnum> funcs = new HashSet<FunctionalityDefinitionEnum>();
		funcs.add(FunctionalityDefinitionEnum.REPORT_GENERATION);
		ECMServiceProvider.blockOtherTabsByFunctionality(funcs, block);
	}

	/**
	 * Returns the panel's progress bar.
	 * 
	 * @return the progress bar
	 */
	public JProgressBar getProgressBar() {
		return this.mainProgressBar;
	}

	public ReportGenerationType getSelectedReport() {
		return this.selectedReport;
	}

	/**
	 * Resets the widget.
	 * 
	 * @inheritDoc
	 */
	@Override
	public void refreshWidget() {
		this.regionNavigator.reset();
	}

	/**
	 * Returns the resources bundle used by this panel
	 * 
	 * @return the resources bundle
	 */
	public ResourceBundle getbundle() {
		return this.bundle;
	}

	/**
	 * 
	 * @param value
	 */
	public void setProgressBarValue(int value) {
		this.mainProgressBar.setValue(value);
		this.mainProgressBar.setString(String.valueOf(value) + "%");
	}

	/**
	 * Checks if is prints the report without password.
	 *
	 * @return true, if is prints the report without password
	 */
	public boolean isPrintReportWithoutPassword() {
		return this.printReportWithoutPasswordCheckBox.isSelected();
	}

	/**
	 * Builds the message to troubleshooting printing.
	 * 
	 * @return the hash map
	 */
	private HashMap<StatusPrinter, String> buildMessageToTroubleshootingPrinting() {

		java.util.ResourceBundle bundle = java.util.ResourceBundle
				.getBundle("com/smartmatic/waffle/ecm/client/resources/ECMApp");

		HashMap<StatusPrinter, String> messageByStatus = new HashMap<IPrinterStatusQuery.StatusPrinter, String>();
		String message;

		message = "<html>"
				+ bundle.getString("printer.cant.no.printing.message")
				+ "<br><br>"
				+ bundle.getString("printer.cant.no.printing.question")

				+ "</html>";
		messageByStatus.put(StatusPrinter.ERROR, message);

		message = "<html>"
				+ bundle.getString("troubleshooting.diagnostic.printer.result."
						+ StatusPrinter.OFFLINE)
				+ ", "
				+ bundle.getString("troubleshooting.diagnostic.printer.instruction."
						+ StatusPrinter.OFFLINE) + "<br><br>"
				+ bundle.getString("printer.cant.no.printing.question")

				+ "</html>";
		messageByStatus.put(StatusPrinter.OFFLINE, message);

		message = "<html>"
				+ bundle.getString("troubleshooting.diagnostic.printer.result."
						+ StatusPrinter.OFFLINE)

				+ bundle.getString("printer.cant.no.printing.question")

				+ "</html>";
		messageByStatus.put(StatusPrinter.DISCONNECTED, message);

		message = "<html>"
				+ bundle.getString("printer.cant.no.printing.message")
				+ ", "
				+ bundle.getString("printer.cant.no.printing.message."
						+ StatusPrinter.OUT_OF_INK)
				+ "<br><br>"
				+ bundle.getString("troubleshooting.diagnostic.printer.instruction."
						+ StatusPrinter.OUT_OF_INK) + "<br><br>"
				+ bundle.getString("printer.cant.no.printing.question")

				+ "</html>";
		messageByStatus.put(StatusPrinter.OUT_OF_INK, message);

		message = "<html>"
				+ bundle.getString("printer.cant.no.printing.message")
				+ ", "
				+ bundle.getString("troubleshooting.diagnostic.printer.result."
						+ StatusPrinter.OUT_OF_PAPER)
				+ "<br><br>"
				+ bundle.getString("troubleshooting.diagnostic.printer.instruction."
						+ StatusPrinter.OUT_OF_PAPER) + "<br><br>"
				+ bundle.getString("printer.cant.no.printing.question")
				+ "</html>";
		messageByStatus.put(StatusPrinter.OUT_OF_PAPER, message);

		message = "<html>"
				+ bundle.getString("printer.cant.no.printing.message")
				+ ", "
				+ bundle.getString("troubleshooting.diagnostic.printer.result."
						+ StatusPrinter.DOOR_OPEN)
				+ "<br><br>"
				+ bundle.getString("troubleshooting.diagnostic.printer.instruction."
						+ StatusPrinter.DOOR_OPEN) + "<br><br>"
				+ bundle.getString("printer.cant.no.printing.question")
				+ "</html>";
		messageByStatus.put(StatusPrinter.DOOR_OPEN, message);

		message = "<html>"
				+ bundle.getString("printer.cant.no.printing.message")
				+ "<br><br>"
				+ bundle.getString("troubleshooting.diagnostic.printer.warning."
						+ StatusPrinter.BUSY)

				+ "<br>"
				+ bundle.getString("troubleshooting.diagnostic.printer.instruction."
						+ StatusPrinter.BUSY + ".1")
				+ "<br>"
				+ bundle.getString("troubleshooting.diagnostic.printer.instruction."
						+ StatusPrinter.BUSY + ".2")
				+ "<br>"
				+ bundle.getString("troubleshooting.diagnostic.printer.instruction."
						+ StatusPrinter.BUSY + ".3") + "<br><br>"
				+ bundle.getString("printer.cant.no.printing.question")
				+ "</html>";
		messageByStatus.put(StatusPrinter.BUSY, message);
		return messageByStatus;

	}

	/**
	 * Action performed after clicking the Report Generation button in the
	 * panel. It generates the reports and prints them if no error was happened
	 * 
	 * @param evt
	 *            Action event generated after clicking the panel button
	 */
	private void generateReport(java.awt.event.ActionEvent evt) {

		String totalizationReport = this.bundle
				.getString("ReportGenerationPanel.rts.pasword");
		String votingDeviceReport = this.bundle
				.getString("ReportGenerationPanel.pen.pasword");

		String recountPasswordReport = this.bundle
				.getString("ReportGenerationPanel.recount.password");

		String reportName = (String) this.reportTypeComboBox.getSelectedItem();

		if (totalizationReport.equals(reportName)
				&& ECMClientSideConstants.AVAILABLE_TOTALISATION_REPORT) {
			this.selectedReport = ReportGenerationType.TOTALISATION_REPORT;
		} else if (votingDeviceReport.equals(reportName)
				&& ECMClientSideConstants.AVAILABLE_VOTING_DEVICE_REPORT) {
			this.selectedReport = ReportGenerationType.VOTING_DEVICE_REPORT;
		} else if (recountPasswordReport.equals(reportName)
				&& ECMClientSideConstants.AVAILABLE_RECOUNT_REPORT) {
			this.selectedReport = ReportGenerationType.RECOUNT_PASSWORDS_REPORT;
		}

		int result = ECMOptionPane.showConfirmDialog(this, this.bundle
				.getString("ReportGenerationPanel.show.report.message"),
				this.bundle
						.getString("ReportGenerationPanel.show.report.title"),
				ECMOptionPane.YES_NO_OPTION, ECMOptionPane.CONFIRM_DIALOG);
		if (0 == result) {
			if (checkPrinterPlugged()) {

				this.setProgressBarValue(0);
				this.statusLabel.setText(null);

				ReportGenerationController reportGenerationController = new ReportGenerationController(
						this);
				reportGenerationController.startWorker();
			}
		}

	}

	/**
	 * Initializes combo box model with its set of available options to be
	 * displayed.
	 * 
	 * @return DefaultComboBoxModel
	 */
	private DefaultComboBoxModel getDefaultModel() {

		List<String> entries = new ArrayList<String>();
		DefaultComboBoxModel comboEntries = null;

		if (ECMClientSideConstants.AVAILABLE_VOTING_DEVICE_REPORT) {
			entries.add(this.bundle
					.getString("ReportGenerationPanel.pen.pasword"));
		}

		if (ECMClientSideConstants.AVAILABLE_RECOUNT_REPORT) {
			entries.add(this.bundle
					.getString("ReportGenerationPanel.recount.password"));
		}

		if (ECMClientSideConstants.AVAILABLE_TOTALISATION_REPORT) {
			entries.add(this.bundle
					.getString("ReportGenerationPanel.rts.pasword"));
		}

		comboEntries = new DefaultComboBoxModel(entries.toArray());

		return comboEntries;

	}

	/**
	 * Action performed after selecting one of the combo box options.
	 * 
	 * @param evt
	 *            Action event generated after selecting a combo box option
	 */
	private void selectReportType(java.awt.event.ActionEvent evt) {

		String totalizationReport = this.bundle
				.getString("ReportGenerationPanel.rts.pasword");

		String votingDeviceReport = this.bundle
				.getString("ReportGenerationPanel.pen.pasword");

		String recountPasswordReport = this.bundle
				.getString("ReportGenerationPanel.recount.password");

		String reportName = (String) this.reportTypeComboBox.getSelectedItem();

		if (totalizationReport.equals(reportName)
				&& ECMClientSideConstants.AVAILABLE_TOTALISATION_REPORT) {
			this.regionNavigator.reset();
		} else if (votingDeviceReport.equals(reportName)
				&& ECMClientSideConstants.AVAILABLE_VOTING_DEVICE_REPORT) {
			this.regionNavigator.reset();
		} else if (recountPasswordReport.equals(reportName)
				&& ECMClientSideConstants.AVAILABLE_RECOUNT_REPORT) {
			this.regionNavigator.reset();
		}
	}

	/**
	 * This method is called from within the constructor to initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is always
	 * regenerated by the Form Editor.
	 */
	private void initComponents() {

		this.generationButton = new javax.swing.JButton();
		this.reportTypeComboBox = new javax.swing.JComboBox();
		this.mainLayeredPane = new javax.swing.JLayeredPane();
		this.logoLabel = new javax.swing.JLabel();
		this.titleLabel = new javax.swing.JLabel();
		this.descriptionLabel = new javax.swing.JLabel();
		this.banner_bg = new javax.swing.JLabel();
		this.mainProgressBar = new javax.swing.JProgressBar();
		this.statusLabel = new javax.swing.JLabel();
		this.mainPanel = new javax.swing.JPanel();
		this.printReportWithoutPasswordCheckBox = new javax.swing.JCheckBox();

		this.generationButton.setText(this.bundle
				.getString("ReportGenerationPanel.generatereport_button.text")); // NOI18N

		this.generationButton.setName("buttonEncrypt"); // NOI18N
		this.generationButton
				.addActionListener(new java.awt.event.ActionListener() {
					@Override
					public void actionPerformed(java.awt.event.ActionEvent evt) {
						generateReport(evt);
					}
				});

		String checkboxMessage = this.bundle
				.getString("ReportGenerationPanelprint_report_without_password_check_box_label");
		String multiLineMessage = "<html>" + checkboxMessage + "</html>";

		this.printReportWithoutPasswordCheckBox
				.setName("printReportWithoutPasswordCheckBox");
		this.printReportWithoutPasswordCheckBox.setSelected(true);
		this.printReportWithoutPasswordCheckBox.setText(multiLineMessage);
		this.printReportWithoutPasswordCheckBox
				.setVerticalTextPosition(SwingConstants.TOP);

		this.reportTypeComboBox.setModel(this.getDefaultModel());
		this.reportTypeComboBox.setName("comboBoxReportType"); // NOI18N
		this.reportTypeComboBox
				.addActionListener(new java.awt.event.ActionListener() {
					@Override
					public void actionPerformed(java.awt.event.ActionEvent evt) {
						selectReportType(evt);
					}
				});

		this.mainLayeredPane.setName("layeredPaneMain"); // NOI18N

		this.logoLabel
				.setIcon(new javax.swing.ImageIcon(
						getClass()
								.getResource(
										"/com/smartmatic/waffle/ecm/client/resources/reports.png"))); // NOI18N
		this.logoLabel.setName("labelReportFuncLogo"); // NOI18N
		this.logoLabel.setBounds(10, 10, 120, 90);
		this.mainLayeredPane.add(this.logoLabel,
				javax.swing.JLayeredPane.DEFAULT_LAYER);

		this.titleLabel.setFont(new java.awt.Font("DejaVu Sans", 1, 14));
		this.titleLabel.setText(this.bundle
				.getString("ReportGenerationPanel.rep_gen_title.text")); // NOI18N
		this.titleLabel.setName("labelReportFuncTitle"); // NOI18N
		this.titleLabel.setBounds(140, 30, 570, 17);
		this.mainLayeredPane.add(this.titleLabel,
				javax.swing.JLayeredPane.DEFAULT_LAYER);

		this.descriptionLabel.setFont(new java.awt.Font("DejaVu Sans", 0, 11));
		this.descriptionLabel.setText(this.bundle
				.getString("ReportGenerationPanel.rep_gen_desc_msg.text")); // NOI18N
		this.descriptionLabel.setName("labelReportFuncDescription"); // NOI18N
		this.descriptionLabel.setBounds(160, 50, 530, 14);
		this.mainLayeredPane.add(this.descriptionLabel,
				javax.swing.JLayeredPane.DEFAULT_LAYER);

		this.banner_bg
				.setIcon(new javax.swing.ImageIcon(
						getClass()
								.getResource(
										"/com/smartmatic/waffle/ecm/client/resources/barra titulo subtitulo.jpg"))); // NOI18N
		this.banner_bg.setName("labelBannerBG"); // NOI18N
		this.banner_bg.setPreferredSize(new java.awt.Dimension(1440, 120));
		this.banner_bg.setBounds(0, 0, 1440, 120);
		this.mainLayeredPane.add(this.banner_bg,
				javax.swing.JLayeredPane.DEFAULT_LAYER);

		this.mainProgressBar.setName("progressBarMain"); // NOI18N
		this.mainProgressBar.setStringPainted(true);

		this.statusLabel.setName("labelResult"); // NOI18N

		this.mainPanel.setMinimumSize(new java.awt.Dimension(400, 150));
		this.mainPanel.setName("panelRegionNav"); // NOI18N

		javax.swing.GroupLayout jPanel1Layout = new javax.swing.GroupLayout(
				this.mainPanel);
		this.mainPanel.setLayout(jPanel1Layout);
		jPanel1Layout.setHorizontalGroup(jPanel1Layout.createParallelGroup(
				javax.swing.GroupLayout.Alignment.LEADING).addGap(0, 711,
				Short.MAX_VALUE));
		jPanel1Layout.setVerticalGroup(jPanel1Layout.createParallelGroup(
				javax.swing.GroupLayout.Alignment.LEADING).addGap(0, 132,
				Short.MAX_VALUE));

		javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
		this.setLayout(layout);
		layout.setHorizontalGroup(layout
				.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addComponent(this.mainLayeredPane,
						javax.swing.GroupLayout.DEFAULT_SIZE, 1296,
						Short.MAX_VALUE)
				.addGroup(
						layout.createSequentialGroup()
								.addGap(41, 41, 41)
								.addGroup(
										layout.createParallelGroup(
												javax.swing.GroupLayout.Alignment.LEADING)
												.addComponent(
														this.mainProgressBar,
														javax.swing.GroupLayout.Alignment.TRAILING,
														javax.swing.GroupLayout.DEFAULT_SIZE,
														1216, Short.MAX_VALUE)
												.addGroup(
														layout.createSequentialGroup()
																.addGroup(
																		layout.createParallelGroup(
																				javax.swing.GroupLayout.Alignment.LEADING)
																				.addComponent(
																						this.statusLabel)
																				.addComponent(
																						this.reportTypeComboBox,
																						javax.swing.GroupLayout.PREFERRED_SIZE,
																						398,
																						javax.swing.GroupLayout.PREFERRED_SIZE)
																				.addComponent(
																						this.printReportWithoutPasswordCheckBox,
																						javax.swing.GroupLayout.PREFERRED_SIZE,
																						398,
																						javax.swing.GroupLayout.PREFERRED_SIZE))
																.addGap(107,
																		107,
																		107)
																.addComponent(
																		this.mainPanel,
																		javax.swing.GroupLayout.DEFAULT_SIZE,
																		javax.swing.GroupLayout.DEFAULT_SIZE,
																		Short.MAX_VALUE)))
								.addGap(39, 39, 39))
				.addGroup(
						layout.createSequentialGroup()
								.addGap(546, 546, 546)
								.addComponent(this.generationButton,
										javax.swing.GroupLayout.PREFERRED_SIZE,
										197,
										javax.swing.GroupLayout.PREFERRED_SIZE)
								.addContainerGap(553, Short.MAX_VALUE)));
		layout.setVerticalGroup(layout
				.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addGroup(
						layout.createSequentialGroup()
								.addComponent(this.mainLayeredPane,
										javax.swing.GroupLayout.PREFERRED_SIZE,
										125,
										javax.swing.GroupLayout.PREFERRED_SIZE)
								.addGroup(
										layout.createParallelGroup(
												javax.swing.GroupLayout.Alignment.LEADING)
												.addGroup(
														layout.createSequentialGroup()
																.addGap(65, 65,
																		65)
																.addComponent(
																		this.reportTypeComboBox,
																		javax.swing.GroupLayout.PREFERRED_SIZE,
																		javax.swing.GroupLayout.DEFAULT_SIZE,
																		javax.swing.GroupLayout.PREFERRED_SIZE)
																.addGap(8, 8, 8)
																.addComponent(
																		this.printReportWithoutPasswordCheckBox,
																		javax.swing.GroupLayout.PREFERRED_SIZE,
																		javax.swing.GroupLayout.DEFAULT_SIZE,
																		javax.swing.GroupLayout.PREFERRED_SIZE)
																.addGap(8, 8, 8)
																.addComponent(
																		this.statusLabel))
												.addGroup(
														layout.createSequentialGroup()
																.addGap(11, 11,
																		11)
																.addComponent(
																		this.mainPanel,
																		javax.swing.GroupLayout.PREFERRED_SIZE,
																		132,
																		javax.swing.GroupLayout.PREFERRED_SIZE)))
								.addGap(48, 48, 48)
								.addComponent(this.generationButton,
										javax.swing.GroupLayout.PREFERRED_SIZE,
										80,
										javax.swing.GroupLayout.PREFERRED_SIZE)
								.addGap(47, 47, 47)
								.addComponent(this.mainProgressBar,
										javax.swing.GroupLayout.PREFERRED_SIZE,
										javax.swing.GroupLayout.DEFAULT_SIZE,
										javax.swing.GroupLayout.PREFERRED_SIZE)
								.addContainerGap(364, Short.MAX_VALUE)));

		this.mainPanel.add(this.regionNavigator);
		this.regionNavigator.setVisible(true);
		this.regionNavigator.setSize(this.regionNavigator.getPreferredSize());
	}

	private javax.swing.JLabel banner_bg;

	private javax.swing.JLabel descriptionLabel;

	private javax.swing.JLabel logoLabel;

	private javax.swing.JLabel titleLabel;

	private javax.swing.JButton generationButton;

	private javax.swing.JComboBox reportTypeComboBox;

	private javax.swing.JLabel statusLabel;

	private javax.swing.JLayeredPane mainLayeredPane;

	private javax.swing.JPanel mainPanel;

	private javax.swing.JProgressBar mainProgressBar;

	private javax.swing.JCheckBox printReportWithoutPasswordCheckBox;
}
