/**
 * ScreenshotGenerationPanel.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */

package com.smartmatic.waffle.ecm.client.ui;

import java.io.File;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.ResourceBundle;
import java.util.Set;

import javax.swing.JFileChooser;
import javax.xml.datatype.Duration;

import org.jdesktop.application.Action;

import com.smartmatic.waffle.domain.contest.ContestClassData;
import com.smartmatic.waffle.domain.contest.ContestData;
import com.smartmatic.waffle.domain.i18n.LanguageData;
import com.smartmatic.waffle.domain.security.FunctionalityDefinitionEnum;
import com.smartmatic.waffle.ecm.client.ECMClientSideConstants;
import com.smartmatic.waffle.ecm.client.ECMServiceProvider;
import com.smartmatic.waffle.ecm.client.providers.ContestBrowserHierarchyProvider;
import com.smartmatic.waffle.ecm.client.ui.controller.IRefreshRegionWidget;
import com.smartmatic.waffle.ecm.data.transfer.objects.BrowserHierarchyDTO;
import com.smartmatic.waffle.ecm.ui.controls.Browser.BrowserHierarchy;
import com.smartmatic.waffle.ecm.ui.core.i18n.controller.LanguageController;
import com.smartmatic.waffle.ecm.ui.util.ECMOptionPane;
import com.smartmatic.waffle.localpersistence.SAESCommonDestinations;
import com.smartmatic.waffle.localpersistence.SAESLocalPersistenceManager;
import com.smartmatic.waffle.log.SMTTLogger;

/**
 * The Class is used to load and draw all the necessary components for the
 * Screenshot Generation Panel.
 */
public class ScreenshotGenerationPanel extends javax.swing.JPanel implements
		GUIGenerationInterface, IRefreshRegionWidget {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = -6153203375383131376L;

	/** The logger. */
	private static SMTTLogger logger = SMTTLogger
			.getLogger(ScreenshotGenerationPanel.class);

	/** The bundle. */
	private java.util.ResourceBundle bundle;

	/** The processing screenshots flag. */
	private boolean processingScreenshotsFlag = false;

	/** The startedschedule check mounted devices. */
	private boolean startedscheduleCheckMountedDevices = false;

	/** The contest list. */
	private List<ContestData> contestList;

	/** The reg lvl nav. */
	private BrowserHierarchy contestNavigation = null;

	/**
	 * ScreenShots generation controller
	 */
	private ScreenshotsGenerationController screenshotsGenerationController;

	/**
	 * ScreenShots processing controller
	 */
	private ScreenshotsProcessingController screenshotsProcessingController;

	/**
	 * FunctionalityDefinitionEnum to define the tab to set focus.
	 */
	final FunctionalityDefinitionEnum functionalityDefinitionEnum = FunctionalityDefinitionEnum.SCREENSHOT_GENERATION;

	/**
	 * Creates new form FileGenerationPanel.
	 */
	public ScreenshotGenerationPanel() {

		ContestBrowserHierarchyProvider contestProvider = getWidgetContests();

		this.bundle = java.util.ResourceBundle
				.getBundle("com/smartmatic/waffle/ecm/client/resources/ECMApp"); // NOI18N

		String titleName = this.bundle
				.getString("BrowserHierarchy.table.header.nameColumn");

		this.contestNavigation = new BrowserHierarchy(contestProvider, true,
				titleName);

		initComponents();

		hideResources();
		unLockPanelButtons();
	}

	/**
	 * Return the provider that will fill the contest navigation widget.
	 * 
	 * @return contest provider.
	 */
	private ContestBrowserHierarchyProvider getWidgetContests() {

		try {
			LanguageData selectedLanguage = LanguageController.getInstance()
					.getSelectedLanguage();

			this.contestList = ECMServiceProvider.getContestByContestClass(
					null, selectedLanguage);

			List<ContestClassData> contestClassList = new ArrayList<ContestClassData>();

			Map<String, List<ContestData>> contestClassContestsMap = new HashMap<String, List<ContestData>>();

			for (ContestData contest : this.contestList) {

				if (contestClassContestsMap.containsKey(contest
						.getContestClass().getCustomCode())) {

					List<ContestData> contestListTmp = contestClassContestsMap
							.get(contest.getContestClass().getCustomCode());

					if (!contestListTmp.contains(contest)) {
						contestListTmp.add(contest);
					}
				} else {
					contestClassList.add(contest.getContestClass());
					List<ContestData> contestListTmp = new ArrayList<ContestData>();
					contestListTmp.add(contest);
					contestClassContestsMap.put(contest.getContestClass()
							.getCustomCode(), contestListTmp);
				}
			}

			ContestBrowserHierarchyProvider provider = new ContestBrowserHierarchyProvider(
					contestClassContestsMap, contestClassList);

			return provider;
		} catch (Exception e) {
			logger.error(e, e.getMessage());

			showErrorMessage("ErrorMessage.GENERIC_ERROR");
		}
		return null;
	}

	/**
	 * Returns a file chosen by the user.
	 * 
	 * @param mountedPath
	 *            the mounted path
	 * @return the chosen file
	 */
	public File chooseFile(String mountedPath) {
		javax.swing.JFileChooser fileChooser = new javax.swing.JFileChooser();
		fileChooser.setFileSelectionMode(JFileChooser.FILES_ONLY);
		fileChooser.setAcceptAllFileFilterUsed(false);
		fileChooser.setCurrentDirectory(new File(mountedPath));
		fileChooser
				.setDialogTitle(this.bundle
						.getString("ScreenshotGenerationPanel.message.folderChooserTitle"));
		fileChooser.setSelectedFile(new File(
				ECMClientSideConstants.SCREEN_SHOT_FILE));
		File destFile = null;
		int returnVal = fileChooser.showSaveDialog(this);
		if (returnVal == JFileChooser.APPROVE_OPTION) {
			destFile = fileChooser.getSelectedFile();
		} else {
			ECMServiceProvider.focusTab(this.functionalityDefinitionEnum);
			int option = ECMOptionPane
					.showConfirmDialog(
							this,
							this.bundle
									.getString("ScreenshotGenerationPanel.copyScreenshot.confirmationDialog.folderChooserWarning"),
							this.bundle
									.getString("ScreenshotGenerationPanel.copyScreenshot.confirmationDialog.title"),
							ECMOptionPane.YES_NO_OPTION,
							ECMOptionPane.CONFIRM_DIALOG);
			if (option != ECMOptionPane.YES_OPTION) {
				this.chooseFile(mountedPath);
			}
		}
		return destFile;
	}

	private void setButtonsText() {
		this.generateDeviceButton
				.setText(this.bundle
						.getString("ScreenshotGenerationPanel.generate_device_button.text"));
		this.processScreenshotsButton
				.setText(this.bundle
						.getString("ScreenshotGenerationPanel.image_device_button.text"));
	}

	/**
	 * Resets the screenshot generation panel to initial state.
	 */
	private void resetScreen() {
		ECMServiceProvider.focusTab(this.functionalityDefinitionEnum);
		hideResources();
		this.startedscheduleCheckMountedDevices = false;
		enableGenerateButton(true);
		enableProcessImageButton(true);
		setButtonsText();
		unLockPanelButtons();
		this.processingScreenshotsFlag = false;
		this.downMessageLabel
				.setText(this.bundle
						.getString("ScreenshotGenerationPanel.message.waiting_for_media_drive"));

		if (this.screenshotsGenerationController != null) {
			this.screenshotsGenerationController.stopDriveFinderWorker();
		}
		if (this.screenshotsProcessingController != null) {
			this.screenshotsProcessingController.stopDriveFinderWorker();
		}
		this.screenshotsGenerationController = null;
		this.screenshotsProcessingController = null;
	}

	/***
	 * Hides elements used during processing.
	 */
	private void hideResources() {
		this.insertPendriveLabel.setVisible(false);
		this.statusIconLabel.setVisible(false);
		this.mainProgressBar.setVisible(false);
		this.imageIconLabel.setVisible(false);
		this.downMessageLabel.setVisible(false);
		this.statusLabel.setVisible(false);
	}

	/**
	 * Unlock panel buttons.
	 */
	public void unLockPanelButtons() {
		HashSet<FunctionalityDefinitionEnum> funcs = new HashSet<FunctionalityDefinitionEnum>();
		funcs.add(FunctionalityDefinitionEnum.SCREENSHOT_GENERATION);
		ECMServiceProvider.blockOtherTabsByFunctionality(funcs, false);
	}

	/**
	 * Validate screenshot generation pre-conditions.
	 *
	 * @return true, if all preconditions are done
	 */
	public boolean validateScreenshotGenerationPreConditions() {

		if (this.getSelectedObjects().size() == 0) {
			showErrorMessage("MasterUsbGenerationPanel.message.no.option.selected");
			return false;
		}

		SAESCommonDestinations defaultDestinations = SAESLocalPersistenceManager
				.getInstance().getDefaultDestinations();

		if (!defaultDestinations.votingDeviceScreenShotImage.exists()) {
			showErrorMessage("MasterUsbMergedPanel.image_not_loaded");
			return false;
		}

		return true;
	}

	@Override
	public int showConfirmDialogStartGeneration(String mountedPath) {

		int result = ECMOptionPane
				.showConfirmDialog(
						this,
						this.bundle
								.getString("FileGenerationPanel.message.format.device")
								+ mountedPath
								+ this.bundle
										.getString("FileGenerationPanel.message.format.device.quetion"),
						this.bundle
								.getString("ScreenshotGenerationPanel.copyScreenshot.confirmationDialog.title"),
						ECMOptionPane.YES_NO_OPTION,
						ECMOptionPane.CONFIRM_DIALOG);

		if (result != 0) {
			showCanceledByUserMessage();
		}

		return result;
	}

	@Override
	public boolean getGenerateNewInitKey() {
		return false;
	}

	/**
	 * Performs operations to process the screenshots.
	 */
	@Action
	public void proccessScreenshots() {
		HashSet<FunctionalityDefinitionEnum> funcs = new HashSet<FunctionalityDefinitionEnum>();
		funcs.add(FunctionalityDefinitionEnum.SCREENSHOT_GENERATION);
		funcs.add(FunctionalityDefinitionEnum.KEY_GENERATION);

		if (!this.startedscheduleCheckMountedDevices) {
			ECMServiceProvider.blockOtherTabsByFunctionality(funcs, true);
			this.processingScreenshotsFlag = true;
			startListenerMediaToProcess();
		} else {
			showCanceledByUserMessage();
			ECMServiceProvider.blockOtherTabsByFunctionality(funcs, false);
		}
	}

	/**
	 * Generates the device with the data.
	 */
	@Action
	public void generateDevice() {

		HashSet<FunctionalityDefinitionEnum> funcs = new HashSet<FunctionalityDefinitionEnum>();
		funcs.add(FunctionalityDefinitionEnum.SCREENSHOT_GENERATION);
		funcs.add(FunctionalityDefinitionEnum.KEY_GENERATION);

		if (!this.startedscheduleCheckMountedDevices) {
			if (validateScreenshotGenerationPreConditions()) {
				ECMServiceProvider.blockOtherTabsByFunctionality(funcs, true);
				this.processingScreenshotsFlag = false;
				startListenerMediaToGenerate();
			}
		} else {
			showCanceledByUserMessage();
			ECMServiceProvider.blockOtherTabsByFunctionality(funcs, false);
		}
	}

	/**
	 * Starts a listener for a media device.
	 */
	private void startListenerMediaToProcess() {
		this.processScreenshotsButton.setText(this.bundle
				.getString("ScreenshotGenerationPanel.cancel"));
		enableGenerateButton(false);
		prepareToStartDriveFinder();

		this.screenshotsProcessingController = new ScreenshotsProcessingController(
				this);
		this.screenshotsProcessingController.startDriveFinderWorker();
	}

	/**
	 * Starts a listener for a media device.
	 */
	private void startListenerMediaToGenerate() {
		this.generateDeviceButton.setText(this.bundle
				.getString("ScreenshotGenerationPanel.cancel"));
		enableProcessImageButton(false);
		prepareToStartDriveFinder();

		this.screenshotsGenerationController = new ScreenshotsGenerationController(
				this);
		this.screenshotsGenerationController.startDriveFinderWorker();
	}

	/**
	 * Prepares interface to start pendrive detection.
	 */
	private void prepareToStartDriveFinder() {
		this.downMessageLabel.setText(this.bundle
				.getString("ScreenshotGenerationPanel.down_msg_label.text"));
		this.downMessageLabel.setVisible(true);
		this.insertPendriveLabel.setVisible(true);
		this.startedscheduleCheckMountedDevices = true;
	}

	/**
	 * Enables generate button.
	 * 
	 * @param value
	 *            the value
	 */
	private void enableGenerateButton(boolean value) {
		this.generateDeviceButton.setEnabled(value);
	}

	/**
	 * Enables process image button.
	 * 
	 * @param value
	 *            the value
	 */
	private void enableProcessImageButton(boolean value) {
		this.processScreenshotsButton.setEnabled(value);
	}

	/**
	 * Shows Informative Message.
	 * 
	 * @param message
	 *            raw message formated by bundle
	 */
	private void showMessage(String message) {
		ECMServiceProvider.focusTab(this.functionalityDefinitionEnum);
		ECMOptionPane.showMessageDialog(this, message,
				this.bundle.getString("NormalMessage.title"),
				ECMOptionPane.INFORMATION_MESSAGE,
				ECMOptionPane.INFORMATION_DIALOG);
	}

	/***
	 * This implementation active the usb generation tab before shown the popup
	 * message<br>
	 * {@inheritDoc}
	 */
	@Override
	public void showErrorMessage(String messageError) {
		ECMServiceProvider.focusTab(this.functionalityDefinitionEnum);
		ECMOptionPane.showMessageDialog(this,
				this.bundle.getString(messageError),
				this.bundle.getString("ErrorMessage.title"),
				ECMOptionPane.ERROR_MESSAGE, ECMOptionPane.ERROR_DIALOG);
		resetScreen();
	}

	@Override
	public void finishProcess(Duration duration) {
		resetScreen();
		showResultMessage(duration);
	}

	public void showResultMessage(Duration duration) {

		ECMServiceProvider.focusTab(this.functionalityDefinitionEnum);
		StringBuilder messageBuilder = new StringBuilder();
		messageBuilder.append(this.bundle
				.getString("ScreenshotGenerationPanel.message.success"));
		messageBuilder.append(" ").append(duration.getHours()).append(" ");
		messageBuilder.append(this.bundle
				.getString("ScreenshotGenerationPanel.time.hour"));
		messageBuilder.append(" ").append(duration.getMinutes()).append(" ");
		messageBuilder.append(this.bundle
				.getString("ScreenshotGenerationPanel.time.minute"));
		messageBuilder.append(" ").append(duration.getSeconds()).append(" ");
		messageBuilder.append(this.bundle
				.getString("ScreenshotGenerationPanel.time.second"));

		showMessage(messageBuilder.toString());
	}

	/**
	 * Shows message of many devices connected
	 */
	@Override
	public void showMessageManyDevicesConnected() {
		ECMOptionPane.showMessageDialog(this, this.bundle
				.getString("MasterUsbMergedPanel.many.devices.connected"),
				this.bundle.getString("WarningMessage.title"),
				ECMOptionPane.WARNING_MESSAGE, ECMOptionPane.WARNING_DIALOG);
		resetScreen();
	}

	/**
	 * Starts the screenshots generation process.
	 * 
	 * @param mountedPath
	 *            the mounted path
	 * @param partitionName
	 *            the partition name
	 */
	@Override
	public void preparePanelToProcess() {

		this.startedscheduleCheckMountedDevices = false;
		this.insertPendriveLabel.setVisible(false);
		this.downMessageLabel
				.setText(this.bundle
						.getString("ScreenshotGenerationPanel.down_msg_label_dont_remove.text"));
		setProgressBarValue(0);
		enableProcessImageButton(false);
		enableGenerateButton(false);
		setLabelStatusProcess("");
		setPendriveOkLabelVisible(false);

		if (this.processingScreenshotsFlag) {
			preparePanelToProcessImages();
		}
	}

	/**
	 * Cancels the process and resets the screenshot generation panel to its
	 * initial state.
	 */
	private void showCanceledByUserMessage() {
		resetScreen();
		showMessage(this.bundle
				.getString("ScreenshotGenerationPanel.message.calceledByUser"));

	}

	/**
	 * Finishes the second process of generation.
	 */
	public void finishSecondProcess(boolean success) {
		if (success) {
			this.showMessage(this.bundle
					.getString("ScreenshotGenerationPanel.message.second_process_finnished"));
		}
		resetScreen();
	}

	/**
	 * Displays a message when the information for the pendrive is incomplete
	 * and resets the screen.
	 */
	public void pendriveIncompleteInformation() {
		ECMOptionPane
				.showMessageDialog(
						this,
						this.bundle
								.getString("ScreenshotGenerationPanel.pendrive.incomplete.information"),
						this.bundle
								.getString("KeyGenerationPanel.popup_error_title"),
						ECMOptionPane.ERROR_MESSAGE, ECMOptionPane.ERROR_DIALOG);
		resetScreen();
	}

	@Override
	public void setLabelStatusProcessingContests(int processed, int toProcess) {

		if (processed > 0) {

			setLabelStatusProcess(getBundle().getString(
					"MasterUsbMergedPanel.status_message.procesing.contest")
					+ "[" + processed + "/" + toProcess + "]");
		} else {
			setLabelStatusProcess(getBundle().getString(
					"MasterUsbMergedPanel.status_message.getting.contest"));
		}

	}

	@Override
	public ResourceBundle getBundle() {
		return this.bundle;
	}

	public List<ContestData> getContestList() {
		return this.contestList;
	}

	/**
	 * Prepares the panel components to process images.
	 */
	private void preparePanelToProcessImages() {
		this.insertPendriveLabel.setVisible(false);
		enableProcessImageButton(false);
		this.downMessageLabel
				.setText(this.bundle
						.getString("ScreenshotGenerationPanel.down_msg_label_dont_remove.text"));

		this.startedscheduleCheckMountedDevices = false;
		setLabelStatusProcess("");
		setPendriveOkLabelVisible(false);
		setProgressBarValue(0);
		setMainProgressBarVisible(true);
		setDocumentImageLabelVisible(true);

	}

	/**
	 * Sets the document image label visible.
	 * 
	 * @param value
	 *            the new document image label visible
	 * @inheritDoc
	 */
	@Override
	public void setDocumentImageLabelVisible(boolean value) {
		this.imageIconLabel.setVisible(value);
	}

	/**
	 * Checks if is document image label visible.
	 * 
	 * @return true, if is document image label visible
	 * @inheritDoc
	 */
	@Override
	public boolean isDocumentImageLabelVisible() {
		return this.imageIconLabel.isVisible();
	}

	/***
	 * {@inheritDoc}
	 */
	@Override
	public void setMainProgressBarVisible(boolean value) {
		this.mainProgressBar.setVisible(value);
	}

	/**
	 * Checks if is main progress bar visible.
	 * 
	 * @return true, if is main progress bar visible
	 * @inheritDoc
	 */
	@Override
	public boolean isMainProgressBarVisible() {
		return this.mainProgressBar.isVisible();
	}

	/**
	 * Sets the pendrive ok label visible.
	 * 
	 * @param value
	 *            the new pendrive ok label visible
	 * @inheritDoc
	 */
	@Override
	public void setPendriveOkLabelVisible(boolean value) {
		this.statusIconLabel.setVisible(value);
	}

	/**
	 * Gets the selected objects.
	 * 
	 * @return the selected objects
	 * @inheritDoc
	 */
	@Override
	public List<Object> getSelectedObjects() {

		List<Object> selectedObjectsToReturn = new ArrayList<Object>();
		Set<BrowserHierarchyDTO> selectedNodes = this.contestNavigation
				.getSelectedObject();

		for (BrowserHierarchyDTO current : selectedNodes) {
			selectedObjectsToReturn.add(current.getId());
		}

		return selectedObjectsToReturn;
	}

	/**
	 * Sets the progress bar value.
	 * 
	 * @param value
	 *            the new progress bar value
	 * @inheritDoc
	 */
	@Override
	public void setProgressBarValue(int value) {
		this.mainProgressBar.setValue(value);
		this.mainProgressBar.setString(String.valueOf(value) + "%");
	}

	/**
	 * Sets the label status proccess.
	 * 
	 * @param message
	 *            the new label status proccess
	 * @inheritDoc
	 */
	@Override
	public void setLabelStatusProcess(String message) {
		this.statusLabel.setText(message);
	}

	/**
	 * Show label status proccess.
	 * 
	 * @param value
	 *            the value
	 * @inheritDoc
	 */
	@Override
	public void showLabelStatusProccess(boolean value) {
		this.statusLabel.setVisible(value);
	}

	/**
	 * Refresh widget.
	 * 
	 * @inheritDoc
	 */
	@Override
	public void refreshWidget() {
		this.contestNavigation.reset();
	}

	/**
	 * Sets the indeterminate bar.
	 * 
	 * @param value
	 *            the new indeterminate bar
	 */
	public void setIndeterminateBar(boolean value) {
		this.mainProgressBar.setValue(0);
		this.mainProgressBar.setString(0 + "%");
		this.mainProgressBar.setIndeterminate(value);
		this.mainProgressBar.setStringPainted(!value);
	}

	/**
	 * Sets the bad lock icon in pendrive ok label.
	 * 
	 * @inheritDoc
	 */
	@Override
	public void setVerificationIconInPendriveOkLabel() {
		this.statusIconLabel
				.setIcon(new javax.swing.ImageIcon(
						getClass()
								.getResource(
										"/com/smartmatic/waffle/ecm/client/resources/usb_find_errors.gif")));
		this.repaint();
	}

	/**
	 * Sets the copy os icon in pendrive ok label.
	 * 
	 * @inheritDoc
	 */
	@Override
	public void setCopyOsIconInPendriveOkLabel() {
		this.statusIconLabel
				.setIcon(new javax.swing.ImageIcon(
						getClass()
								.getResource(
										"/com/smartmatic/waffle/ecm/client/resources/upload_memory.gif")));
		this.repaint();
	}

	/***
	 * {@inheritDoc}
	 */
	@Override
	public void setPrepareContestIconInPendriveOkLabel() {
		this.statusIconLabel
				.setIcon(new javax.swing.ImageIcon(
						getClass()
								.getResource(
										"/com/smartmatic/waffle/ecm/client/resources/build_contest.gif")));
		this.repaint();
	}

	/**
	 * Sets the sync and unmount icon in pendrive label.
	 * 
	 * @inheritDoc
	 */
	@Override
	public void setSyncAndUnmountIconInPendriveOkLabel() {
		this.statusIconLabel
				.setIcon(new javax.swing.ImageIcon(
						getClass()
								.getResource(
										"/com/smartmatic/waffle/ecm/client/resources/syncAndUmountDrive.gif")));
		this.repaint();
	}

	/**
	 * Inits the components.
	 */
	private void initComponents() {

		this.compressedScreenshotsFileChooser = new javax.swing.JFileChooser();
		this.informationLayeredPane = new javax.swing.JLayeredPane();
		this.logoLabel = new javax.swing.JLabel();
		this.titleLabel = new javax.swing.JLabel();
		this.descriptionLabel = new javax.swing.JLabel();
		this.bannerBackgroundLabel = new javax.swing.JLabel();
		this.regNavPanel = new javax.swing.JPanel();
		this.regionWidgetPanel = new javax.swing.JPanel();
		this.mainPanel = new javax.swing.JPanel();
		this.mainLayeredPane = new javax.swing.JLayeredPane();
		this.mainProgressBar = new javax.swing.JProgressBar();
		this.generateDeviceButton = new javax.swing.JButton();
		this.processScreenshotsButton = new javax.swing.JButton();
		this.imageIconLabel = new javax.swing.JLabel();
		this.statusIconLabel = new javax.swing.JLabel();
		this.insertPendriveLabel = new javax.swing.JLabel();
		this.downMessageLabel = new javax.swing.JLabel();
		this.statusLabel = new javax.swing.JLabel();

		this.compressedScreenshotsFileChooser
				.setFileSelectionMode(javax.swing.JFileChooser.DIRECTORIES_ONLY);
		this.compressedScreenshotsFileChooser.setName("fileChooserImagePath"); // NOI18N

		setBorder(javax.swing.BorderFactory
				.createBevelBorder(javax.swing.border.BevelBorder.RAISED));

		this.informationLayeredPane.setName("layeredPaneFunctionalityInfo"); // NOI18N

		this.logoLabel
				.setIcon(new javax.swing.ImageIcon(
						getClass()
								.getResource(
										"/com/smartmatic/waffle/ecm/client/resources/filegeneration.png"))); // NOI18N
		this.logoLabel.setName("labelFunctionalityIcon"); // NOI18N
		this.logoLabel.setBounds(30, 10, 120, 90);
		this.informationLayeredPane.add(this.logoLabel,
				javax.swing.JLayeredPane.DEFAULT_LAYER);

		this.titleLabel.setFont(new java.awt.Font("DejaVu Sans", 1, 14));
		this.titleLabel.setText(this.bundle
				.getString("ScreenshotGenerationPanel.main_title_label.text")); // NOI18N
		this.titleLabel.setName("labelScreenshotTitle"); // NOI18N
		this.titleLabel.setBounds(160, 20, 543, 17);
		this.informationLayeredPane.add(this.titleLabel,
				javax.swing.JLayeredPane.DEFAULT_LAYER);

		this.descriptionLabel.setFont(new java.awt.Font("DejaVu Sans", 0, 11));
		this.descriptionLabel
				.setText(this.bundle
						.getString("ScreenshotGenerationPanel.main_description_label.text")); // NOI18N
		this.descriptionLabel.setName("labelScreenshotDescription"); // NOI18N
		this.descriptionLabel.setBounds(190, 40, 860, 14);
		this.informationLayeredPane.add(this.descriptionLabel,
				javax.swing.JLayeredPane.DEFAULT_LAYER);

		this.bannerBackgroundLabel
				.setIcon(new javax.swing.ImageIcon(
						getClass()
								.getResource(
										"/com/smartmatic/waffle/ecm/client/resources/barra titulo subtitulo.jpg"))); // NOI18N
		this.bannerBackgroundLabel.setName("labelBannerBackground"); // NOI18N
		this.bannerBackgroundLabel.setPreferredSize(new java.awt.Dimension(
				1440, 120));
		this.bannerBackgroundLabel.setBounds(0, -10, 1540, 140);
		this.informationLayeredPane.add(this.bannerBackgroundLabel,
				javax.swing.JLayeredPane.DEFAULT_LAYER);

		this.regNavPanel.setMaximumSize(new java.awt.Dimension(32767, 160));
		this.regNavPanel.setMinimumSize(new java.awt.Dimension(800, 160));
		this.regNavPanel.setName("panelMainRegionWidgetNavigator"); // NOI18N
		this.regNavPanel.setPreferredSize(new java.awt.Dimension(1036, 160));

		this.regionWidgetPanel
				.setMaximumSize(new java.awt.Dimension(1336, 150));
		this.regionWidgetPanel.setMinimumSize(new java.awt.Dimension(591, 150));
		this.regionWidgetPanel.setName("panelRegionWidgetNavigator"); // NOI18N
		this.regionWidgetPanel
				.setPreferredSize(new java.awt.Dimension(744, 140));

		javax.swing.GroupLayout jPanel2Layout = new javax.swing.GroupLayout(
				this.regionWidgetPanel);
		this.regionWidgetPanel.setLayout(jPanel2Layout);
		jPanel2Layout.setHorizontalGroup(jPanel2Layout.createParallelGroup(
				javax.swing.GroupLayout.Alignment.LEADING).addGap(0, 750,
				Short.MAX_VALUE));
		jPanel2Layout.setVerticalGroup(jPanel2Layout.createParallelGroup(
				javax.swing.GroupLayout.Alignment.LEADING).addGap(0, 115,
				Short.MAX_VALUE));

		this.regionWidgetPanel = this.contestNavigation;

		javax.swing.GroupLayout regNavPanelLayout = new javax.swing.GroupLayout(
				this.regNavPanel);
		this.regNavPanel.setLayout(regNavPanelLayout);
		regNavPanelLayout.setHorizontalGroup(regNavPanelLayout
				.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addGroup(
						regNavPanelLayout
								.createSequentialGroup()
								.addGap(310, 310, 310)
								.addComponent(this.regionWidgetPanel,
										javax.swing.GroupLayout.PREFERRED_SIZE,
										750,
										javax.swing.GroupLayout.PREFERRED_SIZE)
								.addContainerGap(262, Short.MAX_VALUE)));
		regNavPanelLayout.setVerticalGroup(regNavPanelLayout
				.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addGroup(
						regNavPanelLayout
								.createSequentialGroup()
								.addContainerGap()
								.addComponent(this.regionWidgetPanel,
										javax.swing.GroupLayout.PREFERRED_SIZE,
										115,
										javax.swing.GroupLayout.PREFERRED_SIZE)
								.addContainerGap(25, Short.MAX_VALUE)));

		this.regionWidgetPanel.setVisible(true);
		this.contestNavigation.setVisible(true);

		this.mainPanel.setName("panelScreenshotGenerator"); // NOI18N
		this.mainPanel.setPreferredSize(new java.awt.Dimension(1324, 551));

		this.mainLayeredPane.setName("layeredPaneScreenshotGenerator"); // NOI18N

		this.mainProgressBar.setName("progressBarMain"); // NOI18N
		this.mainProgressBar.setStringPainted(true);
		this.mainProgressBar.setBounds(520, 200, 274, 20);
		this.mainLayeredPane.add(this.mainProgressBar,
				javax.swing.JLayeredPane.DEFAULT_LAYER);

		javax.swing.ActionMap actionMap = org.jdesktop.application.Application
				.getInstance().getContext()
				.getActionMap(ScreenshotGenerationPanel.class, this);
		this.generateDeviceButton.setAction(actionMap.get("generateDevice")); // NOI18N
		this.generateDeviceButton
				.setText(this.bundle
						.getString("ScreenshotGenerationPanel.generate_device_button.text")); // NOI18N
		this.generateDeviceButton.setName("buttonGenerateDevice"); // NOI18N
		this.generateDeviceButton.setBounds(410, 250, 230, 40);
		this.mainLayeredPane.add(this.generateDeviceButton,
				javax.swing.JLayeredPane.DEFAULT_LAYER);

		this.processScreenshotsButton.setAction(actionMap
				.get("proccessScreenshots")); // NOI18N
		java.util.ResourceBundle bundle1 = java.util.ResourceBundle
				.getBundle("com/smartmatic/waffle/ecm/client/resources/ECMApp"); // NOI18N
		this.processScreenshotsButton
				.setText(bundle1
						.getString("ScreenshotGenerationPanel.image_device_button.text")); // NOI18N
		this.processScreenshotsButton.setName("buttonImageDevice"); // NOI18N
		this.processScreenshotsButton.setBounds(670, 250, 230, 40);
		this.mainLayeredPane.add(this.processScreenshotsButton,
				javax.swing.JLayeredPane.DEFAULT_LAYER);
		this.processScreenshotsButton.getAccessibleContext().setAccessibleName(
				"ProcessImages"); // NOI18N

		this.imageIconLabel
				.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
		this.imageIconLabel
				.setIcon(new javax.swing.ImageIcon(
						getClass()
								.getResource(
										"/com/smartmatic/waffle/ecm/client/resources/download.gif"))); // NOI18N
		this.imageIconLabel.setName("labelDocumentImage"); // NOI18N
		this.imageIconLabel.setBounds(590, 50, 130, 120);
		this.mainLayeredPane.add(this.imageIconLabel,
				javax.swing.JLayeredPane.DEFAULT_LAYER);

		this.statusIconLabel
				.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
		this.statusIconLabel
				.setIcon(new javax.swing.ImageIcon(
						getClass()
								.getResource(
										"/com/smartmatic/waffle/ecm/client/resources/upload_memory.gif"))); // NOI18N
		this.statusIconLabel.setName("labelPendriveOk"); // NOI18N
		this.statusIconLabel.setBounds(540, 0, 230, 220);
		this.mainLayeredPane.add(this.statusIconLabel,
				javax.swing.JLayeredPane.DEFAULT_LAYER);

		this.insertPendriveLabel
				.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
		this.insertPendriveLabel
				.setIcon(new javax.swing.ImageIcon(
						getClass()
								.getResource(
										"/com/smartmatic/waffle/ecm/client/resources/connect_usb_horizontal.gif"))); // NOI18N
		this.insertPendriveLabel.setName("labelInsertPenDrive"); // NOI18N
		this.insertPendriveLabel.setBounds(540, 0, 230, 220);
		this.mainLayeredPane.add(this.insertPendriveLabel,
				javax.swing.JLayeredPane.DEFAULT_LAYER);

		this.downMessageLabel
				.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
		this.downMessageLabel.setText(this.bundle
				.getString("ScreenshotGenerationPanel.down_msg_label.text")); // NOI18N

		this.downMessageLabel.setName("labelDownMessage"); // NOI18N
		this.downMessageLabel.setBounds(410, 290, 490, 30);
		this.mainLayeredPane.add(this.downMessageLabel,
				javax.swing.JLayeredPane.DEFAULT_LAYER);

		this.statusLabel
				.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
		this.statusLabel
				.setText(this.bundle
						.getString("ScreenshotGenerationPanel.jLabelStatusProccess.text")); // NOI18N
		this.statusLabel.setName("labelStatusProccess"); // NOI18N
		this.statusLabel.setBounds(210, 220, 890, 30);
		this.mainLayeredPane.add(this.statusLabel,
				javax.swing.JLayeredPane.DEFAULT_LAYER);

		javax.swing.GroupLayout jPanel1Layout = new javax.swing.GroupLayout(
				this.mainPanel);
		this.mainPanel.setLayout(jPanel1Layout);
		jPanel1Layout.setHorizontalGroup(jPanel1Layout.createParallelGroup(
				javax.swing.GroupLayout.Alignment.LEADING).addGroup(
				javax.swing.GroupLayout.Alignment.TRAILING,
				jPanel1Layout
						.createSequentialGroup()
						.addContainerGap(13, Short.MAX_VALUE)
						.addComponent(this.mainLayeredPane,
								javax.swing.GroupLayout.PREFERRED_SIZE, 1317,
								javax.swing.GroupLayout.PREFERRED_SIZE)
						.addContainerGap()));
		jPanel1Layout.setVerticalGroup(jPanel1Layout.createParallelGroup(
				javax.swing.GroupLayout.Alignment.LEADING).addGroup(
				javax.swing.GroupLayout.Alignment.TRAILING,
				jPanel1Layout
						.createSequentialGroup()
						.addComponent(this.mainLayeredPane,
								javax.swing.GroupLayout.PREFERRED_SIZE, 340,
								javax.swing.GroupLayout.PREFERRED_SIZE)
						.addContainerGap(55, Short.MAX_VALUE)));

		javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
		this.setLayout(layout);
		layout.setHorizontalGroup(layout
				.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addComponent(this.informationLayeredPane,
						javax.swing.GroupLayout.DEFAULT_SIZE, 1342,
						Short.MAX_VALUE)
				.addGroup(
						layout.createSequentialGroup()
								.addComponent(this.regNavPanel,
										javax.swing.GroupLayout.DEFAULT_SIZE,
										1330, Short.MAX_VALUE)
								.addContainerGap())
				.addComponent(this.mainPanel,
						javax.swing.GroupLayout.DEFAULT_SIZE, 1342,
						Short.MAX_VALUE));
		layout.setVerticalGroup(layout
				.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addGroup(
						layout.createSequentialGroup()
								.addComponent(this.informationLayeredPane,
										javax.swing.GroupLayout.PREFERRED_SIZE,
										124,
										javax.swing.GroupLayout.PREFERRED_SIZE)
								.addPreferredGap(
										javax.swing.LayoutStyle.ComponentPlacement.RELATED,
										javax.swing.GroupLayout.DEFAULT_SIZE,
										Short.MAX_VALUE)
								.addComponent(this.regNavPanel,
										javax.swing.GroupLayout.PREFERRED_SIZE,
										152,
										javax.swing.GroupLayout.PREFERRED_SIZE)
								.addPreferredGap(
										javax.swing.LayoutStyle.ComponentPlacement.RELATED)
								.addComponent(this.mainPanel,
										javax.swing.GroupLayout.PREFERRED_SIZE,
										395,
										javax.swing.GroupLayout.PREFERRED_SIZE)
								.addGap(515, 515, 515)));
	}

	private javax.swing.JLabel bannerBackgroundLabel;

	private javax.swing.JLabel imageIconLabel;

	private javax.swing.JLabel downMessageLabel;

	private javax.swing.JButton generateDeviceButton;

	private javax.swing.JButton processScreenshotsButton;

	private javax.swing.JFileChooser compressedScreenshotsFileChooser;

	private javax.swing.JLabel insertPendriveLabel;

	private javax.swing.JLabel statusLabel;

	private javax.swing.JLayeredPane mainLayeredPane;

	private javax.swing.JLayeredPane informationLayeredPane;

	private javax.swing.JPanel mainPanel;

	private javax.swing.JPanel regionWidgetPanel;

	private javax.swing.JLabel logoLabel;

	private javax.swing.JProgressBar mainProgressBar;

	private javax.swing.JLabel descriptionLabel;

	private javax.swing.JLabel titleLabel;

	private javax.swing.JLabel statusIconLabel;

	private javax.swing.JPanel regNavPanel;
}