/**
 * MonitoringDriveException.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.ui.common;

import com.smartmatic.waffle.lang.BaseException;
import com.smartmatic.waffle.lang.IExceptionInfo;

/**
 * Class used to be thrown if a error on drive monitoring is detected.
 */
public class MonitoringDriveException extends BaseException {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = -2389446972044693779L;

	/**
	 * Enum that contains all the possible reasons because the
	 * DriveRemovedExeption can be thrown.
	 */
	public enum ExceptionInfo implements IExceptionInfo {

		/** The drive has been removed. */
		DRIVE_HAS_BEEN_REMOVED("DRIVE_HAS_BEEN_REMOVED"),
		/** The unknown error monitoring drive. */
		UNKNOWN_ERROR_MONITORING_DRIVE("UNKNOWN_ERROR_MONITORING_DRIVE");

		/**
		 * <p>
		 * Each enumerator's resource bundle's key message.
		 * </p>
		 */
		private String message;

		/**
		 * Getter of <code>message</code> property.
		 * 
		 * @return <code>message</code> property value.
		 * @see #message
		 */
		@Override
		public String getMessage() {
			return this.message;
		}

		/**
		 * Constructor.
		 * 
		 * @param message
		 *            the resource bundle's key message
		 */
		private ExceptionInfo(String message) {
			this.message = this.getClass().getName() + "." + message;
		}
	}

	/**
	 * Instantiates a new monitoring drive exception.
	 * 
	 * @param exceptionInfo
	 *            the exception info
	 */
	public MonitoringDriveException(IExceptionInfo exceptionInfo) {
		super(exceptionInfo);
	}

	/**
	 * Instantiates a new monitoring drive exception.
	 * 
	 * @param exceptionInfo
	 *            the exception info
	 * @param e
	 *            the e
	 */
	public MonitoringDriveException(IExceptionInfo exceptionInfo, Throwable e) {
		super(exceptionInfo, e);
	}
}
