/**
 * BlinkListener.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */

package com.smartmatic.waffle.ecm.client.ui.common.notifications.util;

import java.awt.Color;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JLabel;

/**
 * The listener interface for receiving blink events. The class that is
 * interested in processing a blink event implements this interface, and the
 * object created with that class is registered with a component using the
 * component's <code>addBlinkListener<code> method. When
 * the blink event occurs, that object's appropriate
 * method is invoked.
 * 
 * @see BlinkEvent
 */
public class BlinkListener implements ActionListener {

	/** Label where the blinking message will be shown. */
	private JLabel label;

	/** *. */
	private Color originalColor;

	/** *. */
	private boolean isVisibleOriginal;

	/**
	 * Constructor.
	 * 
	 * @param messageLabel
	 *            , the label where the blinking message will be shown
	 * @param color
	 *            the color
	 * @param message
	 *            the message
	 */
	public BlinkListener(JLabel messageLabel, Color color, String message) {
		this.label = messageLabel;
		this.isVisibleOriginal = this.label.isVisible();
		this.label.setVisible(true);
		this.originalColor = this.label.getForeground();
		this.label.setForeground(color);
		this.label.setText(message);
	}

	/**
	 * Action performed.
	 * 
	 * @param e
	 *            the e
	 * @inheritDoc
	 */
	@Override
	public void actionPerformed(ActionEvent e) {
		this.label.setText("");
		this.label.setVisible(this.isVisibleOriginal);
		this.label.setForeground(this.originalColor);
	}
}
