/**
 * PassphraseInputDialog.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.ui.login;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.GridBagLayout;
import java.awt.event.ActionEvent;

import javax.crypto.SecretKey;
import javax.swing.ActionMap;
import javax.swing.JButton;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.SpringLayout;
import javax.swing.SwingConstants;

import org.jdesktop.application.Action;
import org.jdesktop.application.ResourceMap;
import org.jdesktop.application.Task;

import com.smartmatic.waffle.domain.user.UserData;
import com.smartmatic.waffle.ecm.ui.BaseFullScreenJDialog;
import com.smartmatic.waffle.ecm.ui.core.ShutDownMachineActionListener;
import com.smartmatic.waffle.ecm.ui.core.i18n.controller.LanguageController;
import com.smartmatic.waffle.ecm.ui.layout.SpringLayoutUtil;
import com.smartmatic.waffle.ecm.ui.util.GUIComponentUtil;

/**
 * Class used to build and render a passphrase input dialog.
 */
public abstract class PassphraseInputDialog extends BaseFullScreenJDialog {

	/**
	 * the number to serialization.
	 */
	private static final long serialVersionUID = -5788573733048828254L;

	/** The resource message bundle. */
	private ResourceMap resourceMap = LanguageController.getInstance()
			.getApplicationContext().getResourceMap();

	/** The action map. */
	protected ActionMap actionMap = LanguageController.getInstance()
			.getApplicationContext()
			.getActionMap(PassphraseInputDialog.class, this);

	/** The main frame. */
	protected JPanel mainFrame;

	/** The actual frame. */
	protected JPanel actualFrame;

	/** The shutdown button panel. */
	protected javax.swing.JPanel shutdownButtonPanel;

	/** The root. */
	protected JPanel root;

	/** The go_back_flag. */
	public boolean canceled = false;

	/** The is landscape. */
	private boolean isLandscape;

	/** Field used for the user to indicate its <code>username</code>. */
	public JTextField userField;

	/**
	 * Creates new form PassphraseInputDialog.
	 * 
	 * @param parent
	 *            the parent
	 * @param modal
	 *            the modal
	 * @param inputType
	 *            the input type
	 */
	public PassphraseInputDialog(java.awt.Frame parent) {
		super(parent, true);
		this.buildPassphraseInputDialog();
		this.reOrderMainPanel();
	}

	/**
	 * Builds the passphrase input dialog.
	 * 
	 * @param inputType
	 *            the input type
	 */
	private void buildPassphraseInputDialog() {
		this.initComponents();
		this.getRootPane().setDefaultButton(this.okButton);
		this.okButton.setText(this.getString("okButton.text"));
		this.okButton.setToolTipText(null);
		this.okButton.setEnabled(false);
		this.resetButton.setEnabled(true);
	}

	/**
	 * This method is called from within the constructor to initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is always
	 * regenerated by the Form Editor.
	 */
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// desc="Generated Code">//GEN-BEGIN:initComponents
	protected void initComponents() {
		this.shutdownButtonPanel = new javax.swing.JPanel();
		this.upperPanel = new javax.swing.JPanel();
		this.passphraseLabel = new javax.swing.JLabel();
		this.jPanel1 = new javax.swing.JPanel();
		this.passphraseTextField = new javax.swing.JPasswordField();
		this.errorLabel = new javax.swing.JLabel();
		this.lowerPanel = new javax.swing.JPanel();
		this.jPanel2 = new javax.swing.JPanel();
		this.okButton = new javax.swing.JButton();
		this.resetButton = new javax.swing.JButton();

		this.setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
		this.setName("Form"); // NOI18N
		this.getContentPane().setLayout(new java.awt.GridLayout(4, 1));

		this.upperPanel.setBorder(javax.swing.BorderFactory.createEmptyBorder(
				1, 1, 1, 1));
		this.upperPanel.setName("panelUpper"); // NOI18N

		this.passphraseLabel
				.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
		this.passphraseLabel.setName("labelPassphrase"); // NOI18N
		this.upperPanel.add(this.passphraseLabel);

		this.passphraseLabel.setFont(this.resourceMap
				.getFont("passphraseLabel.font")); // NOI18N
		this.getContentPane().add(this.upperPanel);

		this.jPanel1.setName("jPanel1"); // NOI18N

		this.passphraseTextField.setFont(this.resourceMap
				.getFont("passphraseTextField.font")); // NOI18N
		this.passphraseTextField.setHorizontalAlignment(SwingConstants.CENTER);
		this.passphraseTextField.setName("textFieldPassphrase"); // NOI18N
		this.passphraseTextField.setAction(this.actionMap
				.get("checkPassphrase"));
		this.passphraseTextField.setToolTipText(null);

		this.errorLabel
				.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
		this.errorLabel.setName("labelError"); // NOI18N
		this.errorLabel.setForeground(this.resourceMap
				.getColor("errorLabel.foreground"));

		Dimension shutDownPanelSize;

		this.isLandscape = GUIComponentUtil.isLandscape(this);

		if (this.isLandscape) {
			shutDownPanelSize = new Dimension(900, 80);
		} else {
			shutDownPanelSize = new Dimension(700, 80);
		}

		this.shutdownButtonPanel.setMaximumSize(shutDownPanelSize);
		this.shutdownButtonPanel.setMinimumSize(shutDownPanelSize);
		this.shutdownButtonPanel.setName("buttonShutdown"); // NOI18N
		this.shutdownButtonPanel.setOpaque(false);
		this.shutdownButtonPanel.setPreferredSize(shutDownPanelSize);

		JButton shutDown = new JButton();
		shutDown.addActionListener(new ShutDownMachineActionListener(this,
				true, false));

		Dimension shutDownDimension = new Dimension(60, 60);
		shutDown.setPreferredSize(shutDownDimension);
		shutDown.setMaximumSize(shutDownDimension);
		shutDown.setMinimumSize(shutDownDimension);
		shutDown.setAlignmentY(CENTER_ALIGNMENT);
		shutDown.setAlignmentX(CENTER_ALIGNMENT);
		shutDown.setIcon(this.resourceMap.getIcon("Application.shutdown.ico"));
		shutDown.setFocusable(false);
		shutDown.setName("buttonShutdown");

		this.shutdownButtonPanel.add(shutDown);

		javax.swing.GroupLayout jPanel1Layout = new javax.swing.GroupLayout(
				this.jPanel1);
		this.jPanel1.setLayout(jPanel1Layout);
		jPanel1Layout
				.setHorizontalGroup(jPanel1Layout
						.createParallelGroup(
								javax.swing.GroupLayout.Alignment.LEADING)
						.addGroup(
								javax.swing.GroupLayout.Alignment.TRAILING,
								jPanel1Layout
										.createSequentialGroup()
										.addContainerGap(34, Short.MAX_VALUE)
										.addGroup(
												jPanel1Layout
														.createParallelGroup(
																javax.swing.GroupLayout.Alignment.CENTER)
														.addComponent(
																this.passphraseTextField,
																javax.swing.GroupLayout.PREFERRED_SIZE,
																200,
																javax.swing.GroupLayout.PREFERRED_SIZE)
														.addComponent(
																this.errorLabel,
																javax.swing.GroupLayout.PREFERRED_SIZE,
																javax.swing.GroupLayout.DEFAULT_SIZE,
																javax.swing.GroupLayout.PREFERRED_SIZE))
										.addContainerGap(34, Short.MAX_VALUE)));
		jPanel1Layout
				.setVerticalGroup(jPanel1Layout
						.createParallelGroup(
								javax.swing.GroupLayout.Alignment.LEADING)
						.addGroup(
								jPanel1Layout
										.createSequentialGroup()
										.addGap(12, 12, 12)
										.addComponent(
												this.errorLabel,
												javax.swing.GroupLayout.PREFERRED_SIZE,
												javax.swing.GroupLayout.DEFAULT_SIZE,
												javax.swing.GroupLayout.PREFERRED_SIZE)
										.addPreferredGap(
												javax.swing.LayoutStyle.ComponentPlacement.RELATED,
												74, Short.MAX_VALUE)
										.addComponent(
												this.passphraseTextField,
												javax.swing.GroupLayout.PREFERRED_SIZE,
												javax.swing.GroupLayout.DEFAULT_SIZE,
												javax.swing.GroupLayout.PREFERRED_SIZE)
										.addContainerGap()));

		this.getContentPane().add(this.jPanel1);

		this.lowerPanel.setBorder(javax.swing.BorderFactory.createEmptyBorder(
				1, 1, 1, 1));
		this.lowerPanel.setName("panelLower"); // NOI18N
		this.lowerPanel.setLayout(new java.awt.GridLayout(1, 0));
		this.getContentPane().add(this.lowerPanel);

		this.jPanel2.setName("jPanel2"); // NOI18N

		this.okButton.setText(this.getString("OK.BUTTON.TEXT")); // NOI18N
		this.okButton
				.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
		this.okButton.setMaximumSize(new java.awt.Dimension(100, 50));
		this.okButton.setMinimumSize(new java.awt.Dimension(100, 50));
		this.okButton.setName("buttonOk"); // NOI18N
		this.okButton.setPreferredSize(new java.awt.Dimension(100, 50));
		this.okButton.setAction(this.actionMap.get("checkPassphrase")); // NOI18N

		this.resetButton.setText(this.getString("RESET.BUTTON.TEXT")); // NOI18N
		this.resetButton
				.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
		this.resetButton.setMaximumSize(new java.awt.Dimension(100, 50));
		this.resetButton.setMinimumSize(new java.awt.Dimension(100, 50));
		this.resetButton.setName("buttonReset"); // NOI18N
		this.resetButton.setPreferredSize(new java.awt.Dimension(100, 50));
		this.resetButton.addActionListener(new java.awt.event.ActionListener() {
			@Override
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				PassphraseInputDialog.this.resetButtonActionPerformed(evt);
			}
		});
		this.jPanel2.add(this.resetButton);
		this.jPanel2.add(this.okButton);
		this.jPanel2.setMaximumSize(new java.awt.Dimension(100, 175));
		this.jPanel2.setMinimumSize(new java.awt.Dimension(100, 175));
		this.jPanel2.setPreferredSize(new java.awt.Dimension(100, 175));

		this.getContentPane().add(this.jPanel2);

		this.pack();
	}// </editor-fold>//GEN-END:initComponents

	/**
	 * Reset button action performed.
	 * 
	 * @param evt
	 *            the evt
	 */
	protected void resetButtonActionPerformed(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_resetButtonActionPerformed

		this.passphraseTextField.setText("");
		this.okButton.setEnabled(false);
		this.resetButton.setEnabled(false);

		this.canceled = true;
		PassphraseInputDialog.this.setVisible(false);
	}// GEN-LAST:event_resetButtonActionPerformed

	/**
	 * Sets the ok button action.
	 */
	public void setOkButtonAction() {
		javax.swing.ActionMap actionMap = LanguageController.getInstance()
				.getApplicationContext()
				.getActionMap(PassphraseInputDialog.class, this);
		this.okButton.setAction(actionMap.get("checkPassphrase")); // NOI18N
	}

	/**
	 * Re order main panel.
	 */
	protected void reOrderMainPanel() {
		this.actualFrame = new JPanel(new GridBagLayout());

		this.mainFrame = new JPanel(new SpringLayout());
		this.actualFrame.add(this.mainFrame);
		this.mainFrame.removeAll();
		this.mainFrame.add(this.upperPanel);
		this.mainFrame.add(this.jPanel1);
		this.mainFrame.add(this.lowerPanel);
		this.mainFrame.add(this.jPanel2);
		this.mainFrame.add(this.shutdownButtonPanel);

		this.mainFrame.setBorder(new javax.swing.border.LineBorder(Color.BLACK,
				4, true));

		SpringLayoutUtil.makeCompactGrid(this.mainFrame, 5, 1, 30, 30, 20, 20);

		this.root = (JPanel) this.getContentPane();
		this.root.removeAll();
		this.root.setLayout(new SpringLayout());
		this.root.add(this.actualFrame);
		SpringLayoutUtil.makeCompactGrid(this.root, 1, 1, 20, 20, 21, 21);
	}

	/**
	 * Ok button action performed.
	 * 
	 * @param evt
	 *            the evt
	 */
	@SuppressWarnings("unused")
	private void okButtonActionPerformed(ActionEvent evt) {// GEN-FIRST:event_okButtonActionPerformed
		this.checkPassphrase();
	}// GEN-LAST:event_okButtonActionPerformed

	/**
	 * Check passphrase.
	 * 
	 * @return the task
	 */

	@SuppressWarnings("rawtypes")
	@Action
	public abstract Task checkPassphrase();

	// Variables declaration - do not modify//GEN-BEGIN:variables
	/** The error label. */
	public javax.swing.JLabel errorLabel;

	/** The j panel1. */
	protected javax.swing.JPanel jPanel1;

	/** The j panel2. */
	protected javax.swing.JPanel jPanel2;

	/** The lower panel. */
	protected javax.swing.JPanel lowerPanel;

	/** The ok button. */
	public javax.swing.JButton okButton;

	/** The passphrase label. */
	protected javax.swing.JLabel passphraseLabel;

	/** The passphrase text field. */
	public javax.swing.JPasswordField passphraseTextField;

	/** The reset button. */
	public javax.swing.JButton resetButton;

	/** The upper panel. */
	protected javax.swing.JPanel upperPanel;
	// End of variables declaration//GEN-END:variables

	/** The secret key. */
	private SecretKey secretKey;

	/** The user. */
	public UserData user;

	/**
	 * Getter of <code>user</code> property.
	 * 
	 * @return <code>user</code> property value.
	 * @see #user
	 */
	public UserData getUser() {
		return this.user;
	}

	/**
	 * Setter of <code>user</code> property.
	 * 
	 * @param user
	 *            The <code>user</code> to set.
	 * @see #user
	 */
	public void setUser(UserData user) {
		this.user = user;
	}

	/**
	 * Sets the pBE data.
	 * 
	 * @param secretKey
	 *            the new pBE data
	 */
	public void setPBEData(SecretKey secretKey) {
		this.secretKey = secretKey;
	}

	/**
	 * Gets the secret key.
	 * 
	 * @return the secret key
	 */
	public SecretKey getSecretKey() {
		return this.secretKey;
	}

	// End of other variable declarations

	/**
	 * Returns the password entered by the user in the authentication moment.
	 * 
	 * @return the entered password
	 */
	public String getEnteredPassword() {
		return String.valueOf(this.passphraseTextField.getPassword());
	}

	/**
	 * Getter of <code>resourceMap</code> property.
	 * 
	 * @return the resourceMap
	 */
	public ResourceMap getResourceMap() {
		return this.resourceMap;
	}

	/**
	 * Getter of <code>actionMap</code> property.
	 * 
	 * @return the actionMap
	 */
	public ActionMap getActionMap() {
		return this.actionMap;
	}

}
