/**
 * BulkUploadClearDatabaseWorker.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.worker;

import org.apache.commons.lang.StringUtils;

import com.smartmatic.waffle.ecm.client.ECMServiceProvider;
import com.smartmatic.waffle.ecm.client.ui.common.AsynchronousOperation;
import com.smartmatic.waffle.ecm.client.ui.common.AwtOperationType;
import com.smartmatic.waffle.log.SMTTLogger;

/**
 * Class that executes the main process to remove all database records
 */
public class BulkUploadClearDatabaseWorker extends AsynchronousOperation {

	/** For log messages purpose. */
	private static SMTTLogger logger = SMTTLogger
			.getLogger(BulkUploadClearDatabaseWorker.class);

	/**
	 * Instantiates a new BulkUploadClearDatabaseWorker.
	 * 
	 * @param deleteOnlyCodiData
	 *            the delete only codi data
	 */
	public BulkUploadClearDatabaseWorker(boolean deleteOnlyCodiData) {
		this.deleteOnlyCodiData = deleteOnlyCodiData;
	}

	/**
	 * Gets the progress value.
	 * 
	 * @return the progress value
	 */
	public int getProgressValue() {
		return this.progressValue;
	}

	/**
	 * Gets the progress message.
	 * 
	 * @return the progress message
	 */
	public String getProgressMessage() {
		return this.progressMessage;
	}

	/**
	 * Gets the number of truncate process.
	 * 
	 * @return the number of truncate process
	 */
	public int getNumberOfTruncateProcess() {
		return this.numberOfTruncateProcess;
	}

	/**
	 * Method that execute the removal process
	 */
	public void clearDataBase() {
		try {

			int i = 0;

			if (this.deleteOnlyCodiData) {

				this.numberOfTruncateProcess = 5;

				fireAndForgetAwtEvent(AwtOperationType.UPDATE_COMPONENTS);

				refreshStatusLabel("logicalVotingGroup");

				ECMServiceProvider.truncateLogicalVotingGroup();

				updateProgressBar(++i);

				refreshStatusLabel("elegibleOptionsInfo");

				ECMServiceProvider.truncateEligibleOption();

				updateProgressBar(++i);

				refreshStatusLabel("partyAndCandidate");

				ECMServiceProvider.truncateCodiNominationTables();

				updateProgressBar(++i);

				refreshStatusLabel("electoralCenter");

				ECMServiceProvider.truncatePhysicalLocationsTables();

				updateProgressBar(++i);

				refreshStatusLabel("codiFiles");

				ECMServiceProvider.deleteEMLFiles();

				updateProgressBar(++i);

			} else {

				this.numberOfTruncateProcess = 8;

				fireAndForgetAwtEvent(AwtOperationType.UPDATE_COMPONENTS);

				refreshStatusLabel("deviceParameters");

				ECMServiceProvider.truncateDeviceParametersTable();

				updateProgressBar(++i);

				refreshStatusLabel("languageInfo");

				ECMServiceProvider.truncateLanguageTables();

				updateProgressBar(++i);

				refreshStatusLabel("contestInfo");

				ECMServiceProvider.truncateNominationTables();

				updateProgressBar(++i);

				refreshStatusLabel("userInfo");

				ECMServiceProvider.truncateUserTables();

				updateProgressBar(++i);

				refreshStatusLabel("electoralCenter");

				ECMServiceProvider.truncatePhysicalLocationsTables();

				updateProgressBar(++i);

				refreshStatusLabel("regionInfo");

				ECMServiceProvider.truncateDemographyTables();

				updateProgressBar(++i);

				refreshStatusLabel("reportingInfo");

				ECMServiceProvider.truncateReportTemplatesTables();

				updateProgressBar(++i);

				refreshStatusLabel("codiFiles");

				ECMServiceProvider.deleteEMLFiles();

				ECMServiceProvider.deleteVoiceFiles();

				updateProgressBar(++i);
			}

			fireAndForgetAwtEvent(AwtOperationType.SHOW_RESULT_MESSAGE);
		} catch (Exception e) {
			logger.error(e, StringUtils.defaultString(e.getMessage()));
			fireAndForgetAwtEvent(AwtOperationType.SHOW_ERROR_MESSAGE);
		}
	}

	/**
	 * Updates the progress bar.
	 * 
	 * @param progressValue
	 *            new progress bar value
	 */
	private void updateProgressBar(int progressValue) {

		this.progressValue = progressValue;

		fireAndForgetAwtEvent(AwtOperationType.UPDATE_PROGRESS_BAR);
	}

	/**
	 * Refreshes the status label.
	 * 
	 * @param progressMessage
	 *            the progress message
	 */
	private void refreshStatusLabel(String progressMessage) {

		this.progressMessage = progressMessage;

		fireAndForgetAwtEvent(AwtOperationType.REFRESH_LABEL);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.ecm.client.ui.common.AsynchronousOperation#
	 * performOperation()
	 */
	@Override
	protected void performOperation() {
		clearDataBase();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.smartmatic.waffle.ecm.client.ui.common.AsynchronousOperation#onCompleted
	 * ()
	 */
	@Override
	protected void onCompleted() {
	}

	/**
	 * Variable to hold the current progress bar's value.
	 */
	private int progressValue;

	/**
	 * Variable to hold the current progress message's value.
	 */
	private String progressMessage;

	/**
	 * Variable to hold with data will be removed
	 */
	private boolean deleteOnlyCodiData;

	/**
	 * Variable to hold the maximum progress bar's value.
	 */
	private int numberOfTruncateProcess;
}