/**
 * HashGetterWorker.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.worker;

import java.io.File;

import com.smartmatic.waffle.ecm.client.ui.common.AsynchronousOperation;
import com.smartmatic.waffle.ecm.client.ui.common.AwtOperationType;
import com.smartmatic.waffle.ecm.client.util.FileUtilities;

/**
 * Worker class that executes gets the sha265sum in a background thread.
 */
public class HashGetterWorker extends AsynchronousOperation {

	/** Stores the hash when calculated. */
	private String imageHash;

	/** File object to hold the abstract representation of the image. */
	private File srcFile;

	/**
	 * Instantiates a new HashGetterWorker.
	 * 
	 * @param srcFile
	 *            the source image file
	 */
	public HashGetterWorker(File srcFile) {
		this.srcFile = srcFile;
	}

	/**
	 * Gets the image hash.
	 * 
	 * @return the image hash
	 */
	public String getImageHash() {
		return this.imageHash;
	}

	/**
	 * Sets the image hash.
	 * 
	 * @param imageHash
	 *            the new image hash
	 */
	public void setImageHash(String imageHash) {
		this.imageHash = imageHash;
	}

	/**
	 * Gets the sha256 hash.
	 * 
	 * @param image
	 *            the image
	 * @return the sha256 hash
	 */
	public String getSHA256Hash() {
		return FileUtilities.getSHA256sum(this.srcFile);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.ecm.client.ui.common.AsynchronousOperation#
	 * performOperation()
	 */
	@Override
	protected void performOperation() {
		String imageHash = getSHA256Hash();
		setImageHash(imageHash);
		fireAwtEvent(AwtOperationType.REFRESH_LABEL);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.smartmatic.waffle.ecm.client.ui.common.AsynchronousOperation#onCompleted
	 * ()
	 */
	@Override
	protected void onCompleted() {
	}

}
