/**
 * UnmountingWorker.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.worker;

import com.smartmatic.waffle.ecm.client.ui.common.AsynchronousOperation;
import com.smartmatic.waffle.ecm.client.ui.common.AwtOperationType;
import com.smartmatic.waffle.ecm.core.lang.PendriveException;
import com.smartmatic.waffle.ecm.core.pendrive.util.PendriveUtil;
import com.smartmatic.waffle.log.SMTTLogger;

/**
 * Performs synchronization and unmount of mounted path
 */
public class UnmountingWorker extends AsynchronousOperation {

	/** Static SMTT logger instance. */
	private static SMTTLogger logger = SMTTLogger
			.getLogger(UnmountingWorker.class);

	/**
	 * Holds mountedPath to unmount
	 */
	private String mountedPath;

	/**
	 * Holds boolean to define if worker has finished
	 */
	private boolean isDone = false;

	/**
	 * Gets value of isDone
	 * 
	 * @return true if the worker has finished
	 */
	public boolean isDone() {
		return this.isDone;
	}

	public UnmountingWorker(String mountedPath) {
		this.mountedPath = mountedPath;
	}

	@Override
	protected void performOperation() {

		this.fireAwtEvent(AwtOperationType.UPDATE_COMPONENTS);

		try {
			PendriveUtil.chown10001000(this.mountedPath);
			PendriveUtil.sync();
			PendriveUtil.unmountPendrive(this.mountedPath, false);
		} catch (PendriveException e) {
			logger.error(e, "Error unmounting path " + this.mountedPath);
		}
	}

	@Override
	protected void onCompleted() {
		this.isDone = true;
		this.fireAwtEvent(AwtOperationType.UPDATE_COMPONENTS);
	}

}
