package com.smartmatic.waffle.ecm.client.worker;

import java.io.ByteArrayInputStream;
import java.io.InputStream;

import org.apache.commons.io.IOUtils;
import org.apache.commons.lang.StringUtils;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.Mockito;
import org.powermock.api.mockito.PowerMockito;
import org.powermock.core.classloader.annotations.PrepareForTest;
import org.powermock.modules.junit4.PowerMockRunner;

import com.smartmatic.waffle.domain.demographics.ElectionData;
import com.smartmatic.waffle.ecm.data.transfer.type.USBGenerationType;

@RunWith(PowerMockRunner.class)
@PrepareForTest({ CopyOSWorker.class })
public class CopyOSWorkerTest {

	@Test
	public void testCopyOSToMasterUSB() throws Exception {
		// arrange
		CopyOSWorker worker = PowerMockito.spy(new CopyOSWorker("/dev/sdb",
				USBGenerationType.MASTER_USB,
				"UgwzYIdmOlj/7h+7dlEHdpxtree2XUahPKf62tIbvtw="));

		InputStream is = new ByteArrayInputStream("".getBytes());

		Process process = PowerMockito.mock(Process.class);

		PowerMockito.doNothing().when(worker,
				"generateCertificatesForActiveElection");

		PowerMockito.doReturn(process).when(worker, "executeCopyCommand");
		PowerMockito.when(process.getInputStream()).thenReturn(is);

		PowerMockito.doReturn(true).when(worker, "verifyCommandOutput",
				Mockito.anyString(), Mockito.anyCollectionOf(String.class));

		PowerMockito.doNothing().when(worker, "generateCertificates",
				Mockito.any(ElectionData.class));

		PowerMockito.doReturn(StringUtils.EMPTY).when(worker,
				"parseStandardErrorToString", Mockito.any(Process.class));

		IOUtils.toString(process.getInputStream());
		// act
		worker.copyOSToMasterUSB();

		// assert
		PowerMockito.verifyPrivate(worker).invoke("executeCopyCommand");
		PowerMockito.verifyPrivate(worker).invoke("verifyCommandOutput",
				Mockito.anyString(), Mockito.anyCollectionOf(String.class));
		PowerMockito.verifyPrivate(worker).invoke("parseStandardErrorToString",
				Mockito.any(Process.class));

	}
}
