package com.smartmatic.waffle.ecm.client.worker;

import static org.junit.Assert.assertTrue;

import java.io.File;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import org.junit.Before;
import org.junit.Ignore;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.Mockito;
import org.powermock.api.mockito.PowerMockito;
import org.powermock.core.classloader.annotations.PrepareForTest;
import org.powermock.modules.junit4.PowerMockRunner;

import com.smartmatic.waffle.domain.demographics.ElectionData;
import com.smartmatic.waffle.domain.demographics.ProgrammingUnitData;
import com.smartmatic.waffle.domain.device.VotingCentersData.VotingCenter;
import com.smartmatic.waffle.domain.device.VotingDeviceData;
import com.smartmatic.waffle.domain.device.VotingDevicesData;
import com.smartmatic.waffle.domain.eligibleoption.PartyData;
import com.smartmatic.waffle.domain.i18n.LanguageData;
import com.smartmatic.waffle.ecm.client.ECMClientSideConstants;
import com.smartmatic.waffle.ecm.client.ECMServiceProvider;
import com.smartmatic.waffle.ecm.client.util.MasterFileGenerationUtils;

@RunWith(PowerMockRunner.class)
@PrepareForTest({ ScreenshotsFileGenerationWorker.class,
		ECMServiceProvider.class, MasterFileGenerationUtils.class })
public class ScreenshotsFileGenerationWorkerTest {

	ScreenshotsFileGenerationWorker screenshotsFileGenerationWorker;

	@Before
	public void setUp() {

		Map<VotingCenter, ElectionData> votingCenterElectionMap = new HashMap<VotingCenter, ElectionData>();

		VotingCenter votingCenter = new VotingCenter("voting_center_1", "rnd",
				"voting_center_1", "programming unit");

		VotingDevicesData votingDevices = new VotingDevicesData();

		votingCenter.setVotingDevices(votingDevices);

		votingCenterElectionMap.put(votingCenter, new ElectionData());

		String mountedPath = "test/resources/master_folder";

		File mountedFolder = new File(mountedPath);

		mountedFolder.mkdirs();

		this.screenshotsFileGenerationWorker = PowerMockito
				.spy(new ScreenshotsFileGenerationWorker(mountedPath,
						votingCenterElectionMap, new ArrayList()));
	}

	@Test
	@Ignore
	public void testGenerateXML() throws Exception {

		String votingDeviceCustomCode = "VOTING_DEVICE";

		ProgrammingUnitData programmingUnit = new ProgrammingUnitData();
		programmingUnit.setCustomCode("PU_1");

		VotingDevicesData votingDevices = new VotingDevicesData();
		VotingDeviceData votingDevice = new VotingDeviceData();

		Set<LanguageData> languages = new HashSet<LanguageData>();

		votingDevice.setLanguages(languages);

		votingDevices.setVotingDeviceData(votingDevice);

		ElectionData activeElection = new ElectionData();

		PowerMockito.doNothing().when(this.screenshotsFileGenerationWorker,
				"generateElection", Mockito.any(ElectionData.class),
				Mockito.any(ProgrammingUnitData.class));

		PowerMockito.doNothing().when(this.screenshotsFileGenerationWorker,
				"generateStringResources", Mockito.any(File.class),
				Mockito.anySetOf(LanguageData.class));

		PowerMockito.doNothing().when(this.screenshotsFileGenerationWorker,
				"generateVotingDevice", Mockito.any(VotingDeviceData.class),
				Mockito.any(File.class));

		PowerMockito.doReturn(new ArrayList<File>()).when(
				this.screenshotsFileGenerationWorker, "writePartyImages",
				Mockito.anySetOf(PartyData.class));

		this.screenshotsFileGenerationWorker.generateXML(votingDeviceCustomCode,
				programmingUnit, votingDevices, activeElection,
				new ArrayList());

		PowerMockito.verifyPrivate(this.screenshotsFileGenerationWorker)
				.invoke("generateElection", activeElection, programmingUnit);

		PowerMockito.verifyPrivate(this.screenshotsFileGenerationWorker).invoke(
				"generateStringResources", Mockito.any(File.class),
				Mockito.anySetOf(LanguageData.class));

		PowerMockito.verifyPrivate(this.screenshotsFileGenerationWorker).invoke(
				"generateVotingDevice", Mockito.any(VotingDeviceData.class),
				Mockito.any(File.class));

		PowerMockito.verifyPrivate(this.screenshotsFileGenerationWorker)
				.invoke("writePartyImages", Mockito.anySetOf(PartyData.class));

	}

	@Test
	@Ignore
	public void testPerformOperation() throws Exception {

		PowerMockito.mockStatic(ECMServiceProvider.class);

		PowerMockito
				.when(ECMServiceProvider
						.getServerPropertyAsString(Mockito.anyString()))
				.thenReturn("1");

		PowerMockito.mockStatic(ECMClientSideConstants.class);

		PowerMockito.doReturn("test/resources/master_folder")
				.when(this.screenshotsFileGenerationWorker, "getTargetPath");

		PowerMockito.doNothing().when(this.screenshotsFileGenerationWorker,
				"generateXML", Mockito.anyString(),
				Mockito.any(ProgrammingUnitData.class),
				Mockito.any(VotingDevicesData.class),
				Mockito.any(ElectionData.class));

		PowerMockito.doNothing().when(this.screenshotsFileGenerationWorker,
				"generateDefaultLanguages");

		PowerMockito.doNothing().when(this.screenshotsFileGenerationWorker,
				"copyGeneratedFiles");

		PowerMockito.doNothing().when(this.screenshotsFileGenerationWorker,
				"mergeSaesFiles");

		this.screenshotsFileGenerationWorker.performOperation();

		assertTrue(this.screenshotsFileGenerationWorker.isFileGenerationDone());

		PowerMockito.verifyPrivate(this.screenshotsFileGenerationWorker).invoke(
				"generateXML", Mockito.anyString(),
				Mockito.any(ProgrammingUnitData.class),
				Mockito.any(VotingDevicesData.class),
				Mockito.any(ElectionData.class));

		PowerMockito.verifyPrivate(this.screenshotsFileGenerationWorker).invoke(
				"generateVotingCenters", Mockito.anyListOf(VotingCenter.class));

		PowerMockito.verifyPrivate(this.screenshotsFileGenerationWorker)
				.invoke("generateDefaultLanguages");

		PowerMockito.verifyPrivate(this.screenshotsFileGenerationWorker)
				.invoke("copyGeneratedFiles");

	}
}
