package com.smartmatic.waffle.ecm.client.worker;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

import java.util.ArrayList;
import java.util.List;
import java.util.SortedSet;
import java.util.TreeSet;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.powermock.api.mockito.PowerMockito;
import org.powermock.core.classloader.annotations.PrepareForTest;
import org.powermock.modules.junit4.PowerMockRunner;

import com.smartmatic.waffle.domain.contest.ContestData;
import com.smartmatic.waffle.domain.eligibleoption.CandidateData;
import com.smartmatic.waffle.domain.eligibleoption.EligibleOptionData;
import com.smartmatic.waffle.domain.eligibleoption.EligibleOptionRoleData;
import com.smartmatic.waffle.ecm.client.ECMServiceProvider;
import com.smartmatic.waffle.ecm.client.lang.ConnectionException;
import com.smartmatic.waffle.ecm.data.transfer.objects.EligibleOptionSearchDTO;
import com.smartmatic.waffle.ecm.service.lang.NominationException;

/**
 * Test class for SearchCandidateWorker
 * 
 */
@RunWith(PowerMockRunner.class)
@PrepareForTest({ ECMServiceProvider.class, SearchCandidateWorker.class })
public class SearchCandidateWorkerTest {

	private SearchCandidateWorker searchCandidateWorker;

	@Before
	public void setUp() {

		this.searchCandidateWorker = new SearchCandidateWorker("candidate",
				null, null, null, null, 1);
	}

	@Test
	public void testSetTotalNumberOfPages() throws NominationException,
			ConnectionException {
		PowerMockito.mockStatic(ECMServiceProvider.class);

		PowerMockito.when(
				ECMServiceProvider.retrieveNumberOfCandidates("candidate",
						null, null, null)).thenReturn(17);

		this.searchCandidateWorker.setTotalNumberOfPages(17);

		assertEquals(1, this.searchCandidateWorker.getTotalNumberOfPages());

	}

	@Test
	public void testGetCandidates() throws ConnectionException,
			NominationException {

		PowerMockito.mockStatic(ECMServiceProvider.class);

		List<EligibleOptionData> candidatesList = new ArrayList<EligibleOptionData>();

		List<EligibleOptionSearchDTO> candidatesResultList;
		SortedSet<EligibleOptionRoleData> eligibleOptionRoleDataList = new TreeSet<EligibleOptionRoleData>();
		EligibleOptionRoleData eligibleOptionRoleData1 = new EligibleOptionRoleData();
		eligibleOptionRoleData1.setCandidate(new CandidateData());
		eligibleOptionRoleDataList.add(eligibleOptionRoleData1);

		EligibleOptionData eligibleOption1 = new EligibleOptionData();
		eligibleOption1.setBallotName("Candidate 1");
		eligibleOption1.setEligibleOptionRoleData(eligibleOptionRoleDataList);
		eligibleOption1.setContest(new ContestData());
		eligibleOption1.setEligibleOptionParent(new EligibleOptionData());

		EligibleOptionData eligibleOption2 = new EligibleOptionData();
		eligibleOption2.setBallotName("Candidate 2");
		eligibleOption2.setEligibleOptionRoleData(eligibleOptionRoleDataList);
		eligibleOption2.setContest(new ContestData());
		eligibleOption2.setEligibleOptionParent(new EligibleOptionData());

		candidatesList.add(eligibleOption1);
		candidatesList.add(eligibleOption2);

		PowerMockito.when(
				ECMServiceProvider.getCandidates(1, 1, "candidate", null, null,
						null, null)).thenReturn(candidatesList);

		candidatesResultList = this.searchCandidateWorker.getCandidates(1);

		for (EligibleOptionSearchDTO eligibleOptionDTO : candidatesResultList) {
			Object[] values = eligibleOptionDTO.getValues();
			assertNotNull(values[0]);
		}

	}

}
