/**
 * DataTestGenerationDTO.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.data.transfer.objects;

import java.io.Serializable;

import com.smartmatic.waffle.domain.ballot.BallotOptionData;
import com.smartmatic.waffle.domain.eligibleoption.CandidateData;
import com.smartmatic.waffle.domain.eligibleoption.EligibleOptionData;
import com.smartmatic.waffle.domain.eligibleoption.EligibleOptionRoleData;
import com.smartmatic.waffle.domain.eligibleoption.PartyData;

/**
 * Class that hold relevant information for test data generation.
 */
public class DataTestGenerationDTO implements Serializable {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /**
     * the candidate object generated to be used in tests activities.
     */
    private CandidateData candidate;

    /**
     * the party object generated to be used in tests activities.
     */
    private PartyData party;

    /** The ballot option generated. */
    private BallotOptionData ballotOption;

    /**
     * The eligible option generated.
     */
    private EligibleOptionData eligibleOption;

    /** The eligible option rol. */
    private EligibleOptionRoleData eligibleOptionRol;

    /** The eligible option rol parent. */
    private EligibleOptionRoleData eligibleOptionRolParent;

    /**
     * Getter of party property.
     * 
     * @return party property value
     */
    public PartyData getParty() {
        return this.party;
    }

    /**
     * Setter of party property.
     * 
     * @param party
     *            property value
     */
    public void setParty(PartyData party) {
        this.party = party;
    }

    /**
     * Getter of ballotOption property.
     * 
     * @return ballotOption property value
     */
    public BallotOptionData getBallotOption() {
        return this.ballotOption;
    }

    /**
     * Setter of ballotOption property.
     * 
     * @param ballotOption
     *            property value
     */
    public void setBallotOption(BallotOptionData ballotOption) {
        this.ballotOption = ballotOption;
    }

    /**
     * Getter of eligibleOption property.
     * 
     * @return eligibleOption property value
     */
    public EligibleOptionData getEligibleOption() {
        return this.eligibleOption;
    }

    /**
     * Setter of eligibleOption property.
     * 
     * @param eligibleOption
     *            property value
     */
    public void setEligibleOption(EligibleOptionData eligibleOption) {
        this.eligibleOption = eligibleOption;
    }

    /**
     * Getter of eligibleOptionRol property.
     * 
     * @return the eligibleOptionRol property value
     */
    public EligibleOptionRoleData getEligibleOptionRol() {
        return this.eligibleOptionRol;
    }

    /**
     * Sets the eligible option rol.
     * 
     * @param eligibleOptionRol
     *            the new eligible option rol
     */
    public void setEligibleOptionRol(EligibleOptionRoleData eligibleOptionRol) {
        this.eligibleOptionRol = eligibleOptionRol;
    }

    /**
     * Gets the eligible option rol parent.
     * 
     * @return the eligible option rol parent
     */
    public EligibleOptionRoleData getEligibleOptionRolParent() {
        return this.eligibleOptionRolParent;
    }

    /**
     * Sets the eligible option rol parent.
     * 
     * @param eligibleOptionRolParent
     *            the new eligible option rol parent
     */
    public void setEligibleOptionRolParent(
            EligibleOptionRoleData eligibleOptionRolParent) {
        this.eligibleOptionRolParent = eligibleOptionRolParent;
    }

    /**
     * Gets the candidate object generated to be used in tests activities.
     * 
     * @return the candidate object generated to be used in tests activities
     */
    public CandidateData getCandidate() {
        return this.candidate;
    }

    /**
     * Sets the candidate object generated to be used in tests activities.
     * 
     * @param candidate
     *            the new candidate object generated to be used in tests
     *            activities
     */
    public void setCandidate(CandidateData candidate) {
        this.candidate = candidate;
    }

    /**
     * Instantiates a new DataTestGenerationDTO.
     * 
     * @param candidate
     *            the candidate
     * @param ballotOption
     *            the ballot option
     * @param eligibleOption
     *            the eligible option
     * @param eligibleOptionRol
     *            the eligible option rol
     * @param eligibleOptionRolParent
     *            the eligible option rol parent
     */
    public DataTestGenerationDTO(CandidateData candidate,
            BallotOptionData ballotOption, EligibleOptionData eligibleOption,
            EligibleOptionRoleData eligibleOptionRol,
            EligibleOptionRoleData eligibleOptionRolParent) {
        super();
        this.candidate = candidate;
        this.ballotOption = ballotOption;
        this.eligibleOption = eligibleOption;
        this.eligibleOptionRol = eligibleOptionRol;
        this.eligibleOptionRolParent = eligibleOptionRolParent;
    }

    /**
     * Instantiates a new DataTestGenerationDTO.
     */
    public DataTestGenerationDTO() {
        super();
    }
}
