/**
 * ElectionXmlComponentsDTO.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.data.transfer.objects;

import java.io.Serializable;
import java.util.List;
import java.util.Map;
import java.util.Set;

import com.smartmatic.waffle.domain.contest.ContestData;
import com.smartmatic.waffle.domain.contest.ContestGroupData;
import com.smartmatic.waffle.domain.demographics.ElectionData;
import com.smartmatic.waffle.domain.i18n.LanguageData;
import com.smartmatic.waffle.domain.multiLanguage.StringResourceData;

/**
 * Class that holds all processed data from server to be send to client.
 */
public class ElectionXmlComponentsDTO implements Serializable {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The election. */
    private ElectionData election;

    /** The contest group. */
    private List<ContestGroupData> contestGroup;

    /** The generated. */
    private boolean generated;

    /** The resource message. */
    private String resourceMessage;

    /** The resources languages. */
    private Map<String, Map<String, String>> resourcesLanguages;

    /** The contest full list. */
    private Map<Long, ContestData> contestFullList;

    /** The contest group contest. */
    private Map<String, Set<ContestGroupData>> contestGroupContest;

    /** The election languages. */
    Set<LanguageData> electionLanguages;

    /** Eligible options resources by contest */
    private Map<Long, Set<StringResourceData>> contestEligibleOptionResources;

    /**
     * Getter of <code>electionLanguage</code> property.
     * 
     * @return <code>electionLanguage</code> property value.
     * @see #electionLanguages
     */

    public Set<LanguageData> getElectionLanguages() {
        return this.electionLanguages;
    }

    /**
     * Setter of <code>electionLanguage</code> property.
     * 
     * @param electionLanguages
     *            the new election languages
     * @see #electionLanguages
     */
    public void setElectionLanguages(Set<LanguageData> electionLanguages) {
        this.electionLanguages = electionLanguages;

        return;
    }

    /**
     * Getter of <code>contestGroupContest</code> property.
     * 
     * @return <code>contestGroupContest</code> property value.
     * @see #contestGroupContest
     */

    public Map<String, Set<ContestGroupData>> getContestGroupContest() {
        return this.contestGroupContest;
    }

    /**
     * Setter of <code>contestGroupContest</code> property.
     * 
     * @param contestGroupContest
     *            The <code>contestGroupContest</code> to set.
     * @see #contestGroupContest
     */
    public void setContestGroupContest(
            Map<String, Set<ContestGroupData>> contestGroupContest) {
        this.contestGroupContest = contestGroupContest;
    }

    /**
     * Getter of {@link #resourcesLanguages} field.
     * 
     * @return {@link #resourcesLanguages} value.
     */
    public Map<String, Map<String, String>> getResourcesLanguages() {
        return this.resourcesLanguages;
    }

    /**
     * Setter of {@link #resourcesLanguages} field.
     * 
     * @param resourcesLanguages
     *            The Map<String,Map<String,String>> to set.
     */
    public void setResourcesLanguages(
            Map<String, Map<String, String>> resourcesLanguages) {
        this.resourcesLanguages = resourcesLanguages;
    }

    /**
     * Getter of {@link #generated} field.
     * 
     * @return {@link #generated} value.
     */
    public boolean isGenerated() {
        return this.generated;
    }

    /**
     * Setter of {@link #generated} field.
     * 
     * @param generated
     *            The boolean to set.
     */
    public void setGenerated(boolean generated) {
        this.generated = generated;
    }

    /**
     * Getter of {@link #resourceMessage} field.
     * 
     * @return {@link #resourceMessage} value.
     */
    public String getResourceMessage() {
        return this.resourceMessage;
    }

    /**
     * Setter of {@link #resourceMessage} field.
     * 
     * @param resourceMessage
     *            The String to set.
     */
    public void setResourceMessage(String resourceMessage) {
        this.resourceMessage = resourceMessage;
    }

    /**
     * Getter of {@link #contestFullList} field.
     * 
     * @return {@link #contestFullList} value.
     */
    public Map<Long, ContestData> getContestFullList() {
        return this.contestFullList;
    }

    /**
     * Setter of {@link #contestFullList} field.
     * 
     * @param contestFullList
     *            The HashMap<Long,ContestData> to set.
     */
    public void setContestFullList(Map<Long, ContestData> contestFullList) {
        this.contestFullList = contestFullList;
    }

    /**
     * Getter of {@link #election} field.
     * 
     * @return {@link #election} value
     */
    public ElectionData getElection() {
        return this.election;
    }

    /**
     * Setter of {@link #election} field.
     * 
     * @param election
     *            the ElectionData to set
     */
    public void setElection(ElectionData election) {
        this.election = election;
    }

    /**
     * Getter of {@link #contestGroup} field.
     * 
     * @return {@link #contestGroup} value
     */
    public List<ContestGroupData> getContestGroup() {
        return this.contestGroup;
    }

    /**
     * Setter of {@link #contestGroup} field.
     * 
     * @param contest
     *            the List<ContestGroupData> to set
     */
    public void setContestGroup(List<ContestGroupData> contest) {
        this.contestGroup = contest;
    }

    /**
     * Return a map where the contest code is the key and the value is a set of
     * <code>StringResourceData</code> objects.
     * 
     * @return the contestEligibleOptionResources map
     */
    public Map<Long, Set<StringResourceData>> getContestEligibleOptionResources() {
        return contestEligibleOptionResources;
    }

    /**
     * Setter of {@link #contestEligibleOptionResources}
     * 
     * @param contestEligibleOptionResources
     *            the contestEligibleOptionResources to set
     */
    public void setContestEligibleOptionResources(
            Map<Long, Set<StringResourceData>> contestEligibleOptionResources) {
        this.contestEligibleOptionResources = contestEligibleOptionResources;
    }
}
