/**
 * ElectoralAuthorityKeysDTO.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.data.transfer.objects;

import java.io.Serializable;

/**
 * Class that holds electoral authority security information from server to be
 * send to client.
 */
public class ElectoralAuthoritySecurityComponentsDTO implements Serializable {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = -4616092634148306143L;

    /** The symmetric key. */
    String symmetricKey;

    /** The asymmetric key. */
    String asymmetricKey;

    /** The protection key. */
    String protectionKey;

    /** The custom code. */
    String customCode;

    /** The authority key. */
    String authorityKey;

    /** The binary certificate. */
    byte[] binaryCertificate;

    /** The ea username. */
    String eaUsername;

    /** The name. */
    String name;

    /**
     * Getter of <code>name</code> property.
     * 
     * @return <code>name</code> property value.
     * @see #name
     */

    public String getName() {
        return this.name;
    }

    /**
     * Setter of <code>name</code> property.
     * 
     * @param name
     *            The <code>name</code> to set.
     * @see #name
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * Getter of authorityKey property.
     * 
     * @return authorityKey property value
     */
    public String getAuthorityKey() {
        return this.authorityKey;
    }

    /**
     * Sets the authority key.
     * 
     * @param authorityKey
     *            the new authority key
     */
    public void setAuthorityKey(String authorityKey) {
        this.authorityKey = authorityKey;
    }

    /**
     * Creates a new DtoElectoralAuthorityKeys.
     */
    public ElectoralAuthoritySecurityComponentsDTO() {
        super();
    }

    /**
     * Instantiates a new electoral authority keys dto.
     * 
     * @param symmetricKey
     *            the symmetric key
     * @param asymmetricKey
     *            the asymmetric key
     * @param protectionKey
     *            the protection key
     * @param authorityKey
     *            the authority key
     * @param customCode
     *            the custom code
     * @param bynaryCertificate
     *            the bynary certificate
     * @param eaUsername
     *            the ea username
     * @param name
     *            the name
     */
    public ElectoralAuthoritySecurityComponentsDTO(String symmetricKey, String asymmetricKey,
            String protectionKey, String authorityKey, String customCode,
            byte[] bynaryCertificate, String eaUsername, String name) {
        super();
        this.symmetricKey = symmetricKey;
        this.asymmetricKey = asymmetricKey;
        this.protectionKey = protectionKey;
        this.customCode = customCode;
        this.authorityKey = authorityKey;
        if (bynaryCertificate != null) {
            this.binaryCertificate = bynaryCertificate.clone();
        }
        this.eaUsername = eaUsername;
        this.name = name;
    }

    /**
     * Getter of symmetricKey property.
     * 
     * @return symmetricKey property value
     */
    public String getSymmetricKey() {
        return this.symmetricKey;
    }

    /**
     * Setter of symmetricKey property.
     * 
     * @param symmetricKey
     *            property value
     */
    public void setSymmetricKey(String symmetricKey) {
        this.symmetricKey = symmetricKey;
    }

    /**
     * Getter of asymmetricKey property.
     * 
     * @return asymmetricKey property value
     */
    public String getAsymmetricKey() {
        return this.asymmetricKey;
    }

    /**
     * Setter of asymmetricKey property.
     * 
     * @param asymmetricKey
     *            property value
     */
    public void setAsymmetricKey(String asymmetricKey) {
        this.asymmetricKey = asymmetricKey;
    }

    /**
     * Getter of protectionKey property.
     * 
     * @return protectionKey property value
     */
    public String getProtectionKey() {
        return this.protectionKey;
    }

    /**
     * Setter of protectionKey property.
     * 
     * @param protectionKey
     *            property value
     */
    public void setProtectionKey(String protectionKey) {
        this.protectionKey = protectionKey;
    }

    /**
     * Getter of customCode property.
     * 
     * @return customCode property value
     */
    public String getCustomCode() {
        return this.customCode;
    }

    /**
     * Setter of customCode property.
     * 
     * @param customCode
     *            property value
     */
    public void setCustomCode(String customCode) {
        this.customCode = customCode;
    }

    /**
     * Getter of binaryCertificate property.
     * 
     * @return binaryCertificate property value
     */
    public byte[] getBinaryCertificate() {
        return this.binaryCertificate;
    }

    /**
     * Setter of binaryCertificate property.
     * 
     * @param bynaryCertificate
     *            property value
     */
    public void setBinaryCertificate(byte[] bynaryCertificate) {
        if (bynaryCertificate != null) {
            this.binaryCertificate = bynaryCertificate.clone();
        }
    }

    /**
     * Getter of eaUsername property.
     * 
     * @return eaUsername property value
     */
    public String getEaUsername() {
        return this.eaUsername;
    }

    /**
     * Setter of eaUsername property.
     * 
     * @param eaUsername
     *            the new ea username
     */
    public void setEaUsername(String eaUsername) {
        this.eaUsername = eaUsername;
    }
}
