package com.smartmatic.waffle.ecm.installation.dbcreation;
import java.net.URL;
import java.net.URLClassLoader;
import java.security.AccessController;
import java.security.PrivilegedAction;
import java.util.ArrayList;
import java.util.List;


import liquibase.Liquibase;
import liquibase.database.Database;
import liquibase.exception.CommandLineParsingException;
import liquibase.exception.DatabaseException;
import liquibase.exception.LiquibaseException;
import liquibase.integration.commandline.CommandLineResourceAccessor;
import liquibase.integration.commandline.CommandLineUtils;
import liquibase.logging.LogFactory;
import liquibase.resource.ClassLoaderResourceAccessor;
import liquibase.resource.CompositeResourceAccessor;
import liquibase.resource.FileSystemResourceAccessor;
import liquibase.servicelocator.ServiceLocator;
import liquibase.util.StringUtils;

public class UpdateDatabase {
	
    protected Boolean promptForNonLocalDatabase = null;
    protected String logLevel;
    protected Boolean includeSystemClasspath;
    protected ClassLoader classLoader;
    protected String logFile;
    
	/**
	 * @param args
	 */
	public static void main(String[] args) {
		
		UpdateDatabase installDatabase = new UpdateDatabase();
		
		try {
			installDatabase.applyDefaults();
			installDatabase.configureClassLoader();
			installDatabase.doMigration("dropAll", null);
			installDatabase.doMigration("update", "database/install.xml");
			installDatabase.doMigration("update", "database/update.xml");
		} catch (CommandLineParsingException e) {
			e.printStackTrace();
		} catch (LiquibaseException e) {
			e.printStackTrace();
		}
	}
	
    protected void applyDefaults() {
        if (this.promptForNonLocalDatabase == null) {
            this.promptForNonLocalDatabase = Boolean.FALSE;
        }
        if (this.logLevel == null) {
            this.logLevel = "info";
        }
        if (this.includeSystemClasspath == null) {
            this.includeSystemClasspath = Boolean.TRUE;
        }

    }
    
    protected void configureClassLoader() throws CommandLineParsingException {
        final List<URL> urls = new ArrayList<URL>();

        if (includeSystemClasspath) {
            classLoader = AccessController.doPrivileged(new PrivilegedAction<URLClassLoader>() {
                public URLClassLoader run() {
                    return new URLClassLoader(urls.toArray(new URL[urls.size()]), Thread.currentThread().getContextClassLoader());
                }
            });

        } else {
            classLoader = AccessController.doPrivileged(new PrivilegedAction<URLClassLoader>() {
                public URLClassLoader run() {
                    return new URLClassLoader(urls.toArray(new URL[urls.size()]));
                }
            });
        }

        ServiceLocator.getInstance().setResourceAccessor(new ClassLoaderResourceAccessor(classLoader));
        Thread.currentThread().setContextClassLoader(classLoader);
    }
    
    protected void doMigration(String command, String changeLogFile) throws CommandLineParsingException, LiquibaseException {

    	String username = "ecm";
    	String password = "lUvf25t0JoPHTul5";
    	String driver = "org.postgresql.Driver";
    	String url = "jdbc:postgresql:ecm_db";
    	String defaultSchemaName = "public";
    	String databaseClass = null;
    	String driverPropertiesFile = null;
    	
        try {
            if (null != logFile) {
                LogFactory.getLogger().setLogLevel(logLevel, logFile);
            } else {
                LogFactory.getLogger().setLogLevel(logLevel);
            }
        } catch (IllegalArgumentException e) {
            throw new CommandLineParsingException(e.getMessage(), e);
        }

        FileSystemResourceAccessor fsOpener = new FileSystemResourceAccessor();
        CommandLineResourceAccessor clOpener = new CommandLineResourceAccessor(classLoader);
        Database database = CommandLineUtils.createDatabaseObject(classLoader, url, 
            username, password, driver,null, defaultSchemaName, databaseClass, driverPropertiesFile);
        try {
	            CompositeResourceAccessor fileOpener = new CompositeResourceAccessor(fsOpener, clOpener);
	            Liquibase liquibase = new Liquibase(changeLogFile, fileOpener, database);
	
	            if ("dropAll".equals(command)) {
	                liquibase.dropAll();
	                System.out.println(String.format("All objects dropped from %s@%s", liquibase.getDatabase().getConnection().getConnectionUserName(), liquibase.getDatabase().getConnection().getURL()));
	                return;
	            } else if ("update".equalsIgnoreCase(command)) {
				    liquibase.update(null);
				    System.out.println(String.format("Liquibase Update Successful %s@%s", liquibase.getDatabase().getConnection().getConnectionUserName(), liquibase.getDatabase().getConnection().getURL()));
				}
        } finally {
            try {
                database.rollback();
                database.close();
            } catch (DatabaseException e) {
                LogFactory.getLogger().warning("problem closing connection", e);
            }
        }
    }
}

