#!/bin/bash

set -e

readonly analysis_chroot=$(readlink -f ${1})
readonly report_output=${2}
readonly option=${3}

if [ "${option}" = "-v" ]; then
        set -uexo
fi
echo "Starting analysis..."
echo "Software Name# Classification# Version# Manufacturer Name# Component Identifier# Binary Location# Architecture# Functionality# Dependencies# SHA256# Licenses" > ${report_output}
for pkg_name in $( chroot ${analysis_chroot} dpkg --list | grep "^ii" | awk '{print $2}' | sort -u ) ; do
        echo "- ${pkg_name}"
        chroot ${analysis_chroot} dpkg -s "${pkg_name}" | tr -d '#' | tr -d "'" > /tmp/.info
        pkg_name_only=$(echo ${pkg_name} | cut -d: -f1)
        pkg_version=$(cat /tmp/.info | grep Version: | cut -d\  -f2-)
        pkg_arch=$(cat /tmp/.info | grep Architecture: | cut -d\  -f2-)
        pkg_desc=$(cat /tmp/.info | grep Description: | cut -d\  -f2-)
        pkg_depends=$(cat /tmp/.info | grep Depends: | cut -d\  -f2-)
        pkg_mantainer=$(cat /tmp/.info | grep Maintainer: | cut -d\  -f2-)
        if [ -f "/usr/share/doc/${pkg_name_only}/copyright" ]; then
                pkg_licenses=$(grep ^License: /usr/share/doc/${pkg_name_only}/copyright | tr -d \' | tr -d \" | tr -d \# | tr -d \* | cut -d: -f2 | uniq | tr '\n' ' ' | xargs)
                if echo ${pkg_licenses} | grep 'Permission is hereby granted' 2>&1 > /dev/null; then
                        pkg_licenses="Defined inside /usr/share/doc/${pkg_name_only}/copyright"
                fi
        else
               pkg_licenses="Not available"
        fi

        if [ -z "$pkg_licenses" ]; then
                if grep 'GNU General Public License' /usr/share/doc/${pkg_name_only}/copyright 2>&1 > /dev/null; then
                        pkg_licenses="GPL"
                elif grep 'GNU Library General Public License' /usr/share/doc/${pkg_name_only}/copyright 2>&1 > /dev/null; then
                        pkg_licenses="LGPL"
                elif grep 'LGPL' /usr/share/doc/${pkg_name_only}/copyright 2>&1 > /dev/null; then
                        pkg_licenses="LGPL"
                elif grep 'GPL' /usr/share/doc/${pkg_name_only}/copyright 2>&1 > /dev/null; then
                        pkg_licenses="GPL"
                elif grep 'WHAT THE FUCK YOU WANT TO' /usr/share/doc/${pkg_name_only}/copyright 2>&1 > /dev/null; then
                        pkg_licenses="WTFPL"
                elif grep 'This program is free software' /usr/share/doc/${pkg_name_only}/copyright 2>&1 > /dev/null; then
                        pkg_licenses="Free software"
                elif grep 'BSD Software License' /usr/share/doc/${pkg_name_only}/copyright 2>&1 > /dev/null; then
                        pkg_licenses="BSD Software License"
                elif grep 'OpenLDAP' /usr/share/doc/${pkg_name_only}/copyright 2>&1 > /dev/null; then
                        pkg_licenses="OpenLDAP"
                elif grep 'UCB BSD' /usr/share/doc/${pkg_name_only}/copyright 2>&1 > /dev/null; then
                        pkg_licenses="UCB BSD"
                else
                        pkg_licenses="Defined inside /usr/share/doc/${pkg_name_only}/copyright"
                fi

        fi
        chroot ${analysis_chroot} dpkg -L ${pkg_name} | tr -d "'" |  tr -d '#' | xargs -n 1 -I @@ chroot ${analysis_chroot} bash -c 'if [ -f "@@" ]; then sha256sum "@@" | sed "s|^\([^\ ]*\) \(.*\)$|\1\#\2|" | sed "s-\#\#-\#-g"; fi' | xargs -n 1 -I@@@ echo ${pkg_name}\# static\# ${pkg_version}\# ${pkg_mantainer}\# executable code\# @@@\# ${pkg_arch}\# ${pkg_desc}\# ${pkg_depends}\# ${pkg_licenses} | awk -F\# '{print $1,"#",$2,"#",$3,"#",$4,"#",$5,"#",$7,"#",$8,"#",$9,"#",$10,"#",$6,"#",$11}'>> ${report_output}
done
echo "Process finish"
