/**
 * ECMElectoralOrganizationServiceImpl.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.service.impl;

import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.security.KeyStore;
import java.security.PrivateKey;
import java.security.PublicKey;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import javax.ejb.EJB;
import javax.ejb.Local;
import javax.ejb.Remote;
import javax.ejb.Stateless;

import org.apache.commons.codec.binary.Base64;
import org.apache.commons.io.IOUtils;
import org.apache.commons.lang.StringUtils;

import com.smartmatic.waffle.domain.authority.ElectoralAuthorityData;
import com.smartmatic.waffle.domain.demographics.ElectionData;
import com.smartmatic.waffle.domain.demographics.RegionData;
import com.smartmatic.waffle.domain.eligibleoption.ImageWrapper;
import com.smartmatic.waffle.domain.general.KeystoreData;
import com.smartmatic.waffle.ecm.data.transfer.objects.ElectionKeyStoreComponentsDTO;
import com.smartmatic.waffle.ecm.data.transfer.objects.ElectoralAuthoritySecurityComponentsDTO;
import com.smartmatic.waffle.ecm.service.lang.ElectoralOrganizationOperationException;
import com.smartmatic.waffle.ecm.service.lang.ElectoralOrganizationOperationException.ElectoralOrganizationOperationExceptionInfo;
import com.smartmatic.waffle.ecm.service.spec.IECMElectoralOrganizationService;
import com.smartmatic.waffle.ecm.service.spec.IECMElectoralOrganizationServiceLocal;
import com.smartmatic.waffle.log.SMTTLogger;
import com.smartmatic.waffle.persistence.search.SearchExpression;
import com.smartmatic.waffle.persistence.search.criteria.CriteriaFactory;
import com.smartmatic.waffle.persistence.search.criteria.OrderCriteria;
import com.smartmatic.waffle.persistence.search.transformation.TransformationFactory;
import com.smartmatic.waffle.persistence.search.transformation.TransformationsList;
import com.smartmatic.waffle.persistence.service.spec.IPersistenceServiceLocal;
import com.smartmatic.waffle.security.asymmetric.AsymmetricKeyManager;
import com.smartmatic.waffle.security.lang.CryptographicStaticException;

/**
 * Session beans that handles all server side operations related with Electoral
 * Organizations. This class implements all the server services defined in
 * <code>IECMElectoralOrganizationService</code>
 */
@Stateless(name = IECMElectoralOrganizationService.SERVICE_NAME)
@Remote(IECMElectoralOrganizationService.class)
@Local(IECMElectoralOrganizationServiceLocal.class)
public class ECMElectoralOrganizationServiceImpl implements
		IECMElectoralOrganizationServiceLocal {

	/** Object to generate logs during the application execution. */
	private static SMTTLogger logger = SMTTLogger
			.getLogger(ECMElectoralOrganizationServiceImpl.class);

	/**
	 * PersistenceServiceLocal Instance to do any database persistence
	 * operation.
	 */
	@EJB
	private IPersistenceServiceLocal persistenceService;

	/**
	 * Holds the instance of ElectionKeyStoreComponentsDTO;
	 */
	private ElectionKeyStoreComponentsDTO electionKeyStoreComponents;

	public void setPersistenceService(
			IPersistenceServiceLocal persistenceService) {
		this.persistenceService = persistenceService;
	}

	/**
	 * Sets the instance of ElectionKeyStoreComponentsDTO;.
	 * 
	 * @param electionKeyStoreComponents
	 *            the new instance of ElectionKeyStoreComponentsDTO;
	 */
	public void setElectionKeyStoreComponents(
			ElectionKeyStoreComponentsDTO electionKeyStoreComponents) {
		this.electionKeyStoreComponents = electionKeyStoreComponents;
	}

	/**
	 * @inheritDoc
	 */
	@Override
	public ElectionData retrieveActiveElection()
			throws ElectoralOrganizationOperationException {

		SearchExpression search = new SearchExpression(ElectionData.class);

		search.addSearchCriteria(CriteriaFactory.eq("statusActive", true));

		ElectionData election = null;
		try {
			String[] path = { "languages", "keystore" };

			election = (ElectionData) this.persistenceService.searchObject(
					search, path, null);

			if (election == null) {
				throw new ElectoralOrganizationOperationException(
						ElectoralOrganizationOperationException.ElectoralOrganizationOperationExceptionInfo.ACTIVE_ELECTION_NOT_FOUND);
			}

		} catch (ElectoralOrganizationOperationException e) {
			throw e;
		} catch (Exception e) {
			logger.error(e, StringUtils.defaultString(e.getMessage()));
			throw new ElectoralOrganizationOperationException(
					e,
					ElectoralOrganizationOperationException.ElectoralOrganizationOperationExceptionInfo.RETRIEVING_ACTIVE_ELECTION_FAILURE,
					StringUtils.defaultString(e.getMessage()));
		}

		return election;
	}

	/**
	 * @inheritDoc
	 */
	@Override
	public ElectionKeyStoreComponentsDTO getElectionKeyStoreComponents()
			throws ElectoralOrganizationOperationException {
		InputStream electionPkcs12 = null;

		try {
			if (this.electionKeyStoreComponents == null) {

				this.electionKeyStoreComponents = new ElectionKeyStoreComponentsDTO();

				ElectionData electionData = retrieveActiveElection();

				KeystoreData electionKeystore = electionData.getKeystore();

				electionPkcs12 = new ByteArrayInputStream(electionKeystore
						.getPkcs12().getBinaryData());

				KeyStore electionKeyStore = KeyStore
						.getInstance(AsymmetricKeyManager.KEYSTORE_PKCS12);

				electionKeyStore.load(electionPkcs12, electionKeystore
						.getPassword().toCharArray());

				X509Certificate electionX509Certificate = (X509Certificate) electionKeyStore
						.getCertificate(electionKeystore.getAlias());

				PrivateKey electionPrivateKey = (PrivateKey) electionKeyStore
						.getKey(electionKeystore.getAlias(), electionKeystore
								.getPassword().toCharArray());

				this.electionKeyStoreComponents
						.setElectionKeyStore(electionKeyStore);

				this.electionKeyStoreComponents
						.setElectionX509certificate(electionX509Certificate);

				this.electionKeyStoreComponents
						.setElectionPrivateKey(electionPrivateKey);

				this.electionKeyStoreComponents.setAlias(electionKeystore
						.getAlias());

				this.electionKeyStoreComponents.setPassphrase(electionKeystore
						.getPassword().toCharArray());

				return this.electionKeyStoreComponents;
			} else {
				return this.electionKeyStoreComponents;
			}
		} catch (Exception e) {
			logger.error(e, StringUtils.defaultString(e.getMessage()));
			throw new ElectoralOrganizationOperationException(
					e,
					ElectoralOrganizationOperationException.ElectoralOrganizationOperationExceptionInfo.RETRIEVING_ELECTION_KEYSTORE_COMPONENTS_FAILURE,
					StringUtils.defaultString(e.getMessage()));
		} finally {
			if (electionPkcs12 != null) {
				IOUtils.closeQuietly(electionPkcs12);
			}
		}
	}

	/**
	 * @inheritDoc
	 */
	@Override
	public int retrieveElectoralAuthoritiesAmount()
			throws ElectoralOrganizationOperationException {
		try {
			SearchExpression search = new SearchExpression(
					ElectoralAuthorityData.class);

			return this.persistenceService.countObjects(search, null);

		} catch (Exception e) {
			logger.error(e, StringUtils.defaultString(e.getMessage()));
			throw new ElectoralOrganizationOperationException(
					e,
					ElectoralOrganizationOperationException.ElectoralOrganizationOperationExceptionInfo.RETRIEVING_ELECTORAL_AUTHORITIES_AMOUNT_FAILURE,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * @inheritDoc
	 */
	@SuppressWarnings("unchecked")
	@Override
	public void setSecurityComponentsToElectoralAuthorities(int pageNumber,
			int pageSize) throws ElectoralOrganizationOperationException {

		try {
			SearchExpression search = new SearchExpression(
					ElectoralAuthorityData.class);

			search.addOrder(OrderCriteria.asc("customCode"));

			List<ElectoralAuthorityData> electoralAuthorityList;

			electoralAuthorityList = (List<ElectoralAuthorityData>) this.persistenceService
					.searchPagedObjects(search, null, pageNumber, pageSize);

			for (Iterator<ElectoralAuthorityData> iterator = electoralAuthorityList
					.iterator(); iterator.hasNext();) {
				ElectoralAuthorityData electoralAuthority = iterator.next();

				generateElectoralAuthoritySecurityComponents(electoralAuthority);

				this.persistenceService.update(electoralAuthority, null);

				logger.info("Processed " + electoralAuthority.getName());
			}
		} catch (Exception e) {
			logger.error(e, StringUtils.defaultString(e.getMessage()));
			throw new ElectoralOrganizationOperationException(
					e,
					ElectoralOrganizationOperationException.ElectoralOrganizationOperationExceptionInfo.SETTING_SECURITY_COMPONENTS_TO_ELECTORAL_AUTHORITIES_FAILURE,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * @inheritDoc
	 */
	@Override
	public int deleteElectoralAuthoritiesSecurityComponents()
			throws ElectoralOrganizationOperationException {

		try {
			return this.persistenceService
					.executeUpdateNativeQuery("update electoral_authority set protection_key = null, alias = null, asymmetric_key = null, authority_key = null, ea_username = null, symmetric_key = null");
		} catch (Exception e) {
			logger.error(e, StringUtils.defaultString(e.getMessage()));
			throw new ElectoralOrganizationOperationException(
					e,
					ElectoralOrganizationOperationException.ElectoralOrganizationOperationExceptionInfo.DELETING_ELECTORAL_AUTHORITIES_SECURITY_COMPONENTS_FAILURE,
					StringUtils.defaultString(e.getMessage()));
		}

	}

	/**
	 * @inheritDoc
	 */
	@Override
	@SuppressWarnings("unchecked")
	public List<ElectoralAuthoritySecurityComponentsDTO> retrieveElectoralAuthoritiesSecurityComponents(
			int pageNumber, int pageSize)
			throws ElectoralOrganizationOperationException {
		InputStream byteArrayInputStream = null;
		List<ElectoralAuthoritySecurityComponentsDTO> electoralAuthoritiesSecurityComponentsList = new ArrayList<ElectoralAuthoritySecurityComponentsDTO>();

		try {
			SearchExpression searchExpression = new SearchExpression(
					ElectoralAuthorityData.class);
			searchExpression.addOrder(OrderCriteria.asc("customCode"));

			TransformationsList lightTransformation = TransformationFactory
					.transformationList();

			lightTransformation.add(TransformationFactory
					.propertyTransformation("customCode"));
			lightTransformation.add(TransformationFactory
					.propertyTransformation("name"));
			lightTransformation.add(TransformationFactory
					.propertyTransformation("protectionKey"));
			lightTransformation.add(TransformationFactory
					.propertyTransformation("asymmetricKeys"));
			lightTransformation.add(TransformationFactory
					.propertyTransformation("authorityKey"));
			lightTransformation.add(TransformationFactory
					.propertyTransformation("authorityUsername"));
			lightTransformation.add(TransformationFactory
					.propertyTransformation("symmetricKey"));

			searchExpression.setTransformation(lightTransformation);

			Collection<Object[]> electoralAuthoritiesObjects = this.persistenceService
					.searchPagedObjects(searchExpression, null, pageNumber,
							pageSize);

			for (Object[] electoralAuthority : electoralAuthoritiesObjects) {
				String customCode = (String) electoralAuthority[0];
				String name = (String) electoralAuthority[1];
				String protectionKey = (String) electoralAuthority[2];
				ImageWrapper asymmetricKey = (ImageWrapper) electoralAuthority[3];
				String authorityKey = (String) electoralAuthority[4];
				String eaUsername = (String) electoralAuthority[5];
				String symmetricKey = (String) electoralAuthority[6];

				byteArrayInputStream = new ByteArrayInputStream(
						asymmetricKey.getBinaryData());

				PublicKey publicKey = AsymmetricKeyManager.getPublicKey(
						byteArrayInputStream, protectionKey, "anyAlias",
						protectionKey, AsymmetricKeyManager.KEYSTORE_PKCS12);

				String encodedPrivateKey = Base64.encodeBase64String(publicKey
						.getEncoded());

				ElectoralAuthoritySecurityComponentsDTO electoralAuthoritySecurityComponentsDTO = new ElectoralAuthoritySecurityComponentsDTO(
						symmetricKey, encodedPrivateKey, protectionKey,
						authorityKey, customCode,
						asymmetricKey.getBinaryData(), eaUsername, name);

				electoralAuthoritiesSecurityComponentsList
						.add(electoralAuthoritySecurityComponentsDTO);
			}
			return electoralAuthoritiesSecurityComponentsList;
		} catch (Exception e) {
			logger.error(e, StringUtils.defaultString(e.getMessage()));
			throw new ElectoralOrganizationOperationException(
					e,
					ElectoralOrganizationOperationException.ElectoralOrganizationOperationExceptionInfo.RETRIEVING_ELECTORAL_AUTHORITIES_SECURITY_COMPONENTS_FAILURE,
					StringUtils.defaultString(e.getMessage()));
		} finally {
			if (byteArrayInputStream != null) {
				IOUtils.closeQuietly(byteArrayInputStream);
			}
		}
	}

	@SuppressWarnings("unchecked")
	@Override
	public Map<ElectoralAuthorityData, Collection<ElectoralAuthorityData>> getElectoralAuthoritiesByLastLevelRegion(
			RegionData lastLevelRegion)
			throws ElectoralOrganizationOperationException {

		Map<ElectoralAuthorityData, Collection<ElectoralAuthorityData>> electoralAuthorityMap = new HashMap<ElectoralAuthorityData, Collection<ElectoralAuthorityData>>();

		SearchExpression search = new SearchExpression(
				ElectoralAuthorityData.class);

		search.createAlias("region", "region");

		search.createAlias("regionAllChildren", "region.allChildren");

		search.addSearchCriteria(CriteriaFactory.eq("regionAllChildren.code",
				lastLevelRegion.getCode()));

		try {
			Collection<ElectoralAuthorityData> authorities = this.persistenceService
					.searchObjects(search, null);

			ElectoralAuthorityData authority = null;

			for (ElectoralAuthorityData electoralAuthorityData : authorities) {

				if (authority == null) {

					authority = electoralAuthorityData;

				} else if (electoralAuthorityData.getRegion().getCategory()
						.getCategoryLevel().ordinal() < authority.getRegion()
						.getCategory().getCategoryLevel().ordinal()) {

					authority = electoralAuthorityData;
				}
			}

			electoralAuthorityMap.put(authority, authorities);

			return electoralAuthorityMap;

		} catch (Exception e) {
			logger.error(e, StringUtils.defaultString(e.getMessage()));
			throw new ElectoralOrganizationOperationException(
					e,
					ElectoralOrganizationOperationException.ElectoralOrganizationOperationExceptionInfo.GETTING_ELECTORAL_AUTHORITIES_BY_REGION_FAILURE,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	@Override
	public List<ElectoralAuthorityData> getElectoralAuthoritiesByRegion(
			List<RegionData> selectedRegions)
			throws ElectoralOrganizationOperationException {

		SearchExpression search = new SearchExpression(
				ElectoralAuthorityData.class);

		List<Long> selectedRegionsCodes = new ArrayList<Long>();

		for (RegionData region : selectedRegions) {

			selectedRegionsCodes.add(region.getCode());
		}

		if (selectedRegionsCodes.size() > 0) {
			search.createAlias("region", "region");

			search.createAlias("regionAllParents", "region.allParents");

			search.createAlias("regionAllChildren", "region.allChildren");

			search.addSearchCriteria(CriteriaFactory.or(CriteriaFactory.in(
					"regionAllParents.code", selectedRegionsCodes),
					CriteriaFactory.in("regionAllChildren.code",
							selectedRegionsCodes)));
		}

		try {
			List<ElectoralAuthorityData> authorities = (List<ElectoralAuthorityData>) this.persistenceService
					.searchObjects(search, null);

			return authorities;

		} catch (Exception e) {
			logger.error(e, StringUtils.defaultString(e.getMessage()));
			throw new ElectoralOrganizationOperationException(
					e,
					ElectoralOrganizationOperationException.ElectoralOrganizationOperationExceptionInfo.GETTING_ELECTORAL_AUTHORITIES_BY_REGION_FAILURE,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Generates all keys needed by an electoral authority.
	 * 
	 * @param electoralAuthority
	 *            the electoral authority for which to generate all needed keys
	 * @throws CryptographicStaticException
	 *             In case decryption fails because of inappropriate system
	 *             configuration. This exception implies that the server is not
	 *             properly configured. If this exception occurs the only way to
	 *             solve the problem is by reconfiguring the server.
	 * @throws ElectoralOrganizationOperationException
	 *             a signal that an failure occurred generating the keys.
	 */
	private void generateElectoralAuthoritySecurityComponents(
			ElectoralAuthorityData electoralAuthority)
			throws CryptographicStaticException,
			ElectoralOrganizationOperationException {

		String protectionKey = ECMServerCommonImpl.generateSymmetricKey();
		electoralAuthority.setProtectionKey(protectionKey);

		String symmetricKey = ECMServerCommonImpl.generateSymmetricKey();
		electoralAuthority.setSymmetricKey(symmetricKey);

		String authorityKey = ECMServerCommonImpl.generateRandomString(16)
				.toLowerCase();
		electoralAuthority.setAuthorityKey(authorityKey);

		String authorityUserName = generateAuthorityUserName(electoralAuthority
				.getCode());
		electoralAuthority.setAuthorityUsername(authorityUserName);

		electoralAuthority.setAlias("anyAlias");

		ImageWrapper asymmetricKey = generateAsymmetricKeyForElectoralAuthority(
				electoralAuthority.getCode(),
				electoralAuthority.getCustomCode(), protectionKey, "anyAlias");

		electoralAuthority.setAsymmetricKeys(asymmetricKey);

	}

	/**
	 * Generates the user name for an electoral authority.
	 * 
	 * @param electoralAuhorityCode
	 *            the electoral authority code to generate the username.
	 * @return the username generated.
	 */
	private String generateAuthorityUserName(long electoralAuhorityCode) {
		return "eausr" + String.valueOf(electoralAuhorityCode);
	}

	/**
	 * Generate asymmetric keys for an electoral authority
	 * 
	 * @param electoralAuthorityCode
	 *            the electoral authority code used as a certificate serial
	 *            number
	 * @param electoralAuthorityCustomCode
	 *            the electoral authority custom code used as a certificate
	 *            common name
	 * @param electoralAuthorityProtectionKey
	 *            the electoral authority protection key used as a certificate
	 *            passphrase
	 * @param electoralAuthorityAlias
	 *            the electoral authority alias for the certificate
	 * @return the image wrapper object with the asymmetric key built for the
	 *         electoral authority.
	 * 
	 * @throws ElectoralOrganizationOperationException
	 *             Signals that an exception has occurred retrieving the active
	 *             election
	 */
	private ImageWrapper generateAsymmetricKeyForElectoralAuthority(
			long electoralAuthorityCode, String electoralAuthorityCustomCode,
			String electoralAuthorityProtectionKey,
			String electoralAuthorityAlias)
			throws ElectoralOrganizationOperationException {

		try {

			return ECMServerCommonImpl.generateAsymmetricKey(
					electoralAuthorityCode, electoralAuthorityCustomCode,
					electoralAuthorityProtectionKey, electoralAuthorityAlias,
					getElectionKeyStoreComponents());

		} catch (Exception e) {
			logger.error(e, StringUtils.defaultString(e.getMessage()));
			throw new ElectoralOrganizationOperationException(
					e,
					ElectoralOrganizationOperationExceptionInfo.GENERATING_ASYMMETRIC_KEY_FOR_ELECTORAL_AUTHORITY_FAILURE,
					StringUtils.defaultString(e.getMessage()));
		}
	}
}
