/**
 * ElectoralOrganizationOperationException.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.service.lang;

import com.smartmatic.waffle.ecm.core.lang.ECMBaseException;
import com.smartmatic.waffle.ecm.core.lang.IECMExceptionInfo;

/**
 * Class to handle any exception that may occur executing an electoral
 * organization operation.
 */
public class ElectoralOrganizationOperationException extends ECMBaseException {

	/**
	 * Holds the version of the class. It is used by the serialization engine to
	 * determine when a class its equivalent to another
	 */
	private static final long serialVersionUID = 1042224267124632834L;

	/**
	 * Enum that contains all the possible reasons because the
	 * ElectoralOrganizationOperationException can be thrown
	 */
	public enum ElectoralOrganizationOperationExceptionInfo implements
			IECMExceptionInfo {

		ACTIVE_ELECTION_NOT_FOUND("active.election.not.found",
				"No active election found"), RETRIEVING_ACTIVE_ELECTION_FAILURE(
				"retrieving.active.election.failure"), RETRIEVING_ELECTION_KEYSTORE_COMPONENTS_FAILURE(
				"retrieving.election.keystore.components.failure"), RETRIEVING_ELECTORAL_AUTHORITIES_AMOUNT_FAILURE(
				"retrieving.electoral.authorities.amount.failure"), SETTING_SECURITY_COMPONENTS_TO_ELECTORAL_AUTHORITIES_FAILURE(
				"setting.security.components.to.electoral.authorities.failure"), GENERATING_ASYMMETRIC_KEY_FOR_ELECTORAL_AUTHORITY_FAILURE(
				"generating.asymmetric.key.for.electoral.authority.failure"), DELETING_ELECTORAL_AUTHORITIES_SECURITY_COMPONENTS_FAILURE(
				"deleting.electoral.authorities.security.components.failure"), RETRIEVING_ELECTORAL_AUTHORITIES_SECURITY_COMPONENTS_FAILURE(
				"retrieving.electoral.authorities.security.components.failure"), GETTING_ELECTORAL_AUTHORITIES_BY_REGION_FAILURE(
				"getting.electoral.authorities.by.region.failure");

		/**
		 * Variable to hold the exception message.
		 */
		private String exceptionMessage;

		/**
		 * Variable to hold the bundle key to show a user understandable
		 * message.
		 */
		private String bundleKey;

		/**
		 * @inheritDoc
		 */
		@Override
		public String getExceptionMessage() {
			return this.exceptionMessage;
		}

		/**
		 * @inheritDoc
		 */
		@Override
		public String getBundleKey() {
			return this.bundleKey;
		}

		/**
		 * Constructor.
		 * 
		 * @param bundleKey
		 *            Resource bundle's key message
		 */
		private ElectoralOrganizationOperationExceptionInfo(String bundleKey) {
			this.bundleKey = bundleKey;
		}

		/**
		 * Constructor.
		 * 
		 * @param exceptionMessage
		 *            Exception message
		 * 
		 * @param bundleKey
		 *            Resource bundle's key message
		 */
		private ElectoralOrganizationOperationExceptionInfo(String bundleKey,
				String exceptionMessage) {
			this.bundleKey = bundleKey;
			this.exceptionMessage = exceptionMessage;
		}

	}

	/**
	 * Instantiates an ElectoralOrganizationOperationException.
	 * 
	 * @param throwable
	 *            a nested exception
	 * 
	 * @param exceptionInfo
	 *            an enumeration value regarding the cause of the exception
	 */
	public ElectoralOrganizationOperationException(Throwable throwable,
			ElectoralOrganizationOperationExceptionInfo exceptionInfo) {
		super(throwable, exceptionInfo);
	}

	/**
	 * Instantiates an ElectoralOrganizationOperationException.
	 * 
	 * @param throwable
	 *            a nested exception
	 * @param exceptionInfo
	 *            an enumeration value regarding the cause of the exception
	 * @param exceptionMessage
	 *            Exception message of nested exception
	 */
	public ElectoralOrganizationOperationException(Throwable throwable,
			ElectoralOrganizationOperationExceptionInfo exceptionInfo,
			String exceptionMessage) {
		super(throwable, exceptionInfo, exceptionMessage);
	}

	/**
	 * Instantiates an ElectoralOrganizationOperationException.
	 * 
	 * @param exceptionInfo
	 *            an enumeration value regarding the cause of the exception
	 */
	public ElectoralOrganizationOperationException(
			ElectoralOrganizationOperationExceptionInfo exceptionInfo) {
		super(exceptionInfo);
	}

	/**
	 * @inheritDoc
	 */
	@Override
	public String getBundleKey() {
		return this.getClass().getSimpleName() + "."
				+ this.exceptionInfo.getBundleKey();
	}
}
