/**
 * UtilitiesException.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.service.lang;

import com.smartmatic.waffle.ecm.core.lang.ECMBaseException;
import com.smartmatic.waffle.ecm.core.lang.IECMExceptionInfo;

/**
 * Class to manage if any exceptions occurred executing some utility method.
 */
public class UtilitiesException extends ECMBaseException {

	private static final long serialVersionUID = 3636279261407249284L;

	/**
	 * Enum that contains all the possible reasons because the
	 * UtilitiesException can be thrown.
	 */
	public enum UtilitiesExceptionInfo implements IECMExceptionInfo {

		PROBLEM_EXECUTING_QUERY("problem.executing.query"), PROBLEM_CLOSING_CONNECTION(
				"problem.closing.connection"), RETRIEVING_ITEM_BY_CUSTOM_CODE_FAILURE(
				"retrieving.item.by.custom.code.failure"), TRANSLATING_CONTEST_NAME_FAILURE(
				"translating.contest.name.failure"), TRANSLATING_DISTRICT_NAME_FAILURE(
				"translating.district.name.failure"), TRANSLATING_CONTEST_COLLEGE_FAILURE(
				"translating.contest.college.failure"), PROBLEM_PROCESSING_MULTILINGUAL_OBJECT(
				"problem.processing.multilingual.object"), PROBLEM_GETTING_TRASTATION_KEY_PER_LANGUAGE(
				"problem.getting.translation.key.per.language"), PROBLEM_GETTING_LANGUAGES(
				"problem.getting.languages"), TRANSLATING_CONTEST_CLASS_NAME_FAILURE(
				"translating.contest.class.name.failure"), PROBLEM_GETTING_REPORTS_TEMPLATES(
				"problem.getting.reports.templates"), PROBLEM_GETTING_CODI_NO_FILES_FOUND(
				"problem.getting.eml.no.files.found"), PROBLEM_GETTING_VOICE_NO_FILES_FOUND(
				"problem.getting.voice.no.files.found"), PROBLEM_GETTING_EML_FILES(
				"problem.getting.codi.files"), PROBLEM_GETTING_VOICE_FILES(
				"problem.getting.voice.files"), PROBLEM_GETTING_CONTEST_CLASS_TRANSLATIONS(
				"problem.getting.contest.class.translations"), PROBLEM_GENERATING_REPORTS(
				"problem.generating.reports");

		/**
		 * Variable to hold the exception message.
		 */
		private String exceptionMessage;

		/**
		 * Variable to hold the bundle key to show a user understandable
		 * message.
		 */
		private String bundleKey;

		/**
		 * Gets the variable to hold the exception message.
		 * 
		 * @return the variable to hold the exception message
		 * @inheritDoc
		 */
		@Override
		public String getExceptionMessage() {
			return this.exceptionMessage;
		}

		/**
		 * Gets the variable to hold the bundle key to show a user
		 * understandable message.
		 * 
		 * @return the variable to hold the bundle key to show a user
		 *         understandable message
		 * @inheritDoc
		 */
		@Override
		public String getBundleKey() {
			return this.bundleKey;
		}

		/**
		 * Constructor.
		 * 
		 * @param bundleKey
		 *            Resource bundle's key message
		 */
		private UtilitiesExceptionInfo(String bundleKey) {
			this.bundleKey = bundleKey;
		}

		/**
		 * Constructor.
		 * 
		 * @param bundleKey
		 *            Resource bundle's key message
		 * @param exceptionMessage
		 *            Exception message
		 */
		private UtilitiesExceptionInfo(String bundleKey, String exceptionMessage) {
			this.bundleKey = bundleKey;
			this.exceptionMessage = exceptionMessage;
		}
	}

	/**
	 * Instantiates a new utility exception.
	 * 
	 * @param exceptionInfo
	 *            The exception info type
	 */
	public UtilitiesException(UtilitiesExceptionInfo exceptionInfo) {
		super(exceptionInfo);
	}

	/**
	 * Instantiates a new utility exception.
	 * 
	 * @param throwable
	 *            Throwable object that triggers this exception.
	 * @param exceptionInfo
	 *            the exception info
	 */
	public UtilitiesException(Throwable throwable,
			UtilitiesExceptionInfo exceptionInfo) {
		super(throwable, exceptionInfo);
	}

	/**
	 * Instantiates a new utility exception.
	 * 
	 * @param throwable
	 *            ECMServiceUtilitiesTest
	 * @param exceptionInfo
	 *            The exception info type.
	 * @param exceptionMessage
	 *            The exception message
	 */
	public UtilitiesException(Throwable throwable,
			UtilitiesExceptionInfo exceptionInfo, String exceptionMessage) {
		super(throwable, exceptionInfo, exceptionMessage);
	}

	/*
	 * @inheritDoc
	 */
	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.ecm.core.lang.ECMBaseException#getBundleKey()
	 */
	@Override
	public String getBundleKey() {
		return this.getClass().getSimpleName() + "."
				+ this.exceptionInfo.getBundleKey();
	}

}
