/**
 * IECMElectoralPhysicalLocationsRegistryService.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.service.spec;

import java.util.List;

import javax.ejb.Remote;

import com.smartmatic.waffle.domain.demographics.PollingPlaceData;
import com.smartmatic.waffle.domain.demographics.RegionData;
import com.smartmatic.waffle.domain.device.VotingDeviceData;
import com.smartmatic.waffle.ecm.data.transfer.objects.VotingDeviceSecurityComponentsDTO;
import com.smartmatic.waffle.ecm.service.lang.ElectoralOrganizationOperationException;
import com.smartmatic.waffle.ecm.service.lang.ElectoralPhysicalLocationsRegistryException;

/**
 * Remote interface which establishes methods contract that must be implemented
 * by <code>ECMElectoralPhysicalLocationsRegistryServiceImpl</code> class
 */
@Remote
public interface IECMElectoralPhysicalLocationsRegistryService {

	/** Service name constant. */
	public static final String SERVICE_NAME = "com.smartmatic.waffle.ecm.service.spec.IECMElectoralPhysicalLocationsRegistryService";

	/**
	 * Method to retrieve the the voting devices amount loaded in database.
	 * 
	 * @return devices amount loaded in database
	 * 
	 * @throws ElectoralPhysicalLocationsRegistryException
	 *             Signal that an exception has occurred retrieving the voting
	 *             devices amount
	 */
	public int retrieveVotingDevicesAmount()
			throws ElectoralPhysicalLocationsRegistryException;

	/**
	 * Sets the security components of a number of voting devices stored in
	 * database.
	 * 
	 * These security components are: Voting device transmission key, Voting
	 * device protection key, Voting device asymmetric key, Voting device
	 * president key, Voting device recounter key, Voting device numeric key 1
	 * and Voting device numeric key 2.
	 * 
	 * The voting devices will be retrieved from the database by chunks, or
	 * pages, of <code>pageSize</code>, and the method will set the components
	 * for page number <code>pageNumber</code>.
	 * 
	 * @param pageNumber
	 *            Page number to process
	 * @param pageSize
	 *            Total page size
	 * @throws ElectoralPhysicalLocationsRegistryException
	 *             Signal that an exception has occurred setting security
	 *             components to some voting device.
	 * @throws ElectoralOrganizationOperationException
	 *             Signal that an exception has occurred retrieving the active
	 *             election
	 */
	public void setSecurityComponentsToVotingDevices(int pageNumber,
			int pageSize) throws ElectoralPhysicalLocationsRegistryException,
			ElectoralOrganizationOperationException;

	/**
	 * Retrieves the security components of a number of voting devices stored in
	 * database.
	 * 
	 * The security components will be retrieved from the database by chunks, or
	 * pages, of <code>pageSize</code>, and the method will set the components
	 * for page number <code>pageNumber</code>.
	 * 
	 * @param pageNumber
	 *            Page number to process
	 * @param pageSize
	 *            Total page size
	 * 
	 * @return DTO list with security components of a number of voting devices
	 * 
	 * @throws ElectoralPhysicalLocationsRegistryException
	 *             Signal that an exception has occurred retrieving some voting
	 *             device security components.
	 */
	List<VotingDeviceSecurityComponentsDTO> retrieveVotingDeviceSecurityComponents(
			int pageNumber, int pageSize)
			throws ElectoralPhysicalLocationsRegistryException;

	/**
	 * Deletes security components generated for voting devices from the
	 * database.
	 * 
	 * @return number of removed records
	 * 
	 * @throws ElectoralPhysicalLocationsRegistryException
	 *             Signal that an exception has occurred deleting security
	 *             components to some voting device.
	 */
	public int deleteVotingDeviceSecurityComponents()
			throws ElectoralPhysicalLocationsRegistryException;

	/**
	 * Return a list of voting devices filtered by an specific region.
	 * 
	 * @param region
	 *            the region to obtain the voting devices list
	 * @return the voting devices list
	 * @throws ElectoralPhysicalLocationsRegistryException
	 *             Signal that an exception has occurred getting the voting
	 *             devices list.
	 */
	public List<VotingDeviceData> getVotingDevicesByRegion(RegionData region)
			throws ElectoralPhysicalLocationsRegistryException;

	/**
	 * Return a list of voting devices filtered by an specific polling place.
	 * 
	 * @param pollingPlace
	 *            the polling place to obtain the voting devices list
	 * @return the voting devices list
	 * @throws ElectoralPhysicalLocationsRegistryException
	 *             Signal that an exception has occurred getting the voting
	 *             devices list.
	 */
	public List<VotingDeviceData> getVotingDevicesByPollingPlace(
			PollingPlaceData pollingPlace)
			throws ElectoralPhysicalLocationsRegistryException;
}
