/**
 * ECMWorkflowStatus.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.service.workflow;

import java.io.Serializable;

/**
 * Class that holds the worflow pre-processing, post-processing and validations
 * status.
 */
public class ECMWorkflowStatus implements Serializable {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 2L;

	/**
	 * The Enum Validation.
	 */
	public enum Validation {
		DATA_LOADED, INTEGRITY_VALIDATION_CONTEST_CONTESTCLASS_CONTESTGROUP, CERTIFICATES_GENERATED, INTEGRITY_VALIDATION_REGION_LANGUAGE, OS_IMAGES_LOADED
	}

	/**
	 * The Enum PostProcessing.
	 */
	public enum PostProcessing {

		/** The generate logical voting group. */
		GENERATE_LOGICAL_VOTING_GROUP
	}

	/**
	 * The Enum Rollback.
	 */
	public enum Rollback {

		/** The delete os images. */
		DELETE_OS_IMAGES
	}

	/** The validations failed. */
	private Validation[] validationsFailed;

	/** The client side validations. */
	private Validation[] clientSideValidations;

	/** The client side post processing. */
	private PostProcessing[] clientSidePostProcessing;

	/** The client side rollback. */
	private Rollback[] clientSideRollback;

	/**
	 * Instantiates a new eCM workflow status.
	 */
	public ECMWorkflowStatus() {

		this.validationsFailed = new Validation[0];
		this.clientSideValidations = new Validation[0];
		this.clientSidePostProcessing = new PostProcessing[0];
		this.clientSideRollback = new Rollback[0];

	}

	/**
	 * Gets the validations failed.
	 * 
	 * @return the validations failed
	 */
	public Validation[] getValidationsFailed() {
		return this.validationsFailed;
	}

	/**
	 * Sets the validations failed.
	 * 
	 * @param failedArray
	 *            the failed array
	 * @return the eCM workflow status
	 */
	public ECMWorkflowStatus setValidationsFailed(Validation[] failedArray) {

		if (failedArray != null) {
			this.validationsFailed = failedArray.clone();
		} else {
			this.validationsFailed = new Validation[0];
		}

		return this;

	}

	/**
	 * Gets the client side validations.
	 * 
	 * @return the client side validations
	 */
	public Validation[] getClientSideValidations() {
		return this.clientSideValidations;
	}

	/**
	 * Sets the client side validations.
	 * 
	 * @param clientArray
	 *            the client array
	 * @return the eCM workflow status
	 */
	public ECMWorkflowStatus setClientSideValidations(Validation[] clientArray) {

		if (clientArray != null) {
			this.clientSideValidations = clientArray.clone();
		} else {
			this.clientSideValidations = new Validation[0];
		}

		return this;

	}

	/**
	 * Gets the client side post processing.
	 * 
	 * @return the client side post processing
	 */
	public PostProcessing[] getClientSidePostProcessing() {
		return this.clientSidePostProcessing;
	}

	/**
	 * Sets the client side post processing.
	 * 
	 * @param clientArray
	 *            the client array
	 * @return the eCM workflow status
	 */
	public ECMWorkflowStatus setClientSidePostProcessing(
			PostProcessing[] clientArray) {

		if (clientArray != null) {
			this.clientSidePostProcessing = clientArray.clone();
		} else {
			this.clientSidePostProcessing = new PostProcessing[0];
		}

		return this;
	}

	/**
	 * Gets the client side rollback.
	 * 
	 * @return the client side rollback
	 */
	public Rollback[] getClientSideRollback() {
		return this.clientSideRollback;
	}

	/**
	 * Sets the client side rollback.
	 * 
	 * @param clientArray
	 *            the client array
	 * @return the eCM workflow status
	 */
	public ECMWorkflowStatus setClientSideRollback(Rollback[] clientArray) {

		if (clientArray != null) {
			this.clientSideRollback = clientArray.clone();
		} else {
			this.clientSideRollback = new Rollback[0];
		}

		return this;
	}

}
