/**
 * ECMBulkDataLoadServiceImplTest.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.service.impl;

import static org.junit.Assert.assertNotNull;

import java.io.File;

import org.apache.commons.io.FileUtils;
import org.junit.Before;
import org.junit.Test;

import com.smartmatic.waffle.ecm.bulk.service.spec.IBulkServiceLocal;
import com.smartmatic.waffle.ecm.data.transfer.objects.BulkResultDTO;
import com.smartmatic.waffle.ecm.data.transfer.type.EMLFileType;
import com.smartmatic.waffle.ecm.data.transfer.type.SmttFileType;
import com.smartmatic.waffle.ecm.service.lang.BulkDataLoadException;
import com.smartmatic.waffle.ecm.service.stub.ECMBulkDataLoadServiceImplMockClasses;

/**
 * Class to test ECMBulkDataLoadServiceImpl.
 */
public class ECMBulkDataLoadServiceImplTest {

	IBulkServiceLocal bulkServiceLocal;

	/**
	 * SetUp method to prepare the test.
	 * 
	 * @throws Exception
	 *             Signals that an exception has occurred preparing the test.
	 */
	@Before
	public void setUp() throws Exception {
		this.bulkServiceLocal = new ECMBulkDataLoadServiceImplMockClasses().new ECMBulkService();
	}

	/**
	 * Test of <code>uploadSmttFileIntoDataBase</code> method.
	 * 
	 * @throws BulkDataLoadException
	 *             Signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 */
	// @Test
	public void uploadSmttFileIntoDataBaseSmttSiteTest() throws Exception {

		File inputFile = new File("test/resources/BallotLayout.txt");

		byte[] inputFileByte = FileUtils.readFileToByteArray(inputFile);

		ECMBulkDataLoadServiceImpl ecmBulkDataLoadServiceImpl = new ECMBulkDataLoadServiceImplMockClasses().new ECMBulkDataLoadServiceImplSmttStub();

		ecmBulkDataLoadServiceImpl.setBulkService(this.bulkServiceLocal);

		BulkResultDTO bulkResultDTO = ecmBulkDataLoadServiceImpl
				.uploadSmttFileIntoDataBase(inputFile.getName(), inputFileByte,
						SmttFileType.BALLOT_LAYOUT, null);

		assertNotNull(bulkResultDTO);
	}

	/**
	 * Test of <code>uploadSmttFileIntoDataBase</code> method. Case: Codi sites
	 * file.
	 * 
	 * @throws BulkDataLoadException
	 *             Signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 */
	@Test
	public void uploadSmttFileIntoDataBaseTest() throws Exception {

		File inputFile = new File("test/resources/Sites.txt");

		byte[] inputFileByte = FileUtils.readFileToByteArray(inputFile);

		ECMBulkDataLoadServiceImpl ecmBulkDataLoadServiceImpl = new ECMBulkDataLoadServiceImplMockClasses().new ECMBulkDataLoadServiceImplSmttStub();

		ecmBulkDataLoadServiceImpl.setBulkService(this.bulkServiceLocal);

		BulkResultDTO bulkResultDTO = ecmBulkDataLoadServiceImpl
				.uploadSmttFileIntoDataBase(inputFile.getName(), inputFileByte,
						SmttFileType.SITES, null);

		assertNotNull(bulkResultDTO);
	}

	/**
	 * Test of <code>uploadCodiFileIntoDataBase</code> method.
	 * 
	 * @throws BulkDataLoadException
	 *             Signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 */
	// @Test
	public void uploadCodiFileIntoDataBaseTest() throws Exception {

		File inputFile = new File("test/resources/DC11002.CK");

		byte[] inputFileByte = FileUtils.readFileToByteArray(inputFile);

		ECMBulkDataLoadServiceImpl ecmBulkDataLoadServiceImpl = new ECMBulkDataLoadServiceImplMockClasses().new ECMBulkDataLoadServiceImplEMLStub();

		ecmBulkDataLoadServiceImpl.setBulkService(this.bulkServiceLocal);

		BulkResultDTO bulkResultDTO = ecmBulkDataLoadServiceImpl
				.uploadEMLFilesIntoDataBase(inputFile.getName(), inputFileByte,
						EMLFileType.ELECTION, null);

		assertNotNull(bulkResultDTO);

		FileUtils.forceDelete(new File("null"));
	}

	/**
	 * Test of <code>uploadEMLFileIntoDataBase</code> method. Case: Codi sites
	 * file.
	 * 
	 * @throws BulkDataLoadException
	 *             Signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 */
	// @Test
	public void uploadEMLFileIntoDataBaseCodiSiteTest() throws Exception {

		File inputFile = new File("test/resources/K11002.csv");

		byte[] inputFileByte = FileUtils.readFileToByteArray(inputFile);

		ECMBulkDataLoadServiceImpl ecmBulkDataLoadServiceImpl = new ECMBulkDataLoadServiceImplMockClasses().new ECMBulkDataLoadServiceImplEMLStub();

		ecmBulkDataLoadServiceImpl.setBulkService(this.bulkServiceLocal);

		BulkResultDTO bulkResultDTO = ecmBulkDataLoadServiceImpl
				.uploadEMLFilesIntoDataBase(inputFile.getName(), inputFileByte,
						EMLFileType.SITES, null);

		assertNotNull(bulkResultDTO);
	}
}
