/**
 * ECMElectoralOrganizationServiceImplTest.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.service.impl;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.Map;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.Mockito;
import org.powermock.api.mockito.PowerMockito;
import org.powermock.modules.junit4.PowerMockRunner;

import com.smartmatic.waffle.domain.authority.ElectoralAuthorityData;
import com.smartmatic.waffle.domain.demographics.CategoryData;
import com.smartmatic.waffle.domain.demographics.ElectionData;
import com.smartmatic.waffle.domain.demographics.RegionData;
import com.smartmatic.waffle.domain.user.IUser;
import com.smartmatic.waffle.ecm.data.transfer.objects.ElectionKeyStoreComponentsDTO;
import com.smartmatic.waffle.ecm.data.transfer.objects.ElectoralAuthoritySecurityComponentsDTO;
import com.smartmatic.waffle.ecm.service.lang.ElectoralOrganizationOperationException;
import com.smartmatic.waffle.ecm.service.stub.ECMElectoralOrganizationServiceImplMockClasses;
import com.smartmatic.waffle.persistence.search.SearchExpression;
import com.smartmatic.waffle.persistence.service.spec.IPersistenceServiceLocal;

/**
 * The Class ECMElectoralOrganizationServiceImplTest.
 */
@RunWith(PowerMockRunner.class)
public class ECMElectoralOrganizationServiceImplTest {

	/** The ecm electoral organization service impl. */
	ECMElectoralOrganizationServiceImpl ecmElectoralOrganizationServiceImpl;

	/**
	 * Sets the up.
	 * 
	 * @throws Exception
	 *             the exception
	 */
	@Before
	public void setUp() throws Exception {
		this.ecmElectoralOrganizationServiceImpl = new ECMElectoralOrganizationServiceImpl();
	}

	/**
	 * Tests RetrieveActiveElection; case: exist one active election.
	 * 
	 * @throws ElectoralOrganizationOperationException
	 *             signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 */
	@Test
	public void testRetrieveActiveElection()
			throws ElectoralOrganizationOperationException {

		// arrange
		IPersistenceServiceLocal mockedPersistenceServiceLocal = new ECMElectoralOrganizationServiceImplMockClasses().new RetrieveActiveElection();

		long electionCode = 1;

		String electionName = "élections fédérales";

		boolean activeElection = true;

		this.ecmElectoralOrganizationServiceImpl
				.setPersistenceService(mockedPersistenceServiceLocal);

		// act
		ElectionData electionOut = this.ecmElectoralOrganizationServiceImpl
				.retrieveActiveElection();

		// assert
		assertEquals(electionOut.getCode(), electionCode);

		assertEquals(electionOut.getName(), electionName);

		assertEquals(electionOut.isStatusActive(), activeElection);
	}

	/**
	 * Tests RetrieveActiveElection; case: no active election.
	 * 
	 * @throws ElectoralOrganizationOperationException
	 *             signal that some problem occurs testing the method. This test
	 *             is expecting ElectoralOrganizationOperationException
	 */
	@Test(expected = ElectoralOrganizationOperationException.class)
	public void testRetrieveActiveElectionNoActiveElectionFound()
			throws ElectoralOrganizationOperationException {

		// arrange
		IPersistenceServiceLocal mockedPersistenceServiceLocal = new ECMElectoralOrganizationServiceImplMockClasses().new ActiveElectionNotFound();

		this.ecmElectoralOrganizationServiceImpl
				.setPersistenceService(mockedPersistenceServiceLocal);

		try {
			// act
			this.ecmElectoralOrganizationServiceImpl.retrieveActiveElection();
		} catch (ElectoralOrganizationOperationException e) {
			// assert
			assertEquals(e.getBundleKey(),
					"ElectoralOrganizationOperationException.active.election.not.found");

			throw e;
		}
	}

	/**
	 * Tests GetElectionKeyStoreComponents.
	 * 
	 * @throws ElectoralOrganizationOperationException
	 *             signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 */
	@Test
	public void testGetElectionKeyStoreComponents()
			throws ElectoralOrganizationOperationException {

		// arrange
		IPersistenceServiceLocal mockedPersistenceServiceLocal = new ECMElectoralOrganizationServiceImplMockClasses().new GetElectionKeyStoreComponents();

		this.ecmElectoralOrganizationServiceImpl
				.setPersistenceService(mockedPersistenceServiceLocal);

		// act
		ElectionKeyStoreComponentsDTO electionKeyStoreComponents = this.ecmElectoralOrganizationServiceImpl
				.getElectionKeyStoreComponents();

		// assert
		assertNotNull(electionKeyStoreComponents.getElectionKeyStore());
		assertNotNull(electionKeyStoreComponents.getElectionPrivateKey());
		assertNotNull(electionKeyStoreComponents.getElectionX509certificate());
		assertNotNull(electionKeyStoreComponents.getAlias());
		assertNotNull(electionKeyStoreComponents.getPassphrase());
	}

	/**
	 * Tests retrieveElectoralAuthoritiesAmount method
	 * 
	 * @throws ElectoralOrganizationOperationException
	 *             signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 */
	@Test
	public void testRetrieveElectoralAuthoritiesAmount()
			throws ElectoralOrganizationOperationException {

		// arrange
		IPersistenceServiceLocal retrieveElectoralAuthoritiesAmount = new ECMElectoralOrganizationServiceImplMockClasses().new RetrieveElectoralAuthoritiesAmount();

		this.ecmElectoralOrganizationServiceImpl
				.setPersistenceService(retrieveElectoralAuthoritiesAmount);

		// act
		int electoralAuthoritiesAmount = this.ecmElectoralOrganizationServiceImpl
				.retrieveElectoralAuthoritiesAmount();

		// assert
		assertEquals(electoralAuthoritiesAmount, 2000);
	}

	/**
	 * Tests deleteElectoralAuthoritiesSecurityComponents method
	 * 
	 * @throws ElectoralOrganizationOperationException
	 *             signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 */
	@Test
	public void testDeleteElectoralAuthoritiesSecurityComponents()
			throws ElectoralOrganizationOperationException {

		// arrange
		IPersistenceServiceLocal retrieveElectoralAuthoritiesAmount = new ECMElectoralOrganizationServiceImplMockClasses().new RetrieveElectoralAuthoritiesAmount();

		this.ecmElectoralOrganizationServiceImpl
				.setPersistenceService(retrieveElectoralAuthoritiesAmount);

		// act
		int result = this.ecmElectoralOrganizationServiceImpl
				.deleteElectoralAuthoritiesSecurityComponents();

		// assert
		assertEquals(result, 10);
	}

	/**
	 * Tests <code>retrieveElectoralAuthoritiesSecurityComponents</code> method.
	 * 
	 * @throws ElectoralOrganizationOperationException
	 *             signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 */
	@Test
	public void retrieveElectoralAuthoritiesSecurityComponents()
			throws ElectoralOrganizationOperationException {

		// arrange
		IPersistenceServiceLocal retrieveVotingDevicesAmount = new ECMElectoralOrganizationServiceImplMockClasses().new RetrieveElectoralAuthoritiesSecurityComponents();

		this.ecmElectoralOrganizationServiceImpl
				.setPersistenceService(retrieveVotingDevicesAmount);

		// act
		List<ElectoralAuthoritySecurityComponentsDTO> electoralAuthoritySecurityComponents = this.ecmElectoralOrganizationServiceImpl
				.retrieveElectoralAuthoritiesSecurityComponents(1, 3);

		// assert
		assertEquals(electoralAuthoritySecurityComponents.size(), 3);

		for (ElectoralAuthoritySecurityComponentsDTO electoralAuthoritySecurityComponentsDTO : electoralAuthoritySecurityComponents) {
			assertNotNull(electoralAuthoritySecurityComponentsDTO.getName());
			assertNotNull(electoralAuthoritySecurityComponentsDTO
					.getAsymmetricKey());
			assertNotNull(electoralAuthoritySecurityComponentsDTO
					.getSymmetricKey());
			assertNotNull(electoralAuthoritySecurityComponentsDTO
					.getProtectionKey());
			assertNotNull(electoralAuthoritySecurityComponentsDTO
					.getCustomCode());
			assertNotNull(electoralAuthoritySecurityComponentsDTO
					.getAuthorityKey());
			assertNotNull(electoralAuthoritySecurityComponentsDTO
					.getBinaryCertificate());
			assertNotNull(electoralAuthoritySecurityComponentsDTO
					.getEaUsername());
		}
	}

	@Test
	public void testGetElectoralAuthoritiesByLastLevelRegion() throws Exception {

		// arrange
		IPersistenceServiceLocal persistenceService = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		Collection<ElectoralAuthorityData> authorities = new ArrayList<ElectoralAuthorityData>();
		ElectoralAuthorityData electoralAuthority1 = new ElectoralAuthorityData();
		ElectoralAuthorityData electoralAuthority2 = new ElectoralAuthorityData();

		RegionData region1 = new RegionData();
		RegionData region2 = new RegionData();

		CategoryData category1 = new CategoryData();
		CategoryData category2 = new CategoryData();

		category1.setCategoryLevel(CategoryData.Level.FIRST_LEVEL);
		category2.setCategoryLevel(CategoryData.Level.FOURTH_LEVEL);

		region1.setCategory(category1);
		region2.setCategory(category2);

		electoralAuthority1.setRegion(region1);
		electoralAuthority2.setRegion(region2);

		authorities.add(electoralAuthority1);
		authorities.add(electoralAuthority2);

		RegionData lastLevelRegion = new RegionData();

		PowerMockito.doReturn(authorities).when(persistenceService,
				"searchObjects", Mockito.any(SearchExpression.class),
				Mockito.any(IUser.class));

		this.ecmElectoralOrganizationServiceImpl
				.setPersistenceService(persistenceService);

		// act
		Map<ElectoralAuthorityData, Collection<ElectoralAuthorityData>> authoritiesMap = this.ecmElectoralOrganizationServiceImpl
				.getElectoralAuthoritiesByLastLevelRegion(lastLevelRegion);

		ElectoralAuthorityData electoralAuthorityKey = authoritiesMap.keySet()
				.iterator().next();

		// assert
		assertEquals(electoralAuthorityKey.getRegion().getCategory()
				.getCategoryLevel(), electoralAuthority1.getRegion()
				.getCategory().getCategoryLevel());

		assertEquals(authorities, authoritiesMap.get(electoralAuthorityKey));

	}

	@Test
	public void testGetElectoralAuthoritiesByRegion() throws Exception {

		IPersistenceServiceLocal persistenceService = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		List<ElectoralAuthorityData> authorities = new ArrayList<ElectoralAuthorityData>();

		ElectoralAuthorityData electoralAuthority1 = new ElectoralAuthorityData();
		electoralAuthority1.setCode(1);

		ElectoralAuthorityData electoralAuthority2 = new ElectoralAuthorityData();
		electoralAuthority2.setCode(2);

		authorities.add(electoralAuthority1);
		authorities.add(electoralAuthority2);

		List<RegionData> selectedRegions = new ArrayList<RegionData>();
		RegionData region1 = new RegionData();
		region1.setCode(1);

		RegionData region2 = new RegionData();
		region2.setCode(2);

		selectedRegions.add(region1);
		selectedRegions.add(region2);

		PowerMockito.doReturn(authorities).when(persistenceService,
				"searchObjects", Mockito.any(SearchExpression.class),
				Mockito.any(IUser.class));

		this.ecmElectoralOrganizationServiceImpl
				.setPersistenceService(persistenceService);

		List<ElectoralAuthorityData> authoritiesResultList = this.ecmElectoralOrganizationServiceImpl
				.getElectoralAuthoritiesByRegion(selectedRegions);

		assertEquals(2, authoritiesResultList.size());

		assertEquals(electoralAuthority1.getCode(), authoritiesResultList
				.get(0).getCode());
		assertEquals(electoralAuthority2.getCode(), authoritiesResultList
				.get(1).getCode());
	}

}
