package com.smartmatic.waffle.ecm.service.impl;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.Mockito;
import org.powermock.api.mockito.PowerMockito;
import org.powermock.core.classloader.annotations.PrepareForTest;
import org.powermock.modules.junit4.PowerMockRunner;

import com.smartmatic.waffle.domain.ballot.BallotOptionData;
import com.smartmatic.waffle.domain.contest.ContestClassData;
import com.smartmatic.waffle.domain.contest.ContestData;
import com.smartmatic.waffle.domain.demographics.DistrictData;
import com.smartmatic.waffle.domain.demographics.RegionData;
import com.smartmatic.waffle.domain.eligibleoption.EligibleOptionData;
import com.smartmatic.waffle.domain.eligibleoption.EligibleOptionRoleData;
import com.smartmatic.waffle.domain.eligibleoption.PartyData;
import com.smartmatic.waffle.domain.i18n.LanguageData;
import com.smartmatic.waffle.domain.user.IUser;
import com.smartmatic.waffle.ecm.service.lang.NominationException;
import com.smartmatic.waffle.ecm.service.stub.ECMNominationServiceMockClasses;
import com.smartmatic.waffle.ecm.service.stub.ECMUtilitiesServiceMockClasses;
import com.smartmatic.waffle.lang.BaseException;
import com.smartmatic.waffle.persistence.search.SearchExpression;
import com.smartmatic.waffle.persistence.service.spec.IPersistenceServiceLocal;

@RunWith(PowerMockRunner.class)
@PrepareForTest({ ECMNominationServiceImpl.class })
public class ECMNominationServiceImplTest {

	ECMNominationServiceImpl ecmNominationService;

	@Before
	public void setUp() {
		this.ecmNominationService = new ECMNominationServiceImpl();
	}

	@Test
	public void testRetrieveNumberOfCandidates() throws NominationException {
		IPersistenceServiceLocal retriveNumberOfCandidatesMock = new ECMNominationServiceMockClasses().new RetrieveNumberOfCandidates();

		this.ecmNominationService
				.setPersistenceService(retriveNumberOfCandidatesMock);

		List<RegionData> regions = new ArrayList<RegionData>();
		List<ContestData> contests = new ArrayList<ContestData>();
		List<PartyData> parties = new ArrayList<PartyData>();

		RegionData regionData = new RegionData();
		regionData.setCode(1);
		regions.add(regionData);

		ContestData contestData = new ContestData();
		contestData.setCode(1);
		contests.add(contestData);

		PartyData partyData = new PartyData();
		partyData.setCode(1);
		parties.add(partyData);

		assertEquals(20, this.ecmNominationService.retrieveNumberOfCandidates(
				"candidate", null, null, null));
		assertEquals(20, this.ecmNominationService.retrieveNumberOfCandidates(
				"candidate", regions, null, null));
		assertEquals(20, this.ecmNominationService.retrieveNumberOfCandidates(
				"candidate", regions, contests, null));
		assertEquals(20, this.ecmNominationService.retrieveNumberOfCandidates(
				"candidate", regions, contests, parties));

	}

	@Test
	public void testGetCandidates() throws NominationException {
		IPersistenceServiceLocal getCandidatesMock = new ECMNominationServiceMockClasses().new GetCandidates();

		IPersistenceServiceLocal utilitiesMock = new ECMUtilitiesServiceMockClasses().new PersistenceServiceLocalMock();

		ECMUtilitiesServiceImpl utilitiesServiceMock = new ECMUtilitiesServiceImpl();
		utilitiesServiceMock.setPersistenceService(utilitiesMock);

		this.ecmNominationService.setPersistenceService(getCandidatesMock);
		this.ecmNominationService.setECMUtilitiesService(utilitiesServiceMock);

		List<RegionData> regions = new ArrayList<RegionData>();
		List<ContestData> contests = new ArrayList<ContestData>();
		List<PartyData> parties = new ArrayList<PartyData>();
		LanguageData language = new LanguageData();

		RegionData regionData = new RegionData();
		regionData.setCode(1);
		regions.add(regionData);

		ContestData contestData = new ContestData();
		contestData.setCode(1);
		contests.add(contestData);

		PartyData partyData = new PartyData();
		partyData.setCode(1);
		parties.add(partyData);

		List<EligibleOptionData> eligibleOptions;

		eligibleOptions = this.ecmNominationService.getCandidates(1, 1,
				"candidate", null, null, null, language);
		for (EligibleOptionData party : eligibleOptions) {
			assertNotNull(party.getCode());
			assertNotNull(party.getBallotName());
			assertNotNull(party.getContest());
		}

		eligibleOptions = this.ecmNominationService.getCandidates(1, 1,
				"candidate", regions, null, null, language);
		for (EligibleOptionData party : eligibleOptions) {
			assertNotNull(party.getCode());
			assertNotNull(party.getBallotName());
			assertNotNull(party.getContest());
		}

		eligibleOptions = this.ecmNominationService.getCandidates(1, 1,
				"candidate", regions, contests, null, language);
		for (EligibleOptionData party : eligibleOptions) {
			assertNotNull(party.getCode());
			assertNotNull(party.getBallotName());
			assertNotNull(party.getContest());
		}

		eligibleOptions = this.ecmNominationService.getCandidates(1, 1,
				"candidate", regions, contests, parties, language);
		for (EligibleOptionData party : eligibleOptions) {
			assertNotNull(party.getCode());
			assertNotNull(party.getBallotName());
			assertNotNull(party.getContest());
		}

	}

	@Test
	public void testRetrieveNumberOfParties() throws NominationException {
		IPersistenceServiceLocal retrieveNumberOfPartiesMock = new ECMNominationServiceMockClasses().new RetrieveNumberOfParties();

		this.ecmNominationService
				.setPersistenceService(retrieveNumberOfPartiesMock);

		List<RegionData> regions = new ArrayList<RegionData>();
		List<ContestData> contests = new ArrayList<ContestData>();

		RegionData regionData = new RegionData();
		regionData.setCode(1);
		regions.add(regionData);

		ContestData contestData = new ContestData();
		contestData.setCode(1);
		contests.add(contestData);

		assertEquals(20, this.ecmNominationService.retrieveNumberOfParties(
				"party", null, null));
		assertEquals(20, this.ecmNominationService.retrieveNumberOfParties(
				"party", regions, null));
		assertEquals(20, this.ecmNominationService.retrieveNumberOfParties(
				"party", regions, contests));
	}

	@Test
	public void testGetParties() throws NominationException {
		IPersistenceServiceLocal getPartiesMock = new ECMNominationServiceMockClasses().new GetParties();

		IPersistenceServiceLocal utilitiesMock = new ECMUtilitiesServiceMockClasses().new PersistenceServiceLocalMock();

		ECMUtilitiesServiceImpl utilitiesServiceMock = new ECMUtilitiesServiceImpl();
		utilitiesServiceMock.setPersistenceService(utilitiesMock);

		this.ecmNominationService.setPersistenceService(getPartiesMock);
		this.ecmNominationService.setECMUtilitiesService(utilitiesServiceMock);

		List<RegionData> regions = new ArrayList<RegionData>();
		List<ContestData> contests = new ArrayList<ContestData>();
		LanguageData language = new LanguageData();
		List<EligibleOptionData> eligibleOptions;

		RegionData regionData = new RegionData();
		regionData.setCode(1);
		regions.add(regionData);

		ContestData contestData = new ContestData();
		contestData.setCode(1);
		contests.add(contestData);

		eligibleOptions = this.ecmNominationService.getParties(1, 1, "party",
				null, null, language);
		for (EligibleOptionData party : eligibleOptions) {
			assertNotNull(party.getCode());
			assertNotNull(party.getBallotName());
			assertNotNull(party.getContest());
		}

		eligibleOptions = this.ecmNominationService.getParties(1, 1, "party",
				regions, contests, language);
		for (EligibleOptionData party : eligibleOptions) {
			assertNotNull(party.getCode());
			assertNotNull(party.getBallotName());
			assertNotNull(party.getContest());
		}

		eligibleOptions = this.ecmNominationService.getParties(1, 1, "party",
				regions, contests, language);
		for (EligibleOptionData party : eligibleOptions) {
			assertNotNull(party.getCode());
			assertNotNull(party.getBallotName());
			assertNotNull(party.getContest());
		}
	}

	@Test
	public void testGetPartiesFromAdvancedSearch() throws Exception {
		IPersistenceServiceLocal getPartiesMock = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		this.ecmNominationService.setPersistenceService(getPartiesMock);

		List<PartyData> partiesList = new ArrayList<PartyData>();
		PartyData party1 = new PartyData();

		party1.setCode(1);
		party1.setName("party");

		partiesList.add(party1);

		List<PartyData> partiesListResult;

		List<RegionData> regions = new ArrayList<RegionData>();
		List<ContestData> contests = new ArrayList<ContestData>();

		RegionData regionData = new RegionData();
		regionData.setCode(1);
		regions.add(regionData);

		ContestData contestData = new ContestData();
		contestData.setCode(1);
		contests.add(contestData);

		PowerMockito.doReturn(partiesList).when(getPartiesMock,
				"searchObjects", Mockito.any(SearchExpression.class),
				Mockito.any(String[].class), Mockito.any(IUser.class));

		partiesListResult = this.ecmNominationService.getParties(regions,
				contests);

		for (PartyData party : partiesListResult) {
			assertNotNull(party.getCode());
			assertNotNull(party.getName());
		}
	}

	@Test
	public void testGetContests() throws Exception {

		IPersistenceServiceLocal getContestsMock = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		ECMUtilitiesServiceImpl ecmUtilitiesServiceMock = PowerMockito
				.mock(ECMUtilitiesServiceImpl.class);

		this.ecmNominationService.setPersistenceService(getContestsMock);

		this.ecmNominationService
				.setECMUtilitiesService(ecmUtilitiesServiceMock);

		List<ContestData> contestsList = new ArrayList<ContestData>();
		List<ContestData> contestsListResult = new ArrayList<ContestData>();

		ContestData contest1 = new ContestData();
		contest1.setCode(1);
		contest1.setName("contest");
		contestsList.add(contest1);

		List<RegionData> regions = new ArrayList<RegionData>();
		List<PartyData> parties = new ArrayList<PartyData>();
		LanguageData language = new LanguageData();

		PowerMockito.doReturn(contest1).when(ecmUtilitiesServiceMock,
				"translateContestName", contest1, language);

		PowerMockito.doReturn(contestsList).when(getContestsMock,
				"searchObjects", Mockito.any(SearchExpression.class),
				Mockito.any(String[].class), Mockito.any(IUser.class));

		contestsListResult = this.ecmNominationService.getContests(regions,
				parties, language);

		for (ContestData contest : contestsListResult) {
			assertNotNull(contest.getCode());
			assertNotNull(contest.getName());
		}
	}

	@Test
	public void testGetBallotOptionByEligibleOptions() throws BaseException,
			NominationException {

		IPersistenceServiceLocal persistenceService = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		List<Object[]> ballotOptionObjects = new ArrayList<Object[]>();

		Object[] ballotOption = new Object[5];

		ballotOption[0] = (long) 1;
		ballotOption[1] = "ballot-code";
		ballotOption[2] = BallotOptionData.Type.SCREEN;
		ballotOption[3] = 2;
		ballotOption[4] = (long) 1;

		ballotOptionObjects.add(ballotOption);

		List<EligibleOptionData> eligibleOptionsList = new ArrayList<EligibleOptionData>();

		EligibleOptionData eligibleOptionData1 = new EligibleOptionData();
		eligibleOptionData1.setCode(1);

		EligibleOptionData eligibleOptionData2 = new EligibleOptionData();
		eligibleOptionData1.setCode(1);

		eligibleOptionsList.add(eligibleOptionData1);
		eligibleOptionsList.add(eligibleOptionData2);

		PowerMockito
				.doReturn(ballotOptionObjects)
				.when(persistenceService)
				.searchObjects(Mockito.any(SearchExpression.class),
						Mockito.any(IUser.class));

		this.ecmNominationService.setPersistenceService(persistenceService);

		// act
		List<EligibleOptionData> eligibleOptionsListResult = this.ecmNominationService
				.getBallotOptionByEligibleOptions(eligibleOptionsList);

		// assert

		assertEquals(2, eligibleOptionsListResult.size());

		assertEquals(eligibleOptionData1, eligibleOptionsListResult.get(0));
		assertEquals(eligibleOptionData2, eligibleOptionsListResult.get(1));

		Set<BallotOptionData> ballotOptions1 = eligibleOptionsListResult.get(0)
				.getBallotOptions();

		for (BallotOptionData ballotOptionResult : ballotOptions1) {
			assertEquals(1, ballotOptionResult.getCode());
			assertEquals("ballot-code", ballotOptionResult.getCustomCode());
			assertEquals(BallotOptionData.Type.SCREEN,
					ballotOptionResult.getType());
		}

		Set<BallotOptionData> ballotOptions2 = eligibleOptionsListResult.get(1)
				.getBallotOptions();

		for (BallotOptionData ballotOptionResult : ballotOptions2) {
			assertEquals(1, ballotOptionResult.getCode());
			assertEquals("ballot-code", ballotOptionResult.getCustomCode());
			assertEquals(BallotOptionData.Type.SCREEN,
					ballotOptionResult.getType());
		}
	}

	@Test
	public void testGetEligibleOptionRoleByEligibleOption()
			throws BaseException, NominationException {

		// arrange
		IPersistenceServiceLocal persistenceService = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		List<EligibleOptionData> eligibleOptionsList = new ArrayList<EligibleOptionData>();

		EligibleOptionData eligibleOptionData1 = new EligibleOptionData();
		eligibleOptionData1.setCode(1);

		EligibleOptionData eligibleOptionData2 = new EligibleOptionData();
		eligibleOptionData1.setCode(1);

		eligibleOptionsList.add(eligibleOptionData1);
		eligibleOptionsList.add(eligibleOptionData2);

		List<Object[]> eligibleOptionRoleList = new ArrayList<Object[]>();

		Object[] role = new Object[3];
		role[0] = (long) 1;
		role[1] = EligibleOptionRoleData.Role.CHIEF;
		role[2] = (long) 1;
		eligibleOptionRoleList.add(role);

		PowerMockito
				.doReturn(eligibleOptionRoleList)
				.when(persistenceService)
				.searchObjects(Mockito.any(SearchExpression.class),
						Mockito.any(IUser.class));

		this.ecmNominationService.setPersistenceService(persistenceService);

		// act

		List<EligibleOptionData> eligibleOptionsListResult = this.ecmNominationService
				.getEligibleOptionRoleByEligibleOption(eligibleOptionsList);

		// assert

		assertEquals(2, eligibleOptionsListResult.size());

		for (EligibleOptionData eligibleOption : eligibleOptionsListResult) {
			for (EligibleOptionRoleData roleData : eligibleOption
					.getEligibleOptionRoleData()) {
				assertEquals(role[0], roleData.getCode());
				assertEquals(role[1], roleData.getRole());
			}
		}
	}

	@Test
	public void testGetEligibleOptionByContest() throws BaseException,
			NominationException {
		// arrange
		IPersistenceServiceLocal persistenceService = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		ContestData contest = new ContestData();
		contest.setCode(1);

		List<Object[]> eligibleOptionObjectList = new ArrayList<Object[]>();

		Object[] role = new Object[4];
		role[0] = (long) 2;
		role[1] = "custom-code";
		role[2] = "ballot-name";
		role[3] = "1";

		eligibleOptionObjectList.add(role);
		eligibleOptionObjectList.add(role);

		PowerMockito
				.doReturn(eligibleOptionObjectList)
				.when(persistenceService)
				.searchObjects(Mockito.any(SearchExpression.class),
						Mockito.any(IUser.class));

		this.ecmNominationService.setPersistenceService(persistenceService);

		// act

		List<EligibleOptionData> eligibleOptionsListResult = this.ecmNominationService
				.getEligibleOptionsByContest(contest);

		// assert

		assertEquals(2, eligibleOptionsListResult.size());

		for (EligibleOptionData eligibleOption : eligibleOptionsListResult) {
			assertEquals(role[0], eligibleOption.getCode());
			assertEquals(role[1], eligibleOption.getCustomCode());
			assertEquals(role[2], eligibleOption.getBallotName());
			assertEquals(role[3], eligibleOption.getParentCode());
		}
	}

	@Test
	public void testGetContestsByContestsCodes() throws NominationException,
			BaseException {
		// arrange
		IPersistenceServiceLocal persistenceService = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		List<ContestData> contestList = new ArrayList<ContestData>();

		ContestData contestData1 = new ContestData();
		ContestData contestData2 = new ContestData();
		contestData1.setCode(1);
		contestData1.setCustomCode("custom-code-1");

		contestData2.setCode(2);
		contestData1.setCustomCode("custom-code-2");

		contestList.add(contestData1);
		contestList.add(contestData2);

		List<Long> contestCodesList = new ArrayList<Long>();

		PowerMockito
				.doReturn(contestList)
				.when(persistenceService)
				.searchPagedObjects(Mockito.any(SearchExpression.class),
						Mockito.any(String[].class), Mockito.any(IUser.class),
						Mockito.anyInt(), Mockito.anyInt());

		this.ecmNominationService.setPersistenceService(persistenceService);

		// act
		List<ContestData> contestListResult = this.ecmNominationService
				.getContests(contestCodesList, 1, Integer.MAX_VALUE);

		// assert

		assertEquals(2, contestListResult.size());

		assertEquals(contestData1.getCode(), contestListResult.get(0).getCode());
		assertEquals(contestData1.getCustomCode(), contestListResult.get(0)
				.getCustomCode());

		assertEquals(contestData2.getCode(), contestListResult.get(1).getCode());
		assertEquals(contestData2.getCustomCode(), contestListResult.get(1)
				.getCustomCode());
	}

	@Test
	public void testGetContestsByContestClass() throws Exception {

		ECMNominationServiceImpl nominationMock = PowerMockito
				.spy(new ECMNominationServiceImpl());

		ECMUtilitiesServiceImpl ecmUtilitiesServiceMock = PowerMockito
				.mock(ECMUtilitiesServiceImpl.class);

		IPersistenceServiceLocal persistenceServiceMock = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		nominationMock.setECMUtilitiesService(ecmUtilitiesServiceMock);
		nominationMock.setPersistenceService(persistenceServiceMock);

		ContestData contestData = getContestData();

		PowerMockito
				.when(persistenceServiceMock.searchObjects(
						Mockito.any(SearchExpression.class),
						Mockito.any(IUser.class)))
				.thenReturn(getLVGCustomCode()).thenReturn(getContestCode())
				.thenReturn(getContestObject()).thenReturn(getTranslations())
				.thenReturn(getProperties());

		PowerMockito
				.doReturn(contestData)
				.when(ecmUtilitiesServiceMock)
				.translateContestName(Mockito.any(ContestData.class),
						Mockito.any(LanguageData.class));

		List<ContestData> contestsResult = nominationMock
				.getContestsByContestClass("CC1", new LanguageData());

		assertEquals(contestsResult.size(), 1);

		for (ContestData contest : contestsResult) {
			assertEquals(contest, contestData);
		}

	}

	private ContestData getContestData() {
		ContestData contest = new ContestData();
		contest.setName("contest-1");
		contest.setContestClass(new ContestClassData());
		return contest;
	}

	private Collection<String> getLVGCustomCode() {
		List<String> lvgCustomCodeList = new ArrayList<String>();

		lvgCustomCodeList.add("LVGCC1");
		lvgCustomCodeList.add("LVGCC2");

		return lvgCustomCodeList;
	}

	private Collection<Long> getContestCode() {
		List<Long> contestCodeList = new ArrayList<Long>();

		contestCodeList.add(1L);
		contestCodeList.add(2L);

		return contestCodeList;
	}

	private Collection<Map<String, Object>> getContestObject() {
		List<Map<String, Object>> contestObjects = new ArrayList<Map<String, Object>>();
		Map<String, Object> contestObject = new HashMap<String, Object>();

		ContestClassData contestClass = new ContestClassData();
		contestClass.setCode(1L);

		DistrictData districtData = new DistrictData();
		districtData.setCode(1L);

		contestObject.put("contestCustomCode", "CC1");
		contestObject.put("contestCode", 1L);
		contestObject.put("contestName", "CC1");
		contestObject.put("contestCollegeLanguageRFC", "College Language");
		contestObject.put("contestClass", contestClass);
		contestObject.put("district", districtData);

		contestObjects.add(contestObject);

		return contestObjects;
	}

	private Collection<String> getTranslations() {
		List<String> translations = new ArrayList<String>();

		translations.add("Text 1");
		translations.add("Text 2");

		return translations;
	}

	private Collection<String> getProperties() {
		List<String> translations = new ArrayList<String>();

		translations.add("Property 1");
		translations.add("Property 2");

		return translations;
	}
}
