/**
 * ECMServiceUtilitiesTest.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.service.impl;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;

import java.io.File;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import javax.sql.DataSource;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.Mockito;
import org.powermock.api.mockito.PowerMockito;
import org.powermock.core.classloader.annotations.PrepareForTest;
import org.powermock.modules.junit4.PowerMockRunner;

import com.smartmatic.waffle.domain.contest.ContestData;
import com.smartmatic.waffle.domain.demographics.DistrictData;
import com.smartmatic.waffle.domain.i18n.LanguageData;
import com.smartmatic.waffle.domain.multiLanguage.MultiLingualKeyData;
import com.smartmatic.waffle.domain.multiLanguage.TranslationKeyData;
import com.smartmatic.waffle.domain.user.IUser;
import com.smartmatic.waffle.ecm.data.transfer.objects.EntityRecordsQuantitiesDTO;
import com.smartmatic.waffle.ecm.service.lang.BulkDataLoadException;
import com.smartmatic.waffle.ecm.service.lang.ElectoralPhysicalLocationsRegistryException;
import com.smartmatic.waffle.ecm.service.lang.UtilitiesException;
import com.smartmatic.waffle.ecm.service.stub.ECMUtilitiesServiceMockClasses;
import com.smartmatic.waffle.persistence.search.SearchExpression;
import com.smartmatic.waffle.persistence.service.spec.IPersistenceServiceLocal;

/**
 * The test class of ECMServiceUtilities service.
 */
@RunWith(PowerMockRunner.class)
@PrepareForTest({ ECMUtilitiesServiceImpl.class })
public class ECMUtilitiesServiceTest {

	ECMUtilitiesServiceImpl ecmUtilitiesService;

	/**
	 * SetUp method to prepare the test.
	 * 
	 * @throws Exception
	 *             Signals that an exception has occurred preparing the test.
	 */
	@Before
	public void setUp() throws Exception {
		this.ecmUtilitiesService = new ECMUtilitiesServiceImpl();
	}

	/**
	 * Test if the query is executed.
	 * 
	 * @throws SQLException
	 *             the sQL exception
	 */
	@Test
	public void testExecuteQuery() throws SQLException {
		String sqlQuery = "select region_name as 'Région',min(nis_code) as 'NIS Code',array_agg(language_rfc) as 'Langue' from (select r.region_name, r.nis_code, el.language_rfc from region r inner join region_election_language rel on r.region_code = rel.region_code inner join election_language el on el.election_language_code = rel.election_language_code order by region_name, el.precedence asc) as source group by region_name order by 'NIS Code' ";

		final DataSource dataSource = mock(DataSource.class);
		final Connection connection = mock(Connection.class);
		final PreparedStatement statement = mock(PreparedStatement.class);

		when(dataSource.getConnection()).thenReturn(connection);
		when(connection.prepareStatement(sqlQuery)).thenReturn(statement);

		try {
			this.ecmUtilitiesService.setDataSource(dataSource);
			this.ecmUtilitiesService.executeQuery(sqlQuery);
		} catch (UtilitiesException e) {
			e.printStackTrace();
		}
		verify(statement).executeQuery();
	}

	/**
	 * Tests getEntityRecordsQuantities method.
	 * 
	 * @throws BulkDataLoadException
	 *             signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 */
	@Test
	public void testGetEntityRecordsQuantities() throws BulkDataLoadException {

		// arrange
		ECMUtilitiesServiceImpl ecmUtilitiesService = new ECMUtilitiesServiceMockClasses().new ECMUtilitiesServiceMock();

		// act
		List<EntityRecordsQuantitiesDTO> entityRecordsQuantitiesList = ecmUtilitiesService
				.getEntityRecordsQuantities();

		// assert
		assertNotNull(entityRecordsQuantitiesList);
		assertEquals(entityRecordsQuantitiesList.size(), 17);
		for (EntityRecordsQuantitiesDTO entityRecordsQuantities : entityRecordsQuantitiesList) {
			assertNotNull(entityRecordsQuantities.getSmttFileType());
			assertEquals(entityRecordsQuantities.getRecordsQuantities(), 100);
		}
	}

	/**
	 * Tests retrieveMultilingualKeysAmount method.
	 * 
	 * @throws BulkDataLoadException
	 *             signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 */
	@Test
	public void testRetrieveMultilingualKeysAmount()
			throws BulkDataLoadException {

		// arrange
		ECMUtilitiesServiceImpl ecmUtilitiesService = new ECMUtilitiesServiceImpl();
		IPersistenceServiceLocal persistenceServiceLocal = new ECMUtilitiesServiceMockClasses().new PersistenceServiceLocalMock();
		ecmUtilitiesService.setPersistenceService(persistenceServiceLocal);

		// act
		int multilingualKeysAmount = ecmUtilitiesService
				.retrieveMultilingualKeysAmount();

		// assert
		assertEquals(multilingualKeysAmount, 100);
	}

	/**
	 * Tests getTranslationkeysToDownload method.
	 * 
	 * @throws BulkDataLoadException
	 *             signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 */
	@Test
	public void testGetTranslationkeysToDownload()
			throws BulkDataLoadException {

		// arrange
		ECMUtilitiesServiceImpl ecmUtilitiesService = new ECMUtilitiesServiceImpl();
		IPersistenceServiceLocal persistenceServiceLocal = new ECMUtilitiesServiceMockClasses().new PersistenceServiceLocalMock();
		ecmUtilitiesService.setPersistenceService(persistenceServiceLocal);

		// act
		List<String> translationkeysToDownload = ecmUtilitiesService
				.getTranslationkeysToDownload(0, 1);

		// assert
		assertNotNull(translationkeysToDownload);
		assertEquals(translationkeysToDownload.size(), 3);
		for (String translationkey : translationkeysToDownload) {
			assertNotNull(translationkey);
		}
	}

	/**
	 * Tests all methods to remove records in database.
	 * 
	 * @throws Exception
	 *             signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 */
	@Test
	public void testTruncateTables() throws Exception {

		// arrange
		ECMUtilitiesServiceImpl ecmUtilitiesService = new ECMUtilitiesServiceMockClasses().new ECMUtilitiesServiceMock();
		IPersistenceServiceLocal persistenceServiceLocal = new ECMUtilitiesServiceMockClasses().new PersistenceServiceLocalMock();
		ecmUtilitiesService.setPersistenceService(persistenceServiceLocal);

		File reportFolder = new File("test/resources/reports");
		reportFolder.mkdir();
		File report1 = new File(reportFolder, "report1.jrxml");
		File report2 = new File(reportFolder, "report2.jrxml");
		File report3 = new File(reportFolder, "report3.jrxml");

		report1.createNewFile();
		report2.createNewFile();
		report3.createNewFile();

		// act
		ecmUtilitiesService.truncateLanguageTables();
		ecmUtilitiesService.truncateNominationTables();
		ecmUtilitiesService.truncateUserTables();
		ecmUtilitiesService.truncatePhysicalLocationsTables();
		ecmUtilitiesService.truncateDemographyTables();
		ecmUtilitiesService.truncateReportTemplatesTables();
		ecmUtilitiesService.truncateLogicalVotingGroup();
		ecmUtilitiesService.truncateEligibleOption();
		ecmUtilitiesService.truncateCodiNominationTables();
		ecmUtilitiesService.truncateContestLanguagesPair();

		// assert
		assertFalse(report1.exists());
		assertFalse(report2.exists());
		assertFalse(report3.exists());
		assertTrue(reportFolder.delete());
	}

	/**
	 * Tests deleteEMLFiles method.
	 * 
	 * @throws Exception
	 *             signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 */
	@Test
	public void testDeleteEMLFiles() throws Exception {

		// arrange
		ECMUtilitiesServiceImpl ecmUtilitiesService = new ECMUtilitiesServiceMockClasses().new ECMUtilitiesServiceMock();
		IPersistenceServiceLocal persistenceServiceLocal = new ECMUtilitiesServiceMockClasses().new PersistenceServiceLocalMock();
		ecmUtilitiesService.setPersistenceService(persistenceServiceLocal);

		File emlFolder = new File("test/resources/eml");
		emlFolder.mkdir();
		File emlFile1 = new File(emlFolder, "DC11001.EML");
		File emlFile2 = new File(emlFolder, "DC11002.EML");
		File emlFile3 = new File(emlFolder, "DC11003.EML");

		emlFile1.createNewFile();
		emlFile2.createNewFile();
		emlFile3.createNewFile();

		// act
		ecmUtilitiesService.deleteEMLFiles();

		// assert
		assertFalse(emlFile1.exists());
		assertFalse(emlFile2.exists());
		assertFalse(emlFile3.exists());
		assertTrue(emlFolder.delete());
	}

	/**
	 * Tests deleteVoiceFiles method.
	 * 
	 * @throws Exception
	 *             signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 */
	@Test
	public void testDeleteVoiceFiles() throws Exception {

		// arrange
		ECMUtilitiesServiceImpl ecmUtilitiesService = new ECMUtilitiesServiceMockClasses().new ECMUtilitiesServiceMock();
		IPersistenceServiceLocal persistenceServiceLocal = new ECMUtilitiesServiceMockClasses().new PersistenceServiceLocalMock();
		ecmUtilitiesService.setPersistenceService(persistenceServiceLocal);

		File voiceFolder = new File("test/resources/voice_files");
		voiceFolder.mkdir();
		File voiceFile1 = new File(voiceFolder, "voice1.dat");
		File voiceFile2 = new File(voiceFolder, "voice2.dat");
		File voiceFile3 = new File(voiceFolder, "voice3.dat");

		voiceFile1.createNewFile();
		voiceFile2.createNewFile();
		voiceFile3.createNewFile();

		// act
		ecmUtilitiesService.deleteVoiceFiles();

		// assert
		assertFalse(voiceFile1.exists());
		assertFalse(voiceFile2.exists());
		assertFalse(voiceFile3.exists());
		assertFalse(voiceFolder.exists());
	}

	/**
	 * Tests getTranslationkeysToDownload method.
	 * 
	 * @throws BulkDataLoadException
	 *             signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 */
	@Test
	public void testUpdateObject() throws BulkDataLoadException {

		// arrange
		ECMUtilitiesServiceImpl ecmUtilitiesService = new ECMUtilitiesServiceImpl();
		IPersistenceServiceLocal persistenceServiceLocal = new ECMUtilitiesServiceMockClasses().new PersistenceServiceLocalMock();
		ecmUtilitiesService.setPersistenceService(persistenceServiceLocal);

		String newName = "NewContestName";

		ContestData constestData = new ContestData();

		constestData.setCode(1);
		constestData.setName("ContestName");
		constestData.setCustomCode("ContestCustomCode");

		// act
		constestData.setName(newName);
		ContestData constestUpdated = (ContestData) ecmUtilitiesService
				.updateObject(constestData);

		// assert
		assertEquals(constestUpdated.getName(), newName);
	}

	/**
	 * Tests getItemByCustomCode method.
	 * 
	 * @throws UtilitiesException
	 *             signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 */
	@Test
	public void testGetItemByCustomCode() throws UtilitiesException {

		// arrange
		ECMUtilitiesServiceImpl ecmUtilitiesService = new ECMUtilitiesServiceMockClasses().new ECMUtilitiesServiceMock();
		IPersistenceServiceLocal persistenceServiceLocal = new ECMUtilitiesServiceMockClasses().new PersistenceServiceLocalMock();
		ecmUtilitiesService.setPersistenceService(persistenceServiceLocal);

		String contestCustomCode = "ContestCustomCode";

		// act
		ContestData constest = ecmUtilitiesService
				.getItemByCustomCode(contestCustomCode, ContestData.class);

		// assert
		assertEquals(constest.getCustomCode(), contestCustomCode);
	}

	/**
	 * Tests checkIfSecurityComponentsAreGenerated method.
	 * 
	 * @throws ElectoralPhysicalLocationsRegistryException
	 *             signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 */
	@Test
	public void testCheckIfSecurityComponentsAreGenerated()
			throws ElectoralPhysicalLocationsRegistryException {

		// arrange
		ECMUtilitiesServiceImpl ecmUtilitiesService = new ECMUtilitiesServiceMockClasses().new ECMUtilitiesServiceMock();
		IPersistenceServiceLocal persistenceServiceLocal = new ECMUtilitiesServiceMockClasses().new PersistenceServiceLocalMock();
		ecmUtilitiesService.setPersistenceService(persistenceServiceLocal);

		// act
		boolean securityComponentsAreGenerated = ecmUtilitiesService
				.checkIfSecurityComponentsAreGenerated();

		// assert
		assertTrue(securityComponentsAreGenerated);
	}

	@Test
	public void testTranslateContestName() throws Exception {
		// arrange
		IPersistenceServiceLocal persistenceServiceLocal = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		ContestData contest = getContestWithDistrict();

		List<TranslationKeyData> translationList = new ArrayList<TranslationKeyData>();

		TranslationKeyData translation = new TranslationKeyData();
		translation.setTranslationText("Contest name translated");

		translationList.add(translation);

		PowerMockito.doReturn(translationList).when(persistenceServiceLocal,
				"searchObjects", Mockito.any(SearchExpression.class),
				Mockito.any(IUser.class));

		this.ecmUtilitiesService.setPersistenceService(persistenceServiceLocal);

		// act
		ContestData contestOut = this.ecmUtilitiesService
				.translateContestName(contest, new LanguageData());

		// assert
		assertNotNull(contestOut.getContestNameTranslate());
		PowerMockito.verifyPrivate(persistenceServiceLocal).invoke(
				"searchObjects", Mockito.any(SearchExpression.class),
				Mockito.any(IUser.class));
		PowerMockito.verifyPrivate(persistenceServiceLocal).invoke(
				"searchObject", Mockito.any(SearchExpression.class),
				Mockito.any(IUser.class));

	}

	@Test
	public void testTranslateContestNameCaseTranslationNotFound()
			throws Exception {
		// arrange
		IPersistenceServiceLocal persistenceServiceLocal = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		ContestData contest = getContestWithDistrict();

		PowerMockito.doReturn(null).when(persistenceServiceLocal,
				"searchObjects", Mockito.any(SearchExpression.class),
				Mockito.any(IUser.class));

		this.ecmUtilitiesService.setPersistenceService(persistenceServiceLocal);

		// act
		ContestData contestOut = this.ecmUtilitiesService
				.translateContestName(contest, new LanguageData());

		// assert
		assertNotNull(contestOut.getContestNameTranslate());
		PowerMockito.verifyPrivate(persistenceServiceLocal).invoke(
				"searchObjects", Mockito.any(SearchExpression.class),
				Mockito.any(IUser.class));
		PowerMockito.verifyPrivate(persistenceServiceLocal).invoke(
				"searchObject", Mockito.any(SearchExpression.class),
				Mockito.any(IUser.class));

	}

	@Test
	public void testTranslateDistrictName() throws Exception {
		// arrange
		IPersistenceServiceLocal persistenceServiceLocal = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		DistrictData district = getDistrict();

		TranslationKeyData translation = new TranslationKeyData();
		translation.setTranslationText("District name translated");

		PowerMockito.doReturn(translation).when(persistenceServiceLocal,
				"searchObject", Mockito.any(SearchExpression.class),
				Mockito.any(IUser.class));

		this.ecmUtilitiesService.setPersistenceService(persistenceServiceLocal);

		// act
		DistrictData districtOut = this.ecmUtilitiesService
				.translateDistrictName(district, new LanguageData());

		// assert
		assertNotNull(districtOut.getDistrictNameTraslated());
		PowerMockito.verifyPrivate(persistenceServiceLocal).invoke(
				"searchObject", Mockito.any(SearchExpression.class),
				Mockito.any(IUser.class));
	}

	@Test
	public void testTranslateDistrictNameCaseTranslationNotFound()
			throws Exception {
		// arrange
		IPersistenceServiceLocal persistenceServiceLocal = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		DistrictData district = getDistrict();

		PowerMockito.doReturn(null).when(persistenceServiceLocal,
				"searchObject", Mockito.any(SearchExpression.class),
				Mockito.any(IUser.class));

		this.ecmUtilitiesService.setPersistenceService(persistenceServiceLocal);

		// act
		DistrictData districtOut = this.ecmUtilitiesService
				.translateDistrictName(district, new LanguageData());

		// assert
		assertNotNull(districtOut.getDistrictNameTraslated());
		PowerMockito.verifyPrivate(persistenceServiceLocal).invoke(
				"searchObject", Mockito.any(SearchExpression.class),
				Mockito.any(IUser.class));
	}

	@Test
	public void testProccessMultilingualObject() throws Exception {

		// arrange
		IPersistenceServiceLocal persistenceServiceLocal = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		DistrictData district = getDistrict();

		Map<String, Map<String, String>> resourcesLanguages = new HashMap<String, Map<String, String>>();

		Set<LanguageData> languages = new HashSet<LanguageData>();

		LanguageData language1 = new LanguageData();

		language1.setCode(1);
		language1.setName("English");
		language1.setCustomCode("ENGLISH");
		language1.setOfficialLanguage(true);
		language1.setLanguageRFC("EN");

		languages.add(language1);

		List<TranslationKeyData> translationList = new ArrayList<TranslationKeyData>();

		TranslationKeyData translation1 = new TranslationKeyData();
		translation1.setCustomCode("COLLEGEKEY");
		translation1.setTranslationText("College name translated");

		translation1.setElectionLanguage(language1);

		TranslationKeyData translation2 = new TranslationKeyData();
		translation2.setCustomCode("COLLEGEKEY");

		translation2.setElectionLanguage(language1);

		MultiLingualKeyData multiLingualKeyData = new MultiLingualKeyData();

		multiLingualKeyData.setCode(1);
		multiLingualKeyData.setForeignKey(1);
		multiLingualKeyData.setKey("key");
		multiLingualKeyData.setField("name");

		translation1.setMultilingualKey(multiLingualKeyData);
		translation2.setMultilingualKey(multiLingualKeyData);

		translationList.add(translation1);
		translationList.add(translation2);

		PowerMockito.doReturn(translationList).when(persistenceServiceLocal,
				"searchObjects", Mockito.any(SearchExpression.class),
				Mockito.any(IUser.class));

		this.ecmUtilitiesService.setPersistenceService(persistenceServiceLocal);

		// act
		Map<String, Map<String, String>> resourcesLanguagesOut = this.ecmUtilitiesService
				.processMultilingualObject(languages, resourcesLanguages,
						district);

		// assert
		assertNotNull(resourcesLanguagesOut);
		assertEquals(2, resourcesLanguagesOut.keySet().size());
		PowerMockito.verifyPrivate(persistenceServiceLocal, Mockito.times(2))
				.invoke("searchObjects", Mockito.any(SearchExpression.class),
						Mockito.any(IUser.class));
	}

	@Test
	public void testTranslateCollege() throws Exception {
		// arrange
		IPersistenceServiceLocal persistenceServiceLocal = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		ContestData contest = new ContestData();

		contest.setCode(1);
		contest.setCustomCode("CONTEST1");
		contest.setName("Contest name");

		List<TranslationKeyData> translationList = new ArrayList<TranslationKeyData>();

		TranslationKeyData translation = new TranslationKeyData();
		translation.setTranslationText("College name translated");

		translationList.add(translation);

		PowerMockito.doReturn(translationList).when(persistenceServiceLocal,
				"searchObjects", Mockito.any(SearchExpression.class),
				Mockito.any(IUser.class));

		this.ecmUtilitiesService.setPersistenceService(persistenceServiceLocal);

		// act
		ContestData contestOut = this.ecmUtilitiesService
				.translateCollege(contest, new LanguageData());

		// assert
		assertNotNull(contestOut.getCollegeTranslate());
		PowerMockito.verifyPrivate(persistenceServiceLocal).invoke(
				"searchObjects", Mockito.any(SearchExpression.class),
				Mockito.any(IUser.class));
	}

	private DistrictData getDistrict() {
		DistrictData district = new DistrictData();

		district.setCode(1);
		district.setCustomCode("DISTRICT1");
		district.setName("District name");
		district.setDistrictName("District name");
		return district;
	}

	private ContestData getContestWithDistrict() {
		ContestData contest = new ContestData();

		contest.setCode(1);
		contest.setCustomCode("CONTEST1");
		contest.setName("Contest name");

		DistrictData district = getDistrict();

		contest.setDistrict(district);
		return contest;
	}
}
