/**
 * ECMElectoralOrganizationServiceImplStubClasses.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.service.stub;

import java.io.File;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import org.apache.commons.io.FileUtils;

import com.smartmatic.waffle.domain.IBaseDataObject;
import com.smartmatic.waffle.domain.authority.ElectoralAuthorityData;
import com.smartmatic.waffle.domain.demographics.ElectionData;
import com.smartmatic.waffle.domain.eligibleoption.ImageWrapper;
import com.smartmatic.waffle.domain.general.KeystoreData;
import com.smartmatic.waffle.domain.user.IUser;
import com.smartmatic.waffle.lang.BaseException;
import com.smartmatic.waffle.persistence.search.SearchExpression;

/**
 * Class that hold all mock inner classes needed to test
 * ECMElectoralOrganizationServiceImpl.
 */
public class ECMElectoralOrganizationServiceImplMockClasses {

	/**
	 * Inner class to override searchObject and return an active election.
	 */
	public class RetrieveActiveElection extends PersistenceServiceLocalStub {

		/*
		 * (non-Javadoc)
		 * 
		 * @see
		 * com.smartmatic.waffle.ecm.service.stub.PersistenceServiceLocalStub
		 * #searchObject
		 * (com.smartmatic.waffle.persistence.search.SearchExpression,
		 * java.lang.String[], com.smartmatic.waffle.domain.user.IUser)
		 */
		@Override
		public Object searchObject(SearchExpression searchExpression,
				String[] path, IUser user) throws BaseException {

			long electionCode = 1;

			String electionName = "élections fédérales";

			boolean activeElection = true;

			ElectionData electionIn = new ElectionData();

			electionIn.setCode(electionCode);
			electionIn.setName(electionName);
			electionIn.setStatusActive(activeElection);

			return electionIn;
		}
	}

	/**
	 * Inner class to override searchObject and return null to simulate that was
	 * not found any active election.
	 */
	public class ActiveElectionNotFound extends PersistenceServiceLocalStub {

		/*
		 * (non-Javadoc)
		 * 
		 * @see
		 * com.smartmatic.waffle.ecm.service.stub.PersistenceServiceLocalStub
		 * #searchObject
		 * (com.smartmatic.waffle.persistence.search.SearchExpression,
		 * java.lang.String[], com.smartmatic.waffle.domain.user.IUser)
		 */
		@Override
		public Object searchObject(SearchExpression searchExpression,
				String[] path, IUser user) throws BaseException {

			return null;
		}
	}

	/**
	 * Inner class to override searchObject and return an active election with
	 * key store.
	 */
	public class GetElectionKeyStoreComponents extends
			PersistenceServiceLocalStub {

		/*
		 * (non-Javadoc)
		 * 
		 * @see
		 * com.smartmatic.waffle.ecm.service.stub.PersistenceServiceLocalStub
		 * #searchObject
		 * (com.smartmatic.waffle.persistence.search.SearchExpression,
		 * java.lang.String[], com.smartmatic.waffle.domain.user.IUser)
		 */
		@Override
		public Object searchObject(SearchExpression searchExpression,
				String[] path, IUser user) throws BaseException {

			try {
				long electionCode = 1;

				String electionName = "élections fédérales";

				boolean activeElection = true;

				ElectionData electionObject = new ElectionData();

				electionObject.setCode(electionCode);
				electionObject.setName(electionName);
				electionObject.setStatusActive(activeElection);

				KeystoreData electionKeystore = new KeystoreData();

				electionKeystore.setAlias("test");
				electionKeystore.setPassword("test");
				electionKeystore.setDefaultKey(true);

				ImageWrapper keyStoreFile = new ImageWrapper();

				keyStoreFile.setBinaryData(FileUtils
						.readFileToByteArray(new File(
								"test/resources/test_cert.p12")));

				electionKeystore.setPkcs12(keyStoreFile);
				electionObject.setKeystore(electionKeystore);

				return electionObject;
			} catch (Exception e) {
				return null;
			}
		}
	}

	/**
	 * Inner class to override the countObjects method to simulate a number of
	 * electoral authorities are stored.
	 * 
	 */
	public class RetrieveElectoralAuthoritiesAmount extends
			PersistenceServiceLocalStub {

		@Override
		public int countObjects(SearchExpression searchExpression, IUser user)
				throws BaseException {

			return 2000;
		}

		@Override
		public int executeUpdateNativeQuery(String query) throws BaseException,
				RuntimeException {

			return 10;
		}
	}

	/**
	 * Inner class to override the searchPagedObjects, searchObject and update
	 * methods used when setting the security components to electoral
	 * authorities.
	 * 
	 */
	public class SetSecurityComponentsToElectoralAuthorities extends
			PersistenceServiceLocalStub {

		List<ElectoralAuthorityData> electoralAuthorityDataList = new ArrayList<ElectoralAuthorityData>();

		@Override
		public Collection searchPagedObjects(SearchExpression searchExpression,
				IUser user, int pageNumber, int pageSize) throws BaseException {

			Collection<ElectoralAuthorityData> electoralAuthorityCollection = new ArrayList<ElectoralAuthorityData>();

			ElectoralAuthorityData electoralAuthorityData1 = new ElectoralAuthorityData();
			electoralAuthorityData1.setCode(1);
			electoralAuthorityData1.setCustomCode("ITALY");
			electoralAuthorityData1.setName("Italy");

			ElectoralAuthorityData electoralAuthorityData2 = new ElectoralAuthorityData();
			electoralAuthorityData2.setCode(2);
			electoralAuthorityData2.setCustomCode("HOLLAND");
			electoralAuthorityData2.setName("Holland");

			electoralAuthorityCollection.add(electoralAuthorityData1);
			electoralAuthorityCollection.add(electoralAuthorityData2);

			return electoralAuthorityCollection;
		}

		@Override
		public <T extends IBaseDataObject> T update(T component, IUser user)
				throws BaseException {

			this.electoralAuthorityDataList
					.add((ElectoralAuthorityData) component);

			return component;
		}

		/**
		 * Gets the electoral authority data list.
		 * 
		 * @return the electoral authority data list
		 */
		public List<ElectoralAuthorityData> getElectoralAuthorityDataList() {
			return this.electoralAuthorityDataList;
		}

		@Override
		public Object searchObject(SearchExpression searchExpression,
				String[] path, IUser user) throws BaseException {
			return new RetrieveActiveElection().searchObject(searchExpression,
					path, user);
		}
	}

	/**
	 * Inner class to simulate retrieve a voting device collection from database
	 * and update the security objects
	 */
	public class RetrieveElectoralAuthoritiesSecurityComponents extends
			PersistenceServiceLocalStub {

		/*
		 * (non-Javadoc)
		 * 
		 * @see
		 * com.smartmatic.waffle.ecm.service.stub.PersistenceServiceLocalStub
		 * #searchObject
		 * (com.smartmatic.waffle.persistence.search.SearchExpression,
		 * java.lang.String[], com.smartmatic.waffle.domain.user.IUser, int,
		 * int)
		 */
		@Override
		public Collection searchPagedObjects(SearchExpression searchExpression,
				IUser user, int pageNumber, int pageSize) throws BaseException {

			try {
				return retrieveElectoralAuthorityObjectCollection();
			} catch (Exception e) {
				return null;
			}
		}

		public Collection<Object[]> retrieveElectoralAuthorityObjectCollection()
				throws Exception {
			Collection<Object[]> electoralAuthorityDataCollection = new ArrayList<Object[]>();

			ImageWrapper keyStoreFile = new ImageWrapper();

			keyStoreFile.setBinaryData(FileUtils.readFileToByteArray(new File(
					"test/resources/votingDeviceCertificate.p12")));

			Object[] electoralAuthorityObject1 = { "ANTWERPEN_001",
					"ANTWERPEN001",
					"Iimsdu/k7KRmGo+BlA1SFHEGRO+0yIcjvZInxymVDr8=",
					keyStoreFile, "cbrtshfgaquvynco", "user1",
					"Iimsdu/k7KRmGo+BlA1SFHEGRO+0yIcjvZInxymVDr8=" };

			electoralAuthorityDataCollection.add(electoralAuthorityObject1);

			Object[] electoralAuthorityObject2 = { "ANTWERPEN_002",
					"ANTWERPEN002",
					"Iimsdu/k7KRmGo+BlA1SFHEGRO+0yIcjvZInxymVDr8=",
					keyStoreFile, "cbrtshfgaquvynco", "user2",
					"Iimsdu/k7KRmGo+BlA1SFHEGRO+0yIcjvZInxymVDr8=" };

			electoralAuthorityDataCollection.add(electoralAuthorityObject2);

			Object[] electoralAuthorityObject3 = { "ANTWERPEN_003",
					"ANTWERPEN003",
					"Iimsdu/k7KRmGo+BlA1SFHEGRO+0yIcjvZInxymVDr8=",
					keyStoreFile, "cbrtshfgaquvynco", "user3",
					"Iimsdu/k7KRmGo+BlA1SFHEGRO+0yIcjvZInxymVDr8=" };

			electoralAuthorityDataCollection.add(electoralAuthorityObject3);

			return electoralAuthorityDataCollection;
		}
	}

}
