/**
 * ECMUtilitiesServiceMockClasses.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.service.stub;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.Map;

import org.apache.commons.io.FileUtils;
import org.apache.commons.lang.StringUtils;

import com.smartmatic.waffle.domain.IBaseDataObject;
import com.smartmatic.waffle.domain.contest.ContestData;
import com.smartmatic.waffle.domain.demographics.ElectionData;
import com.smartmatic.waffle.domain.eligibleoption.ImageWrapper;
import com.smartmatic.waffle.domain.general.KeystoreData;
import com.smartmatic.waffle.domain.i18n.LanguageData;
import com.smartmatic.waffle.domain.multiLanguage.MultiLingualKeyData;
import com.smartmatic.waffle.domain.multiLanguage.TranslationKeyData;
import com.smartmatic.waffle.domain.user.IUser;
import com.smartmatic.waffle.ecm.data.transfer.objects.EntityRecordsQuantitiesDTO;
import com.smartmatic.waffle.ecm.data.transfer.type.SmttFileType;
import com.smartmatic.waffle.ecm.service.impl.ECMServerCommonImpl;
import com.smartmatic.waffle.ecm.service.impl.ECMUtilitiesServiceImpl;
import com.smartmatic.waffle.ecm.service.lang.ElectoralOrganizationOperationException;
import com.smartmatic.waffle.lang.BaseException;
import com.smartmatic.waffle.persistence.search.SearchExpression;

/**
 * Class that hold all mock inner classes needed to test
 * ECMUtilitiesServiceImpl.
 */
public class ECMUtilitiesServiceMockClasses {

	/**
	 * Inner class to override methods needed to test ECMUtilitiesServiceImpl
	 * class.
	 */
	public class ECMUtilitiesServiceMock extends ECMUtilitiesServiceImpl {

		/**
		 * @inheritDoc
		 */
		@Override
		@SuppressWarnings("rawtypes")
		protected EntityRecordsQuantitiesDTO getEntityRecordsQuantities(
				SmttFileType smttFileType, Class classToCountRecords)
				throws BaseException {

			EntityRecordsQuantitiesDTO entityRecordsQuantitiesDTO = new EntityRecordsQuantitiesDTO();

			entityRecordsQuantitiesDTO.setSmttFileType(smttFileType);
			entityRecordsQuantitiesDTO.setRecordsQuantities(100);

			return entityRecordsQuantitiesDTO;
		}

		/**
		 * @inheritDoc
		 */
		@Override
		public File getReportFilesDir() {
			return new File("test/resources/reports");
		}

		/**
		 * @inheritDoc
		 */
		@Override
		public File getEMLFilesDir() {
			return new File("test/resources/eml");
		}

		/**
		 * @inheritDoc
		 */
		@Override
		public File getVoiceFolder() {
			return new File("test/resources/voice_files");
		}

		/**
		 * @inheritDoc
		 */
		@Override
		public ElectionData getActiveElection()
				throws ElectoralOrganizationOperationException {

			try {
				long electionCode = 1;

				String electionName = "élections fédérales";

				boolean activeElection = true;

				ElectionData electionObject = new ElectionData();

				electionObject.setCode(electionCode);
				electionObject.setName(electionName);
				electionObject.setStatusActive(activeElection);

				KeystoreData electionKeystore = new KeystoreData();

				electionKeystore.setAlias("test");
				electionKeystore.setPassword("test");
				electionKeystore.setDefaultKey(true);

				ImageWrapper keyStoreFile = new ImageWrapper();

				keyStoreFile.setBinaryData(FileUtils
						.readFileToByteArray(new File(
								"test/resources/test_cert.p12")));

				electionKeystore.setPkcs12(keyStoreFile);
				electionObject.setKeystore(electionKeystore);

				return electionObject;
			} catch (IOException e) {
				return null;
			}
		}

		/**
		 * @inheritDoc
		 */
		@Override
		public boolean getServerPropertyAsBoolean(String key) {
			return false;
		}

		/**
		 * @inheritDoc
		 */
		@Override
		public String getServerPropertyAsString(String key) {
			if (key.equals("encryption.algorithm")) {
				return "CBC";
			} else if (key.equals("length.of.vector.for.cbc.encryption")) {
				return "1024";
			} else {
				return StringUtils.EMPTY;
			}
		}

		/**
		 * @inheritDoc
		 */
		@Override
		protected String signDetachedXML(byte[] electionPkcs12,
				String electionAliasToSign, String electionPasswordToSign,
				Map<String, List<File>> filesByUriBase,
				String signatureAlgorithm) throws Exception {
			return "<?xml version='1.0' encoding='UTF-8' standalone='no'?><databaseChangeLog></databaseChangeLog>";
		}

		/**
		 * @inheritDoc
		 */
		@Override
		protected void removeRefObjectFromBulkCache() {
		}
	}

	/**
	 * Inner class to override methods needed to test ECMUtilitiesServiceImpl
	 * class.
	 */
	public class PersistenceServiceLocalMock extends
			PersistenceServiceLocalStub {

		/**
		 * @inheritDoc
		 */
		@Override
		public int countObjects(SearchExpression searchExpression, IUser user)
				throws BaseException {

			return 100;
		}

		/**
		 * @inheritDoc
		 */
		@Override
		public Object searchObject(SearchExpression searchExpression, IUser user)
				throws BaseException {

			if (searchExpression.getEntityClass().equals(
					MultiLingualKeyData.class)) {
				MultiLingualKeyData multiLingualKeyData = new MultiLingualKeyData();

				multiLingualKeyData.setCode(1);
				multiLingualKeyData.setCustomCode(ECMServerCommonImpl
						.generateRandomString(4));
				multiLingualKeyData.setCustomCodeRef(ECMServerCommonImpl
						.generateRandomString(4));
				multiLingualKeyData.setField(ECMServerCommonImpl
						.generateRandomString(4));
				multiLingualKeyData.setForeignKey(Long
						.parseLong(ECMServerCommonImpl
								.generateRandomNumericString(4)));
				multiLingualKeyData.setForeignKey(Long
						.parseLong(ECMServerCommonImpl
								.generateRandomNumericString(4)));
				multiLingualKeyData.setKey(ECMServerCommonImpl
						.generateRandomString(4));
				multiLingualKeyData.setValueOfKey(ECMServerCommonImpl
						.generateRandomString(4));

				return multiLingualKeyData;
			} else {
				ContestData constestData = new ContestData();

				constestData.setCode(1);
				constestData.setName("ContestName");
				constestData.setCustomCode("ContestCustomCode");

				return constestData;
			}
		}

		/**
		 * @inheritDoc
		 */
		@Override
		public Collection searchObjects(SearchExpression searchExpression,
				IUser user) throws BaseException {

			if (searchExpression.getEntityClass().equals(LanguageData.class)) {
				Collection<LanguageData> languageDataList = new ArrayList<LanguageData>();

				LanguageData languageData = new LanguageData();

				languageData.setCode(1);
				languageData.setCustomCode(ECMServerCommonImpl
						.generateRandomString(4));
				languageData.setDefaultLanguage(false);

				languageDataList.add(languageData);

				return languageDataList;
			} else if (searchExpression.getEntityClass().equals(
					TranslationKeyData.class)) {
				Collection<TranslationKeyData> translationKeyDataList = new ArrayList<TranslationKeyData>();

				TranslationKeyData translationKeyData = new TranslationKeyData();
				translationKeyData.setCode(1);
				translationKeyData.setTranslationText("translated");

				translationKeyDataList.add(translationKeyData);

				return translationKeyDataList;

			} else {
				return null;
			}
		}

		/**
		 * @inheritDoc
		 */
		@Override
		public Collection searchPagedObjects(SearchExpression searchExpression,
				IUser user, int pageNumber, int pageSize) throws BaseException {

			return createMultilingualKeyCollection();
		}

		/**
		 * @inheritDoc
		 */
		@Override
		public int executeUpdateNativeQuery(String query) throws BaseException {
			return 10;
		}

		/**
		 * @inheritDoc
		 */
		@Override
		public <T extends IBaseDataObject> T update(T component, IUser user)
				throws BaseException {

			return component;
		}

		/**
		 * Creates a MultiLingualKeyData collection with dummy objects.
		 * 
		 * @return MultiLingualKeyData collection with dummy objects
		 */
		private Collection<MultiLingualKeyData> createMultilingualKeyCollection() {

			Collection<MultiLingualKeyData> multiLingualKeyDataList = new ArrayList<MultiLingualKeyData>();

			MultiLingualKeyData multiLingualKeyData = new MultiLingualKeyData();

			multiLingualKeyData.setCode(1);
			multiLingualKeyData.setCustomCode(ECMServerCommonImpl
					.generateRandomString(4));
			multiLingualKeyData.setCustomCodeRef(ECMServerCommonImpl
					.generateRandomString(4));
			multiLingualKeyData.setField("customCode");
			multiLingualKeyData.setForeignKey(Long
					.parseLong(ECMServerCommonImpl
							.generateRandomNumericString(4)));
			multiLingualKeyData.setForeignKey(Long
					.parseLong(ECMServerCommonImpl
							.generateRandomNumericString(4)));
			multiLingualKeyData
					.setKey("com.smartmatic.waffle.domain.i18n.LanguageData");
			multiLingualKeyData.setValueOfKey(ECMServerCommonImpl
					.generateRandomString(4));

			multiLingualKeyDataList.add(multiLingualKeyData);

			multiLingualKeyData.setCode(2);
			multiLingualKeyData.setCustomCode(ECMServerCommonImpl
					.generateRandomString(4));
			multiLingualKeyData.setCustomCodeRef(ECMServerCommonImpl
					.generateRandomString(4));
			multiLingualKeyData.setField("customCode");
			multiLingualKeyData.setForeignKey(Long
					.parseLong(ECMServerCommonImpl
							.generateRandomNumericString(4)));
			multiLingualKeyData.setForeignKey(Long
					.parseLong(ECMServerCommonImpl
							.generateRandomNumericString(4)));
			multiLingualKeyData
					.setKey("com.smartmatic.waffle.domain.i18n.LanguageData");
			multiLingualKeyData.setValueOfKey(ECMServerCommonImpl
					.generateRandomString(4));

			multiLingualKeyDataList.add(multiLingualKeyData);

			multiLingualKeyData.setCode(3);
			multiLingualKeyData.setCustomCode(ECMServerCommonImpl
					.generateRandomString(4));
			multiLingualKeyData.setCustomCodeRef(ECMServerCommonImpl
					.generateRandomString(4));
			multiLingualKeyData.setField("customCode");
			multiLingualKeyData.setForeignKey(Long
					.parseLong(ECMServerCommonImpl
							.generateRandomNumericString(4)));
			multiLingualKeyData.setForeignKey(Long
					.parseLong(ECMServerCommonImpl
							.generateRandomNumericString(4)));
			multiLingualKeyData
					.setKey("com.smartmatic.waffle.domain.i18n.LanguageData");
			multiLingualKeyData.setValueOfKey(ECMServerCommonImpl
					.generateRandomString(4));

			multiLingualKeyDataList.add(multiLingualKeyData);

			return multiLingualKeyDataList;
		}
	}

}
