/**
 * BaseFullScreenJDialog.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */

/*
 * BaseJDialog.java
 * 
 * Created on Jan 13, 2009, 3:19:28 PM
 */

package com.smartmatic.waffle.ecm.ui;

import java.awt.Color;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.GridLayout;
import java.awt.HeadlessException;
import java.awt.Toolkit;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.net.URL;
import java.util.jar.Attributes;
import java.util.jar.Manifest;
import java.util.zip.ZipException;

import javax.swing.JDialog;
import javax.swing.border.LineBorder;

import org.jdesktop.application.ResourceMap;

import com.smartmatic.waffle.ecm.core.IFunctDispatcher;
import com.smartmatic.waffle.ecm.ui.core.i18n.controller.LanguageController;

/**
 * Class used to build a base dialog that will contain all the components for
 * each of the functionalities.
 */
public class BaseFullScreenJDialog extends javax.swing.JDialog {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 2823936745279622239L;

	/** The resource map. */
	protected ResourceMap resourceMap = LanguageController.getInstance()
			.getResourceMap();

	/** The initialized. */
	private boolean initialized = false;

	/**
	 * Returns a string from a resource map matched with the given key.
	 * 
	 * @param key
	 *            the string key to search
	 * @param arg
	 *            a list of additional arguments
	 * @return the matched string
	 */
	public String getString(String key, Object... arg) {
		String result = this.resourceMap.getString(key, arg);
		if (result == null || result.length() == 0) {
			result = key;
		}
		return result;
	}

	/**
	 * Creates new form BaseFullScreenJDialog instance.
	 * 
	 * @param parent
	 *            the parent
	 * @param modal
	 *            the modal
	 */
	public BaseFullScreenJDialog(java.awt.Frame parent, boolean modal) {
		super(parent, modal);

		this.initComponents();

		this.setUndecorated(true);
		this.setResizable(false);
		this.loadVersion();
		this.initialized = true;
		this.basePanel.setLayout(new GridLayout(1, 1));

	}

	/**
	 * Creates new form BaseFullScreenJDialog instance.
	 * 
	 * @param parent
	 *            the parent
	 * @param modal
	 *            the modal
	 */
	public BaseFullScreenJDialog(JDialog parent, boolean modal) {
		super(parent, modal);
		this.initComponents();

		this.setUndecorated(true);
		this.setResizable(false);
		this.loadVersion();
		this.initialized = true;
		this.basePanel.setLayout(new GridLayout(1, 1));
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.JDialog#getContentPane()
	 */
	@Override
	public Container getContentPane() {
		if (!this.initialized) {
			return super.getContentPane();
		} else {
			return this.basePanel;
		}
	}

	/**
	 * Load version.
	 */
	private void loadVersion() {
		boolean setDefaultValue = false;
		try {
			Manifest manifest = findEarManifest(BaseFullScreenJDialog.class);
			setDefaultValue = setVersionNumber(manifest);
		} catch (IOException e) {
			e.printStackTrace();
		}
		if (setDefaultValue) {
			this.versionLabel.setText(this.resourceMap
					.getString("Application.version"));
		}
	}

	/**
	 * Sets the version number.
	 * 
	 * @param manifest
	 *            the manifest
	 * @return true, if successful
	 */
	private boolean setVersionNumber(Manifest manifest) {
		if (manifest != null) {
			Attributes entries = manifest.getMainAttributes();
			String versionNumber = entries.getValue("Specification-Version");
			if (versionNumber != null) {
				this.versionLabel.setText(versionNumber);
				return false;
			}
		}
		return true;
	}

	/**
	 * Find ear manifest.
	 * 
	 * @param clazz
	 *            the clazz
	 * @return the manifest
	 * @throws IOException
	 *             Signals that an I/O exception has occurred.
	 */
	private static Manifest findEarManifest(Class<?> clazz) throws IOException {
		String clazzName = clazz.getName();
		clazzName = "/" + clazzName.replaceAll("\\.", "/") + ".class";
		URL url = clazz.getResource(clazzName);
		String urlString = url.toString();
		try {
			if (urlString.startsWith("vfszip:")) {
				String filename = urlString.replace(clazzName, "");
				filename = filename.replace("vfszip:", "");
				filename = filename.substring(0,
						filename.lastIndexOf(".ear") + 4);

				File manifestFile = new File(filename, "META-INF/MANIFEST.MF");

				if (!manifestFile.exists()) {
					return null;
				} else {
					FileInputStream is = new FileInputStream(manifestFile);
					Manifest manifest = new Manifest(is);
					is.close();
					return manifest;
				}
			} else {
				return null;
			}
		} catch (ZipException e) {
			return null;
		}
	}

	/**
	 * This method is called from within the constructor to initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is always
	 * regenerated by the Form Editor.
	 */
	private void initComponents() {

		this.versionLabel = new javax.swing.JLabel();
		this.basePanel = new javax.swing.JPanel();
		this.upperPanel = new javax.swing.JPanel();
		this.logoLabel = new javax.swing.JLabel();
		this.applicationNameLabel = new javax.swing.JLabel();
		this.companyLogoLabel = new javax.swing.JLabel();
		Dimension dimension = new Dimension(66, 50);

		this.setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
		this.setName("Form"); // NOI18N

		this.versionLabel.setFont(this.versionLabel.getFont().deriveFont(
				this.versionLabel.getFont().getSize() - 3f));
		this.versionLabel
				.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
		this.versionLabel.setText(this.resourceMap
				.getString("Application.version"));
		this.versionLabel.setName("versionLabel"); // NOI18N
		this.getContentPane().add(this.versionLabel,
				java.awt.BorderLayout.PAGE_END);

		this.basePanel.setBorder(new LineBorder(Color.BLACK, 1));
		this.basePanel.setName("basePanel"); // NOI18N
		this.getContentPane().add(this.basePanel, java.awt.BorderLayout.CENTER);

		// this.upperPanel.setBackground(new java.awt.Color(255, 255, 255));
		this.upperPanel.setBorder(javax.swing.BorderFactory
				.createLineBorder(new java.awt.Color(0, 0, 0)));
		this.upperPanel.setName("upperPanel"); // NOI18N
		this.upperPanel.setLayout(new java.awt.BorderLayout());

		this.logoLabel.setIcon(this.resourceMap.getIcon("logoLabel.icon"));
		// NOI18N

		this.logoLabel.setMinimumSize(dimension);
		this.logoLabel.setPreferredSize(dimension);
		this.logoLabel.setMaximumSize(dimension);
		this.logoLabel.setText(this.resourceMap.getString("logoLabel.text")); // NOI18N
		this.logoLabel.setName("logoLabel"); // NOI18N
		this.upperPanel.add(this.logoLabel, java.awt.BorderLayout.LINE_START);

		this.applicationNameLabel.setFont(this.applicationNameLabel.getFont()
				.deriveFont(
						this.applicationNameLabel.getFont().getStyle()
								| java.awt.Font.BOLD,
						this.applicationNameLabel.getFont().getSize() + 3));
		this.applicationNameLabel
				.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
		this.applicationNameLabel.setText(this.resourceMap
				.getString("applicationNameLabel.text")); // NOI18N
		this.applicationNameLabel
				.setHorizontalTextPosition(javax.swing.SwingConstants.LEFT);
		this.applicationNameLabel.setName("applicationNameLabel"); // NOI18N
		this.upperPanel.add(this.applicationNameLabel,
				java.awt.BorderLayout.CENTER);

		this.companyLogoLabel.setIcon(this.resourceMap
				.getIcon("companyLogoLabel.icon")); // NOI18N

		this.companyLogoLabel.setMinimumSize(dimension);
		this.companyLogoLabel.setPreferredSize(dimension);
		this.companyLogoLabel.setMaximumSize(dimension);

		this.companyLogoLabel.setText(this.resourceMap
				.getString("companyLogoLabel.text")); // NOI18N
		this.companyLogoLabel.setName("companyLogoLabel"); // NOI18N
		this.upperPanel.add(this.companyLogoLabel,
				java.awt.BorderLayout.LINE_END);

		this.getContentPane().add(this.upperPanel,
				java.awt.BorderLayout.PAGE_START);
	}

	/** The application name label. */
	private javax.swing.JLabel applicationNameLabel;

	/** The base panel. */
	private javax.swing.JPanel basePanel;

	/** The company logo label. */
	private javax.swing.JLabel companyLogoLabel;

	/** The logo label. */
	private javax.swing.JLabel logoLabel;

	/** The upper panel. */
	private javax.swing.JPanel upperPanel;

	/** The version label. */
	private javax.swing.JLabel versionLabel;

	/**
	 * Overrides the setVisible method to display the dialog maximized.
	 * 
	 * @param value
	 *            the new visible
	 */
	@Override
	public void setVisible(boolean value) {
		if (value) {

			Dimension size = this.getCalculatedSize();

			this.setMinimumSize(size);
			this.setPreferredSize(size);
			this.setMaximumSize(size);
		}
		super.setVisible(value);

		if (value) {
			this.requestFocus();
			this.toFront();
		}
	}

	/**
	 * Gets the calculated size.
	 * 
	 * @return the calculated size
	 * @throws HeadlessException
	 *             the headless exception
	 * @throws NumberFormatException
	 *             the number format exception
	 */
	protected Dimension getCalculatedSize() throws HeadlessException,
			NumberFormatException {
		Dimension size = Toolkit.getDefaultToolkit().getScreenSize();
		this.setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);

		if (Boolean.getBoolean("nofullscreenmodal")) {
			if (Boolean.getBoolean("landscapemodal")) {
				size = new Dimension(1024, 600);
			} else {
				size = new Dimension(768, 1024);
			}

			this.setDefaultCloseOperation(HIDE_ON_CLOSE);
		}

		if (System.getProperty("resolution") != null) {
			String[] resolution = System.getProperty("resolution").split("x");
			if (resolution.length == 2) {
				Dimension desktopSize = size;

				size = new Dimension(Integer.parseInt(resolution[0].trim()),
						Integer.parseInt(resolution[1].trim()));

				if (System.getProperty("location") != null) {
					String[] location = System.getProperty("location").split(
							",");
					if (location.length == 2) {
						this.setLocation(Integer.parseInt(location[0].trim()),
								Integer.parseInt(location[1].trim()));
					}
				} else {
					this.setLocation((desktopSize.width - size.width) / 2,
							(desktopSize.height - size.height) / 2);
				}
			}
		}
		return size;
	}

	/** The current dispatcher. */
	private IFunctDispatcher currentDispatcher;

	/**
	 * Getter of <code>currentDispatcher</code> property.
	 * 
	 * @return <code>currentDispatcher</code> property value.
	 * @see #currentDispatcher
	 */
	public IFunctDispatcher getCurrentDispatcher() {
		return this.currentDispatcher;
	}

}
