/**
 * BaseMessageDialog.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */

/*
 * BaseMessageDialog.java
 *
 * Created on Mar 4, 2009, 6:25:34 PM
 */

package com.smartmatic.waffle.ecm.ui;

import java.awt.Container;
import java.awt.Dialog;
import java.awt.Dimension;
import java.awt.Toolkit;

import org.jdesktop.application.ResourceMap;

import com.smartmatic.waffle.ecm.ui.core.i18n.controller.LanguageController;

/**
 * Class used to build a base message dialog.
 */
public class BaseMessageDialog extends javax.swing.JDialog {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = -5189316453254411632L;

	/** The resource map. */
	protected ResourceMap resourceMap = LanguageController.getInstance()
			.getResourceMap();

	/** The initialized. */
	private boolean initialized = false;

	/**
	 * Creates new form BaseMessageDialog instance.
	 * 
	 * @param parent
	 *            the parent
	 * @param modal
	 *            the modal
	 */
	public BaseMessageDialog(java.awt.Frame parent, boolean modal) {
		super(parent, modal);
		this.initComponents();

		this.setUndecorated(true);
		this.setResizable(false);

		if (Boolean.getBoolean("nofullscreenmodal")) {
			this.setUndecorated(false);
			this.setResizable(true);
		}

		this.initialized = true;
		this.setIcons();
	}

	/**
	 * Creates new form BaseMessageDialog instance.
	 * 
	 * @param parent
	 *            the parent
	 * @param modal
	 *            the modal
	 */
	public BaseMessageDialog(Dialog parent, boolean modal) {
		super(parent, modal);
		this.initComponents();

		this.setUndecorated(true);
		this.setResizable(false);

		if (Boolean.getBoolean("nofullscreenmodal")) {
			this.setUndecorated(false);
			this.setResizable(true);
		}

		this.initialized = true;
		this.setIcons();
	}

	/**
	 * This method is called from within the constructor to initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is always
	 * regenerated by the Form Editor.
	 */
	private void initComponents() {

		this.contentPanel = new javax.swing.JPanel();
		this.upperPanel1 = new javax.swing.JPanel();
		this.logoLabel1 = new javax.swing.JLabel();
		this.applicationNameLabel1 = new javax.swing.JLabel();
		this.companyLogoLabel1 = new javax.swing.JLabel();

		this.setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);

		this.contentPanel.setBorder(null);
		this.contentPanel.setName("contentPanel"); // NOI18N

		javax.swing.GroupLayout contentPanelLayout = new javax.swing.GroupLayout(
				this.contentPanel);
		this.contentPanel.setLayout(contentPanelLayout);
		contentPanelLayout.setHorizontalGroup(contentPanelLayout
				.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addGap(0, 538, Short.MAX_VALUE));
		contentPanelLayout.setVerticalGroup(contentPanelLayout
				.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addGap(0, 248, Short.MAX_VALUE));

		this.getContentPane().add(this.contentPanel,
				java.awt.BorderLayout.CENTER);

		this.upperPanel1.setBorder(javax.swing.BorderFactory
				.createLineBorder(new java.awt.Color(0, 0, 0)));
		this.upperPanel1.setName("upperPanel1"); // NOI18N
		this.upperPanel1.setLayout(new java.awt.BorderLayout());

		this.logoLabel1.setIcon(null);
		this.logoLabel1.setName("logoLabel1"); // NOI18N
		this.logoLabel1.setOpaque(true);
		this.upperPanel1.add(this.logoLabel1, java.awt.BorderLayout.LINE_START);

		this.applicationNameLabel1.setFont(this.applicationNameLabel1.getFont()
				.deriveFont(
						this.applicationNameLabel1.getFont().getStyle()
								| java.awt.Font.BOLD,
						this.applicationNameLabel1.getFont().getSize() + 3));
		this.applicationNameLabel1
				.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
		this.applicationNameLabel1.setText("");
		this.applicationNameLabel1
				.setHorizontalTextPosition(javax.swing.SwingConstants.LEFT);
		this.applicationNameLabel1.setName("applicationNameLabel1"); // NOI18N
		this.upperPanel1.add(this.applicationNameLabel1,
				java.awt.BorderLayout.CENTER);

		this.companyLogoLabel1.setIcon(null);
		this.companyLogoLabel1.setName("companyLogoLabel1"); // NOI18N
		this.upperPanel1.add(this.companyLogoLabel1,
				java.awt.BorderLayout.LINE_END);

		this.getContentPane().add(this.upperPanel1,
				java.awt.BorderLayout.PAGE_START);
	}

	/**
	 * Sets the icons.
	 */
	private void setIcons() {
		this.logoLabel1.setIcon(this.resourceMap.getIcon("logoLabel.icon"));
		this.companyLogoLabel1.setIcon(this.resourceMap
				.getIcon("companyLogoLabel.icon"));
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.JDialog#getContentPane()
	 */
	@Override
	public Container getContentPane() {
		if (!this.initialized) {
			return super.getContentPane();
		} else {
			return this.contentPanel;
		}
	}

	/** The application name label1. */
	private javax.swing.JLabel applicationNameLabel1;

	/** The company logo label1. */
	private javax.swing.JLabel companyLogoLabel1;

	/** The content panel. */
	private javax.swing.JPanel contentPanel;

	/** The logo label1. */
	private javax.swing.JLabel logoLabel1;

	/** The upper panel1. */
	private javax.swing.JPanel upperPanel1;

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.awt.Dialog#setVisible(boolean)
	 */
	@Override
	public void setVisible(boolean value) {
		if (value) {

			Dimension size = Toolkit.getDefaultToolkit().getScreenSize();
			this.setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);

			if (Boolean.getBoolean("nofullscreenmodal")) {
				size = new Dimension(768, 1024);
				this.setDefaultCloseOperation(HIDE_ON_CLOSE);
			}

			if (System.getProperty("resolution") != null) {
				String[] resolution = System.getProperty("resolution").split(
						"x");
				if (resolution.length == 2) {
					Dimension desktopSize = size;

					size = new Dimension(
							Integer.parseInt(resolution[0].trim()),
							Integer.parseInt(resolution[1].trim()));

					if (System.getProperty("location") != null) {
						String[] location = System.getProperty("location")
								.split(",");
						if (location.length == 2) {
							this.setLocation(
									Integer.parseInt(location[0].trim()),
									Integer.parseInt(location[1].trim()));
						}
					} else {
						this.setLocation((desktopSize.width - size.width) / 2,
								(desktopSize.height - size.height) / 2);
					}
				}
			}

			this.setMinimumSize(size);
			this.setPreferredSize(size);
			this.setMaximumSize(size);
		}
		super.setVisible(value);
	}

	/**
	 * Returns a string from resource map matched with the given key.
	 * 
	 * @param key
	 *            the string key to search
	 * @param arg
	 *            additional arguments
	 * @return the matched string
	 */
	public String getString(String key, Object... arg) {
		String result = this.resourceMap.getString(key, arg);
		if (result == null || result.length() == 0) {
			result = key;
		}
		return result;
	}

}
