/**
 * BrowserHierarchy.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.ui.controls.Browser;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.ResourceBundle;
import java.util.Set;

import javax.swing.JCheckBox;
import javax.swing.JOptionPane;
import javax.swing.table.DefaultTableModel;

import com.smartmatic.waffle.ecm.data.transfer.comparators.BrowserHierarchyComparator;
import com.smartmatic.waffle.ecm.data.transfer.objects.BrowserHierarchyDTO;
import com.smartmatic.waffle.ecm.data.transfer.objects.BrowserHierarchyTreeDTO;
import com.smartmatic.waffle.ecm.data.transfer.type.BrowserHierarchyStatusType;
import com.smartmatic.waffle.ecm.ui.controls.commons.CellButtonEditor;
import com.smartmatic.waffle.ecm.ui.controls.commons.CellButtonRenderer;
import com.smartmatic.waffle.ecm.ui.controls.commons.CellCheckEditor;
import com.smartmatic.waffle.ecm.ui.controls.commons.ICellButtonEventListener;
import com.smartmatic.waffle.ecm.ui.controls.commons.ICellCheckEventListener;
import com.smartmatic.waffle.lang.BaseException;
import com.smartmatic.waffle.log.SMTTLogger;

/**
 * Class used to build a data browser widget.
 */
public class BrowserHierarchy extends javax.swing.JPanel implements
		ICellButtonEventListener, ICellCheckEventListener {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 7889425579641991382L;

	/** The logger. */
	private SMTTLogger logger = SMTTLogger.getLogger(BrowserHierarchy.class);

	/***
	 * The resource bundle object.
	 */
	private ResourceBundle bundle;

	/***
	 * Object that provide the data to show in the widget.
	 */
	private IBrowserHierarchyProvider provider;

	/***
	 * The current selected object. in initial page the values in null
	 */
	private BrowserHierarchyDTO currentSelectedObject;

	/** *. */
	private BrowserHierarchyStatusType initialStatus;

	/***
	 * Tree object to keep the objects loaded in memory.
	 */
	private BrowserHierarchyTreeDTO treeMemory;

	/** The On click node listeners. */
	private List<ClickedNodeListener> OnClickNodeListeners;

	/** The On select node listeners. */
	private List<SelectNodeListener> OnSelectNodeListeners;

	/** The On unselect node listeners. */
	private List<UnselectNodeListener> OnUnselectNodeListeners;

	/** The title name. */
	String titleName;

	/**
	 * Adds the on unselect node listener.
	 * 
	 * @param listener
	 *            the listener
	 */
	public void addOnUnselectNodeListener(UnselectNodeListener listener) {
		synchronized (this.OnUnselectNodeListeners) {
			if (!this.OnUnselectNodeListeners.contains(listener)
					&& listener != null) {
				this.OnUnselectNodeListeners.add(listener);
			}
		}
	}

	/**
	 * Removes the on unselect node listener.
	 * 
	 * @param listener
	 *            the listener
	 */
	public void removeOnUnselectNodeListener(UnselectNodeListener listener) {
		synchronized (this.OnUnselectNodeListeners) {
			if (this.OnUnselectNodeListeners.contains(listener)
					&& listener != null) {
				this.OnUnselectNodeListeners.remove(listener);
			}
		}
	}

	/**
	 * Adds the on select node listener.
	 * 
	 * @param listener
	 *            the listener
	 */
	public void addOnSelectNodeListener(SelectNodeListener listener) {
		synchronized (this.OnSelectNodeListeners) {
			if (!this.OnSelectNodeListeners.contains(listener)
					&& listener != null) {
				this.OnSelectNodeListeners.add(listener);
			}
		}
	}

	/**
	 * Removes the on select node listener.
	 * 
	 * @param listener
	 *            the listener
	 */
	public void removeOnSelectNodeListener(SelectNodeListener listener) {
		synchronized (this.OnSelectNodeListeners) {
			if (this.OnSelectNodeListeners.contains(listener)
					&& listener != null) {
				this.OnSelectNodeListeners.remove(listener);
			}
		}
	}

	/**
	 * Adds the on click node listener.
	 * 
	 * @param listener
	 *            the listener
	 */
	public void addOnClickNodeListener(ClickedNodeListener listener) {
		synchronized (this.OnClickNodeListeners) {
			if (!this.OnClickNodeListeners.contains(listener)
					&& listener != null) {
				this.OnClickNodeListeners.add(listener);
			}
		}
	}

	/**
	 * Removes the on click node listener.
	 * 
	 * @param listener
	 *            the listener
	 */
	public void removeOnClickNodeListener(ClickedNodeListener listener) {
		synchronized (this.OnClickNodeListeners) {
			if (this.OnClickNodeListeners.contains(listener)
					&& listener != null) {
				this.OnClickNodeListeners.remove(listener);
			}
		}
	}

	/**
	 * Fire onclick node event.
	 * 
	 * @param node
	 *            the node
	 */
	public void fireOnclickNodeEvent(BrowserHierarchyDTO node) {
		synchronized (this.OnClickNodeListeners) {
			for (ClickedNodeListener current : this.OnClickNodeListeners) {
				current.onClickNode(new BrowserHierarchyEvent(node));
			}
		}
	}

	/**
	 * Fire on select event.
	 * 
	 * @param node
	 *            the node
	 */
	public void fireOnSelectEvent(BrowserHierarchyDTO node) {
		synchronized (this.OnSelectNodeListeners) {
			for (SelectNodeListener current : this.OnSelectNodeListeners) {
				current.OnSelectNode(new BrowserHierarchyEvent(node));
			}
		}
	}

	/**
	 * Fire on unselect event.
	 * 
	 * @param node
	 *            the node
	 */
	public void fireOnUnselectEvent(BrowserHierarchyDTO node) {
		synchronized (this.OnUnselectNodeListeners) {
			for (UnselectNodeListener current : this.OnUnselectNodeListeners) {
				current.OnUnselectNode(new BrowserHierarchyEvent(node));
			}
		}
	}

	/**
	 * Default class constructor.
	 */
	public BrowserHierarchy() {
		initComponents();
		postInitComponents();
	}

	/**
	 * Class constructor.
	 * 
	 * @param provider
	 *            the provider
	 */
	public BrowserHierarchy(IBrowserHierarchyProvider provider) {
		initComponents();
		postInitComponents();
		this.provider = provider;
		this.treeMemory = new BrowserHierarchyTreeDTO();
		this.initialStatus = BrowserHierarchyStatusType.UNSELECTED;
		load();
	}

	/**
	 * Class constructor.
	 * 
	 * @param provider
	 *            the provider
	 * @param initialStatus
	 *            the initial status
	 * @param titleName
	 *            the title name
	 */
	public BrowserHierarchy(IBrowserHierarchyProvider provider,
			boolean initialStatus, String titleName) {
		initComponents();
		postInitComponents();
		this.titleName = titleName;
		this.provider = provider;
		this.treeMemory = new BrowserHierarchyTreeDTO();
		if (initialStatus) {// the initial status is selected
			this.initialStatus = BrowserHierarchyStatusType.FULL_SELECTED;
		} else {// the initial status is not selected
			this.initialStatus = BrowserHierarchyStatusType.UNSELECTED;
		}
		load();
	}

	/**
	 * Post init components.
	 */
	public void postInitComponents() {
		this.bundle = java.util.ResourceBundle
				.getBundle("com/smartmatic/waffle/ecm/client/resources/ECMApp"); // NOI18N

		this.jButton1.setText("<");

		this.jButton2.setText(this.bundle
				.getString("BrowserHierarchy.selectAllButton.name"));

		this.jButton3.setText(this.bundle
				.getString("BrowserHierarchy.refreshButton.name"));

		this.OnClickNodeListeners = new ArrayList<ClickedNodeListener>();
		this.OnSelectNodeListeners = new ArrayList<SelectNodeListener>();
		this.OnUnselectNodeListeners = new ArrayList<UnselectNodeListener>();

	}

	/**
	 * This method is called from within the constructor to initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is always
	 * regenerated by the Form Editor.
	 */
	@SuppressWarnings("unchecked")
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// desc="Generated Code">//GEN-BEGIN:initComponents
	private void initComponents() {

		this.jButton1 = new javax.swing.JButton();
		this.jScrollPane1 = new javax.swing.JScrollPane();
		this.jTable1 = new javax.swing.JTable();
		this.jButton2 = new javax.swing.JButton();
		this.jButton3 = new javax.swing.JButton();

		this.jButton1.setFont(new java.awt.Font("Dialog", 0, 12));
		this.jButton1.setForeground(new java.awt.Color(0, 0, 0));
		this.jButton1.setText("<");
		this.jButton1.setName("buttonPrevious"); // NOI18N
		this.jButton1.addActionListener(new java.awt.event.ActionListener() {
			@Override
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				getLastNodes(evt);
			}
		});

		this.jScrollPane1.setName("scrollPaneMain"); // NOI18N

		this.jTable1.setModel(new javax.swing.table.DefaultTableModel(
				new Object[][] {

				}, new String[] {

				}));
		this.jTable1.setName("browserHierarchyTableList"); // NOI18N
		this.jScrollPane1.setViewportView(this.jTable1);

		this.jButton2.setName("buttonSelectAll"); // NOI18N
		this.jButton2.addActionListener(new java.awt.event.ActionListener() {
			@Override
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				selectedAndUnselected(evt);
			}
		});

		this.jButton3.setName("buttonRefresh"); // NOI18N
		this.jButton3.addActionListener(new java.awt.event.ActionListener() {
			@Override
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				reset(evt);
			}
		});

		javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
		this.setLayout(layout);
		layout.setHorizontalGroup(layout
				.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addGroup(
						layout.createSequentialGroup()
								.addComponent(this.jButton1)
								.addPreferredGap(
										javax.swing.LayoutStyle.ComponentPlacement.RELATED)
								.addComponent(this.jScrollPane1,
										javax.swing.GroupLayout.PREFERRED_SIZE,
										537,
										javax.swing.GroupLayout.PREFERRED_SIZE)
								.addGap(18, 18, 18)
								.addGroup(
										layout.createParallelGroup(
												javax.swing.GroupLayout.Alignment.LEADING)
												.addComponent(
														this.jButton2,
														javax.swing.GroupLayout.DEFAULT_SIZE,
														97, Short.MAX_VALUE)
												.addComponent(
														this.jButton3,
														javax.swing.GroupLayout.DEFAULT_SIZE,
														97, Short.MAX_VALUE))
								.addContainerGap()));
		layout.setVerticalGroup(layout
				.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addComponent(this.jButton1,
						javax.swing.GroupLayout.DEFAULT_SIZE, 111,
						Short.MAX_VALUE)
				.addComponent(this.jScrollPane1,
						javax.swing.GroupLayout.DEFAULT_SIZE, 111,
						Short.MAX_VALUE)
				.addGroup(
						layout.createSequentialGroup()
								.addComponent(this.jButton2)
								.addPreferredGap(
										javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
								.addComponent(this.jButton3).addContainerGap()));
	}// </editor-fold>//GEN-END:initComponents

	/**
	 * Reset.
	 * 
	 * @param evt
	 *            the evt
	 */
	private void reset(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_reset
		this.reset();
	}// GEN-LAST:event_reset

	/**
	 * Gets the last nodes.
	 * 
	 * @param evt
	 *            the evt
	 * @return the last nodes
	 */
	private void getLastNodes(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_getLastNodes
		this.lastNode();
	}// GEN-LAST:event_getLastNodes

	/**
	 * Selected and unselected.
	 * 
	 * @param evt
	 *            the evt
	 */
	private void selectedAndUnselected(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_selectedAndUnselected
		// this.treeMemory.selectedAllCurrentNodes();
		if (this.currentSelectedObject != null) {
			BrowserHierarchyDTO BrowserHierarchyDto = this.currentSelectedObject;
			this.treeMemory.updateCurrentStatus(BrowserHierarchyDto);
		} else {
			this.treeMemory.selectedAllCurrentNodes();
		}
		this.jTable1.repaint();
	}

	/** The j button1. */
	private javax.swing.JButton jButton1;

	/** The j button2. */
	private javax.swing.JButton jButton2;

	/** The j button3. */
	private javax.swing.JButton jButton3;

	/** The j scroll pane1. */
	private javax.swing.JScrollPane jScrollPane1;

	/** The j table1. */
	private javax.swing.JTable jTable1;

	/**
	 * Load.
	 */
	private void load() {
		try {
			Set<BrowserHierarchyDTO> tableElements = this.provider
					.initialLoad();
			for (BrowserHierarchyDTO current : tableElements) {
				current.setCurrentStatus(this.initialStatus);
			}
			BrowserHierarchyDTO dummyDto = new BrowserHierarchyDTO();
			dummyDto.setChildElements(tableElements);
			dummyDto.setTextToShow("Dummy");
			this.treeMemory.setNode(dummyDto);
			this.treeMemory.refreshSelectedNodes();
			this.fillTable(tableElements);
		} catch (BaseException e) {
			this.logger.error(e,
					"One error was occurred  during getting the data");
			JOptionPane.showMessageDialog(this, this.bundle
					.getString("BrowserHierarchy.message.error.getting.data"),
					this.bundle
							.getString("BrowserHierarchy.title.error.message"),
					JOptionPane.ERROR_MESSAGE);
		}
	}

	/**
	 * Fill table.
	 * 
	 * @param listElements
	 *            the list elements
	 */
	private void fillTable(Set<BrowserHierarchyDTO> listElements) {
		DefaultTableModel model = new javax.swing.table.DefaultTableModel(
				new Object[][] {

				}, new String[] { this.titleName, "", "" }) {
			boolean[] canEdit = new boolean[] { false, true, true };

			@Override
			public boolean isCellEditable(int rowIndex, int columnIndex) {
				return this.canEdit[columnIndex];
			}

		};
		this.jTable1.setModel(model);

		List<BrowserHierarchyDTO> sortList = new ArrayList<BrowserHierarchyDTO>(
				listElements);
		Collections.sort(sortList, new BrowserHierarchyComparator());
		for (BrowserHierarchyDTO current : sortList) {
			Object[] columns = new Object[3];
			columns[0] = current.getTextToShow();
			columns[1] = current;
			columns[2] = current;
			model.addRow(columns);
		}

		JCheckBox jCheckBox = new JCheckBox();

		jCheckBox.setName("selectionCheckBox");

		this.jTable1.getColumnModel().getColumn(2)
				.setCellRenderer(new CellButtonRenderer());
		this.jTable1.getColumnModel().getColumn(2)
				.setCellEditor(new CellButtonEditor(jCheckBox, this));

		this.jTable1.getColumnModel().getColumn(1)
				.setCellRenderer(new CellCheckRenderer(this.treeMemory));
		this.jTable1.getColumnModel().getColumn(1)
				.setCellEditor(new CellCheckEditor(jCheckBox, this));

		this.jTable1.getColumnModel().getColumn(0).setResizable(false);
		this.jTable1.getColumnModel().getColumn(1).setResizable(false);
		this.jTable1.getColumnModel().getColumn(2).setResizable(false);

		this.jTable1.getColumnModel().getColumn(0).setResizable(false);
		this.jTable1.getColumnModel().getColumn(1).setResizable(false);
		this.jTable1.getColumnModel().getColumn(2).setResizable(false);

		this.jTable1.getColumnModel().getColumn(1).setPreferredWidth(20);
		this.jTable1.getColumnModel().getColumn(1).setMaxWidth(20);
		this.jTable1.getColumnModel().getColumn(2).setPreferredWidth(40);
		this.jTable1.getColumnModel().getColumn(2).setMaxWidth(40);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.smartmatic.waffle.ecm.ui.controls.commons.ICellButtonEventListener
	 * #onClick(java.lang.Object)
	 */
	@Override
	public void onClick(Object selectObject) {
		try {
			Set<BrowserHierarchyDTO> tableElements;
			BrowserHierarchyDTO tmpSelectedObject = (BrowserHierarchyDTO) selectObject;

			if (this.treeMemory.isChildrenLoaded(tmpSelectedObject)) {
				tableElements = this.treeMemory.getChildren(tmpSelectedObject);
			} else {
				tableElements = this.provider.nextLevel(tmpSelectedObject);
				if (tableElements != null) {
					for (BrowserHierarchyDTO current : tableElements) {
						current.setParentElement(tmpSelectedObject);
					}
					tmpSelectedObject.setChildElements(tableElements);
				}
			}
			if ((tableElements != null) && (!tableElements.isEmpty())) {
				this.currentSelectedObject = tmpSelectedObject;
				this.fillTable(tableElements);
			} else {
				JOptionPane
						.showMessageDialog(
								this,
								this.bundle
										.getString("BrowserHierarchy.message.noChildren"),
								this.bundle
										.getString("BrowserHierarchy.title.info.message"),
								JOptionPane.INFORMATION_MESSAGE);
			}
		} catch (BaseException e) {
			this.logger.error(e,
					"One error was occurred  during getting the data");
			JOptionPane.showMessageDialog(this, this.bundle
					.getString("BrowserHierarchy.message.error.getting.data"),
					this.bundle
							.getString("BrowserHierarchy.title.error.message"),
					JOptionPane.ERROR_MESSAGE);
		}
	}

	/**
	 * Last node.
	 */
	public void lastNode() {
		Set<BrowserHierarchyDTO> tableElements;
		if (this.currentSelectedObject == null) {
			JOptionPane.showMessageDialog(this, this.bundle
					.getString("BrowserHierarchy.message.noParent"),
					this.bundle
							.getString("BrowserHierarchy.title.info.message"),
					JOptionPane.INFORMATION_MESSAGE);
		} else if (this.treeMemory.isParentLoaded(this.currentSelectedObject)) {
			BrowserHierarchyDTO parent = this.treeMemory
					.getParent(this.currentSelectedObject);
			if (this.treeMemory.isChildrenLoaded(parent)) {
				this.currentSelectedObject = parent;
				tableElements = this.treeMemory.getChildren(parent);
				this.fillTable(tableElements);
			}
		} else {
			this.currentSelectedObject = null;
			tableElements = this.treeMemory.getFirstNode();
			this.fillTable(tableElements);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.smartmatic.waffle.ecm.ui.controls.commons.ICellCheckEventListener
	 * #onPush(java.lang.Object)
	 */
	@Override
	public void onPush(Object objectSelected) {
		BrowserHierarchyDTO node = (BrowserHierarchyDTO) objectSelected;
		this.treeMemory.updateCurrentStatus(node);
		this.fireOnclickNodeEvent(node);
		if (node.getCurrentStatus() == BrowserHierarchyStatusType.FULL_SELECTED) {
			this.fireOnSelectEvent(node);
		} else if (node.getCurrentStatus() == BrowserHierarchyStatusType.UNSELECTED) {
			this.fireOnUnselectEvent(node);
		}
	}

	/**
	 * Gets the selected object.
	 * 
	 * @return the selected object
	 */
	public Set<BrowserHierarchyDTO> getSelectedObject() {
		return this.treeMemory.getSelectedNodes();
	}

	/**
	 * Gets the first node.
	 * 
	 * @return the first node
	 */
	public Set<BrowserHierarchyDTO> getFirstNode() {
		return this.treeMemory.getFirstNode();
	}

	/**
	 * Reset.
	 */
	public void reset() {
		this.clear();
		this.load();
	}

	/**
	 * Clear.
	 */
	public void clear() {
		this.treeMemory.clear();
		this.currentSelectedObject = null;
	}
}
