/**
 * ShutDownMachineActionListener.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.ui.core;

import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JDialog;
import javax.swing.JOptionPane;

import com.smartmatic.waffle.ecm.ui.core.i18n.controller.LanguageController;
import com.smartmatic.waffle.ecm.ui.util.PopUpOptionDialog;
import com.smartmatic.waffle.localpersistence.SAESCommonDestinations;

/**
 * The listener interface for receiving shutDownMachineAction events. The class
 * that is interested in processing a shutDownMachineAction event implements
 * this interface, and the object created with that class is registered with a
 * component using the component's
 * <code>addShutDownMachineActionListener<code> method. When
 * the shutDownMachineAction event occurs, that object's appropriate
 * method is invoked.
 * 
 * @see ShutDownMachineActionEvent
 */
public class ShutDownMachineActionListener implements ActionListener {

	/** The parent. */
	Component parent;

	/** The show question. */
	boolean showQuestion;

	/** The show all languages. */
	boolean showAllLanguages;

	/**
	 * Instantiates a new shut down machine action listener.
	 * 
	 * @param modalParent
	 *            the modal parent
	 */
	public ShutDownMachineActionListener(Component modalParent) {
		this.parent = modalParent;
		this.showQuestion = true;
		this.showAllLanguages = true;
	}

	/**
	 * Instantiates a new shut down machine action listener.
	 * 
	 * @param modalParent
	 *            the modal parent
	 * @param showQuestion
	 *            the show question
	 */
	public ShutDownMachineActionListener(Component modalParent,
			boolean showQuestion) {
		this.parent = modalParent;
		this.showQuestion = showQuestion;
		this.showAllLanguages = true;
	}

	/**
	 * Instantiates a new shut down machine action listener.
	 * 
	 * @param modalParent
	 *            the modal parent
	 * @param showQuestion
	 *            the show question
	 * @param showAllLanguages
	 *            the show all languages
	 */
	public ShutDownMachineActionListener(Component modalParent,
			boolean showQuestion, boolean showAllLanguages) {
		this.parent = modalParent;
		this.showQuestion = showQuestion;
		this.showAllLanguages = showAllLanguages;
	}

	/**
	 * Process.
	 */
	public void process() {
		Thread exitThread = new Thread(new Runnable() {
			@Override
			public void run() {

				if (ShutDownMachineActionListener.this.showQuestion) {
					LanguageController lc = LanguageController.getInstance();

					int result;

					if (ShutDownMachineActionListener.this.showAllLanguages) {

						result = PopUpOptionDialog.showPopUpOptionDialog(
								ShutDownMachineActionListener.this.parent,
								"Application.shutdown.dialog.message",
								"Application.shutdown.dialog.title",
								JOptionPane.YES_NO_OPTION,
								JOptionPane.QUESTION_MESSAGE, null, null,
								lc.getLanguageList());

					} else {
						result = PopUpOptionDialog.showPopUpOptionDialog(
								ShutDownMachineActionListener.this.parent,
								"Application.shutdown.dialog.message",
								"Application.shutdown.dialog.title",
								JOptionPane.YES_NO_OPTION,
								JOptionPane.QUESTION_MESSAGE, null, null,
								lc.getResourceMap());

					}

					if (result == JOptionPane.YES_OPTION) {
						Component currentParent = ShutDownMachineActionListener.this.parent;
						while (!(currentParent instanceof JDialog)
								&& currentParent != null) {
							currentParent = currentParent.getParent();
						}
						if (currentParent != null) {
							((JDialog) currentParent).setVisible(false);
						}
						MachineUtils.getInstance().shutdownMachine(
								SAESCommonDestinations.getInstance());
					}
				} else {
					MachineUtils.getInstance().shutdownMachine(
							SAESCommonDestinations.getInstance());
				}
			}
		});
		exitThread.start();
	}

	/*
	 * @see
	 * java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	@Override
	public void actionPerformed(ActionEvent arg0) {
		this.process();
	}
}
