/**
 * GeneralMenuDialog.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.ui.menu;

import java.awt.BorderLayout;
import java.awt.Frame;
import java.awt.event.ActionListener;
import java.util.Collection;
import java.util.HashSet;

import javax.swing.JLabel;

import com.smartmatic.waffle.domain.security.ApplicationDefinitionEnum;
import com.smartmatic.waffle.domain.security.FunctionalityDefinitionEnum;
import com.smartmatic.waffle.ecm.ui.BaseFullScreenJDialog;
import com.smartmatic.waffle.ecm.ui.menu.MenuConfiguration.MenuType;

/**
 * Class used to build the base general menu dialog that will contain the menu
 * and status components.
 */
public class GeneralMenuDialog extends BaseFullScreenJDialog {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 2L;

	/** The view. */
	private final IGeneralMenuView view;

	/** The instance. */
	private static GeneralMenuDialog instance;

	/** The parent. */
	private Frame parent;

	/** The titled. */
	private static JLabel titled;

	/** The printer status. */
	private static JLabel printerStatus;

	/** The battery status. */
	private static JLabel batteryStatus;

	/** The master status. */
	private static JLabel masterStatus;

	/**
	 * Creates new form GeneralMenuDialog.
	 * 
	 * @param parent
	 *            the parent
	 * @param modal
	 *            the modal
	 * @param funcSelectedDispatcher
	 *            the func selected dispatcher
	 * @param theMenuType
	 *            the the menu type
	 */
	public GeneralMenuDialog(java.awt.Frame parent, boolean modal,
			IFunctionalitySelected funcSelectedDispatcher, MenuType theMenuType) {
		super(parent, modal);
		this.parent = parent;
		this.initComponents();

		switch (theMenuType) {
		case TABS:
			final GeneralMenuTabsViewPanel generalMenuTabsViewPanel;
			if (GeneralMenuDialog.titled != null) {
				generalMenuTabsViewPanel = new GeneralMenuTabsViewPanel(
						GeneralMenuDialog.titled,
						GeneralMenuDialog.printerStatus,
						GeneralMenuDialog.batteryStatus,
						GeneralMenuDialog.masterStatus);
			} else {
				generalMenuTabsViewPanel = new GeneralMenuTabsViewPanel();
			}

			this.view = generalMenuTabsViewPanel;

			this.setGlassPane(generalMenuTabsViewPanel.glassPane);

			this.getContentPane().add(generalMenuTabsViewPanel,
					BorderLayout.CENTER);
			break;

		case BUTTONS:
			final GeneralMenuButtonsViewPanel generalMenuButtonsViewPanel = new GeneralMenuButtonsViewPanel();
			this.view = generalMenuButtonsViewPanel;

			this.getContentPane().add(generalMenuButtonsViewPanel,
					BorderLayout.CENTER);
			break;
		default:
			this.view = null;
		}

		this.showCloseButton(false);
		this.view.setCloseActionListener(new java.awt.event.ActionListener() {

			@Override
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				GeneralMenuDialog.this.closeButtonActionPerformed(evt);
			}
		});
		this.view.setFuncSelectedDispatcher(funcSelectedDispatcher);

		GeneralMenuDialog.instance = this;
	}

	/**
	 * Creates a new GeneralMenuDialog instance.
	 * 
	 * @param parent
	 *            parent frame
	 * @param modal
	 *            the modal property
	 * @param funcSelectedDispatcher
	 *            the dispatcher
	 * @param theMenuType
	 *            the type of menu
	 * @param title
	 *            the dialog title
	 * @param printerStatus
	 *            printer status label
	 * @param batteryStatus
	 *            battery status label
	 * @param masterStatus
	 *            master USB status label
	 */
	public GeneralMenuDialog(java.awt.Frame parent, boolean modal,
			IFunctionalitySelected funcSelectedDispatcher,
			MenuType theMenuType, JLabel title, JLabel printerStatus,
			JLabel batteryStatus, JLabel masterStatus) {
		super(parent, modal);
		this.parent = parent;
		GeneralMenuDialog.titled = title;
		GeneralMenuDialog.printerStatus = printerStatus;
		GeneralMenuDialog.batteryStatus = batteryStatus;
		GeneralMenuDialog.masterStatus = masterStatus;
		this.initComponents();

		switch (theMenuType) {
		case TABS:
			final GeneralMenuTabsViewPanel generalMenuTabsViewPanel;
			if (GeneralMenuDialog.titled != null) {
				generalMenuTabsViewPanel = new GeneralMenuTabsViewPanel(
						GeneralMenuDialog.titled,
						GeneralMenuDialog.printerStatus,
						GeneralMenuDialog.batteryStatus,
						GeneralMenuDialog.masterStatus);
			} else {
				generalMenuTabsViewPanel = new GeneralMenuTabsViewPanel();
			}

			this.view = generalMenuTabsViewPanel;

			this.setGlassPane(generalMenuTabsViewPanel.glassPane);

			this.getContentPane().add(generalMenuTabsViewPanel,
					BorderLayout.CENTER);
			break;

		case BUTTONS:
			final GeneralMenuButtonsViewPanel generalMenuButtonsViewPanel = new GeneralMenuButtonsViewPanel();
			this.view = generalMenuButtonsViewPanel;

			this.getContentPane().add(generalMenuButtonsViewPanel,
					BorderLayout.CENTER);
			break;
		default:
			this.view = null;
		}

		this.showCloseButton(false);
		this.view.setCloseActionListener(new java.awt.event.ActionListener() {

			@Override
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				GeneralMenuDialog.this.closeButtonActionPerformed(evt);
			}
		});
		this.view.setFuncSelectedDispatcher(funcSelectedDispatcher);

		GeneralMenuDialog.instance = this;
	}

	/**
	 * Gets the single instance of GeneralMenuDialog.
	 * 
	 * @return single instance of GeneralMenuDialog
	 */
	public static GeneralMenuDialog getInstance() {
		return GeneralMenuDialog.instance;
	}

	/**
	 * Sets the menu configuration.
	 * 
	 * @param categoryList
	 *            the category list
	 * @param applicationDefinitionEnum
	 *            the application definition enum
	 */
	public void setMenuConfiguration(Collection<BasicMenuItem> categoryList,
			ApplicationDefinitionEnum applicationDefinitionEnum) {

		this.view.setMenuConfiguration(categoryList, applicationDefinitionEnum);
	}

	/**
	 * Check status panel.
	 * 
	 * @param app
	 *            the app
	 */
	void checkStatusPanel(ApplicationDefinitionEnum app) {
		this.view.checkStatusPanel(app);
	}

	/**
	 * This method is called from within the constructor to initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is always
	 * regenerated by the Form Editor.
	 */
	// desc="Generated Code">//GEN-BEGIN:initComponents
	private void initComponents() {

		this.setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
		this.setName("Form"); // NOI18N
		this.getContentPane().setLayout(new java.awt.BorderLayout(1, 1));

		this.pack();
	}// </editor-fold>//GEN-END:initComponents

	/**
	 * Close button action performed.
	 * 
	 * @param evt
	 *            the evt
	 */
	private void closeButtonActionPerformed(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_closeButtonActionPerformed
		ApplicationDefinitionEnum current = GeneralMenuDialogController
				.getInstance().getApp();
		switch (current) {
		case RTS:
			break;
		default:
			break;
		}
	}// GEN-LAST:event_closeButtonActionPerformed

	/**
	 * Sets the action listener close button.
	 * 
	 * @param listener
	 *            the new action listener close button
	 */
	public void setActionListenerCloseButton(ActionListener listener) {
		this.view.setCloseActionListener(listener);
	}

	/**
	 * Show close button.
	 * 
	 * @param showCloseButton
	 *            the show close button
	 */
	public void showCloseButton(boolean showCloseButton) {
		this.view.showCloseButton(showCloseButton);
	}

	/**
	 * Getter of <code>parent</code> property.
	 * 
	 * @return <code>parent</code> property value.
	 * @see #parent
	 */
	@Override
	public Frame getParent() {
		return this.parent;
	}

	/**
	 * Method to set tab focus.
	 * 
	 * @param func
	 *            Functionality to set focus
	 */
	public void focusTab(FunctionalityDefinitionEnum func) {
		((GeneralMenuTabsViewPanel) this.view).setSelectedTabByFunction(func);
	}

	/**
	 * Sets all the panel tabs other than the one related to an specific
	 * functionality as enabled or disabled.
	 * 
	 * @param func
	 *            Functionality of pivotal the panel tab
	 * @param block
	 *            Status of the other panel tabs. <code>true</code> blocks all
	 *            the other tabs, <code>false</code> unblocks them.
	 * @author Mario Bislick (mario.bislick@smartmatic.com)
	 */
	public void blockOtherTabsByFunctionality(
			HashSet<FunctionalityDefinitionEnum> func, boolean block) {
		((GeneralMenuTabsViewPanel) this.view).blockOtherTabsByFunctionality(
				func, block);
	}

	/**
	 * Blocks or unblocks the application's exit tab button.
	 * 
	 * @param block
	 *            the block
	 * @author Mario Bislick (mario.bislick@smartmatic.com)
	 */
	public void blockExitTab(boolean block) {
		((GeneralMenuTabsViewPanel) this.view).blockExitTab(block);
	}
}