/**
 * GeneralMenuDialogController.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.ui.menu;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import javax.swing.JFrame;
import javax.swing.JPanel;

import com.smartmatic.waffle.domain.security.ApplicationDefinitionEnum;
import com.smartmatic.waffle.domain.security.FunctionalityData;
import com.smartmatic.waffle.domain.security.FunctionalityDefinitionEnum;
import com.smartmatic.waffle.domain.security.IActionData;
import com.smartmatic.waffle.domain.security.ProfileData;
import com.smartmatic.waffle.ecm.core.IFunctDispatcher;
import com.smartmatic.waffle.ecm.ui.menu.MenuConfiguration.MenuType;

/**
 * Class used to control the action for the general menu dialog.
 */
public class GeneralMenuDialogController implements IFunctionalitySelected {

	/** The category list. */
	private ArrayList<BasicMenuItem> categoryList;

	/** The func impl. */
	private Map<FunctionalityDefinitionEnum, IFunctDispatcher> funcImpl = new HashMap<FunctionalityDefinitionEnum, IFunctDispatcher>();

	/** The current role info. */
	private Map<FunctionalityDefinitionEnum, List<IActionData>> currentRoleInfo;

	/** The menu dialog. */
	private GeneralMenuDialog menuDialog;

	/** The app. */
	private ApplicationDefinitionEnum app;

	/** The menu type. */
	private MenuType menuType;

	/** Singleton instance of this class. */
	private static GeneralMenuDialogController singletonInstance = new GeneralMenuDialogController();

	/**
	 * Gets the single instance of GeneralMenuDialogController.
	 * 
	 * @return single instance of GeneralMenuDialogController
	 */
	public static GeneralMenuDialogController getInstance() {
		return GeneralMenuDialogController.singletonInstance;
	}

	/**
	 * Gets the menu dialog.
	 * 
	 * @return the menu dialog
	 */
	public GeneralMenuDialog getMenuDialog() {
		return this.menuDialog;
	}

	/**
	 * Register func impl.
	 * 
	 * @param funcDefinition
	 *            the func definition
	 * @param dispatcher
	 *            the dispatcher
	 */
	public void registerFuncImpl(FunctionalityDefinitionEnum funcDefinition,
			IFunctDispatcher dispatcher) {
		this.funcImpl.put(funcDefinition, dispatcher);
	}

	/**
	 * Instantiates a new general menu dialog controller.
	 */
	private GeneralMenuDialogController() {
		super();
	}

	/**
	 * Load menu configuration.
	 * 
	 * @param menu
	 *            the menu
	 * @throws Exception
	 *             the exception
	 */
	@SuppressWarnings("rawtypes")
	public synchronized void loadMenuConfiguration(MenuConfiguration menu)
			throws Exception {

		this.menuType = menu.getMenuType();

		this.categoryList = new ArrayList<BasicMenuItem>();

		this.categoryList.addAll(menu.getFuncShortcut());

		final List<MenuCategoryItem> menuCategory = menu.getMenuCategory();
		if (menuCategory != null) {
			Iterator iter = menuCategory.iterator();

			while (iter.hasNext()) {

				MenuCategoryItem actualCategory = (MenuCategoryItem) iter
						.next();

				Map<FunctionalityDefinitionEnum, List<IActionData>> functionalities = new HashMap<FunctionalityDefinitionEnum, List<IActionData>>();

				Iterator funcDefIterator = actualCategory.getFunctionalities()
						.iterator();
				while (funcDefIterator.hasNext()) {

					FunctionalityDefinitionEnum actualFunctionality = (FunctionalityDefinitionEnum) funcDefIterator
							.next();
					functionalities.put(actualFunctionality,
							new ArrayList<IActionData>());
				}
				actualCategory.setFunctionalityDefinitions(functionalities);
				this.categoryList.add(actualCategory);

			}
		}

		this.menuDialog = new GeneralMenuDialog(new JFrame(), true, this,
				this.menuType);
	}

	/**
	 * Load menu configuration.
	 * 
	 * @param menu
	 *            the menu
	 * @param parent
	 *            the parent
	 * @throws Exception
	 *             the exception
	 */
	public synchronized void loadMenuConfiguration(MenuConfiguration menu,
			java.awt.Frame parent) throws Exception {
		this.loadMenuConfiguration(menu);
		this.menuDialog = new GeneralMenuDialog(parent, true, this,
				this.menuType);
	}

	/**
	 * Sets the default profile.
	 * 
	 * @param profile
	 *            the profile
	 * @param currentApp
	 *            the current app
	 */
	public void setDefaultProfile(ProfileData profile,
			ApplicationDefinitionEnum currentApp) {
		this.currentRoleInfo = GeneralMenuDialogController.convertProfile(
				profile, currentApp);
	}

	/**
	 * Show menu.
	 * 
	 * @param profile
	 *            the profile
	 * @param showCloseButton
	 *            the show close button
	 * @param app
	 *            the app
	 */
	public void showMenu(ProfileData profile, boolean showCloseButton,
			ApplicationDefinitionEnum app) {

		Collection<BasicMenuItem> restrictedMenu = this.restrictMenuCategories(
				this.currentRoleInfo, this.categoryList);

		if (profile.isAdminProfile()) {
			this.menuDialog.setMenuConfiguration(this.categoryList, app);
		} else {
			this.menuDialog.setMenuConfiguration(restrictedMenu, app);
		}

		this.menuDialog.showCloseButton(showCloseButton);
		this.menuDialog.setVisible(true);
	}

	/**
	 * Restrict menu categories.
	 * 
	 * @param availableFunctionalites
	 *            the available functionalites
	 * @param baseConfiguration
	 *            the base configuration
	 * @return the collection
	 */
	private Collection<BasicMenuItem> restrictMenuCategories(
			Map<FunctionalityDefinitionEnum, List<IActionData>> availableFunctionalites,
			Collection<BasicMenuItem> baseConfiguration) {

		Collection<BasicMenuItem> customMenuConfiguration = new ArrayList<BasicMenuItem>();

		for (BasicMenuItem menuCategoryData : baseConfiguration) {

			// Copies the menu category info into a custom categor
			BasicMenuItem customMenuCategory = menuCategoryData
					.cloneRestricedMenuItem(availableFunctionalites);

			// Checks if the category contains some functionality to add the
			// category to the menuConfiguration
			if (customMenuCategory.functionalityCount() > 0) {
				customMenuConfiguration.add(customMenuCategory);
			}

		}

		return customMenuConfiguration;
	}

	/**
	 * Convert profile.
	 * 
	 * @param profile
	 *            the profile
	 * @param currentApplication
	 *            the current application
	 * @return the map
	 */
	private static Map<FunctionalityDefinitionEnum, List<IActionData>> convertProfile(
			ProfileData profile, ApplicationDefinitionEnum currentApplication) {
		Map<FunctionalityDefinitionEnum, List<IActionData>> mappedFunctionalities = new HashMap<FunctionalityDefinitionEnum, List<IActionData>>();
		if (profile.getFunctionalities() == null) {
			return mappedFunctionalities;
		}
		for (FunctionalityData actualFunctionalityData : profile
				.getFunctionalities()) {
			// Checks if the current functionality is supported by the
			// application
			FunctionalityDefinitionEnum functDefinition = actualFunctionalityData
					.getFunctionalityDefinition();
			if (isFunctionalityDefinitionSupportedByApplication(
					functDefinition, currentApplication)) {
				// Checks if exist a previous action with the given
				// functionality definition
				List<IActionData> actionsSupported = mappedFunctionalities
						.get(functDefinition);
				if (actionsSupported == null) {
					actionsSupported = new ArrayList<IActionData>();
				}
				mappedFunctionalities.put(functDefinition, actionsSupported);
			}
		}
		return mappedFunctionalities;
	}

	/**
	 * Checks if is functionality definition supported by application.
	 * 
	 * @param functionality
	 *            the functionality
	 * @param application
	 *            the application
	 * @return true, if is functionality definition supported by application
	 */
	private static boolean isFunctionalityDefinitionSupportedByApplication(
			FunctionalityDefinitionEnum functionality,
			ApplicationDefinitionEnum application) {
		ApplicationDefinitionEnum[] supportedApplications = functionality
				.getSupportedApplications();
		for (ApplicationDefinitionEnum applicationDefinitionEnum : supportedApplications) {
			if (applicationDefinitionEnum == application) {
				return true;
			}
		}
		return false;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.smartmatic.waffle.ui.menu.IFunctionalitySelected#functionalitySelected
	 * (com.smartmatic.waffle.domain.security.FunctionalityDefinitionEnum)
	 */
	@Override
	public JPanel functionalitySelected(
			FunctionalityDefinitionEnum functionality, boolean allowDisplay) {
		IFunctDispatcher dispatchItem = this.funcImpl.get(functionality);
		if (dispatchItem != null) {
			return dispatchItem.dispatch(
					this.currentRoleInfo.get(functionality), allowDisplay);
		}
		return null;
	}

	/**
	 * Gets the by app definition enum.
	 * 
	 * @param app
	 *            the app
	 * @return the by app definition enum
	 */
	public IFunctDispatcher getByAppDefinitionEnum(
			FunctionalityDefinitionEnum app) {
		return this.funcImpl.get(app);
	}

	/**
	 * Getter of <code>app</code> property.
	 * 
	 * @return <code>app</code> property value.
	 * @see #app
	 */
	public ApplicationDefinitionEnum getApp() {
		return this.app;
	}

	/**
	 * Setter of <code>app</code> property.
	 * 
	 * @param app
	 *            The <code>app</code> to set.
	 * @see #app
	 */
	public void setApp(ApplicationDefinitionEnum app) {
		this.app = app;

		return;
	}
}
