/**
 * GeneralMenuTabsViewPanel.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.ui.menu;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashSet;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;

import javax.swing.AbstractButton;
import javax.swing.Icon;
import javax.swing.JButton;
import javax.swing.JInternalFrame;
import javax.swing.JLabel;
import javax.swing.JLayeredPane;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JTabbedPane;
import javax.swing.WindowConstants;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import javax.swing.event.InternalFrameAdapter;
import javax.swing.event.InternalFrameEvent;
import javax.swing.event.MouseInputAdapter;

import com.smartmatic.waffle.domain.security.ApplicationDefinitionEnum;
import com.smartmatic.waffle.domain.security.FunctionalityDefinitionEnum;
import com.smartmatic.waffle.ecm.ui.DialogState;
import com.smartmatic.waffle.ecm.ui.core.i18n.controller.LanguageController;
import com.smartmatic.waffle.ecm.ui.core.spec.IParentCloseable;
import com.smartmatic.waffle.ecm.ui.util.PopUpOptionDialog;

/**
 * Class used to build the General Menu Tabs View Panel.
 */
public class GeneralMenuTabsViewPanel extends AbstractGeneralMenuView implements
		IGeneralMenuView {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = -1492089659387841693L;

	/** The new text selected. */
	private String newTextSelected;

	/** The old text selected. */
	private String oldTextSelected;

	/** The image loading. */
	private JLabel imageLoading;

	/**
	 * Title of window.
	 */
	private static JLabel titled;

	/**
	 * Printer Status.
	 */
	private static JLabel printerStatus;

	/**
	 * Battery Status.
	 */
	private static JLabel batteryStatus;

	/** Master Status. */
	private static JLabel masterStatus;

	/** The internal frame listener. */
	private InternalFrameListener internalFrameListener;

	/**
	 * Creates new form GeneralMenuTabsViewPanel.
	 */
	public GeneralMenuTabsViewPanel() {
		this.initComponents();
		this.categoryPanelMap = new Hashtable<BasicMenuItem, JPanel>();

	}

	/**
	 * Creates a new GeneralMenuTabsViewPanel.
	 * 
	 * @param theTitle
	 *            title
	 * @param printerStatus
	 *            the status of the printer
	 * @param batteryStatus
	 *            the status of the battery
	 * @param masterStatus
	 *            the status of the master USB
	 */
	public GeneralMenuTabsViewPanel(JLabel theTitle, JLabel printerStatus,
			JLabel batteryStatus, JLabel masterStatus) {
		GeneralMenuTabsViewPanel.titled = theTitle;
		GeneralMenuTabsViewPanel.printerStatus = printerStatus;
		GeneralMenuTabsViewPanel.batteryStatus = batteryStatus;
		GeneralMenuTabsViewPanel.masterStatus = masterStatus;
		this.initComponents();
		this.categoryPanelMap = new Hashtable<BasicMenuItem, JPanel>();

	}

	/**
	 * Gets the menu item by tab title.
	 * 
	 * @param title
	 *            the title
	 * @return the menu item by tab title
	 */
	private BasicMenuItem getMenuItemByTabTitle(String title) {
		JPanel currentPanel = (JPanel) this.funcContainerPane
				.getComponentAt(this.funcContainerPane.indexOfTab(title));
		Iterator<BasicMenuItem> it = this.categoryPanelMap.keySet().iterator();
		for (; it.hasNext();) {
			BasicMenuItem key = it.next();
			JPanel value = this.categoryPanelMap.get(key);
			if (value.equals(currentPanel)) {
				return key;
			}
		}
		return null;
	}

	/**
	 * Enables or disables an specific tab pane given the functionality
	 * associated with it.
	 * 
	 * @param func
	 *            Functionality of the tab pane to enable or disable
	 * @param enabled
	 *            Indicates if the tab pane is going to be enabled or disabled.
	 *            True enables the tab pane, false disables it.
	 * @param recoursive
	 *            the recoursive
	 */
	public void setEnabledByFunction(FunctionalityDefinitionEnum func,
			boolean enabled, boolean recoursive) {
		String tabText = null;
		for (BasicMenuItem item : this.categoryPanelMap.keySet()) {
			if (item instanceof MenuCategoryItem) {
				MenuCategoryItem menu = (MenuCategoryItem) item;
				Iterator<FunctionalityDefinitionEnum> it = menu.functionalities
						.iterator();
				for (; it.hasNext();) {
					if (it.next().equals(func)) {
						tabText = menu.getCategoryTitle();
						break;
					}
				}
			} else {
				FunctionalityShortcutMenuItem function = (FunctionalityShortcutMenuItem) item;
				if (function.getFunctionality().equals(func)) {
					tabText = function.getCategoryTitle();
					break;
				}
			}
		}
		if (tabText != null) {
			String text = LanguageController.getInstance().getResourceMap()
					.getString(tabText).trim();
			int index = this.getIndexAt(text);
			if (index == -1) {
				return;
			}
			JPanel currentPanel = (JPanel) this.funcContainerPane
					.getComponentAt(index);
			if (recoursive) {
				this.setEnabledRecoursive(currentPanel, enabled);
			}
			this.funcContainerPane.setEnabledAt(index, enabled);
		}
		// find buttons childs of menu category items
		JButton button = this.mapButtons.get(func);
		if (button != null) {
			button.setEnabled(enabled);
		}
	}

	/**
	 * Enables or disables an specific tab pane given the functionality
	 * associated with it.
	 * 
	 * @param func
	 *            Functionality of the tab pane to enable or disable
	 * @param enabled
	 *            Indicates if the tab pane is going to be enabled or disabled.
	 *            True enables the tab pane, false disables it.
	 */
	public void setEnabledByFunction(FunctionalityDefinitionEnum func,
			boolean enabled) {
		setEnabledByFunction(func, enabled, false);
	}

	/**
	 * Selects a tab pane given the functionality associated with it.
	 * 
	 * @param func
	 *            Functionality of the tab pane to enable or disable
	 */
	public void setSelectedTabByFunction(FunctionalityDefinitionEnum func) {
		String tabText = null;
		for (BasicMenuItem item : this.categoryPanelMap.keySet()) {
			if (item instanceof MenuCategoryItem) {
				MenuCategoryItem menu = (MenuCategoryItem) item;
				Iterator<FunctionalityDefinitionEnum> it = menu.functionalities
						.iterator();
				for (; it.hasNext();) {
					if (it.next().equals(func)) {
						tabText = menu.getCategoryTitle();
						break;
					}
				}
			} else {
				FunctionalityShortcutMenuItem function = (FunctionalityShortcutMenuItem) item;
				if (function.getFunctionality().equals(func)) {
					tabText = function.getCategoryTitle();
					break;
				}
			}
		}
		if (tabText != null) {
			String text = LanguageController.getInstance().getResourceMap()
					.getString(tabText).trim();
			int index = this.getIndexAt(text);
			if (index == -1) {
				return;
			}
			if (index != this.funcContainerPane.getSelectedIndex()) {
				this.funcContainerPane.setSelectedIndex(index);
			}
		}
	}

	/**
	 * Sets the enabled recoursive.
	 * 
	 * @param currentPanel
	 *            the current panel
	 * @param enabled
	 *            the enabled
	 */
	private void setEnabledRecoursive(Component currentPanel, boolean enabled) {
		if (currentPanel instanceof Container) {
			Component[] com = ((Container) currentPanel).getComponents();
			for (int a = 0; a < com.length; a++) {
				this.setEnabledRecoursive(com[a], enabled);
			}
		}
		currentPanel.setEnabled(enabled);
	}

	/**
	 * Gets the tab pane's index which its title coincides with a given string.
	 * 
	 * @param textToFind
	 *            Title of the tab pane which index wants to be returned
	 * @return Tab pane's index which title is the same as
	 *         <code>textToFind</code>
	 */
	private int getIndexAt(String textToFind) {
		int index = -1;
		for (int j = 0; j < this.funcContainerPane.getTabCount(); j++) {
			if (this.funcContainerPane.getTitleAt(j).trim().equals(textToFind)) {
				return index = j;
			}
		}
		return index;
	}

	/**
	 * The Class ExtendedTabbedPane.
	 */
	class ExtendedTabbedPane extends JTabbedPane {

		/** The Constant serialVersionUID. */
		private static final long serialVersionUID = -5459852166271273641L;

		/*
		 * (non-Javadoc)
		 * 
		 * @see javax.swing.JTabbedPane#setSelectedIndex(int)
		 */
		@Override
		public void setSelectedIndex(int index) {

			AbstractMenuDispatch dispatcher = null;

			if (GeneralMenuTabsViewPanel.this.oldTextSelected == null) {
				super.setSelectedIndex(index);
				return;
			}

			BasicMenuItem oldValue = GeneralMenuTabsViewPanel.this
					.getMenuItemByTabTitle(GeneralMenuTabsViewPanel.this.oldTextSelected);

			if (oldValue == null) {
				super.setSelectedIndex(index);
				return;
			}

			String menuValue = "";
			if (oldValue instanceof MenuCategoryItem) {
				menuValue = ((MenuCategoryItem) oldValue).getFunctionalities()
						.iterator().next().toString();
			} else if (oldValue instanceof FunctionalityShortcutMenuItem) {
				menuValue = ((FunctionalityShortcutMenuItem) oldValue)
						.getFunctionality().toString();
			}

			FunctionalityDefinitionEnum funcSelected = Enum.valueOf(
					FunctionalityDefinitionEnum.class, menuValue);

			dispatcher = (AbstractMenuDispatch) GeneralMenuDialogController
					.getInstance().getByAppDefinitionEnum(funcSelected);

			if (dispatcher != null) {

				if (dispatcher.getState().equals(DialogState.CHANGED)) {

					int option = PopUpOptionDialog.showPopUpOptionDialog(
							GeneralMenuDialog.getInstance(),
							"question.quit.tab", "question.title.text",
							JOptionPane.YES_NO_OPTION,
							JOptionPane.QUESTION_MESSAGE, null, null,
							GeneralMenuTabsViewPanel.this.resourceMap);

					if (option == JOptionPane.OK_OPTION) {
						dispatcher.refresh();
					} else {
						return;
					}
				}
			}
			GeneralMenuTabsViewPanel.this.oldTextSelected = GeneralMenuTabsViewPanel.this.newTextSelected;
			super.setSelectedIndex(index);
		}

		/**
		 * Blocks or unblocks all the tab panes other than the active one,
		 * identified by its title.
		 * 
		 * @param block
		 *            Enabled state of the tab panes. True sets the tab panes as
		 *            enabled, false disables the tab panes.
		 * @param tabTitles
		 *            the tab titles
		 * @author Mario Bislick (mario.bislick@smartmatic.com)
		 */
		public void blockUnactiveTabs(boolean block, List<String> tabTitles) {
			int tabCount = this.getTabCount();
			HashSet<Integer> indexes = new HashSet<Integer>();
			for (String tabTitle : tabTitles) {
				String text = LanguageController.getInstance().getResourceMap()
						.getString(tabTitle).trim();
				int index = getIndexAt(text);
				if (index != -1) {
					indexes.add(index);
				}
			}
			if (indexes.isEmpty()) {
				return;
			}
			for (int tabIndex = 0; tabIndex < tabCount - 1; tabIndex++) {
				if (!indexes.contains(tabIndex)) {
					this.setEnabledAt(tabIndex, !block);
				}
			}
		}

		/**
		 * Blocks or unblocks the exit tab button.
		 * 
		 * @param block
		 *            Enabled state of the exit tab button. <code>true</code>
		 *            sets the tab as disabled, <code>false</code> enables the
		 *            exit tab.
		 * @author Mario Bislick (mario.bislick@smartmatic.com)
		 */
		public void blockExitTab(boolean block) {
			int tabCount = this.getTabCount();
			if (tabCount < 1) {
				return;
			}
			this.setEnabledAt(tabCount - 1, !block);

		}

		/**
		 * Unblocks all the tab panes.
		 * 
		 * @author Mario Bislick (mario.bislick@smartmatic.com)
		 */
		public void unblockTabs() {
			int tabCount = this.getTabCount();
			for (int tabIndex = 0; tabIndex < tabCount; tabIndex++) {
				this.setEnabledAt(tabIndex, true);
			}
		}

	}

	/**
	 * This method is called from within the constructor to initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is always
	 * regenerated by the Form Editor.
	 */
	// <editor-fold defaultstate="collapsed"
	// desc="Generated Code">//GEN-BEGIN:initComponents
	private void initComponents() {

		this.glassPane = new javax.swing.JLayeredPane() {

			private static final long serialVersionUID = 1L;

			/**
			 * Layout each of the components in this JLayeredPane so that they
			 * all fill the entire extents of the layered pane -- from (0,0) to
			 * (getWidth(), getHeight())
			 */
			@Override
			public void doLayout() {

				/*
				 * Synchronizing on getTreeLock, because I see other layouts
				 * doing that. see BorderLayout::layoutContainer(Container)
				 */
				synchronized (this.getTreeLock()) {
					int w = this.getWidth();
					int h = this.getHeight();
					for (java.awt.Component c : this.getComponents()) {
						if (c instanceof javax.swing.JInternalFrame == false) {
							c.setBounds(0, 0, w, h);
						}
					}
				}
			}

		};
		this.internalFrame = new javax.swing.JInternalFrame();
		javax.swing.JPanel closeButtonPanel = new javax.swing.JPanel();
		this.closeButton = new javax.swing.JButton();
		this.funcContainerPane = new ExtendedTabbedPane();

		this.glassPane.setName("paneGlass"); // NOI18N

		this.internalFrame.setClosable(true);
		this.internalFrame.setName("internalFrame"); // NOI18N
		this.internalFrame.setBounds(0, 0, 380, 290);
		this.glassPane.add(this.internalFrame,
				javax.swing.JLayeredPane.MODAL_LAYER);

		closeButtonPanel.setName("panelCloseButton"); // NOI18N
		closeButtonPanel.setOpaque(false);
		this.closeButton.setFocusable(false);
		this.closeButton.setName("buttonClose"); // NOI18N
		this.closeButton.addActionListener(new java.awt.event.ActionListener() {
			@Override
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				GeneralMenuTabsViewPanel.this.closeButtonActionPerformed(evt);
			}
		});

		javax.swing.GroupLayout closeButtonPanelLayout = new javax.swing.GroupLayout(
				closeButtonPanel);
		closeButtonPanel.setLayout(closeButtonPanelLayout);
		closeButtonPanelLayout.setHorizontalGroup(closeButtonPanelLayout
				.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addGroup(
						javax.swing.GroupLayout.Alignment.TRAILING,
						closeButtonPanelLayout.createSequentialGroup()
								.addContainerGap(212, Short.MAX_VALUE)
								.addComponent(this.closeButton)
								.addGap(22, 22, 22)));
		closeButtonPanelLayout.setVerticalGroup(closeButtonPanelLayout
				.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addGroup(
						javax.swing.GroupLayout.Alignment.TRAILING,
						closeButtonPanelLayout.createSequentialGroup()
								.addContainerGap(203, Short.MAX_VALUE)
								.addComponent(this.closeButton)
								.addGap(31, 31, 31)));

		closeButtonPanel.setBounds(0, 0, -1, -1);
		this.glassPane.add(closeButtonPanel,
				javax.swing.JLayeredPane.DEFAULT_LAYER);

		this.setLayout(new java.awt.BorderLayout());

		this.funcContainerPane.setName("paneFuncContainer"); // NOI18N

		Font font = new Font("Dialog", Font.BOLD, 12);

		JLabel printerStatusLabel = new JLabel(
				this.resourceMap.getString("printer.status.label"));

		JLabel batteryStatusLabel = new JLabel(
				this.resourceMap.getString("battery.status.label"));

		JLabel masterStatusLabel = new JLabel(
				this.resourceMap.getString("master.status.label"));

		printerStatusLabel.setFont(font);

		batteryStatusLabel.setFont(font);

		masterStatusLabel.setFont(font);

		JPanel titled = new JPanel();

		JPanel labels = new JPanel();

		JPanel statusBar = new JPanel();

		FlowLayout titledLayout = buildVFlowLayaut(FlowLayout.RIGHT, 5);

		titled.setLayout(titledLayout);

		if (GeneralMenuTabsViewPanel.printerStatus != null
				&& GeneralMenuTabsViewPanel.batteryStatus != null
				|| (GeneralMenuTabsViewPanel.printerStatus != null && GeneralMenuTabsViewPanel.masterStatus != null)
				|| (GeneralMenuTabsViewPanel.batteryStatus != null && GeneralMenuTabsViewPanel.masterStatus != null)) {
			JLabel lbSquareBracketOpen = new JLabel("[");
			lbSquareBracketOpen.setFont(font);
			labels.add(lbSquareBracketOpen);
		}

		if (GeneralMenuTabsViewPanel.printerStatus != null) {
			FlowLayout labelLayout = buildVFlowLayaut(FlowLayout.CENTER, 5);

			labels.setLayout(labelLayout);

			labels.add(printerStatusLabel);

			labels.add(GeneralMenuTabsViewPanel.printerStatus);
		}

		if (GeneralMenuTabsViewPanel.printerStatus != null
				&& GeneralMenuTabsViewPanel.batteryStatus != null
				|| (GeneralMenuTabsViewPanel.printerStatus != null && GeneralMenuTabsViewPanel.masterStatus != null)
				|| (GeneralMenuTabsViewPanel.batteryStatus != null && GeneralMenuTabsViewPanel.masterStatus != null)) {
			JLabel lbPipe = new JLabel("|");
			lbPipe.setFont(font);
			labels.add(lbPipe);
		}

		if (GeneralMenuTabsViewPanel.batteryStatus != null) {
			FlowLayout labelLayout = buildVFlowLayaut(FlowLayout.CENTER, 5);

			labels.setLayout(labelLayout);

			labels.add(batteryStatusLabel);

			labels.add(GeneralMenuTabsViewPanel.batteryStatus);
		}

		if (GeneralMenuTabsViewPanel.printerStatus != null
				&& GeneralMenuTabsViewPanel.batteryStatus != null
				&& GeneralMenuTabsViewPanel.masterStatus != null) {
			JLabel lbPipe = new JLabel("|");
			lbPipe.setFont(font);
			labels.add(lbPipe);
		}

		if (GeneralMenuTabsViewPanel.printerStatus != null
				&& GeneralMenuTabsViewPanel.batteryStatus != null
				&& GeneralMenuTabsViewPanel.masterStatus == null) {
			JLabel lbSquareBracketClose = new JLabel("]");
			lbSquareBracketClose.setFont(font);
			labels.add(lbSquareBracketClose);
		}

		if (GeneralMenuTabsViewPanel.masterStatus != null) {
			FlowLayout labelLayout = buildVFlowLayaut(FlowLayout.CENTER, 5);

			labels.setLayout(labelLayout);

			labels.add(masterStatusLabel);

			labels.add(GeneralMenuTabsViewPanel.masterStatus);
		}

		if (GeneralMenuTabsViewPanel.printerStatus != null
				&& GeneralMenuTabsViewPanel.batteryStatus != null
				|| (GeneralMenuTabsViewPanel.printerStatus != null && GeneralMenuTabsViewPanel.masterStatus != null)
				|| (GeneralMenuTabsViewPanel.batteryStatus != null && GeneralMenuTabsViewPanel.masterStatus != null)) {
			JLabel lbSquareBracketClose = new JLabel("]");
			lbSquareBracketClose.setFont(font);
			labels.add(lbSquareBracketClose);
		}

		if (GeneralMenuTabsViewPanel.titled != null) {
			titled.add(GeneralMenuTabsViewPanel.titled);
		}

		statusBar.setLayout(new BorderLayout());
		statusBar.add(labels, BorderLayout.WEST);
		statusBar.add(titled, BorderLayout.EAST);

		this.add(statusBar, BorderLayout.NORTH);

		this.add(this.funcContainerPane, java.awt.BorderLayout.CENTER);

	}// </editor-fold>//GEN-END:initComponents

	/**
	 * Builds the v flow layaut.
	 * 
	 * @param aligment
	 *            the aligment
	 * @param hGap
	 *            the h gap
	 * @return the flow layout
	 */
	private FlowLayout buildVFlowLayaut(int aligment, int hGap) {
		FlowLayout layout = new FlowLayout();
		layout.setAlignment(aligment);
		layout.setVgap(hGap);
		return layout;
	}

	/**
	 * Close button action performed.
	 * 
	 * @param evt
	 *            the evt
	 */
	private void closeButtonActionPerformed(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_closeButtonActionPerformed
		if (this.closeActionListener != null) {

			this.closeActionListener.actionPerformed(evt);
		}
	}// GEN-LAST:event_closeButtonActionPerformed

	// Variables declaration - do not modify//GEN-BEGIN:variables
	/** The close button. */
	javax.swing.JButton closeButton;

	/** The func container pane. */
	ExtendedTabbedPane funcContainerPane;

	/** The glass pane. */
	javax.swing.JLayeredPane glassPane;

	/** The internal frame. */
	private javax.swing.JInternalFrame internalFrame;

	// End of variables declaration//GEN-END:variables

	/**
	 * Displays the menu with the list of categories received.
	 * 
	 * @param menuCategories
	 *            The collection of categories to display in the menu
	 * @param app
	 *            the app
	 */
	@Override
	public void setMenuConfiguration(Collection<BasicMenuItem> menuCategories,
			ApplicationDefinitionEnum app) {

		ActionListener funcButtonActionListener = new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent evt) {
				GeneralMenuTabsViewPanel.this.funcButtonActionPerformed(evt);
			}
		};

		/*
		 * Iterates over the list of categories, and construct the category
		 * buttons and its panel
		 */
		for (BasicMenuItem menuCategoryData : menuCategories) {
			JPanel funcPanel;
			if (menuCategoryData instanceof MenuCategoryItem) {
				funcPanel = this.buildPanelByMenuCategory(
						(MenuCategoryItem) menuCategoryData,
						funcButtonActionListener, app);

			} else {

				FunctionalityDefinitionEnum funcSelected = Enum.valueOf(
						FunctionalityDefinitionEnum.class,
						((FunctionalityShortcutMenuItem) menuCategoryData)
								.getFunctionality().toString());

				funcPanel = this.funcSelectedDispatcher.functionalitySelected(
						funcSelected, true);

			}

			if (funcPanel != null) {
				this.categoryPanelMap.put(menuCategoryData, funcPanel);
				String tab_title = menuCategoryData.getCategoryTitle();
				Icon tab_icon = this.resourceMap.getIcon(tab_title + ".icon");
				funcPanel
						.setName(((FunctionalityShortcutMenuItem) menuCategoryData)
								.getFunctionality()
								.getFunctionalityMainPanelName());

				this.funcContainerPane.addTab(
						this.resourceMap.getString(tab_title) + "  ", tab_icon,
						funcPanel);
			}
		}

		if (this.funcContainerPane.getSelectedIndex() >= 0) {
			this.oldTextSelected = this.funcContainerPane
					.getTitleAt(this.funcContainerPane.getSelectedIndex());
		}

		this.configureChangeListener();

	}

	/**
	 * Configure change listener.
	 */
	private void configureChangeListener() {
		this.funcContainerPane.addChangeListener(new ChangeListener() {
			@Override
			public void stateChanged(ChangeEvent e) {
				JTabbedPane tabSelected = (JTabbedPane) e.getSource();

				GeneralMenuTabsViewPanel.this.newTextSelected = tabSelected
						.getTitleAt(tabSelected.getSelectedIndex());
				GeneralMenuTabsViewPanel.this.oldTextSelected = GeneralMenuTabsViewPanel.this.newTextSelected;
			}
		});
	}

	/**
	 * Func button action performed.
	 * 
	 * @param evt
	 *            the evt
	 */
	private void funcButtonActionPerformed(ActionEvent evt) {
		AbstractButton sourceButton = (AbstractButton) evt.getSource();
		String funcName = sourceButton.getName();

		FunctionalityDefinitionEnum funcSelected = Enum.valueOf(
				FunctionalityDefinitionEnum.class, funcName);

		this.showFunctionalityByEnumValue(funcSelected);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.ecm.ui.menu.IGeneralMenuView#
	 * showFunctionalityByEnumValue
	 * (com.smartmatic.waffle.domain.security.FunctionalityDefinitionEnum)
	 */
	@Override
	public void showFunctionalityByEnumValue(
			FunctionalityDefinitionEnum funcToShow) {
		if (this.funcSelectedDispatcher != null) {
			JPanel funcPanel = this.funcSelectedDispatcher
					.functionalitySelected(funcToShow, true);
			if (funcPanel != null) {
				this.showPopupPanel(funcPanel, true);
			}
		}
	}

	/**
	 * Creates a new tab that will act as the logout button.
	 * 
	 * @param showCloseButton
	 *            the show close button
	 * @author Yenny Villalba <yenny.villalba@smartmatic.com>
	 */
	@Override
	public void showCloseButton(boolean showCloseButton) {
		this.closeButton.setVisible(showCloseButton);

		if (showCloseButton) {
			this.closeButton.setVisible(false);

			class TabButton extends JPanel {
				private static final long serialVersionUID = 1L;

				public TabButton() {
					super(new FlowLayout(FlowLayout.CENTER, 1, 1));
					JButton button = new JButton(
							GeneralMenuTabsViewPanel.this.resourceMap
									.getIcon("logout.tab.icon"));
					button.setToolTipText(GeneralMenuTabsViewPanel.this.resourceMap
							.getString("logout.tab.tooltip"));
					button.setBorder(null);

					button.addActionListener(new java.awt.event.ActionListener() {
						@Override
						public void actionPerformed(
								java.awt.event.ActionEvent evt) {
							GeneralMenuTabsViewPanel.this
									.closeButtonActionPerformed(evt);
						}
					});

					this.add(button);
					this.setOpaque(false);
				}
			}

			this.funcContainerPane.addTab("", null);
			int tabPosition = this.funcContainerPane.getTabCount() - 1;
			this.funcContainerPane.setTabComponentAt(tabPosition,
					new TabButton());
		}

		this.glassPane.setVisible(showCloseButton);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.smartmatic.waffle.ecm.ui.menu.IGeneralMenuView#showPopupPanel(javax
	 * .swing.JPanel, boolean)
	 */
	@Override
	public void showPopupPanel(final JPanel thePanel, boolean fixedSize) {
		this.showPopupPanel(thePanel, fixedSize, null);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.smartmatic.waffle.ecm.ui.menu.IGeneralMenuView#showPopupPanel(javax
	 * .swing.JPanel, boolean, javax.swing.JButton)
	 */
	@Override
	public void showPopupPanel(final JPanel thePanel, boolean fixedSize,
			JButton theCloseButton) {

		this.internalFrame = new JInternalFrame();

		this.internalFrame.setClosable(true);
		this.internalFrame
				.setDefaultCloseOperation(WindowConstants.DO_NOTHING_ON_CLOSE);
		this.internalFrame.setName("internalFrame"); // NOI18N
		this.internalFrame.setBounds(0, 0, 380, 290);
		this.glassPane.add(this.internalFrame,
				javax.swing.JLayeredPane.MODAL_LAYER);

		this.internalFrame.add(thePanel, BorderLayout.CENTER);

		int parentWidth = this.getWidth();
		int parentHeight = this.getHeight();

		if (fixedSize) {
			this.internalFrame.setSize(parentWidth - 100, parentHeight * 2 / 3);
			int frameWidth = this.internalFrame.getWidth();
			this.internalFrame.setLocation((parentWidth - frameWidth) / 2,
					parentHeight / 3);
		} else {
			this.internalFrame.pack();
			int frameWidth = this.internalFrame.getWidth();
			int frameHeight = this.internalFrame.getHeight();
			this.internalFrame.setLocation((parentWidth - frameWidth) / 2,
					(parentHeight - frameHeight) / 2);
		}

		/* Necessary to reset the JInternalFrame's closed property */
		this.glassPane.remove(this.internalFrame);
		this.glassPane.add(this.internalFrame, JLayeredPane.MODAL_LAYER);

		// removed popup menu
		this.internalFrame.setComponentPopupMenu(null);

		this.internalFrame.setVisible(true);
		this.internalFrameListener = new InternalFrameListener(thePanel);

		this.internalFrame.addInternalFrameListener(this.internalFrameListener);

		if (theCloseButton != null) {
			theCloseButton.addActionListener(new ActionListener() {

				@Override
				public void actionPerformed(ActionEvent theE) {
					GeneralMenuTabsViewPanel.this.internalFrame
							.doDefaultCloseAction();
					return;
				}
			});
		}

		MouseInputAdapter adapter = new MouseInputAdapter() {
		};

		this.glassPane.addMouseListener(adapter);
		this.glassPane.addMouseMotionListener(adapter);
		this.glassPane.setVisible(true);

		return;
	}

	/**
	 * Closes the popup.
	 */
	public void closePopup() {
		GeneralMenuTabsViewPanel.this.glassPane
				.remove(GeneralMenuTabsViewPanel.this.internalFrame);
		GeneralMenuTabsViewPanel.this.glassPane.setVisible(false);
		GeneralMenuTabsViewPanel.this.internalFrame
				.remove(this.internalFrameListener.getPanel());
		GeneralMenuTabsViewPanel.this.internalFrame
				.removeInternalFrameListener(this.internalFrameListener);
		GeneralMenuTabsViewPanel.this.internalFrame.dispose();
	}

	/**
	 * Returns a button from a map matched with the given functionality.
	 * 
	 * @param func
	 *            the functionality to match
	 * @return the button matched
	 */
	public JButton getButtonByFunctionality(FunctionalityDefinitionEnum func) {
		return this.mapButtons.get(func);
	}

	/**
	 * Blocks the screen while a process is occurring.
	 */
	public synchronized void blockScreen() {
		this.imageLoading = new JLabel(
				this.resourceMap.getIcon("imageLabel_reading.icon"));
		this.glassPane.add(this.imageLoading,
				javax.swing.JLayeredPane.MODAL_LAYER);
		int parentWidth = this.getWidth();
		int parentHeight = this.getHeight();

		this.imageLoading.setSize(parentWidth, parentHeight);
		int frameWidth = this.imageLoading.getWidth();
		int frameHeight = this.imageLoading.getHeight();
		this.imageLoading.setLocation((parentWidth - frameWidth) / 2,
				(parentHeight - frameHeight) / 2);
		this.glassPane.remove(this.imageLoading);

		this.imageLoading.setVisible(true);
		this.glassPane.add(this.imageLoading, JLayeredPane.MODAL_LAYER);
		MouseInputAdapter adapter = new MouseInputAdapter() {
		};

		this.glassPane.addMouseListener(adapter);
		this.glassPane.addMouseMotionListener(adapter);
		this.glassPane.setVisible(true);
	}

	/**
	 * Unblocks the screen.
	 */
	public synchronized void unblockScreen() {
		this.glassPane.remove(this.imageLoading);
		this.glassPane.setVisible(false);
		this.glassPane.updateUI();
		this.updateUI();
	}

	/**
	 * Set the title for the pane.
	 * 
	 * @param theTitle
	 *            the title
	 */
	public void setTitle(JLabel theTitle) {
		GeneralMenuTabsViewPanel.titled = theTitle;
	}

	/**
	 * The listener interface for receiving internalFrame events. The class that
	 * is interested in processing a internalFrame event implements this
	 * interface, and the object created with that class is registered with a
	 * component using the component's
	 * <code>addInternalFrameListener<code> method. When
	 * the internalFrame event occurs, that object's appropriate
	 * method is invoked.
	 * 
	 * @see InternalFrameEvent
	 */
	class InternalFrameListener extends InternalFrameAdapter {

		/** The inside. */
		JPanel inside;

		/**
		 * Instantiates a new internal frame listener.
		 * 
		 * @param panel
		 *            the panel
		 */
		public InternalFrameListener(JPanel panel) {
			this.inside = panel;
		}

		/*
		 * (non-Javadoc)
		 * 
		 * @see
		 * javax.swing.event.InternalFrameAdapter#internalFrameClosing(javax
		 * .swing.event.InternalFrameEvent)
		 */
		@Override
		public void internalFrameClosing(InternalFrameEvent theE) {
			if (this.inside instanceof IParentCloseable) {
				((IParentCloseable) this.inside)
						.fireParentClosedEvent(GeneralMenuTabsViewPanel.this);
			} else {
				closePopup();
			}
		}

		/**
		 * Gets the panel.
		 * 
		 * @return the panel
		 */
		public JPanel getPanel() {
			return this.inside;
		}
	}

	/**
	 * Blocks or unblocks all the tab panes which title is different than an
	 * given one.
	 * 
	 * @param block
	 *            Status of the other tab panes. True blocks the other tab
	 *            panes, false unblocks them all.
	 * @param tabTitles
	 *            the tab titles
	 * @author Mario Bislick (mario.bislick@smartmatic.com)
	 */
	public void blockTabpanes(boolean block, List<String> tabTitles) {
		this.funcContainerPane.blockUnactiveTabs(block, tabTitles);
	}

	/**
	 * Blocks or unblocks the exit tab button.
	 * 
	 * @param block
	 *            Status of exit tab button. <code>true</code> blocks tab while
	 *            <code>false</code> unblocks it.
	 * @author Mario Bislick (mario.bislick@smartmatic.com)
	 */
	public void blockExitTab(boolean block) {
		this.funcContainerPane.blockExitTab(block);
	}

	/**
	 * Sets all the panel tabs other than the ones related to one or more
	 * specific functionalities as enabled or disabled.
	 * 
	 * @param funcs
	 *            Sets of functionalities of the tabs to remain unchanged
	 * @param block
	 *            Status of the other panel tabs. <code>true</code> blocks all
	 *            the other tabs, <code>false</code> unblocks them.
	 * @author Mario Bislick (mario.bislick@smartmatic.com)
	 */
	public void blockOtherTabsByFunctionality(
			HashSet<FunctionalityDefinitionEnum> funcs, boolean block) {
		String tabText = null;
		List<String> tabTextPivot = new ArrayList<String>();
		List<String> otherTabs = new ArrayList<String>();
		for (BasicMenuItem item : this.categoryPanelMap.keySet()) {
			if (item instanceof MenuCategoryItem) {
				MenuCategoryItem menu = (MenuCategoryItem) item;
				Iterator<FunctionalityDefinitionEnum> it = menu.functionalities
						.iterator();
				for (; it.hasNext();) {
					if (!funcs.contains(it.next())) {
						tabText = menu.getCategoryTitle();
						otherTabs.add(tabText);
						// break;
					} else {
						tabTextPivot.add(menu.getCategoryTitle());
					}
				}
			} else {
				FunctionalityShortcutMenuItem function = (FunctionalityShortcutMenuItem) item;
				if (!funcs.contains(function.getFunctionality())) {
					tabText = function.getCategoryTitle();
					otherTabs.add(tabText);
				} else {
					tabTextPivot.add(function.getCategoryTitle());
				}

			}
		}

		if (tabTextPivot != null) {
			this.funcContainerPane.blockUnactiveTabs(block, tabTextPivot);
		}

	}

	/**
	 * Resizes the menu tabs.
	 */
	public void resizeTabs() {

		int compCount = this.funcContainerPane.getComponentCount();
		int maxWidth = this.funcContainerPane.getWidth() / 5;
		for (int i = 0; i < compCount; i++) {
			JPanel currentPanel = (JPanel) this.funcContainerPane
					.getComponentAt(i);
			Dimension panelSize = currentPanel.getSize();
			currentPanel.setMaximumSize(new Dimension(maxWidth, (int) panelSize
					.getHeight()));
		}
	}
}
