/**
 * ECMOptionPane.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */

package com.smartmatic.waffle.ecm.ui.util;

import java.awt.Component;
import java.awt.HeadlessException;
import java.awt.Window;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.List;
import java.util.Locale;

import javax.swing.Icon;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.SwingUtilities;
import javax.swing.UIManager;

import org.jdesktop.application.ResourceMap;

import com.smartmatic.waffle.domain.i18n.LanguageData;
import com.smartmatic.waffle.ecm.ui.core.i18n.controller.LanguageController;

// TODO: Auto-generated Javadoc
/**
 * The Class ECMOptionPane.
 * 
 * @version 1.0 (Mar 25, 2013)
 * @author Frederick Faria (frederick.faria@smartmatic.com)
 */
public class ECMOptionPane extends JOptionPane {

	/**
	 * Used for error messages.
	 */
	public static final String ERROR_DIALOG = "dialogError";
	/**
	 * Used for information messages.
	 */
	public static final String INFORMATION_DIALOG = "dialogInformation";
	/**
	 * Used for confirm messages.
	 */
	public static final String CONFIRM_DIALOG = "dialogConfirm";
	/**
	 * Used for confirm messages.
	 */
	public static final String WARNING_DIALOG = "dialogWarning";

	/**
	 * The Constant serialVersionUID.
	 */
	private static final long serialVersionUID = 7705627503384152604L;

	/**
	 * The options key of the buttons by default.
	 */
	private static String[] optionsKey = { "general.answer.yes",
			"general.answer.no" };

	/**
	 * Brings up an information-message dialog titled "Message".
	 * 
	 * @param parentComponent
	 *            determines the <code>Frame</code> in which the dialog is
	 *            displayed; if <code>null</code>, or if the
	 *            <code>parentComponent</code> has no <code>Frame</code>, a
	 *            default <code>Frame</code> is used
	 * @param message
	 *            the <code>Object</code> to display JDialog component name
	 * @param name
	 *            the name
	 * @throws HeadlessException
	 *             if <code>GraphicsEnvironment.isHeadless</code> returns
	 *             <code>true</code>
	 * @see java.awt.GraphicsEnvironment#isHeadless
	 */
	public static void showMessageDialog(Component parentComponent,
			Object message, String name) throws HeadlessException {
		showMessageDialog(parentComponent, message,
				UIManager.getString("OptionPane.messageDialogTitle"),
				INFORMATION_MESSAGE, name);
	}

	/**
	 * Brings up a dialog that displays a message using a default icon
	 * determined by the <code>messageType</code> parameter.
	 * 
	 * @param parentComponent
	 *            determines the <code>Frame</code> in which the dialog is
	 *            displayed; if <code>null</code>, or if the
	 *            <code>parentComponent</code> has no <code>Frame</code>, a
	 *            default <code>Frame</code> is used
	 * @param message
	 *            the <code>Object</code> to display
	 * @param title
	 *            the title string for the dialog
	 * @param messageType
	 *            the type of message to be displayed:
	 *            <code>ERROR_MESSAGE</code>, <code>INFORMATION_MESSAGE</code>,
	 *            <code>WARNING_MESSAGE</code>, <code>QUESTION_MESSAGE</code>,
	 *            or <code>PLAIN_MESSAGE</code>
	 * @param name
	 *            JDialog component name
	 * @throws HeadlessException
	 *             if <code>GraphicsEnvironment.isHeadless</code> returns
	 *             <code>true</code>
	 * @see java.awt.GraphicsEnvironment#isHeadless
	 */
	public static void showMessageDialog(Component parentComponent,
			Object message, String title, int messageType, String name)
			throws HeadlessException {
		showMessageDialog(parentComponent, message, title, messageType, null,
				name);
	}

	/**
	 * Brings up a dialog displaying a message, specifying all parameters.
	 * 
	 * @param parentComponent
	 *            determines the <code>Frame</code> in which the dialog is
	 *            displayed; if <code>null</code>, or if the
	 *            <code>parentComponent</code> has no <code>Frame</code>, a
	 *            default <code>Frame</code> is used
	 * @param message
	 *            the <code>Object</code> to display
	 * @param title
	 *            the title string for the dialog
	 * @param messageType
	 *            the type of message to be displayed:
	 *            <code>ERROR_MESSAGE</code>, <code>INFORMATION_MESSAGE</code>,
	 *            <code>WARNING_MESSAGE</code>, <code>QUESTION_MESSAGE</code>,
	 *            or <code>PLAIN_MESSAGE</code>
	 * @param icon
	 *            an icon to display in the dialog that helps the user identify
	 *            the kind of message that is being displayed
	 * @param name
	 *            JDialog component name
	 * @throws HeadlessException
	 *             if <code>GraphicsEnvironment.isHeadless</code> returns
	 *             <code>true</code>
	 * @see java.awt.GraphicsEnvironment#isHeadless
	 */
	public static void showMessageDialog(Component parentComponent,
			Object message, String title, int messageType, Icon icon,
			String name) throws HeadlessException {
		showOptionDialog(parentComponent, message, title, DEFAULT_OPTION,
				messageType, icon, null, null, name);
	}

	/**
	 * Brings up a dialog with the options <i>Yes</i>, <i>No</i> and
	 * <i>Cancel</i>; with the title, <b>Select an Option</b>.
	 * 
	 * @param parentComponent
	 *            determines the <code>Frame</code> in which the dialog is
	 *            displayed; if <code>null</code>, or if the
	 *            <code>parentComponent</code> has no <code>Frame</code>, a
	 *            default <code>Frame</code> is used
	 * @param message
	 *            the <code>Object</code> to display
	 * @param name
	 *            JDialog component name
	 * @return an integer indicating the option selected by the user
	 * @throws HeadlessException
	 *             if <code>GraphicsEnvironment.isHeadless</code> returns
	 *             <code>true</code>
	 * @see java.awt.GraphicsEnvironment#isHeadless
	 */
	public static int showConfirmDialog(Component parentComponent,
			Object message, String name) throws HeadlessException {
		return showConfirmDialog(parentComponent, message,
				UIManager.getString("OptionPane.titleText"),
				YES_NO_CANCEL_OPTION, name);
	}

	/**
	 * Brings up a dialog where the number of choices is determined by the
	 * <code>optionType</code> parameter.
	 * 
	 * @param parentComponent
	 *            determines the <code>Frame</code> in which the dialog is
	 *            displayed; if <code>null</code>, or if the
	 *            <code>parentComponent</code> has no <code>Frame</code>, a
	 *            default <code>Frame</code> is used
	 * @param message
	 *            the <code>Object</code> to display
	 * @param title
	 *            the title string for the dialog
	 * @param optionType
	 *            an int designating the options available on the dialog:
	 *            <code>YES_NO_OPTION</code>, <code>YES_NO_CANCEL_OPTION</code>,
	 *            or <code>OK_CANCEL_OPTION</code>
	 * @param name
	 *            JDialog component name
	 * @return an int indicating the option selected by the user
	 * @throws HeadlessException
	 *             if <code>GraphicsEnvironment.isHeadless</code> returns
	 *             <code>true</code>
	 * @see java.awt.GraphicsEnvironment#isHeadless
	 */
	public static int showConfirmDialog(Component parentComponent,
			Object message, String title, int optionType, String name)
			throws HeadlessException {
		return showConfirmDialog(parentComponent, message, title, optionType,
				QUESTION_MESSAGE, name);
	}

	/**
	 * Brings up a dialog where the number of choices is determined by the
	 * <code>optionType</code> parameter, where the <code>messageType</code>
	 * parameter determines the icon to display. The <code>messageType</code>
	 * parameter is primarily used to supply a default icon from the Look and
	 * Feel.
	 * 
	 * @param parentComponent
	 *            determines the <code>Frame</code> in which the dialog is
	 *            displayed; if <code>null</code>, or if the
	 *            <code>parentComponent</code> has no <code>Frame</code>, a
	 *            default <code>Frame</code> is used.
	 * @param message
	 *            the <code>Object</code> to display
	 * @param title
	 *            the title string for the dialog
	 * @param optionType
	 *            an integer designating the options available on the dialog:
	 *            <code>YES_NO_OPTION</code>, <code>YES_NO_CANCEL_OPTION</code>,
	 *            or <code>OK_CANCEL_OPTION</code>
	 * @param messageType
	 *            an integer designating the kind of message this is; primarily
	 *            used to determine the icon from the pluggable Look and Feel:
	 *            <code>ERROR_MESSAGE</code>, <code>INFORMATION_MESSAGE</code>,
	 *            <code>WARNING_MESSAGE</code>, <code>QUESTION_MESSAGE</code>,
	 *            or <code>PLAIN_MESSAGE</code>
	 * @param name
	 *            JDialog component name
	 * @return an integer indicating the option selected by the user
	 * @throws HeadlessException
	 *             if <code>GraphicsEnvironment.isHeadless</code> returns
	 *             <code>true</code>
	 * @see java.awt.GraphicsEnvironment#isHeadless
	 */
	public static int showConfirmDialog(Component parentComponent,
			Object message, String title, int optionType, int messageType,
			String name) throws HeadlessException {
		return showConfirmDialog(parentComponent, message, title, optionType,
				messageType, null, name);
	}

	/**
	 * Brings up a dialog with a specified icon, where the number of choices is
	 * determined by the <code>optionType</code> parameter. The
	 * <code>messageType</code> parameter is primarily used to supply a default
	 * icon from the look and feel.
	 * 
	 * @param parentComponent
	 *            determines the <code>Frame</code> in which the dialog is
	 *            displayed; if <code>null</code>, or if the
	 *            <code>parentComponent</code> has no <code>Frame</code>, a
	 *            default <code>Frame</code> is used
	 * @param message
	 *            the Object to display
	 * @param title
	 *            the title string for the dialog
	 * @param optionType
	 *            an int designating the options available on the dialog:
	 *            <code>YES_NO_OPTION</code>, <code>YES_NO_CANCEL_OPTION</code>,
	 *            or <code>OK_CANCEL_OPTION</code>
	 * @param messageType
	 *            an int designating the kind of message this is, primarily used
	 *            to determine the icon from the pluggable Look and Feel:
	 *            <code>ERROR_MESSAGE</code>, <code>INFORMATION_MESSAGE</code>,
	 *            <code>WARNING_MESSAGE</code>, <code>QUESTION_MESSAGE</code>,
	 *            or <code>PLAIN_MESSAGE</code>
	 * @param icon
	 *            the icon to display in the dialog
	 * @param name
	 *            JDialog component name
	 * @return an int indicating the option selected by the user
	 * @throws HeadlessException
	 *             if <code>GraphicsEnvironment.isHeadless</code> returns
	 *             <code>true</code>
	 * @see java.awt.GraphicsEnvironment#isHeadless
	 */
	public static int showConfirmDialog(Component parentComponent,
			Object message, String title, int optionType, int messageType,
			Icon icon, String name) throws HeadlessException {
		return showOptionDialog(parentComponent, message, title, optionType,
				messageType, icon, null, null, name);
	}

	/**
	 * Brings up a dialog with a specified icon, where the number of choices is
	 * determined by the <code>optionType</code> parameter.
	 * <p>
	 * If <code>optionType</code> is <code>YES_NO_OPTION</code>, or
	 * <code>YES_NO_CANCEL_OPTION</code> and the <code>options</code> parameter
	 * is <code>null</code>, then the options are supplied by the look and feel.
	 * <p>
	 * The <code>messageType</code> parameter is primarily used to supply a
	 * default icon from the look and feel.
	 * 
	 * @param parentComponent
	 *            determines the <code>Frame</code> in which the dialog is
	 *            displayed; if <code>null</code>, or if the
	 *            <code>parentComponent</code> has no <code>Frame</code>, a
	 *            default <code>Frame</code> is used
	 * @param message
	 *            the <code>Object</code> to display
	 * @param title
	 *            the title string for the dialog
	 * @param optionType
	 *            an integer designating the options available on the dialog:
	 *            <code>DEFAULT_OPTION</code>, <code>YES_NO_CANCEL_OPTION</code>
	 *            , <code>YES_NO_OPTION</code> or <code>OK_CANCEL_OPTION</code>
	 * @param messageType
	 *            an integer designating the kind of message this is, primarily
	 *            used to determine the icon from the pluggable Look and Feel:
	 *            <code>ERROR_MESSAGE</code>, <code>INFORMATION_MESSAGE</code>,
	 *            <code>WARNING_MESSAGE</code>, <code>QUESTION_MESSAGE</code>,
	 *            or <code>PLAIN_MESSAGE</code>
	 * @param icon
	 *            the icon to display in the dialog
	 * @param options
	 *            an array of objects indicating the possible choices the user
	 *            can make; if the objects are components, they are rendered
	 *            properly; non-<code>String</code> objects are rendered using
	 *            their <code>toString</code> methods; if this parameter is
	 *            <code>null</code>, the options are determined by the Look and
	 *            Feel
	 * @param name
	 *            the name
	 * @return an integer indicating the option chosen by the user, or
	 *         <code>CLOSED_OPTION</code> if the user closed the dialog
	 * @see javax.swing.JOptionPane
	 */
	public static int showPopUpOptionDialog(Component parentComponent,
			Object message, String title, int optionType, int messageType,
			Icon icon, Object[] options, String name) {

		int result = showOptionDialog(parentComponent, message, title,
				optionType, messageType, icon, options, null, name);

		return result;
	}

	/**
	 * Brings up a dialog with a specified icon, where the number of choices is
	 * determined by the <code>optionType</code> parameter.
	 * <p>
	 * If <code>optionType</code> is <code>YES_NO_OPTION</code>, or
	 * <code>YES_NO_CANCEL_OPTION</code> and the <code>options</code> parameter
	 * is <code>null</code>, then the options are supplied by the look and feel.
	 * <p>
	 * The <code>messageType</code> parameter is primarily used to supply a
	 * default icon from the look and feel.
	 * 
	 * @param parentComponent
	 *            determines the <code>Frame</code> in which the dialog is
	 *            displayed; if <code>null</code>, or if the
	 *            <code>parentComponent</code> has no <code>Frame</code>, a
	 *            default <code>Frame</code> is used
	 * @param messageKey
	 *            the key of the string message to display
	 * @param titleKey
	 *            the key of the string title for the dialog
	 * @param optionType
	 *            an integer designating the options available on the dialog:
	 *            <code>DEFAULT_OPTION</code>, <code>YES_NO_OPTION</code> or
	 *            <code>OK_CANCEL_OPTION</code>
	 * @param messageType
	 *            an integer designating the kind of message this is, primarily
	 *            used to determine the icon from the pluggable Look and Feel:
	 *            <code>ERROR_MESSAGE</code>, <code>INFORMATION_MESSAGE</code>,
	 *            <code>WARNING_MESSAGE</code>, <code>QUESTION_MESSAGE</code>,
	 *            or <code>PLAIN_MESSAGE</code>
	 * @param icon
	 *            the icon to display in the dialog
	 * @param optionsKey
	 *            an array of key of the strings indicating the possible choices
	 *            the user can make; if this parameter is <code>null</code>, the
	 *            options are determined by the <code>optionsKey</code> array.
	 * @param languages
	 *            the language list to use in the popup.
	 * @param name
	 *            the name
	 * @return an integer indicating the option chosen by the user, or
	 *         <code>CLOSED_OPTION</code> if the user closed the dialog
	 * @see javax.swing.JOptionPane
	 */
	public static int showPopUpOptionDialog(Component parentComponent,
			String messageKey, String titleKey, int optionType,
			int messageType, Icon icon, String[] optionsKey,
			List<LanguageData> languages, String name) {

		ResourceMap resourceMap = null;

		String title = "";
		String question = "";
		String ok = "";
		String cancel = "";

		LanguageController lc = LanguageController.getInstance();
		LanguageData currentLanguage = lc.getSelectedLanguage();
		Locale currentLocal = Locale.getDefault();
		boolean isFirst = true;
		Locale selectedLocale = null;

		if (optionsKey == null) {
			optionsKey = ECMOptionPane.optionsKey;
		}

		for (LanguageData lang : lc.getLanguageList()) {
			if (!isFirst) {
				title += " / ";
				question += "\n\n";
				ok += " / ";
				cancel += " / ";
			} else {
				isFirst = false;
			}
			lc.setSelectedLanguage(lang);
			selectedLocale = lc.getLocaleFromLanguage(lang);
			Locale.setDefault(selectedLocale);
			resourceMap = lc.getResourceMap();
			title += resourceMap.getString(titleKey);
			question += resourceMap.getString(messageKey);
			ok += resourceMap.getString(optionsKey[0]);

			cancel += resourceMap.getString(optionsKey[1]);
		}
		if (currentLanguage == null) {
			lc.setSelectedLanguage(null);
		} else {
			lc.setSelectedLanguage(currentLanguage);
		}
		Locale.setDefault(currentLocal);

		String[] options = { ok, cancel };

		int result = showOptionDialog(parentComponent, question, title,
				optionType, messageType, icon, options, null, name);

		return result;
	}

	/**
	 * Brings up a dialog with a specified icon, where the number of choices is
	 * determined by the <code>optionType</code> parameter.
	 * <p>
	 * If <code>optionType</code> is <code>YES_NO_OPTION</code>, or
	 * <code>YES_NO_CANCEL_OPTION</code> and the <code>options</code> parameter
	 * is <code>null</code>, then the options are supplied by the look and feel.
	 * <p>
	 * The <code>messageType</code> parameter is primarily used to supply a
	 * default icon from the look and feel.
	 * 
	 * @param parentComponent
	 *            determines the <code>Frame</code> in which the dialog is
	 *            displayed; if <code>null</code>, or if the
	 *            <code>parentComponent</code> has no <code>Frame</code>, a
	 *            default <code>Frame</code> is used
	 * @param messageKey
	 *            the key of the string message to display
	 * @param titleKey
	 *            the key of the string title for the dialog
	 * @param optionType
	 *            an integer designating the options available on the dialog:
	 *            <code>DEFAULT_OPTION</code>, <code>YES_NO_OPTION</code> or
	 *            <code>OK_CANCEL_OPTION</code>
	 * @param messageType
	 *            an integer designating the kind of message this is, primarily
	 *            used to determine the icon from the pluggable Look and Feel:
	 *            <code>ERROR_MESSAGE</code>, <code>INFORMATION_MESSAGE</code>,
	 *            <code>WARNING_MESSAGE</code>, <code>QUESTION_MESSAGE</code>,
	 *            or <code>PLAIN_MESSAGE</code>
	 * @param icon
	 *            the icon to display in the dialog
	 * @param optionsKey
	 *            an array of key of the strings indicating the possible choices
	 *            the user can make; if this parameter is <code>null</code>, the
	 *            options are determined by the <code>optionsKey</code> array.
	 * @param resourceMap
	 *            the resource map of the language to use in the popup.
	 * @param name
	 *            the name
	 * @return an integer indicating the option chosen by the user, or
	 *         <code>CLOSED_OPTION</code> if the user closed the dialog
	 * @see javax.swing.JOptionPane
	 */
	public static int showPopUpOptionDialog(Component parentComponent,
			String messageKey, String titleKey, int optionType,
			int messageType, Icon icon, String[] optionsKey,
			ResourceMap resourceMap, String name) {

		String title = resourceMap.getString(titleKey);
		String message = resourceMap.getString(messageKey);

		return showOptionDialog(parentComponent, message, title, optionType,
				messageType, icon, null, null, name);
	}

	/**
	 * Brings up a dialog with a specified icon, where the initial choice is
	 * determined by the <code>initialValue</code> parameter and the number of
	 * choices is determined by the <code>optionType</code> parameter.
	 * <p>
	 * If <code>optionType</code> is <code>YES_NO_OPTION</code>, or
	 * <code>YES_NO_CANCEL_OPTION</code> and the <code>options</code> parameter
	 * is <code>null</code>, then the options are supplied by the look and feel.
	 * <p>
	 * The <code>messageType</code> parameter is primarily used to supply a
	 * default icon from the look and feel.
	 * 
	 * @param parentComponent
	 *            determines the <code>Frame</code> in which the dialog is
	 *            displayed; if <code>null</code>, or if the
	 *            <code>parentComponent</code> has no <code>Frame</code>, a
	 *            default <code>Frame</code> is used
	 * @param message
	 *            the <code>Object</code> to display
	 * @param title
	 *            the title string for the dialog
	 * @param optionType
	 *            an integer designating the options available on the dialog:
	 *            <code>DEFAULT_OPTION</code>, <code>YES_NO_OPTION</code>,
	 *            <code>YES_NO_CANCEL_OPTION</code>, or
	 *            <code>OK_CANCEL_OPTION</code>
	 * @param messageType
	 *            an integer designating the kind of message this is, primarily
	 *            used to determine the icon from the pluggable Look and Feel:
	 *            <code>ERROR_MESSAGE</code>, <code>INFORMATION_MESSAGE</code>,
	 *            <code>WARNING_MESSAGE</code>, <code>QUESTION_MESSAGE</code>,
	 *            or <code>PLAIN_MESSAGE</code>
	 * @param icon
	 *            the icon to display in the dialog
	 * @param options
	 *            an array of objects indicating the possible choices the user
	 *            can make; if the objects are components, they are rendered
	 *            properly; non-<code>String</code> objects are rendered using
	 *            their <code>toString</code> methods; if this parameter is
	 *            <code>null</code>, the options are determined by the Look and
	 *            Feel
	 * @param initialValue
	 *            the object that represents the default selection for the
	 *            dialog; only meaningful if <code>options</code> is used; can
	 *            be <code>null</code>
	 * @param name
	 *            JDialog component name
	 * @return an integer indicating the option chosen by the user, or
	 *         <code>CLOSED_OPTION</code> if the user closed the dialog
	 * @see java.awt.GraphicsEnvironment#isHeadless
	 */
	public static int showOptionDialog(Component parentComponent,
			Object message, String title, int optionType, int messageType,
			Icon icon, Object[] options, Object initialValue, String name) {

		String optionOk = "";
		String optionCancel = "";

		java.util.ResourceBundle bundle = java.util.ResourceBundle
				.getBundle("com/smartmatic/waffle/ecm/client/resources/ECMApp");// NOI18N

		JOptionPane pane = new JOptionPane(getMessageLabels(message, name),
				messageType, optionType, icon);

		if (options == null) {
			if (name.equals(ECMOptionPane.ERROR_DIALOG)
					|| name.equals(ECMOptionPane.INFORMATION_DIALOG)) {
				optionOk = "Ok";
			} else {
				optionOk = bundle.getString(ECMOptionPane.optionsKey[0]);
			}
			optionCancel = bundle.getString(ECMOptionPane.optionsKey[1]);
		} else {
			if (options instanceof String[]) {
				optionOk = options[0].toString();
				optionCancel = options[1].toString();
				options = null;
			}
		}
		pane.setOptions(getOptions(pane, name, optionOk, optionCancel));
		pane.setInitialValue(initialValue);
		pane.setComponentOrientation(((parentComponent == null) ? getRootFrame()
				: parentComponent).getComponentOrientation());
		pane.setMessageType(messageType);

		JDialog dialog = pane.createDialog(parentComponent, title);

		dialog.setName(name);

		pane.selectInitialValue();
		dialog.show();
		dialog.dispose();

		Object selectedValue = pane.getValue();

		if (selectedValue == null) {
			return CLOSED_OPTION;
		}
		if (options == null) {
			if (selectedValue instanceof Integer) {
				return ((Integer) selectedValue).intValue();
			}
			return CLOSED_OPTION;
		}
		for (int counter = 0, maxCounter = options.length; counter < maxCounter; counter++) {
			if (options[counter].equals(selectedValue)) {
				return counter;
			}
		}
		return CLOSED_OPTION;
	}

	/**
	 * Gets the options.
	 * 
	 * @param pane
	 *            the pane
	 * @param name
	 *            the name
	 * @param buttonOkText
	 *            the button ok text
	 * @param buttonNoText
	 *            the button no text
	 * @return the options
	 */
	private static JButton[] getOptions(final JOptionPane pane, String name,
			String buttonOkText, String buttonNoText) {
		JButton[] buttons = null;
		String dialogType = Character.toUpperCase(name.charAt(0))
				+ name.substring(1);
		final JButton buttonOk = new JButton(buttonOkText);
		buttonOk.setName("buttonOk" + dialogType);
		buttonOk.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				pane.setValue(JOptionPane.OK_OPTION);
				Window w = SwingUtilities.getWindowAncestor(buttonOk);
				if (w != null) {
					w.setVisible(false);
				}
			}
		});

		if (name.equals(ECMOptionPane.CONFIRM_DIALOG)) {
			final JButton buttonCancel = new JButton(buttonNoText);
			buttonCancel.setName("buttonCancel" + dialogType);
			buttonCancel.addActionListener(new ActionListener() {
				@Override
				public void actionPerformed(ActionEvent e) {
					/* close the dialog */
					Window w = SwingUtilities.getWindowAncestor(buttonCancel);
					if (w != null) {
						w.setVisible(false);
					}
				}
			});
			buttons = new JButton[] { buttonOk, buttonCancel };
		} else {
			buttons = new JButton[] { buttonOk };
		}
		return buttons;
	}

	/**
	 * Gets the message labels.
	 * 
	 * @param message
	 *            the message
	 * @param name
	 *            the name
	 * @return the message labels
	 */
	private static JLabel[] getMessageLabels(Object message, String name) {

		String[] lines = message.toString().split("\\n");
		JLabel[] labels = new JLabel[lines.length];
		for (int i = 0; i < lines.length; i++) {
			labels[i] = new JLabel(lines[i]);
			labels[i].setName("label" + name);
		}

		return labels;
	}

}
