/**
 * GUIComponentUtil.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.ui.util;

import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.FontMetrics;
import java.awt.GridBagConstraints;
import java.awt.HeadlessException;
import java.awt.Toolkit;
import java.text.BreakIterator;

import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.SwingUtilities;
import javax.swing.WindowConstants;

/**
 * The Class GUIComponentUtil.
 */
public class GUIComponentUtil {

	/**
	 * Builds the constraints.
	 * 
	 * @param col
	 *            the col
	 * @param row
	 *            the row
	 * @param resize
	 *            the resize
	 * @param insets
	 *            the insets
	 * @return the grid bag constraints
	 */
	public static GridBagConstraints buildConstraints(int col, int row,
			boolean resize, boolean insets) {
		java.awt.GridBagConstraints gridBagConstraints = new GridBagConstraints();
		gridBagConstraints = new java.awt.GridBagConstraints();
		if (col >= 0) {
			gridBagConstraints.gridx = col;
		}
		gridBagConstraints.gridy = row;
		if (resize) {
			gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		}
		gridBagConstraints.weightx = 1.0;
		gridBagConstraints.weighty = 1.0;
		if (insets) {
			gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
		} else {
			gridBagConstraints.insets = new java.awt.Insets(0, 2, 0, 2);
		}

		return gridBagConstraints;
	}

	/**
	 * Wrap label text.
	 * 
	 * @param label
	 *            the label
	 * @param text
	 *            the text
	 */
	public static void wrapLabelText(JLabel label, String text) {
		wrapLabelText(label, text, 0);
	}

	/**
	 * Wrap label text.
	 * 
	 * @param label
	 *            the label
	 * @param text
	 *            the text
	 * @param width
	 *            the width
	 */
	public static void wrapLabelText(JLabel label, String text, int width) {
		FontMetrics fm = label.getFontMetrics(label.getFont());
		int containerWidth = width;

		if (!text.contains("<html>")) {
			if (containerWidth < 1) {
				Container container = label.getParent();
				if (container != null) {
					containerWidth = container.getWidth();
				} else {
					containerWidth = label.getWidth();
				}

			}

			BreakIterator boundary = BreakIterator.getWordInstance();
			boundary.setText(text);

			StringBuffer trial = new StringBuffer();
			StringBuffer real = new StringBuffer("<html>");

			int start = boundary.first();
			for (int end = boundary.next(); end != BreakIterator.DONE; start = end, end = boundary
					.next()) {
				String word = text.substring(start, end);
				trial.append(word);
				int trialWidth = SwingUtilities.computeStringWidth(fm,
						trial.toString());
				if (trialWidth > containerWidth) {
					trial = new StringBuffer(word);
					real.append("</br>");
				}
				real.append(word);
			}

			real.append("</html>");

			label.setText(real.toString());
		}

	}

	/**
	 * Gets the calculated size.
	 * 
	 * @param component
	 *            the component
	 * @return the calculated size
	 * @throws HeadlessException
	 *             the headless exception
	 * @throws NumberFormatException
	 *             the number format exception
	 */
	public static Dimension getCalculatedSize(Component component)
			throws HeadlessException, NumberFormatException {
		Dimension size = Toolkit.getDefaultToolkit().getScreenSize();

		if ((component != null) && (component instanceof JDialog)) {
			((JDialog) component)
					.setDefaultCloseOperation(WindowConstants.DO_NOTHING_ON_CLOSE);
		}

		if (Boolean.getBoolean("nofullscreenmodal")) {
			if (Boolean.getBoolean("landscapemodal")) {
				size = new Dimension(1024, 600);
			} else {
				size = new Dimension(768, 1024);
			}
			if ((component != null) && component instanceof JDialog) {
				((JDialog) component)
						.setDefaultCloseOperation(WindowConstants.HIDE_ON_CLOSE);
			}
		}

		if (System.getProperty("resolution") != null) {
			String[] resolution = System.getProperty("resolution").split("x");
			if (resolution.length == 2) {
				Dimension desktopSize = size;

				size = new Dimension(Integer.parseInt(resolution[0].trim()),
						Integer.parseInt(resolution[1].trim()));

				if ((component != null) && (component instanceof JDialog)) {
					((JDialog) component).setLocation(
							(desktopSize.width - size.width) / 2,
							(desktopSize.height - size.height) / 2);
				}
			}
		}
		return size;
	}

	/**
	 * Checks if is landscape.
	 * 
	 * @param component
	 *            the component
	 * @return true, if is landscape
	 */
	public static boolean isLandscape(Component component) {
		boolean isLandscape;
		Dimension size = getCalculatedSize(component);
		isLandscape = (size.width > size.height);
		return isLandscape;
	}

	/**
	 * Gets the html formatted text.
	 * 
	 * @param text
	 *            the text
	 * @param color
	 *            the color
	 * @param fontDef
	 *            the font def
	 * @param align
	 *            the align
	 * @return the html formatted text
	 */
	public static String getHtmlFormattedText(String text, String color,
			String fontDef, String align) {
		StringBuffer contentBuffer = new StringBuffer();
		String style = "";
		contentBuffer.append("<html>");

		contentBuffer.append("<div align=\"" + align + "\">");

		contentBuffer.append("<font ");

		if (color != null && color.length() > 0) {
			contentBuffer.append("color=\"");
			contentBuffer.append(color);
			contentBuffer.append("\"");
		}

		if (fontDef != null && fontDef.length() > 0) {
			String[] ftAtt = fontDef.split("-");
			contentBuffer.append(" face=\"");
			contentBuffer.append(ftAtt[0]);
			contentBuffer.append("\"");
			style = ftAtt[1];
			contentBuffer.append(" size=\"");
			int s = Integer.parseInt(ftAtt[2]);
			if (s > 11) {
				s = s - 11;
			}
			contentBuffer.append(s);
			contentBuffer.append("\"");
		}

		contentBuffer.append(" >");

		text = getBoldOrItalicTagged(text, style);

		contentBuffer.append(text);

		contentBuffer.append("</font>");

		contentBuffer.append("</div>");

		contentBuffer.append("</html>");

		return contentBuffer.toString();
	}

	/**
	 * Gets the bold or italic tagged.
	 * 
	 * @param text
	 *            the text
	 * @param style
	 *            the style
	 * @return the bold or italic tagged
	 */
	private static String getBoldOrItalicTagged(String text, String style) {
		if (style.length() > 0) {
			if (style.toUpperCase().contains("BOLD")) {
				text = "<b>" + text + "</b>";
			}
			if (style.toUpperCase().contains("ITALIC")) {
				text = "<i>" + text + "</i>";
			}
		}
		return text;
	}
}
