/**
 * VotingExperienceDialog.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.ui.votingexperience;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;

import javax.swing.AbstractButton;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.Timer;

import com.smartmatic.waffle.ecm.ui.BaseFullScreenJDialog;
import com.smartmatic.waffle.ecm.ui.BlockingMessageDialog;
import com.smartmatic.waffle.ecm.ui.util.GUIComponentUtil;

/**
 * Dialog used to display and select the choices that the voter chooses in its
 * voting experience.
 */
public class VotingExperienceDialog extends BaseFullScreenJDialog implements
		FocusListener {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 1L;

	/** The Constant DISABLED. */
	static final String DISABLED = "DISABLED";

	/** The instance. */
	public static VotingExperienceDialog instance;

	/** The invalid message dialog. */
	private BlockingMessageDialog invalidMessageDialog;

	/**
	 * Instantiates a new voting experience dialog.
	 * 
	 * @param parent
	 *            the parent
	 * @param modal
	 *            the modal
	 */
	public VotingExperienceDialog(java.awt.Frame parent, boolean modal) {
		super(parent, modal);
		this.addFocusListener(this);
		VotingExperienceDialog.instance = this;

		this.initVotinExperience();
	}

	/**
	 * Instantiates a new voting experience dialog.
	 * 
	 * @param parent
	 *            the parent
	 * @param modal
	 *            the modal
	 */
	public VotingExperienceDialog(JDialog parent, boolean modal) {
		super(parent, modal);

		this.addFocusListener(this);
		VotingExperienceDialog.instance = this;
		this.initVotinExperience();
	}

	/**
	 * Inits the votin experience.
	 */
	private void initVotinExperience() {
		this.initComponents();
		this.resizeStraightPartyButton();
	}

	/**
	 * Resize straight party button.
	 */
	private void resizeStraightPartyButton() {
		this.straightPartyButton.setIcon(this.resourceMap
				.getImageIcon("straightButton.icon"));
		this.straightPartyButton.setSelectedIcon(this.resourceMap
				.getImageIcon("straightButton.selected.icon"));
	}

	/**
	 * Holds the number of selections performed by the voter.
	 */
	int selectionCount = 0;

	/**
	 * This method is called from within the constructor to initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is always
	 * regenerated by the Form Editor.
	 */
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// desc="Generated Code">//GEN-BEGIN:initComponents
	private void initComponents() {

		this.optionsPanelScrollable = new javax.swing.JScrollPane();
		this.partyOptionsPanel = new javax.swing.JPanel();
		this.nextButton = new javax.swing.JButton();
		this.resetButton = new javax.swing.JButton();
		this.upperPanel = new javax.swing.JPanel();
		this.straightPartyButton = new javax.swing.JRadioButton();
		javax.swing.JPanel jPanel1 = new javax.swing.JPanel();
		this.contestNameLabel = new javax.swing.JTextPane();
		this.partyNameLabel = new javax.swing.JTextPane();

		this.contestNameLabel.setOpaque(false);

		this.contestNameLabel.setBorder(null);
		this.partyNameLabel.setBorder(null);

		this.contestNameLabel.setEditable(false);
		this.partyNameLabel.setEditable(false);

		this.contestNameLabel.setContentType("text/html");
		this.partyNameLabel.setContentType("text/html");

		Dimension buttonSize = new Dimension(250, 100);
		this.nextButton.setPreferredSize(buttonSize);
		this.nextButton.setMinimumSize(buttonSize);
		this.nextButton.setMaximumSize(buttonSize);

		this.resetButton.setPreferredSize(buttonSize);
		this.resetButton.setMinimumSize(buttonSize);
		this.resetButton.setMaximumSize(buttonSize);

		this.setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);

		this.optionsPanelScrollable.setBorder(javax.swing.BorderFactory
				.createEtchedBorder());
		this.optionsPanelScrollable.setName("optionsPanelScrollable"); // NOI18N

		this.partyOptionsPanel.setName("partyOptionsPanel"); // NOI18N

		javax.swing.GroupLayout partyOptionsPanelLayout = new javax.swing.GroupLayout(
				this.partyOptionsPanel);
		this.partyOptionsPanel.setLayout(partyOptionsPanelLayout);
		partyOptionsPanelLayout.setHorizontalGroup(partyOptionsPanelLayout
				.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addGap(0, 944, Short.MAX_VALUE));
		partyOptionsPanelLayout.setVerticalGroup(partyOptionsPanelLayout
				.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addGap(0, 440, Short.MAX_VALUE));

		this.optionsPanelScrollable.setViewportView(this.partyOptionsPanel);

		this.optionsPanelScrollable.setBorder(javax.swing.BorderFactory
				.createEmptyBorder());

		this.nextButton.setFont(this.nextButton.getFont().deriveFont(
				this.nextButton.getFont().getStyle() | java.awt.Font.BOLD));
		this.nextButton.setText(this
				.getString("voting.experience.vote.button.text"));
		this.nextButton.setFocusPainted(false);
		this.nextButton.setName("nextButton"); // NOI18N
		this.nextButton.addActionListener(new java.awt.event.ActionListener() {
			@Override
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				if (VotingExperienceDialog.DISABLED.equals(((JButton) evt
						.getSource()).getActionCommand())) {
					VotingExperienceDialog.this.invalidActionPerformed();
				} else {
					VotingExperienceDialog.this.nextButtonActionPerformed(evt);
				}

			}
		});

		this.resetButton.setFont(this.resetButton.getFont().deriveFont(
				this.resetButton.getFont().getStyle() | java.awt.Font.BOLD));
		this.resetButton.setText(this.getString("BACK.BUTTON.TEXT"));
		this.resetButton.setFocusPainted(false);
		this.resetButton.setName("resetButton"); // NOI18N
		this.resetButton.addActionListener(new java.awt.event.ActionListener() {
			@Override
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				VotingExperienceDialog.this.resetButtonActionPerformed(evt);
			}
		});

		this.upperPanel.setBorder(javax.swing.BorderFactory
				.createEtchedBorder());
		this.upperPanel.setName("upperPanel"); // NOI18N
		this.upperPanel.setLayout(new javax.swing.BoxLayout(this.upperPanel,
				javax.swing.BoxLayout.LINE_AXIS));

		this.straightPartyButton.setIcon(this.resourceMap
				.getIcon("straightButton.icon")); // NOI18N
		this.straightPartyButton.setName("straightPartyButton"); // NOI18N
		this.straightPartyButton
				.addActionListener(new java.awt.event.ActionListener() {
					@Override
					public void actionPerformed(java.awt.event.ActionEvent evt) {
						VotingExperienceDialog.this
								.straightPartyButtonActionPerformed(evt);
					}
				});
		this.upperPanel.add(this.straightPartyButton);

		jPanel1.setName("jPanel1"); // NOI18N

		javax.swing.GroupLayout jPanel1Layout = new javax.swing.GroupLayout(
				jPanel1);
		jPanel1.setLayout(jPanel1Layout);

		this.contestNameLabel.setName("contestNameLabel"); // NOI18N

		this.partyNameLabel.setName("partyNameLabel"); // NOI18N
		this.partyNameLabel.setOpaque(true);

		jPanel1Layout.setHorizontalGroup(jPanel1Layout.createParallelGroup(
				javax.swing.GroupLayout.Alignment.LEADING).addGroup(
				jPanel1Layout
						.createSequentialGroup()
						.addComponent(this.partyNameLabel, 300, 300, 300)
						.addComponent(this.contestNameLabel, 300, 300,
								Short.MAX_VALUE)));
		jPanel1Layout
				.setVerticalGroup(jPanel1Layout
						.createParallelGroup(
								javax.swing.GroupLayout.Alignment.LEADING)
						.addGroup(
								jPanel1Layout
										.createSequentialGroup()
										.addGroup(
												jPanel1Layout
														.createParallelGroup(
																javax.swing.GroupLayout.Alignment.BASELINE)
														.addComponent(
																this.partyNameLabel,
																40, 40, 40)
														.addComponent(
																this.contestNameLabel,
																40, 40, 40))));

		this.upperPanel.add(jPanel1);

		this.paintButtonsLayout(true, true);
	}// </editor-fold>//GEN-END:initComponents

	/**
	 * Paint buttons layout.
	 * 
	 * @param resetButtonVisible
	 *            the reset button visible
	 * @param nextButtonVisible
	 *            the next button visible
	 */
	public void paintButtonsLayout(boolean resetButtonVisible,
			boolean nextButtonVisible) {
		javax.swing.GroupLayout layout = new javax.swing.GroupLayout(
				this.getContentPane());
		this.getContentPane().setLayout(layout);

		this.resetButton.setVisible(resetButtonVisible);

		this.nextButton.setVisible(nextButtonVisible);

		if (resetButtonVisible && nextButtonVisible) {
			layout.setHorizontalGroup(layout
					.createParallelGroup(
							javax.swing.GroupLayout.Alignment.LEADING)
					.addGroup(
							layout.createSequentialGroup()
									.addContainerGap()
									.addComponent(
											this.resetButton,
											javax.swing.GroupLayout.PREFERRED_SIZE,
											javax.swing.GroupLayout.PREFERRED_SIZE,
											javax.swing.GroupLayout.PREFERRED_SIZE)
									.addPreferredGap(
											javax.swing.LayoutStyle.ComponentPlacement.RELATED,
											238, Short.MAX_VALUE)
									.addComponent(
											this.nextButton,
											javax.swing.GroupLayout.PREFERRED_SIZE,
											javax.swing.GroupLayout.PREFERRED_SIZE,
											javax.swing.GroupLayout.PREFERRED_SIZE)
									.addContainerGap())
					.addComponent(this.upperPanel,
							javax.swing.GroupLayout.DEFAULT_SIZE, 469,
							Short.MAX_VALUE)
					.addComponent(this.optionsPanelScrollable,
							javax.swing.GroupLayout.Alignment.TRAILING,
							javax.swing.GroupLayout.DEFAULT_SIZE, 469,
							Short.MAX_VALUE));
			layout.setVerticalGroup(layout
					.createParallelGroup(
							javax.swing.GroupLayout.Alignment.LEADING)
					.addGroup(
							layout.createSequentialGroup()
									.addComponent(this.upperPanel, 40, 40, 40)
									.addComponent(
											this.optionsPanelScrollable,
											javax.swing.GroupLayout.DEFAULT_SIZE,
											344, Short.MAX_VALUE)
									.addPreferredGap(
											javax.swing.LayoutStyle.ComponentPlacement.RELATED)
									.addGroup(
											layout.createParallelGroup(
													javax.swing.GroupLayout.Alignment.TRAILING,
													false)
													.addComponent(
															this.resetButton,
															javax.swing.GroupLayout.PREFERRED_SIZE,
															javax.swing.GroupLayout.PREFERRED_SIZE,
															javax.swing.GroupLayout.PREFERRED_SIZE)
													.addComponent(
															this.nextButton,
															javax.swing.GroupLayout.PREFERRED_SIZE,
															javax.swing.GroupLayout.PREFERRED_SIZE,
															javax.swing.GroupLayout.PREFERRED_SIZE))
									.addContainerGap()));
		} else if (nextButtonVisible) {
			layout.setHorizontalGroup(layout
					.createParallelGroup(
							javax.swing.GroupLayout.Alignment.LEADING)
					.addGroup(
							layout.createSequentialGroup()
									.addContainerGap(380, Short.MAX_VALUE)
									.addComponent(
											this.nextButton,
											javax.swing.GroupLayout.PREFERRED_SIZE,
											javax.swing.GroupLayout.PREFERRED_SIZE,
											javax.swing.GroupLayout.PREFERRED_SIZE)
									.addContainerGap(380, Short.MAX_VALUE))
					.addComponent(this.upperPanel,
							javax.swing.GroupLayout.DEFAULT_SIZE, 469,
							Short.MAX_VALUE)
					.addComponent(this.optionsPanelScrollable,
							javax.swing.GroupLayout.Alignment.TRAILING,
							javax.swing.GroupLayout.DEFAULT_SIZE, 469,
							Short.MAX_VALUE));
			layout.setVerticalGroup(layout
					.createParallelGroup(
							javax.swing.GroupLayout.Alignment.LEADING)
					.addGroup(
							layout.createSequentialGroup()
									.addComponent(this.upperPanel, 40, 40, 40)
									.addComponent(
											this.optionsPanelScrollable,
											javax.swing.GroupLayout.DEFAULT_SIZE,
											344, Short.MAX_VALUE)
									.addPreferredGap(
											javax.swing.LayoutStyle.ComponentPlacement.RELATED)
									.addGroup(
											layout.createParallelGroup(
													javax.swing.GroupLayout.Alignment.TRAILING,
													false)
													.addComponent(
															this.nextButton,
															javax.swing.GroupLayout.PREFERRED_SIZE,
															javax.swing.GroupLayout.PREFERRED_SIZE,
															javax.swing.GroupLayout.PREFERRED_SIZE))
									.addContainerGap()));
		} else if (resetButtonVisible) {
			layout.setHorizontalGroup(layout
					.createParallelGroup(
							javax.swing.GroupLayout.Alignment.LEADING)
					.addGroup(
							layout.createSequentialGroup()
									.addContainerGap(380, Short.MAX_VALUE)
									.addComponent(
											this.resetButton,
											javax.swing.GroupLayout.PREFERRED_SIZE,
											javax.swing.GroupLayout.PREFERRED_SIZE,
											javax.swing.GroupLayout.PREFERRED_SIZE)
									.addContainerGap(380, Short.MAX_VALUE))
					.addComponent(this.upperPanel,
							javax.swing.GroupLayout.DEFAULT_SIZE, 469,
							Short.MAX_VALUE)
					.addComponent(this.optionsPanelScrollable,
							javax.swing.GroupLayout.Alignment.TRAILING,
							javax.swing.GroupLayout.DEFAULT_SIZE, 469,
							Short.MAX_VALUE));
			layout.setVerticalGroup(layout
					.createParallelGroup(
							javax.swing.GroupLayout.Alignment.LEADING)
					.addGroup(
							layout.createSequentialGroup()
									.addComponent(this.upperPanel, 40, 40, 40)
									.addComponent(
											this.optionsPanelScrollable,
											javax.swing.GroupLayout.DEFAULT_SIZE,
											344, Short.MAX_VALUE)
									.addPreferredGap(
											javax.swing.LayoutStyle.ComponentPlacement.RELATED)
									.addGroup(
											layout.createParallelGroup(
													javax.swing.GroupLayout.Alignment.TRAILING,
													false)
													.addComponent(
															this.resetButton,
															javax.swing.GroupLayout.PREFERRED_SIZE,
															javax.swing.GroupLayout.PREFERRED_SIZE,
															javax.swing.GroupLayout.PREFERRED_SIZE))
									.addContainerGap()));
		}

		this.pack();
		this.repaint();

	}

	/**
	 * Method invoked when the straight party button is pressed.
	 * 
	 * @param evt
	 *            the evt
	 */
	private void straightPartyButtonActionPerformed(
			java.awt.event.ActionEvent evt) {// GEN-FIRST:event_straightPartyButtonActionPerformed
		this.performStraightAction();

	}// GEN-LAST:event_straightPartyButtonActionPerformed

	/**
	 * Perform straight action.
	 */
	private void performStraightAction() {
		if (this.straightPartyButton.isSelected()) {
			this.partyNameLabel.setBackground(this.resourceMap
					.getColor("partyNameLabel.background.color"));
		} else {
			this.partyNameLabel.setBackground(Color.WHITE);
		}

		this.resetBallotOptionsButtons(this.straightPartyButton.isSelected());
	}

	/**
	 * Method invoked when a ballot option button is pressed.
	 * 
	 * @param evt
	 *            The event that trigered the action
	 */
	public void ballotOptionActionPerformed(java.awt.event.ActionEvent evt) {
		AbstractButton button = (AbstractButton) evt.getSource();
		if (button.isSelected()) {
			this.selectionCount++;
		} else {
			this.selectionCount--;
		}
		this.checkVoteButtons();
	}

	/**
	 * Handles the voting buttons state during the voting process. This method
	 * is invoked when the voters selects/deselects a voting option.
	 */
	private void checkVoteButtons() {
		// If there are selections then the user could vote and reset the
		// selections
		if (this.selectionCount == 1
				|| (this.straightPartyButton.isSelected() && this.selectionCount == 0)) {
			this.resetButton.setText(this.getString("RESET.BUTTON.TEXT"));
			this.nextButton.setVisible(true);
			this.nextButton.setActionCommand("");

		}
		// If there aren't any selection then the user could only go back.
		else if (this.selectionCount == 0) {
			this.resetButton.setText(this.getString("BACK.BUTTON.TEXT"));
			// this.nextButton.setVisible(false);
			this.nextButton.setActionCommand(DISABLED);
			// this.partyNameLabel.setBackground(Color.WHITE);
		}

		if (this.ballotOptionButtons != null) {
			if (this.ballotOptionButtons.length > this.selectionCount) {
				this.straightPartyButton.setSelected(false);
				this.partyNameLabel.setBackground(Color.WHITE);
			}
		}
	}

	/**
	 * Method that handles the events trigerred by the next button. This is the
	 * method that moves the voter in its voting experience.
	 * 
	 * @param evt
	 *            the evt
	 */
	private void nextButtonActionPerformed(java.awt.event.ActionEvent evt) {
		throw new IllegalStateException("NOT IMPLEMENTED YET");
	}

	/**
	 * Reset button action performed.
	 * 
	 * @param evt
	 *            the evt
	 */
	void resetButtonActionPerformed(java.awt.event.ActionEvent evt) {

		if (this.selectionCount > 0 || this.straightPartyButton.isSelected()) {
			this.straightPartyButton.setSelected(false);
			this.partyNameLabel.setBackground(Color.WHITE);
			if (this.selectionCount > 0) {
				for (int i = 0; i < this.ballotOptionButtons.length; i++) {
					if (this.ballotOptionButtons[i].isSelected()) {
						this.ballotOptionButtons[i].setSelected(false);
					}
				}
			}
			this.selectionCount = 0;
			this.checkVoteButtons();
		}
	}

	/**
	 * Reset ballot options buttons.
	 * 
	 * @param isSelected
	 *            the is selected
	 */
	private void resetBallotOptionsButtons(boolean isSelected) {
		if (!isSelected) {
			this.resetButton.setText(this.getString("BACK.BUTTON.TEXT"));
			this.nextButton.setActionCommand(DISABLED);
			this.partyNameLabel.setBackground(Color.WHITE);
		} else {
			this.nextButton.setActionCommand("");
		}

		if (this.selectionCount > 0) {
			for (int i = 0; i < this.ballotOptionButtons.length; i++) {
				if (this.ballotOptionButtons[i].isSelected()) {
					this.ballotOptionButtons[i].setSelected(false);
				}
			}
		}
		this.selectionCount = 0;
	}

	// Variables declaration - do not modify//GEN-BEGIN:variables
	/** The contest name label. */
	javax.swing.JTextPane contestNameLabel;

	/** The next button. */
	javax.swing.JButton nextButton;

	/** The options panel scrollable. */
	private javax.swing.JScrollPane optionsPanelScrollable;

	/** The party name label. */
	javax.swing.JTextPane partyNameLabel;

	/** The party options panel. */
	javax.swing.JPanel partyOptionsPanel;

	/** The reset button. */
	javax.swing.JButton resetButton;

	/** The straight party button. */
	javax.swing.JRadioButton straightPartyButton;

	/** The upper panel. */
	javax.swing.JPanel upperPanel;
	// End of variables declaration//GEN-END:variables

	/**
	 * Radio buttons displayed in this form to select the language desired.
	 */
	AbstractButton[] ballotOptionButtons;

	/**
	 * Sets the contest name text.
	 * 
	 * @param name
	 *            the new contest name text
	 */
	void setContestNameText(String name) {

		String font = this.resourceMap.getString("contestNameLabel.font");

		String color = this.resourceMap
				.getString("contestNameLabel.color.text");

		name = GUIComponentUtil.getHtmlFormattedText(name + "&nbsp;", color,
				font, "right");

		this.contestNameLabel.setText(name);

		this.partyNameLabel.setText("&nbsp;");
		this.resetButton.setVisible(false);
		this.nextButton.setVisible(false);
		this.straightPartyButton.setVisible(false);
		this.partyNameLabel.setBackground(Color.WHITE);
	}

	/**
	 * Inits the party buttons.
	 * 
	 * @param partyButtons
	 *            the party buttons
	 */
	@SuppressWarnings("unused")
	public void initPartyButtons(AbstractButton[] partyButtons) {
		this.partyOptionsPanel.removeAll();

		this.partyOptionsPanel.setLayout(new GridBagLayout());

		int partySize = partyButtons.length;
		int rows = Math.min(partySize, PARTY_BUTTONS_VERT_LIMIT);
		int cols = partySize / rows;
		if (partySize % rows != 0) {
			cols++;
		}

		GridBagLayout layout = new GridBagLayout();
		JPanel insidePanel = new JPanel(layout);

		GridBagConstraints con = new GridBagConstraints();
		con.insets = new Insets(PARTY_VERTICAL_GAP, PARTY_HORIZ_GAP,
				PARTY_VERTICAL_GAP, PARTY_HORIZ_GAP);

		for (int k = 0; k < partySize; k++) {
			con.gridx = k / rows;
			con.gridy = k % rows;

			partyButtons[k].setAlignmentY(CENTER_ALIGNMENT);
			partyButtons[k].setAlignmentX(CENTER_ALIGNMENT);

			insidePanel.add(partyButtons[k], con);

		}

		this.partyOptionsPanel.add(insidePanel);

	}

	// Limits the number of buttons per columns displayed in the voting
	// experience dialog
	/** The Constant PARTY_BUTTONS_VERT_LIMIT. */
	private static final int PARTY_BUTTONS_VERT_LIMIT = 7;

	// Gap used to separate the party buttons;
	/** The Constant PARTY_VERTICAL_GAP. */
	private static final int PARTY_VERTICAL_GAP = 5;
	// Gap used to separate the party buttons;
	/** The Constant PARTY_HORIZ_GAP. */
	private static final int PARTY_HORIZ_GAP = 5;

	/**
	 * Sets the full panel.
	 * 
	 * @param panel
	 *            the new full panel
	 */
	public void setFullPanel(JPanel panel) {
		this.nextButton.setEnabled(true);
		this.resetButton.setEnabled(true);
		this.upperPanel.setVisible(false);
		this.nextButton.setVisible(false);
		this.resetButton.setVisible(false);
		this.nextButton.setActionCommand(DISABLED);
		this.resetButton.setText(this.getString("BACK.BUTTON.TEXT"));
		this.resetButton.setActionCommand("");
		this.optionsPanelScrollable.setViewportView(panel);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.awt.event.FocusListener#focusGained(java.awt.event.FocusEvent)
	 */
	@Override
	public void focusGained(FocusEvent theE) {
		this.requestFocus();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.awt.event.FocusListener#focusLost(java.awt.event.FocusEvent)
	 */
	@Override
	public void focusLost(FocusEvent theE) {
		return;
	}

	/**
	 * Invalid action performed.
	 */
	public void invalidActionPerformed() {

		if (this.invalidMessageDialog == null) {
			this.invalidMessageDialog = new BlockingMessageDialog(new JFrame(),
					false);
		}

		this.invalidMessageDialog.setMessages(this
				.getString("voting.invalid.action.button.text"));

		this.invalidMessageDialog.setVisible(true);

		Timer t = new javax.swing.Timer(1500, new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				VotingExperienceDialog.this.invalidMessageDialog
						.setVisible(false);
			}
		});
		t.setRepeats(false);
		t.start();
	}
}
