/**
 * WorkflowServiceBean.java
 * 
 * Revision: $Revision$ (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 * 
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.workflow.service.impl;

import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.ejb.Local;
import javax.ejb.Remote;
import javax.ejb.Remove;
import javax.ejb.Stateful;
import javax.ejb.TransactionManagement;
import javax.ejb.TransactionManagementType;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.Query;

import org.drools.KnowledgeBase;
import org.drools.KnowledgeBaseFactory;
import org.drools.builder.KnowledgeBuilder;
import org.drools.builder.KnowledgeBuilderFactory;
import org.drools.builder.ResourceType;
import org.drools.io.ResourceFactory;
import org.drools.logger.KnowledgeRuntimeLogger;
import org.drools.logger.KnowledgeRuntimeLoggerFactory;
import org.drools.persistence.PersistenceContextManager;
import org.drools.persistence.jpa.JPAKnowledgeService;
import org.drools.persistence.jpa.JpaPersistenceContext;
import org.drools.persistence.jta.JtaTransactionManager;
import org.drools.runtime.Environment;
import org.drools.runtime.EnvironmentName;
import org.drools.runtime.StatefulKnowledgeSession;
import org.drools.runtime.process.NodeInstance;
import org.drools.runtime.process.WorkItem;
import org.drools.runtime.process.WorkItemHandler;
import org.drools.runtime.process.WorkItemManager;
import org.jbpm.persistence.JpaProcessPersistenceContext;
import org.jbpm.persistence.ProcessPersistenceContext;
import org.jbpm.persistence.ProcessPersistenceContextManager;
import org.jbpm.process.instance.ProcessInstance;
import org.jbpm.workflow.instance.WorkflowProcessInstance;

import com.smartmatic.waffle.ecm.workflow.service.spec.IWorkflowService;
import com.smartmatic.waffle.ecm.workflow.service.spec.IWorkflowServiceLocal;
import com.smartmatic.waffle.ecm.workflow.service.spec.WorkflowData;
import com.smartmatic.waffle.log.SMTTLogger;

/**
 * Session Bean implementation class WorkflowServiceBean.
 */
@Stateful(name = IWorkflowService.SERVICE_NAME)
@Remote(IWorkflowService.class)
@Local(IWorkflowServiceLocal.class)
@TransactionManagement(TransactionManagementType.CONTAINER)
@org.jboss.ejb3.annotation.CacheConfig(idleTimeoutSeconds = 7000)
public class WorkflowServiceBean implements IWorkflowService,
        IWorkflowServiceLocal {

    /** The entity manager. */
    @PersistenceContext(unitName = "org.jbpm.persistence.jpa")
    EntityManager entityManager;

    /** The knowledge base. */
    KnowledgeBase knowledgeBase;

    /** The actual work item. */
    protected WorkItem actualWorkItem;

    /** The actual work item manager. */
    protected WorkItemManager actualWorkItemManager;

    /** The process id. */
    private long processId;

    /** The session id. */
    private int sessionId;

    /** The step. */
    private int step;

    /** The workflow data. */
    private WorkflowData workflowData;

    protected WorkflowData getWorkflowData() {
        return this.workflowData;
    }

    /** The logger. */
    private static SMTTLogger logger = SMTTLogger
            .getLogger(WorkflowServiceBean.class);

    /**
     * {@inheritDoc}
     */
    public void init(byte[] processData) {

        KnowledgeBuilder kbuilder = KnowledgeBuilderFactory
                .newKnowledgeBuilder();
        kbuilder.add(ResourceFactory.newByteArrayResource(processData),
                ResourceType.BPMN2);
        this.knowledgeBase = kbuilder.newKnowledgeBase();

    }

    /**
     * Creates the session.
     * 
     * @return the stateful knowledge session
     */
    protected StatefulKnowledgeSession createSession() {
        Environment env = KnowledgeBaseFactory.newEnvironment();

        MyPersistenceContextManager persistenceContextManager = new MyPersistenceContextManager();

        env = KnowledgeBaseFactory.newEnvironment();
        env.set(EnvironmentName.PERSISTENCE_CONTEXT_MANAGER,
                persistenceContextManager);
        env.set(EnvironmentName.TRANSACTION_MANAGER,
                new JtaTransactionManager(null, null, null));

        StatefulKnowledgeSession ksession = JPAKnowledgeService
                .newStatefulKnowledgeSession(this.knowledgeBase, null,
                        env);

        initSession(ksession);

        return ksession;
    }

    /**
     * Load session.
     * 
     * @return the stateful knowledge session
     */
    private StatefulKnowledgeSession loadSession() {

        Environment env = KnowledgeBaseFactory.newEnvironment();

        MyPersistenceContextManager persistenceContextManager = new MyPersistenceContextManager();

        env = KnowledgeBaseFactory.newEnvironment();
        env.set(EnvironmentName.PERSISTENCE_CONTEXT_MANAGER,
                persistenceContextManager);
        env.set(EnvironmentName.TRANSACTION_MANAGER,
                new JtaTransactionManager(null, null, null));

        StatefulKnowledgeSession ksession = JPAKnowledgeService
                .loadStatefulKnowledgeSession(this.sessionId,
                        this.knowledgeBase,
                        null,
                        env);

        initSession(ksession);

        return ksession;

    }

    /**
     * Inits the session.
     * 
     * @param ksession
     *            the ksession
     */
    protected void initSession(final StatefulKnowledgeSession ksession) {
        ksession.getWorkItemManager().registerWorkItemHandler(
                "Human Task", new WorkItemHandler() {

                    public void abortWorkItem(WorkItem workItem,
                            WorkItemManager manager) {
                        return;
                    }

                    public void executeWorkItem(WorkItem workItem,
                            WorkItemManager manager) {

                        WorkflowServiceBean.this.actualWorkItem = workItem;
                        WorkflowServiceBean.this.actualWorkItemManager = manager;

                        if (WorkflowServiceBean.this.workflowData != null) {
                            WorkflowServiceBean.this.workflowData
                                    .setWorkItemId(workItem.getId());

                            WorkflowServiceBean.this.entityManager
                                    .merge(WorkflowServiceBean.this.workflowData);
                            WorkflowServiceBean.this.workflowData = WorkflowServiceBean.this.entityManager
                                    .find(
                                            WorkflowServiceBean.this.workflowData
                                                    .getClass(),
                                            WorkflowServiceBean.this.workflowData
                                                    .getCode());

                        }
                    }
                });

        KnowledgeRuntimeLogger logger = KnowledgeRuntimeLoggerFactory
                .newConsoleLogger(ksession);

        this.sessionId = ksession.getId();

    }

    /**
     * Gets the process instance.
     * 
     * @param ksession
     *            the ksession
     * @return the process instance
     */
    private WorkflowProcessInstance getProcessInstance(
            StatefulKnowledgeSession ksession) {

        return (WorkflowProcessInstance) ksession
                .getProcessInstance(this.processId);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.smartmatic.waffle.ecm.workflow.service.spec.IWorkflowService#remove()
     */
    @Override
    @Remove
    public void remove() {
        return;
    }

    /**
     * The Class MyPersistenceContextManager.
     */
    class MyPersistenceContextManager implements PersistenceContextManager,
            ProcessPersistenceContextManager {

        /*
         * (non-Javadoc)
         * 
         * @see org.drools.persistence.PersistenceContextManager#
         * getApplicationScopedPersistenceContext()
         */
        public org.drools.persistence.PersistenceContext getApplicationScopedPersistenceContext() {
            return new JpaPersistenceContext(
                    WorkflowServiceBean.this.entityManager);
        }

        /*
         * (non-Javadoc)
         * 
         * @see org.drools.persistence.PersistenceContextManager#
         * getCommandScopedPersistenceContext()
         */
        public org.drools.persistence.PersistenceContext getCommandScopedPersistenceContext() {
            return new JpaPersistenceContext(
                    WorkflowServiceBean.this.entityManager);
        }

        /*
         * (non-Javadoc)
         * 
         * @see org.drools.persistence.PersistenceContextManager#
         * beginCommandScopedEntityManager()
         */
        public void beginCommandScopedEntityManager() {
            return;
        }

        /*
         * (non-Javadoc)
         * 
         * @see org.drools.persistence.PersistenceContextManager#
         * endCommandScopedEntityManager()
         */
        public void endCommandScopedEntityManager() {
            return;
        }

        /*
         * (non-Javadoc)
         * 
         * @see org.drools.persistence.PersistenceContextManager#dispose()
         */
        public void dispose() {
            return;
        }

        /*
         * (non-Javadoc)
         * 
         * @see org.jbpm.persistence.ProcessPersistenceContextManager#
         * getProcessPersistenceContext()
         */
        public ProcessPersistenceContext getProcessPersistenceContext() {
            return new JpaProcessPersistenceContext(
                    WorkflowServiceBean.this.entityManager);
        }

    }

    /**
     * Start a process named by processName.
     * 
     * @param processName
     *            the name of the process provided in init section
     * @param parameters
     *            optional parameters to be used for in-process scripts
     * @param businessObject
     *            optional object passed to in-process scripts to call business
     *            methods
     * @return the workflow id that can be used to reload it from database
     */
    @Override
    public Long startProcess(String processName,
            Map<String, Object> parameters,
            Object businessObject) {
        StatefulKnowledgeSession ksession = createSession();

        Map<String, Object> passedParameters = new HashMap<String, Object>(
                parameters);

        if (businessObject != null) {
            passedParameters.put("businessObject", businessObject);
        }

        org.drools.runtime.process.ProcessInstance processInstance = ksession
                .startProcess(processName, passedParameters);

        this.processId = processInstance.getId();

        this.step = 1;

        ksession.fireAllRules();

        ksession.dispose();

        this.entityManager.flush();

        this.workflowData = new WorkflowData();
        this.workflowData.setProcessId(this.processId);
        this.workflowData.setSessionId(ksession.getId());
        this.workflowData.setStep(this.step);

        if (this.actualWorkItem != null) {
            this.workflowData.setWorkItemId(this.actualWorkItem.getId());
        }

        this.entityManager.persist(this.workflowData);

        return this.workflowData.getCode();

    }

    /**
     * Reloads a workflow from database.
     * 
     * @param workflowId
     *            workflow code to be loaded
     * @param businessObject
     *            optional object passed to in-process scripts to call business
     *            methods
     */
    @Override
    public void loadProcess(Long workflowId, Object businessObject) {

        this.workflowData = this.entityManager.find(
                WorkflowData.class, workflowId);

        this.sessionId = this.workflowData.getSessionId();
        this.processId = this.workflowData.getProcessId();

        this.step = this.workflowData.getStep();
        StatefulKnowledgeSession ksession = loadSession();
        try {
            if (businessObject != null) {

                WorkflowProcessInstance processInstance = (WorkflowProcessInstance) ksession
                        .getProcessInstance(this.processId);

                processInstance.setVariable("businessObject", businessObject);
                //                ksession.setGlobal("businessObject", businessObject);
            }

            if (this.workflowData.getWorkItemId() != null) {
                org.drools.process.instance.WorkItemManager workItemManager = (org.drools.process.instance.WorkItemManager) ksession
                        .getWorkItemManager();

                this.actualWorkItem = workItemManager
                        .getWorkItem(this.workflowData
                                .getWorkItemId());
                this.actualWorkItemManager = workItemManager;
            }
        } finally {
            ksession.dispose();
        }

    }

    /**
     * {@inheritDoc}
     */
    public String getActualNodeName() {
        StatefulKnowledgeSession ksession = loadSession();
        try {
            int state;

            WorkflowProcessInstance processInstance = getProcessInstance(ksession);
            if (processInstance != null) {
                state = processInstance.getState();
            } else {
                state = ProcessInstance.STATE_COMPLETED;
            }

            switch (state) {
            case ProcessInstance.STATE_COMPLETED:
                return "EndProcess";

            default:
                Collection<NodeInstance> nodeInstances = processInstance
                        .getNodeInstances();

                if (nodeInstances.isEmpty() == false) {
                    NodeInstance nodeInstance = nodeInstances.iterator().next();
                    return nodeInstance.getNodeName();
                } else {
                    return null;
                }
            }
        } finally {
            ksession.dispose();
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Object getVariable(String variableName) {
        StatefulKnowledgeSession ksession = loadSession();
        try {
            WorkflowProcessInstance processInstance = getProcessInstance(ksession);

            Object value = this.actualWorkItem.getParameter(variableName);

            if (value != null) {

                return value;
            } else {

                value = processInstance.getVariable(variableName);

                if (value != null) {

                    return value;
                } else {
                    return ksession.getGlobal(variableName);
                }
            }

        } finally {
            ksession.dispose();
        }
    }

    /**
     * {@inheritDoc}
     */
    public void gotoNext() {
        StatefulKnowledgeSession ksession = loadSession();
        try {
            WorkflowProcessInstance processInstance = getProcessInstance(ksession);
            if (processInstance.getState() == ProcessInstance.STATE_ACTIVE) {
                this.actualWorkItemManager
                        .completeWorkItem(this.actualWorkItem.getId(),
                                Collections
                                        .singletonMap(
                                                "gotoNext",
                                                (Object) Boolean.TRUE));
            }

        } finally {
            ksession.dispose();
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.smartmatic.waffle.ecm.workflow.service.spec.IWorkflowService#
     * getWorkflowIds
     * ()
     */
    @Override
    public Long[] getWorkflowIds() {
        Query query = this.entityManager
                .createQuery("select code from com.smartmatic.waffle.ecm.workflow.service.spec.WorkflowData");

        List<Long> resultList = query.getResultList();

        return resultList.toArray(new Long[resultList.size()]);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.smartmatic.waffle.ecm.workflow.service.spec.IWorkflowService#goBack()
     */
    @Override
    public void goBack() {

        StatefulKnowledgeSession ksession = loadSession();
        try {
            WorkflowProcessInstance processInstance = getProcessInstance(ksession);

            if (processInstance.getState() == ProcessInstance.STATE_ACTIVE) {
                this.actualWorkItemManager
                        .completeWorkItem(this.actualWorkItem.getId(),
                                Collections
                                        .singletonMap(
                                                "gotoNext",
                                                (Object) Boolean.FALSE));
            }

        } finally {
            ksession.dispose();
        }

    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.smartmatic.waffle.ecm.workflow.service.spec.IWorkflowService#moveForward
     * ()
     */
    public void moveForward() {
        this.workflowData = this.entityManager.find(
                this.workflowData.getClass(), this.workflowData.getCode());
        this.workflowData.setStep(++this.step);
        this.entityManager.persist(this.workflowData);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.smartmatic.waffle.ecm.workflow.service.spec.IWorkflowService#moveBackward
     * ()
     */
    public void moveBackward() {
        this.workflowData = this.entityManager.find(
                this.workflowData.getClass(), this.workflowData.getCode());
        this.workflowData.setStep(--this.step);
        this.entityManager.persist(this.workflowData);
    }

    /**
     * Passivate.
     */
    @javax.ejb.PrePassivate
    public void passivate() {
        this.knowledgeBase = null;

        this.actualWorkItem = null;
        this.actualWorkItemManager = null;

    }

    /**
     * Activate.
     */
    @javax.ejb.PostActivate
    public void activate() {
        return;
    }

}
