/**
 * IWorkflowService.java
 * 
 * Revision: $Revision$ (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 * 
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.workflow.service.spec;

import java.util.Map;

/**
 * The Interface IWorkflowService.
 */
public interface IWorkflowService {

    /**
     * Holds the name of the bean that implements this interface.
     * 
     */

    public static final String SERVICE_NAME = "com.smartmatic.waffle.ecm.workflow.service.spec.IWorkflowService";

    /**
     * Creates the KnowledgeBase using the supplied process XML data.
     * 
     * @param processData
     *            byte array containg the process xml data in BPMN2 format
     */
    void init(byte[] processData);

    /**
     * Start a process named by processName.
     * 
     * @param processName
     *            the name of the process provided in init section
     * @param parameters
     *            optional parameters to be used for in-process scripts
     * @param businessObject
     *            optional object passed to in-process scripts to call business
     *            methods
     * @return the workflow id that can be used to reload it from database
     */
    Long startProcess(String processName, Map<String, Object> parameters,
            Object businessObject);

    /**
     * Returns the name of the node that the workflow is.
     * 
     * @return Node name
     */
    String getActualNodeName();

    /**
     * Advance to the next node.
     */
    void gotoNext();

    /**
     * Rewinds to the last node executed.
     */
    void goBack();

    /**
     * Reloads a workflow from database.
     * 
     * @param workflowId
     *            workflow code to be loaded
     * @param businessObject
     *            optional object passed to in-process scripts to call business
     *            methods
     */
    void loadProcess(Long workflowId, Object businessObject);

    /**
     * Removes the.
     */
    void remove();

    /**
     * Returns the value of the specific process instance's variable.
     * 
     * @param variableName
     *            process instance's variable name
     * @return the variable value
     */
    Object getVariable(String variableName);

    /**
     * Gets the workflow ids.
     * 
     * @return the workflow ids
     */
    Long[] getWorkflowIds();

    /**
     * Increments one step the workflow and updates the database.
     */
    void moveForward();

    /**
     * Decrements one step the workflow and updates the database.
     */
    void moveBackward();
}
