/*
 * HistoricFileException.java
 *
 * Version 1.0 (25/08/2011)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.localpersistence.exception;

import com.smartmatic.waffle.lang.BaseException;
import com.smartmatic.waffle.lang.IExceptionInfo;

/**
 * Class used to be thrown if an error occurred during processing for historic
 * files of core of the application.
 * 
 * 
 * @version 1.0 (Aug 25, 2011)
 * @author Fernando Alvarez (fernando.alvarez@smartmatic.com)
 */
public class HistoricFileException extends BaseException {

	/**
	 * 
	 */
	private static final long serialVersionUID = -5473899462539434714L;

	/**
	 * Class used for specifying cause of exceptions.
	 * 
	 * @version 1.0 (Aug 25, 2011)
	 * @author Fernando Alvarez (fernando.alvarez@smartmatic.com)
	 */
	public enum ExceptionInfo implements IExceptionInfo {
		UNRECOVERY_HISTORIC_FILE_EXCEPTION;

		/**
		 * 
		 */
		private String message;

		/**
		 * 
		 * @inheritDoc
		 */
		@Override
		public String getMessage() {
			return this.message;
		}

		/**
		 * 
		 */
		private ExceptionInfo() {
			this.message = this.getClass().getName() + "." + this.name();
		}

	}

	/**
	 * Constructor.
	 * 
	 * @param exceptionInfo
	 *            the exception info.
	 * @param throwable
	 *            the error.
	 * 
	 * @param parameters
	 *            the parameters.
	 */
	public HistoricFileException(IExceptionInfo exceptionInfo,
			Throwable throwable, Object... parameters) {
		super(exceptionInfo, throwable, parameters);
	}

	/**
	 * Constructor.
	 * 
	 * @param exceptionInfo
	 *            the exception info.
	 * @param throwable
	 *            the error
	 */
	public HistoricFileException(IExceptionInfo exceptionInfo,
			Throwable throwable) {
		super(exceptionInfo, throwable);
	}

	/**
	 * Constructor.
	 * 
	 * @param exceptionInfo
	 *            the exception info.
	 */
	public HistoricFileException(IExceptionInfo exceptionInfo) {
		super(exceptionInfo);
	}

	/**
	 * Constructor.
	 * 
	 * @param exceptionInfo
	 *            the exception info.
	 * @param parameters
	 *            the parameters
	 */
	public HistoricFileException(IExceptionInfo exceptionInfo,
			Object... parameters) {
		super(exceptionInfo, parameters);
	}
}
