/**
 * SMTTLog.java
 *
 * $Revision: 1.3 $ ($Date: 2009-11-12 21:15:10 $)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.log;

import java.util.Map;
import java.util.ResourceBundle;

/**
 * Interface that specifies the set of operations available for an extension of
 * the log4j logging services. These extensions, among other things, include
 * counting with a context provider and a resource bundle. The new logging
 * method <code> Audit </code> will serve as a midpoint between standard
 * <code> info </code> and <code> warn </code> log4j methods.
 * 
 * @see org.apache.log4j.Logger
 * 
 * @author Ricardo Monascal
 */
public interface SMTTLog {
	/**
	 * Context provider setter method
	 * 
	 * @param contextProvider
	 *            Context provider to set
	 */
	void setContextProvider(ContextProvider contextProvider);

	/**
	 * Resource Bundle setter method
	 * 
	 * @param resourceBundle
	 *            Resource bundle to set
	 */
	void setResourceBundle(ResourceBundle resourceBundle);

	/**
	 * Current thread properties setter method
	 * 
	 * @param proporties
	 *            The current thread properties
	 */
	void setCurrentThreadProperties(Map<String, Object> proporties);

	/**
	 * Current thread properties clear method
	 * 
	 * @param proporties
	 *            The current thread properties
	 */
	void clearCurrentThreadProperties(Map<String, Object> properties);

	// Debug templates.

	/**
	 * Log a debug level message
	 * 
	 * @param messageCode
	 *            The message code to log
	 * 
	 */
	void debug(String messageCode);

	/**
	 * Log a debug level message
	 * 
	 * @param messageCode
	 *            The message code to log
	 * @param t
	 *            A throw able message to log
	 * 
	 */
	void debug(String messageCode, Throwable t);

	/**
	 * Log a debug level message
	 * 
	 * @param messageCode
	 *            The message code to log
	 * @param properties
	 *            The properties to log
	 * 
	 */
	void debug(String messageCode, Map<String, Object> properties);

	/**
	 * Log a debug level message
	 * 
	 * @param messageCode
	 *            The message code to log
	 * @param properties
	 *            The properties to log
	 * @param t
	 *            A throw able message to log
	 * 
	 */
	void debug(String messageCode, Map<String, Object> properties, Throwable t);

	// info templates.

	/**
	 * Log an info level message
	 * 
	 * @param messageCode
	 *            The message code to log
	 * 
	 */
	void info(String messageCode);

	/**
	 * Log an info level message
	 * 
	 * @param messageCode
	 *            The message code to log
	 * @param messageArguments
	 *            The message arguments to set
	 * 
	 */
	void info(String messageCode, Object... messageArguments);

	/**
	 * Log an info level message
	 * 
	 * @param messageCode
	 *            The message code to log
	 * @param t
	 *            A throw able message to log
	 * 
	 */
	void info(String messageCode, Throwable t);

	/**
	 * Log an info level message
	 * 
	 * @param messageCode
	 *            The message code to log
	 * @param properties
	 *            The properties to log
	 * 
	 */
	void info(String messageCode, Map<String, Object> properties);

	/**
	 * Log an info level message
	 * 
	 * @param messageCode
	 *            The message code to log
	 * @param properties
	 *            The properties to log
	 * @param messageArguments
	 *            The message arguments to set
	 * 
	 */
	void info(String messageCode, Map<String, Object> properties,
			Object... messageArguments);

	/**
	 * Log an info level message
	 * 
	 * @param messageCode
	 *            The message code to log
	 * @param properties
	 *            The properties to log
	 * @param t
	 *            A throw able message to log
	 */
	void info(String messageCode, Map<String, Object> properties, Throwable t);

	// audit templates.

	/**
	 * Log an audit level message
	 * 
	 * @param messageCode
	 *            The message code to log
	 * 
	 */
	void audit(String messageCode);

	/**
	 * Log an audit level message
	 * 
	 * @param messageCode
	 *            The message code to log
	 * @param messageArguments
	 *            The message arguments to set
	 * 
	 */
	void audit(String messageCode, Object... messageArgumments);

	// warn templates.

	/**
	 * Log a warn level message
	 * 
	 * @param messageCode
	 *            The message code to log
	 * 
	 */
	void warn(String messageCode);

	/**
	 * Log a warn level message
	 * 
	 * @param messageCode
	 *            The message code to log
	 * @param t
	 *            A throw able message to log
	 * 
	 */
	void warn(String messageCode, Throwable t);

	/**
	 * Log a warn level message
	 * 
	 * @param messageCode
	 *            The message code to log
	 * @param properties
	 *            The properties to log
	 * 
	 */
	void warn(String messageCode, Map<String, Object> properties);

	/**
	 * Log a warn level message
	 * 
	 * @param messageCode
	 *            The message code to log
	 * @param properties
	 *            The properties to log
	 * @param t
	 *            A throw able message to log
	 * 
	 */
	void warn(String messageCode, Map<String, Object> properties, Throwable t);

	// error templates.

	/**
	 * Log an error level message
	 * 
	 * @param messageCode
	 *            The message code to log
	 * 
	 */
	void error(String messageCode);

	/**
	 * Log an error level message
	 * 
	 * @param messageCode
	 *            The message code to log
	 * @param t
	 *            A throw able message to log
	 */
	void error(String messageCode, Throwable t);

	/**
	 * Log an error level message
	 * 
	 * @param messageCode
	 *            The message code to log
	 * @param properties
	 *            The properties to log
	 * 
	 */
	void error(String messageCode, Map<String, Object> properties);

	/**
	 * Log an error level message
	 * 
	 * @param messageCode
	 *            The message code to log
	 * @param properties
	 *            The properties to log
	 * @param t
	 *            A throw able message to log
	 * 
	 */
	void error(String messageCode, Map<String, Object> properties, Throwable t);

	// fatal templates.

	/**
	 * Log a fatal level message
	 * 
	 * @param messageCode
	 *            The message code to log
	 * 
	 */
	void fatal(String messageCode);

	/**
	 * Log a fatal level message
	 * 
	 * @param messageCode
	 *            The message code to log
	 * @param t
	 *            A throw able message to log
	 * 
	 */
	void fatal(String messageCode, Throwable t);

	/**
	 * Log a fatal level message
	 * 
	 * @param messageCode
	 *            The message code to log
	 * @param properties
	 *            The properties to log
	 * 
	 */
	void fatal(String messageCode, Map<String, Object> properties);

	/**
	 * Log a fatal level message
	 * 
	 * @param messageCode
	 *            The message code to log
	 * @param properties
	 *            The properties to log
	 * @param t
	 *            A throw able message to log
	 * 
	 */
	void fatal(String messageCode, Map<String, Object> properties, Throwable t);

	// Enables/disabled level controllers.

	/**
	 * Boolean indicate is Debug Enabled
	 */
	boolean isDebugEnabled = false;

	/**
	 * Boolean indicate is Info Enabled
	 */
	boolean isInfoEnabled = false;

	/**
	 * Boolean indicate is Warn Enabled
	 */
	boolean isWarnEnabled = false;

	/**
	 * Boolean indicate is Error Enabled
	 */
	boolean isErrorEnabled = false;

	/**
	 * Boolean indicate is Fatal Enabled
	 */
	boolean isFatalEnabled = false;

}
