/**
 * EqCriteria.java
 *
 * $Revision: 1.3 $ ($Date: 2011-04-06 04:45:07 $)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */

package com.smartmatic.waffle.persistence.search.criteria;

/**
 * Class that implements a Equal Expression when the value to be compared is a
 * property and a fixed value.
 * 
 * @author Ithamar Torres
 */

public class EqCriteria extends SimpleCriteria {

	/**
	 * Holds the serialization id of the class
	 */

	private static final long serialVersionUID = 2749581568972796446L;

	/**
	 * Constructor of a Equal Expression.
	 * 
	 * @param propertyName
	 *            property that will be used in the equal comparison
	 * @param value
	 *            Value that will be used in the comparison process
	 * @param ignoreCase
	 *            parameter that indicate if the comparison is case sensitive or
	 *            not
	 */

	public EqCriteria(String propertyName, Object value, boolean ignoreCase) {
		super(propertyName, value, ignoreCase);
	}

	/**
	 * Constructor of a Equal Expression.
	 * 
	 * @param propertyName
	 *            property that will be used in the equal comparison
	 * @param value
	 *            Value that will be used in the comparison process
	 */

	public EqCriteria(String propertyName, Object value) {
		super(propertyName, value);
	}

	/**
	 * Operator applied to the logical expression
	 * 
	 * @return The operator used in the logical operation
	 */
	@Override
	String getOp() {
		return "=";
	}

}
