/**
 * FullTextSearchCriteriaFactory.java
 * 
 * $Revision: 1.8 $ ($Date: 2011-04-06 04:45:07 $)
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 * 
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.persistence.search.criteria;

/**
 * Represent a searching binary logical expressions.
 * 
 * @author Carlos Lameda (carlos.lameda@smartmatic.com)
 * @version 1.0 (Nov 9, 2009)
 */
public class FullTextSearchCriteriaFactory {

	/**
	 * Default constructor. It is private because this is a class used to create
	 * a factory pattern. And this class doesn't have any semantics but the
	 * creation of another classes
	 */

	private FullTextSearchCriteriaFactory() {
	}

	/**
	 * Apply an "equal" constraint to the named property
	 * 
	 * 
	 * @param propertyName
	 *            property that will be used in the equal comparison
	 * @param value
	 *            Value that will be used in the comparison process
	 */

	public static FullTextSearchSimpleCriteria eq(String propertyName,
			String value) {
		return new FullTextSearchEqCriteria(propertyName, value);
	}

	/**
	 * Apply an "equal" constraint to the named property. Gives the option to
	 * automatically add wildcards
	 * 
	 * 
	 * @param propertyName
	 *            property that will be used in the equal comparison
	 * @param value
	 *            Value that will be used in the comparison process
	 * @param addWildcards
	 *            gives the option to automatically add wildcards
	 */

	public static FullTextSearchSimpleCriteria eq(String propertyName,
			String value, boolean addWildcards) {
		return new FullTextSearchEqCriteria(propertyName, value, true,
				addWildcards);
	}

	/**
	 * This constructor receives the expressions located in both sides of the or
	 * operation
	 * 
	 * @param lhs
	 *            Left hand side parameter of the binary expression.
	 * @param rhs
	 *            Right hand side parameter of the binary expression.
	 * @return The text search criteria
	 */
	public static IFullTextSearchCriteria or(IFullTextSearchCriteria lhs,
			IFullTextSearchCriteria rhs) {
		return new FullTextSearchOrCriteria(lhs, rhs);
	}

	/**
	 * Constrains the property to a specified list of values
	 * 
	 * @param propertyName
	 *            Property that will be used in the <code>in</code> evaluation
	 * @param theLocatedForSearch
	 *            Values that will be used in the evaluation of the expression
	 * @return The text search criteria
	 */
	public static IFullTextSearchCriteria in(String theString,
			String[] theLocatedForSearch) {
		return new FullTextSearchInCriteria(theString, theLocatedForSearch);

	}
}
