/**
 * FullTextSearchInCriteria.java
 *
 * $Revision: 1.3 $ ($Date: 2011-04-06 04:44:54 $)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.persistence.search.criteria;

/**
 * Constrains the property to a specified list of values
 * 
 * @author Luis Cisneros
 */

public class FullTextSearchInCriteria implements IFullTextSearchCriteria {

	/**
	 * Holds the serialization id of the class
	 */

	private static final long serialVersionUID = 2929177536910740265L;

	/**
	 * Property that will be used in the evaluation of the expression
	 */

	private final String propertyName;

	/**
	 * Values that will be used in the evaluation of the expression
	 */

	private final String[] values;

	/**
	 * Getter of <code>propertyName</code> property.
	 * 
	 * @return <code>propertyName</code> property value.
	 * @see #propertyName
	 */

	public String getPropertyName() {
		return this.propertyName;
	}

	/**
	 * Getter of <code>values</code> property.
	 * 
	 * @return <code>values</code> property value.
	 * @see #values
	 */

	public String[] getValues() {
		return this.values;
	}

	/**
	 * Constructor of a IlikeExpression
	 * 
	 * @param propertyName
	 *            Property that will be used in the <code>in</code> evaluation
	 * @param values
	 *            Values that will be used in the evaluation of the expression
	 */

	public FullTextSearchInCriteria(String propertyName, String[] values) {
		this.propertyName = propertyName;
		this.values = (values != null) ? values.clone() : null;
	}

	/**
	 * Builds the String representation of the object
	 * 
	 * @return String representing the object
	 */
	@Override
	public String toString() {
		StringBuffer strBuffer = new StringBuffer(this.propertyName + " in ("
				+ this.values[0].toString());

		for (int i = 1; i < this.values.length; i++) {
			strBuffer.append(", " + this.values[i].toString());
		}
		strBuffer.append(")");
		return strBuffer.toString();
	}

}
