/**
 * IlikeCriteria.java
 *
 * $Revision: 1.3 $ ($Date: 2011-04-06 04:44:54 $)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.persistence.search.criteria;

/**
 * A case-insensitive "like" expression
 * 
 * @author Ithamar Torres
 */

public class IlikeCriteria implements ISearchCriteria {

	/**
	 * Holds the serialization id of the class
	 */

	private static final long serialVersionUID = 7049362692722100744L;

	/**
	 * Getter of <code>propertyName</code> property.
	 * 
	 * @return <code>propertyName</code> property value.
	 * @see #propertyName
	 */

	public String getPropertyName() {
		return this.propertyName;
	}

	/**
	 * Getter of <code>value</code> property.
	 * 
	 * @return <code>value</code> property value.
	 * @see #value
	 */

	public Object getValue() {
		return this.value;
	}

	/**
	 * Property that will be used in the ilike comparison
	 */

	private final String propertyName;

	/**
	 * Value that will be used in the comparison process
	 */

	private final Object value;

	/**
	 * Constructor of a IlikeExpression
	 * 
	 * @param propertyName
	 *            Property that will be used in the ilike comparison
	 * @param value
	 *            Value that will be used in the comparison process
	 */

	IlikeCriteria(String propertyName, Object value) {
		this.propertyName = propertyName;
		this.value = value;
	}

	/**
	 * Constructor of a IlikeExpression
	 * 
	 * @param propertyName
	 *            Property that will be used in the ilike comparison
	 * @param value
	 *            Value that will be used in the comparison process
	 * @param matchMode
	 *            mode that will be used in the comparison process
	 * 
	 * @see com.smartmatic.waffle.persistence.search.criteria.MatchCriteriaMode
	 */

	IlikeCriteria(String propertyName, String value, MatchCriteriaMode matchMode) {
		this(propertyName, matchMode.toMatchString(value));
	}

	/**
	 * Returns a string representation of the object.
	 * 
	 * @return The string representation of the criteria
	 */
	@Override
	public String toString() {
		return this.propertyName + " ilike " + this.value;
	}

}
