/**
 * JunctionCriteria.java
 *
 * $Revision: 1.4 $ ($Date: 2011-04-06 04:45:07 $)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */

package com.smartmatic.waffle.persistence.search.criteria;

import java.util.ArrayList;
import java.util.List;

/**
 * A sequence of a logical expressions combined by some associative logical
 * operator
 * 
 * @author Ithamar Torres
 */

public abstract class JunctionCriteria implements ISearchCriteria {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * Getter of <code>criteria</code> property.
	 * 
	 * @return <code>criteria</code> property value.
	 * @see #criteria
	 */

	public List<ISearchCriteria> getCriteria() {
		return this.criteria;
	}

	/**
	 * Collection of expressions
	 */

	private List<ISearchCriteria> criteria = new ArrayList<ISearchCriteria>();

	/**
	 * Method that allows to add new expressions to the junction
	 * 
	 * @param criterion
	 *            The expression that will be added to the junction collection
	 * @return the Junction where the expressions are grouped
	 */

	public JunctionCriteria add(ISearchCriteria criterion) {
		this.criteria.add(criterion);
		return this;
	}

	/**
	 * Operator applied to the logical expression
	 * 
	 * @return The operator used in the logical operation
	 */
	abstract String getOp();

	/**
	 * Returns a string representation of the object.
	 * 
	 * @return The string representation of the criteria
	 */
	@Override
	public String toString() {
		return null;
	}

}
