/**
 * NullCriteria.java
 *
 * $Revision: 1.3 $ ($Date: 2011-04-06 04:45:07 $)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.persistence.search.criteria;

/**
 * Constrains a property to be null
 * 
 * @author Ithamar Torres
 */
public class NullCriteria implements ISearchCriteria {

	/**
	 * Holds the serialization id of the class
	 */

	private static final long serialVersionUID = -1451295541424849605L;

	/**
	 * Getter of <code>propertyName</code> property.
	 * 
	 * @return <code>propertyName</code> property value.
	 * @see #propertyName
	 */

	public String getPropertyName() {
		return this.propertyName;
	}

	/**
	 * Property that needs to be compared to the null value
	 */

	private final String propertyName;

	/**
	 * Constructor of a NullExpression.
	 * 
	 * @param propertyName
	 *            Property that needs to be compared.
	 */

	public NullCriteria(String propertyName) {
		this.propertyName = propertyName;
	}

	/**
	 * Returns a string representation of the object.
	 * 
	 * @return The string representation of the criteria
	 */
	@Override
	public String toString() {
		return this.propertyName + " is null";
	}

}
