/**
 * PropertyCriteria.java
 *
 * $Revision: 1.3 $ ($Date: 2011-04-06 04:45:08 $)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.persistence.search.criteria;

/**
 * Superclass for comparisons between two properties (with SQL binary operators)
 * 
 * @author Ithamar Torres
 */

public abstract class PropertyCriteria implements ISearchCriteria {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * Getter of <code>otherPropertyName</code> property.
	 * 
	 * @return <code>otherPropertyName</code> property value.
	 * @see #otherPropertyName
	 */

	public String getOtherPropertyName() {
		return this.otherPropertyName;
	}

	/**
	 * Getter of <code>propertyName</code> property.
	 * 
	 * @return <code>propertyName</code> property value.
	 * @see #propertyName
	 */

	public String getPropertyName() {
		return this.propertyName;
	}

	/**
	 * First property that will be used in the evaluation of the expression
	 */

	private final String propertyName;

	/**
	 * Other property that will be used in the evaluation of the expression
	 */

	private final String otherPropertyName;

	/**
	 * Constructor of a PropertyExpression.
	 * 
	 * @param propertyName
	 *            First property that will be used in the evaluation of the
	 *            expression
	 * @param otherPropertyName
	 *            Other property that will be used in the evaluation of the
	 *            expression
	 */

	PropertyCriteria(String propertyName, String otherPropertyName) {
		this.propertyName = propertyName;
		this.otherPropertyName = otherPropertyName;
	}

	/**
	 * Returns a string representation of the object.
	 * 
	 * @return The string representation of the criteria
	 */
	@Override
	public String toString() {
		return this.propertyName + this.getOp() + this.otherPropertyName;
	}

	/**
	 * Method used to obtain the operation that is used in the expression
	 * 
	 * @return The String representation of the operation
	 */

	abstract String getOp();

}
