/**
 * TransformationFactory.java
 * 
 * $Revision: 1.8 $ ($Date: 2011-04-06 04:45:09 $)
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 * 
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.persistence.search.transformation;

/**
 * Transformation factory.
 * 
 * @version 1.0 (16/04/2005)
 * @author Ithamar Torres
 */

public class TransformationFactory {

	/**
	 * Creates a transformation list.
	 * 
	 * @return The resulting transformation list
	 */

	public static TransformationsList transformationList() {
		return new TransformationsList();
	}

	/**
	 * Creates a transformation list that returns a map where the keys are the
	 * alias names and the values are the result values for the added
	 * transformations.
	 * 
	 * @return the created empty transformation list.
	 */

	public static AliasTransformationsMap aliasTransformationMap() {
		return new AliasTransformationsMap();
	}

	/**
	 * Method that creates a Property Transformation
	 * 
	 * @param property
	 *            The property to obtain
	 * @return The property transformation instance
	 */
	public static PropertyTransformation propertyTransformation(String property) {
		return new PropertyTransformation(property);
	}

	/**
	 * Method that creates a minimum transformation
	 * 
	 * @param property
	 *            The property used to create the transformation
	 * @return The minimum transformation instance
	 */
	public static MinTransformation minTransformation(String property) {
		return new MinTransformation(property);
	}

	/**
	 * Method that creates a maximum transformation
	 * 
	 * @param property
	 *            The property used to create the transformation
	 * @return The maximum transformation instance
	 */
	public static MaxTransformation maxTransformation(String property) {
		return new MaxTransformation(property);
	}

	/**
	 * Method that creates a row count transformation
	 * 
	 * @return The row count transformation instance
	 */
	public static RowCountTransformation rowCountTransformation() {
		return new RowCountTransformation();
	}

	/**
	 * Method that creates a identifier transformation
	 * 
	 * @return The identifier transformation instance
	 */
	public static IdentifierTransformation idTransformation() {
		return new IdentifierTransformation();
	}

	/**
	 * Method that creates a sum transformation
	 * 
	 * @param property
	 *            The property used to create the transformation
	 * @return Returns the created sum transformation
	 */

	public static SumTransformation sumTransformation(String property) {
		return new SumTransformation(property);
	}

	/**
	 * Method that creates a group transformation
	 * 
	 * @param property
	 *            The property used to create the transformation
	 * @return Returns the created group transformation
	 */

	public static GroupTransformation groupTransformation(String property) {
		return new GroupTransformation(property);
	}

	/**
	 * Creates a transformation list that returns a bean where the property
	 * names are the alias names and the property values are the result values
	 * for the added transformations.
	 * 
	 * @param beanClass
	 *            the bean's class that will be used to generate the result
	 *            objects.
	 * @return the created empty transformation list.
	 */
	public static AliasTransformationsMap aliasTransformationMap(Class beanClass) {

		return new AliasTransformationsMap(beanClass);

	}

	/**
	 * Creates a transformation that will apply a distinct over the supplied
	 * transformation.
	 * 
	 * @param theTargetTransformation
	 *            Transformation which the distinct will be applied
	 * @return a transformation that will apply a distinct over the supplied
	 *         transformation
	 */
	public static DistinctTransformation distinctTransformation(
			ITransformation theTargetTransformation) {
		return new DistinctTransformation(theTargetTransformation);
	}

	/**
	 * Method that creates a count transformation
	 * 
	 * @param property
	 *            The property used to create the transformation
	 * @return The count transformation instance
	 */
	public static CountTransformation countTransformation(String property) {
		return new CountTransformation(property);
	}

	/**
	 * Method that creates a distinct count transformation
	 * 
	 * @param property
	 *            The property used to create the transformation
	 * @return Returns the created distinct count transformation
	 */

	public static CountTransformation distinctCountTransformation(
			String property) {
		return new CountTransformation(property, true);
	}

	/**
	 * Method that creates a count distinct transformation
	 * 
	 * @param property
	 *            The property used to create the transformation
	 * @return The count distinct transformation instance
	 */
	public static CountDistinctTransformation countDistinctTransformation(
			String property) {
		return new CountDistinctTransformation(property);
	}

}
