package com.smartmatic.waffle.persistence.service.impl;

import static org.junit.Assert.assertNotNull;

import javax.persistence.EntityManager;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.powermock.api.mockito.PowerMockito;
import org.powermock.modules.junit4.PowerMockRunner;

import com.smartmatic.waffle.lang.BaseException;
import com.smartmatic.waffle.persistence.service.impl.util.Foo;

/**
 * Class used to write unit tests for PersistenceServiceBean.
 */
@RunWith(PowerMockRunner.class)
public class PersistenceServiceBeanTest {

	PersistenceServiceBean persistenceServiceBean;

	@Before
	public void setup() {
		this.persistenceServiceBean = new PersistenceServiceBean();
	}

	@Test
	public void persistTest() throws BaseException, RuntimeException {
		this.persistenceServiceBean.entityManager = PowerMockito
				.mock(EntityManager.class);

		Foo foo = new Foo();
		Foo fooPersisted = this.persistenceServiceBean.persist(foo, null);

		assertNotNull(fooPersisted);
	}

	@Test(expected = RuntimeException.class)
	public void persistExceptionTest() throws Exception {
		this.persistenceServiceBean.entityManager = PowerMockito
				.mock(EntityManager.class);
		PowerMockito.when(EntityManager.class, "persist").thenThrow(
				new RuntimeException());

		Foo foo = new Foo();
		Foo fooPersisted = this.persistenceServiceBean.persist(foo, null);

		assertNotNull(fooPersisted);
	}

	@Test
	public void batchPersistTest() throws BaseException, RuntimeException {
		this.persistenceServiceBean.entityManager = PowerMockito
				.mock(EntityManager.class);

		Foo foo = new Foo();
		Foo fooPersisted = this.persistenceServiceBean.batchPersist(foo, null);

		assertNotNull(fooPersisted);
	}

	@Test(expected = RuntimeException.class)
	public void batchPersistExceptionTest() throws Exception {
		this.persistenceServiceBean.entityManager = PowerMockito
				.mock(EntityManager.class);
		PowerMockito.when(EntityManager.class, "persist").thenThrow(
				new RuntimeException());

		Foo foo = new Foo();
		Foo fooPersisted = this.persistenceServiceBean.batchPersist(foo, null);

		assertNotNull(fooPersisted);
	}

}