/**
 * ApplicationPropertiesException.java
 *
 * $Revision: 1.2 $ ($Date: 2011-04-06 04:46:26 $)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.properties;

import com.smartmatic.waffle.lang.BaseRuntimeException;
import com.smartmatic.waffle.lang.IExceptionInfo;

/**
 * Represents a error condition occurred handling application properties.
 * 
 * @author Carlos Lameda (carlos.lameda@smartmatic.com)
 * @version 1.0 (Nov 6, 2009)
 */

public class ApplicationPropertiesException extends BaseRuntimeException {

	/**
	 * Holds the version of the class. It is used by the serialization engine to
	 * determine when a class its equivalent to another
	 * 
	 * @author Ithamar Torres (itorres@smartmatic.com)
	 */

	private static final long serialVersionUID = -7351410891184276848L;

	/**
	 * Enum that contains all the possible reasons because the
	 * ApplicationPropertiesException can be thrown
	 * 
	 * 
	 * @version 1.0 (23/10/2006)
	 * @author Ithamar Torres (itorres@smartmatic.com)
	 */

	public enum ExceptionInfo implements IExceptionInfo {
		SERVICE_NOT_INITIALIZED("SERVICE_NOT_INITIALIZED"), SERVICE_ALREADY_INITIALIZED(
				"SERVICE_ALREADY_INITIALIZED"), INITIALIZATION_EXCEPTION(
				"INITIALIZATION_EXCEPTION"), PROPERTY_NOT_FOUND(
				"PROPERTY_NOT_FOUND"), ERROR_CONVERTING_TO_TYPE(
				"ERROR_CONVERTING_TO_TYPE");

		/**
		 * <p>
		 * Each enumerator's resource bundle's key message.
		 * </p>
		 */

		private String message;

		/**
		 * Getter of <code>message</code> property.
		 * 
		 * @return <code>message</code> property value.
		 * @see #message
		 * 
		 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
		 */

		@Override
		public String getMessage() {
			return this.message;
		}

		/**
		 * Constructor
		 * 
		 * @param msg
		 *            the resource bundle's key message
		 * 
		 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
		 */

		private ExceptionInfo(String msg) {
			this.message = this.getClass().getName() + "." + msg;
		}
	}

	/**
	 * Creates a instance of a JNICommunicationException
	 * 
	 * @param exceptionInfo
	 *            The reason because the exception is being thrown
	 * 
	 * @author Ithamar Torres (itorres@smartmatic.com)
	 */

	public ApplicationPropertiesException(IExceptionInfo exceptionInfo) {
		super(exceptionInfo);
		return;
	}

	/**
	 * Creates a instance of a JNICommunicationException
	 * 
	 * @param exceptionInfo
	 *            The reason because the exception is being thrown
	 * @param e
	 *            params used to give information about the exception
	 * 
	 * @author Ithamar Torres (itorres@smartmatic.com)
	 */

	public ApplicationPropertiesException(IExceptionInfo exceptionInfo,
			Throwable e) {
		super(exceptionInfo, e);
		return;
	}

	/**
	 * Creates a instance of a JNICommunicationException
	 * 
	 * @param exceptionInfo
	 *            The reason because the exception is being thrown
	 * @param parameters
	 *            params used to give information about the exception
	 * 
	 * @author Ithamar Torres (itorres@smartmatic.com)
	 */
	public ApplicationPropertiesException(IExceptionInfo exceptionInfo,
			Object... parameters) {
		super(exceptionInfo, parameters);
		return;
	}

	/**
	 * Creates a instance of a JNICommunicationException
	 * 
	 * @param exceptionInfo
	 *            The reason because the exception is being thrown
	 * @param parameters
	 *            params used to give information about the exception
	 * 
	 * @author Ithamar Torres (itorres@smartmatic.com)
	 */
	public ApplicationPropertiesException(IExceptionInfo exceptionInfo,
			String message) {
		super(exceptionInfo, message);
		return;
	}
}
