/**
 * Validator.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.validator;

import java.lang.reflect.Method;

import javax.ejb.TransactionAttribute;
import javax.ejb.TransactionAttributeType;

import com.smartmatic.waffle.client.ClientJNDIWrapper;
import com.smartmatic.waffle.client.JNDICommunicationException;
import com.smartmatic.waffle.domain.general.BaseGeneralInfo;
import com.smartmatic.waffle.domain.multiLanguage.MultiLingualKeyData;
import com.smartmatic.waffle.lang.BaseException;
import com.smartmatic.waffle.lang.util.ReflectHelper;
import com.smartmatic.waffle.persistence.metadata.MultilingualPropertyAnnotation;
import com.smartmatic.waffle.persistence.service.spec.IPersistenceService;

/**
 * Class used to perform validations on persistence events.
 */
public class Validator {

	/**
	 * Pre persist.
	 * 
	 * @param component
	 *            the component
	 */
	public void prePersist(BaseGeneralInfo component) {

		if (checkMultilingualAnnotation(component)) {
			proccessMultilingualFields(component);
		}

	}

	/**
	 * Pre remove.
	 * 
	 * @param component
	 *            the component
	 */
	public void preRemove(BaseGeneralInfo component) {
		// TODO Auto-generated method stub

	}

	/**
	 * Pre update.
	 * 
	 * @param component
	 *            the component
	 */
	public void preUpdate(BaseGeneralInfo component) {
		// TODO Auto-generated method stub

	}

	/**
	 * Checks if a class have multilingual annotation processing methods.
	 * 
	 * @param object
	 *            The object to process
	 * @return If the object have multilingual annotation
	 */

	private boolean checkMultilingualAnnotation(BaseGeneralInfo object) {

		Method[] methods = object.getClass().getMethods();
		Class multilingualAnnotationClass = MultilingualPropertyAnnotation.class;
		for (Method theElement : methods) {
			MultilingualPropertyAnnotation annotation = (MultilingualPropertyAnnotation) theElement
					.getAnnotation(multilingualAnnotationClass);
			if (annotation != null) {
				return true;
			}
		}
		return false;
	}

	/**
	 * Method responsible of maintain updated all the multilingual information
	 * that should be persisted in the database. This method search in each
	 * object all those fields defined as multilingual and stores
	 * 
	 * @param object
	 *            The object to process
	 */
	@SuppressWarnings("unchecked")
	private void proccessMultilingualFields(BaseGeneralInfo object) {

		try {
			IPersistenceService iPersistenceService = ClientJNDIWrapper
					.getInstance().getReference(IPersistenceService.class);
			Method[] methods = object.getClass().getMethods();
			Class multilingualAnnotationClass = MultilingualPropertyAnnotation.class;
			for (Method theElement : methods) {
				MultilingualPropertyAnnotation annotation = (MultilingualPropertyAnnotation) theElement
						.getAnnotation(multilingualAnnotationClass);

				if (annotation != null) {
					MultiLingualKeyData multilingualKey = this
							.generateMultilanguageKey(object, theElement);
					iPersistenceService.persist(multilingualKey, null);

				}
			}
		} catch (JNDICommunicationException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (BaseException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Generate multilanguage key.
	 * 
	 * @param object
	 *            the object
	 * @param theElement
	 *            the the element
	 * @return the multi lingual key data
	 */
	@TransactionAttribute(TransactionAttributeType.NOT_SUPPORTED)
	public MultiLingualKeyData generateMultilanguageKey(BaseGeneralInfo object,
			Method theElement) {
		// Process all methods finding the multilingual ones

		// Save the multilingual resource
		MultiLingualKeyData multilingualKey = new MultiLingualKeyData();

		multilingualKey.setKey(object.getClass().getName());

		multilingualKey.setField(ReflectHelper
				.getPropertyNameFromGetter(theElement));

		multilingualKey.setCustomCodeRef(object.getCustomCode());

		multilingualKey.setCustomCode(object.getClass().getSimpleName()
				.toUpperCase()
				+ "_"
				+ "_"
				+ multilingualKey.getField().toUpperCase()
				+ "_"
				+ multilingualKey.getCustomCodeRef().toUpperCase());

		multilingualKey.setForeignKey(object.getCode());
		return multilingualKey;
	}
}
