/**
 * ValidatorEligibleOption.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.validator;

import java.lang.reflect.Method;

import javax.ejb.TransactionAttribute;
import javax.ejb.TransactionAttributeType;

import com.smartmatic.waffle.client.ClientJNDIWrapper;
import com.smartmatic.waffle.client.JNDICommunicationException;
import com.smartmatic.waffle.domain.contest.ContestData;
import com.smartmatic.waffle.domain.contest.ContestClassData.Type;
import com.smartmatic.waffle.domain.eligibleoption.EligibleOptionData;
import com.smartmatic.waffle.domain.multiLanguage.MultiLingualKeyData;
import com.smartmatic.waffle.lang.BaseException;
import com.smartmatic.waffle.lang.util.ReflectHelper;
import com.smartmatic.waffle.persistence.metadata.MultilingualPropertyAnnotation;
import com.smartmatic.waffle.persistence.search.SearchExpression;
import com.smartmatic.waffle.persistence.search.criteria.CriteriaFactory;
import com.smartmatic.waffle.persistence.search.transformation.TransformationFactory;
import com.smartmatic.waffle.persistence.search.transformation.TransformationsList;
import com.smartmatic.waffle.persistence.service.spec.IPersistenceService;

/**
 * Class used to validate eligible option data..
 */
public class ValidatorEligibleOption {

	/**
	 * Pre persist.
	 * 
	 * @param component
	 *            the component
	 */
	public void prePersist(EligibleOptionData component) {

		if (checkMultilingualAnnotation(component)) {
			proccessMultilingualFields(component);
		}

	}

	/**
	 * Checks if a class have multilingual annotation processing methods.
	 * 
	 * @param eligibleOption
	 *            the eligible option
	 * @return If the object have multilingual annotation
	 */

	private boolean checkMultilingualAnnotation(
			EligibleOptionData eligibleOption) {

		Method[] methods = eligibleOption.getClass().getMethods();
		Class multilingualAnnotationClass = MultilingualPropertyAnnotation.class;
		for (Method theElement : methods) {
			MultilingualPropertyAnnotation annotation = (MultilingualPropertyAnnotation) theElement
					.getAnnotation(multilingualAnnotationClass);
			if (annotation != null) {
				return true;
			}
		}
		return false;
	}

	/**
	 * Checks if is contest class type issue.
	 * 
	 * @param contestCode
	 *            the contest code
	 * @return true, if is contest class type issue
	 */
	private boolean isContestClassTypeIssue(long contestCode) {
		try {
			IPersistenceService iPersistenceService = ClientJNDIWrapper
					.getInstance().getReference(IPersistenceService.class);

			SearchExpression search = new SearchExpression(ContestData.class);

			search.createAlias("contestClass", "contestClass");

			search.addSearchCriteria(CriteriaFactory.eq("code", contestCode));

			TransformationsList lightTransformation = TransformationFactory
					.transformationList();

			lightTransformation = TransformationFactory.transformationList();
			lightTransformation.add(TransformationFactory
					.propertyTransformation("code"));
			lightTransformation.add(TransformationFactory
					.propertyTransformation("contestClass.type"));

			search.setTransformation(lightTransformation);

			Object[] contestClass = (Object[]) iPersistenceService
					.searchObject(search, null);

			Type type = (Type) contestClass[1];

			if (type.equals(Type.ISSUE)) {
				return true;
			}
		} catch (JNDICommunicationException e) {
			e.printStackTrace();
		} catch (BaseException e) {
			e.printStackTrace();
		}
		return false;
	}

	/**
	 * Method responsible of maintain updated all the multilingual information
	 * that should be persisted in the database. This method search in each
	 * eligibleOption all those fields defined as multilingual and stores
	 * 
	 * @param eligibleOption
	 *            The eligibleOption to process
	 */
	@SuppressWarnings("unchecked")
	private void proccessMultilingualFields(EligibleOptionData eligibleOption) {

		try {
			if (isContestClassTypeIssue(eligibleOption.getContest().getCode())) {
				IPersistenceService iPersistenceService = ClientJNDIWrapper
						.getInstance().getReference(IPersistenceService.class);
				Method[] methods = eligibleOption.getClass().getMethods();
				Class multilingualAnnotationClass = MultilingualPropertyAnnotation.class;
				for (Method theElement : methods) {
					MultilingualPropertyAnnotation annotation = (MultilingualPropertyAnnotation) theElement
							.getAnnotation(multilingualAnnotationClass);

					if (annotation != null) {
						MultiLingualKeyData multilingualKey = this
								.generateMultilanguageKey(eligibleOption,
										theElement);
						iPersistenceService.persist(multilingualKey, null);
					}
				}
			}
		} catch (JNDICommunicationException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (BaseException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Generate multilanguage key.
	 * 
	 * @param eligibleOption
	 *            the eligible option
	 * @param theElement
	 *            the the element
	 * @return the multi lingual key data
	 */
	@TransactionAttribute(TransactionAttributeType.NOT_SUPPORTED)
	public MultiLingualKeyData generateMultilanguageKey(
			EligibleOptionData eligibleOption, Method theElement) {
		// Process all methods finding the multilingual ones

		// Save the multilingual resource
		MultiLingualKeyData multilingualKey = new MultiLingualKeyData();

		multilingualKey.setKey(eligibleOption.getClass().getName());

		multilingualKey.setField(ReflectHelper
				.getPropertyNameFromGetter(theElement));

		multilingualKey.setCustomCodeRef(eligibleOption.getCustomCode());

		multilingualKey.setCustomCode(eligibleOption.getClass().getSimpleName()
				.toUpperCase()
				+ "_"
				+ "_"
				+ multilingualKey.getField().toUpperCase()
				+ "_"
				+ multilingualKey.getCustomCodeRef().toUpperCase());

		multilingualKey.setForeignKey(eligibleOption.getCode());
		return multilingualKey;
	}
}
