/**
 * InvalidConversionDataTypeException.java
 *
 * $Revision: 1.5 $ ($Date: 2011-04-06 05:08:30 $)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.lang;

/**
 * Class used to indicate that a exception is thrown because a problem with
 * related to conversion data types occurred.
 * 
 * @author Héctor Rodríguez (hector.rodriguez@smartmatic.com)
 * @version 1.0 (21/01/2009)
 */
public class InvalidConversionDataTypeException extends BaseException {
	/**
	 * Holds the version of the class. It is used by the serialization engine to
	 * determine when a class its equivalent to another
	 * 
	 * @author Carlos Lameda (carlos.lameda@smartmatic.com)
	 */
	private static final long serialVersionUID = -6122866654229143512L;

	/**
	 * Enum that contains all the possible reasons because the
	 * NotSerializableObjectException can be thrown
	 * 
	 * 
	 * @version 1.0 (21/01/2009)
	 * @author Héctor Rodríguez (hector.rodriguez@smartmatic.com)
	 */

	public enum ExceptionInfo implements IExceptionInfo {

		INVALID_CHARACTER_HEXADECIMAL("INVALID_CHARACTER_HEXADECIMAL"), INVALID_CHAIN_HEXADECIMAL_CHARACTER(
				"INVALID_CHAIN_HEXADECIMAL_CHARACTER");
		/**
		 * <p>
		 * Each enumerator's resource bundle's key message.
		 * </p>
		 */

		private String message;

		/**
		 * Getter of <code>message</code> property.
		 * 
		 * @author Héctor Rodríguez (hector.rodriguez@smartmatic.com)
		 * @return <code>message</code> property value.
		 * @see #message
		 */
		@Override
		public String getMessage() {
			return this.message;
		}

		/**
		 * Constructor
		 * 
		 * @author Héctor Rodríguez (hector.rodriguez@smartmatic.com)
		 * @param msg
		 *            the resource bundle's key message
		 */
		private ExceptionInfo(String msg) {
			this.message = this.getClass().getName() + "." + msg;
		}
	}

	/**
	 * Creates a instance of a InvalidConversionDataTypeException
	 * 
	 * @param exceptionInfo
	 *            The reason because the exception is being thrown
	 * 
	 */
	public InvalidConversionDataTypeException(IExceptionInfo exceptionInfo) {
		super(exceptionInfo);
	}

	/**
	 * Creates a instance of a InvalidConversionDataTypeException
	 * 
	 * @param exceptionInfo
	 *            The reason because the exception is being thrown
	 * @param throwable
	 *            params used to give information about the exception
	 * 
	 */
	public InvalidConversionDataTypeException(IExceptionInfo exceptionInfo,
			Throwable throwable) {
		super(exceptionInfo, throwable);
	}

	/**
	 * Creates a instance of a InvalidConversionDataTypeException
	 * 
	 * @author Ithamar Torres (itorres@smartmatic.com)
	 * @param exceptionInfo
	 *            The reason because the exception is being thrown
	 * @param throwable
	 *            params used to give information about the exception
	 * @param parameters
	 *            The array of placeholder values used as parameters for this
	 *            exception's enumerated cause's related message
	 */
	public InvalidConversionDataTypeException(IExceptionInfo exceptionInfo,
			Throwable throwable, Object... parameters) {
		super(exceptionInfo, throwable, parameters);
	}

	/**
	 * Creates a instance of a InvalidConversionDataTypeException
	 * 
	 * @author Ithamar Torres (itorres@smartmatic.com)
	 * @param exceptionInfo
	 *            The reason because the exception is being thrown
	 * @param parameters
	 *            The array of placeholder values used as parameters for this
	 *            exception's enumerated cause's related message
	 */
	public InvalidConversionDataTypeException(IExceptionInfo exceptionInfo,
			Object... parameters) {
		super(exceptionInfo, parameters);
	}

}
