/**
 * NotSerializableObjectException.java
 *
 * $Revision: 1.5 $ ($Date: 2011-04-06 05:08:30 $)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.lang;

/**
 * Class that represents any exception during a serialization process.
 * 
 * @author Héctor Rodríguez (hector.rodriguez@smartmatic.com)
 * @version 1.0 (20/01/2009)
 */
public class NotSerializableObjectException extends BaseException {
	/**
	 * Holds the version of the class. It is used by the serialization engine to
	 * determine when a class its equivalent to another
	 * 
	 * @author Carlos Lameda (carlos.lameda@smartmatic.com)
	 */
	private static final long serialVersionUID = -2448026738988419370L;

	/**
	 * Enum that contains all the possible reasons because the
	 * NotSerializableObjectException can be thrown
	 * 
	 * 
	 * @version 1.0 (30/08/2007)
	 * @author Ithamar Torres (itorres@smartmatic.com)
	 */

	public enum ExceptionInfo implements IExceptionInfo {

		INVALID_INNER_REFERENCE("INVALID_INNER_REFERENCE"), UNKNOWN_INNER_REFERENCE(
				"UNKNOWN_INNER_REFERENCE");
		/**
		 * <p>
		 * Each enumerator's resource bundle's key message.
		 * </p>
		 */

		private String message;

		/**
		 * Getter of <code>message</code> property.
		 * 
		 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
		 * @return <code>message</code> property value.
		 * @see #message
		 */
		@Override
		public String getMessage() {
			return this.message;
		}

		/**
		 * Constructor
		 * 
		 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
		 * @param msg
		 *            the resource bundle's key message
		 */
		private ExceptionInfo(String msg) {
			this.message = this.getClass().getName() + "." + msg;
		}
	}

	/**
	 * Creates a ObjectDataValidatorException instance
	 * 
	 * @param exceptionInfo
	 *            The cause of the exception
	 */

	public NotSerializableObjectException(IExceptionInfo exceptionInfo) {
		super(exceptionInfo);
	}

	/**
	 * Creates a ObjectDataValidatorException instance
	 * 
	 * @param exceptionInfo
	 *            The cause of the exception
	 * @param inner
	 *            Inner exception cause of the error condition
	 */

	public NotSerializableObjectException(IExceptionInfo exceptionInfo,
			Exception inner) {
		super(exceptionInfo, inner);
	}
}
