/**
 * ObjectDataValidator.java
 *
 * $Revision: 1.4 $ ($Date: 2011-04-06 05:08:28 $)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.validator;

/**
 * Class that defines the required methods in the validation process. The class
 * can be extended by the other classes to be validated.
 * 
 * @author Carlos Lameda (carlos.lameda@smartmatic.com)
 * @version 1.0 (04/09/2006)
 */
public class ObjectDataValidator<T> implements IObjectDataValidator<T> {

	/**
	 * Method to execute before persisting a component. It must implements
	 * business rules.
	 * 
	 * @author Carlos Lameda (carlos.lameda@smartmatic.com)
	 * @param component
	 *            to be saved.
	 */
	@Override
	public void prePersist(T component) throws ObjectDataValidatorException {
	}

	/**
	 * Method to execute after persisting a component. It must implements
	 * business rules.
	 * 
	 * @author Carlos Lameda (carlos.lameda@smartmatic.com)
	 * @param the
	 *            saved component.
	 */
	@Override
	public void postPersist(T component) throws ObjectDataValidatorException {
	}

	/**
	 * Method to execute before removing a component. It must implements
	 * business rules.
	 * 
	 * @author Carlos Lameda (carlos.lameda@smartmatic.com)
	 * @param the
	 *            component to remove.
	 */
	@Override
	public void preRemove(T component) throws ObjectDataValidatorException {
	}

	/**
	 * Method to execute after removing a component. It must implements business
	 * rules.
	 * 
	 * @author Carlos Lameda (carlos.lameda@smartmatic.com)
	 * @param the
	 *            removed component.
	 */
	@Override
	public void postRemove(T component) throws ObjectDataValidatorException {
	}

	/**
	 * Method to execute before updating a component. It must implements
	 * business rules.
	 * 
	 * @author Carlos Lameda (carlos.lameda@smartmatic.com)
	 * @param the
	 *            component to update.
	 */
	@Override
	public void preUpdate(T component) throws ObjectDataValidatorException {
	}

	/**
	 * Method to execute after updating a component. It must implements business
	 * rules.
	 * 
	 * @author Carlos Lameda (carlos.lameda@smartmatic.com)
	 * @param the
	 *            updated component.
	 */
	@Override
	public void postUpdate(T component) throws ObjectDataValidatorException {
	}
}