/*
 * ConfigLogger.cxx
 *
 *  Created on: 23/08/2011
 *      Author: soto
 */

#include "Config.hxx"
#include <Runtime/Environment/MemoryPathController.h>
#include <log4cxx/DynamicPathRollingFileAppender.hxx>
#include <Configuration/s-a-e-s-common-conf-manager.h>
#include <Configuration/SmartmaticLanguageController.hxx>
#include <Configuration/smartmaticgui-language-controller.h>
#include <Configuration/saes-language-controller.h>
#include <Configuration/saes-common-language-controller.h>
#include <Configuration/saes-hardware-language-controller.h>
#include <Configuration/saes-functionality-language-controller.h>
#include <Configuration/saes-gui-language-controller.h>
#include <log4cxx/CryptoLayout.hxx>
#include <Log/LogCryptoPool.hxx>
#include <pcscd/PCSCDManager.hxx>
#include <Log/SMTTLogManager.h>
#include <Log/LogBasePath.hxx>
#include <System/IO/Directory.h>
#include <System/IO/Path.h>
#include <glib.h>
#include <Operation/MachineOperationManager.hxx>
#include <Operation/CheckDataManager.hxx>
#include <System/Security/OpenSSLSecurity.hxx>
#include <System/Security/XmlSecurityC.hxx>
#include <Operation/Monitor/DeviceTypeMonitorPool.hxx>
#include <Operation/MemoryEventManager.hxx>
#include <Operation/Devices/Polling/CardPolling.hxx>
#include <Operation/Devices/Polling/BCRPolling.hxx>
#include <Operation/Devices/Polling/AlarmPolling.hxx>
#include <Operation/Devices/Polling/AbleDPolling.hxx>
#include <Operation/Voting/VotingEnqueuer.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::Election;
using namespace Smartmatic::SAES::Runtime::Environment;
using namespace Smartmatic::SAES::Common::Configuration;
using namespace Smartmatic::SAES::PCSCD;
using namespace Smartmatic::SAES::Log;
using namespace Smartmatic::System::IO;
using namespace Smartmatic::Log;
using namespace Smartmatic::Configuration;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::HW::Configuration;
using namespace Smartmatic::SAES::Functionality::Configuration;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::Operation::Monitor;
using namespace Smartmatic::SAES::Operation::Devices;
using namespace Smartmatic::SAES::Operation::Voting;

void Config::start()
{
    Smartmatic::System::Security::OpenSSLSecurity::init();
    Smartmatic::System::Security::XmlSecurityC::init();

    MemoryPathController::getInstance()->updatePaths();

    DeviceTypeMonitorPool::getInstance();
    MemoryEventManager::getInstance();

    CardPolling::getInstance();
    BCRPolling::getInstance();
    AlarmPolling::getInstance();
    AbleDPolling::getInstance();
    VotingEnqueuer::getInstance();

    // Don't remove, this line configure the signal to show usb driver actions
    CheckDataManager::getInstance()->stopDetection();

    // Don't remove, this lines configure the logger
    LogBasePath * basePathDom = MachineOperationManager::getInstance()->getLogBasePathDom();
    LogBasePath * basePathFlash = MachineOperationManager::getInstance()->getLogBasePathFlash();
    log4cxx::CryptoLayout::setCryptoMap ( LogCryptoPool::getInstance()->getCryptoMap() );
    log4cxx::DynamicPathRollingFileAppender::putBasePathInterface ( basePathDom );
    log4cxx::DynamicPathRollingFileAppender::putBasePathInterface ( basePathFlash );

    SMTTLogManager::getInstance()->Reconfigure();

    //Init rand funtion
    Glib::TimeVal time;
    time.assign_current_time();
    int seed = time.as_double();
    srand ( seed );

    PCSCDManager::start();
    SmartmaticLanguageController smartLang;
    smartLang.InitializeLanguage();
    SmartmaticGUILanguageController smartguiLang;
    smartguiLang.InitializeLanguage();
    SAESLanguageController saesLang;
    saesLang.InitializeLanguage();
    SAESGUILanguageController saesguiLang;
    saesguiLang.InitializeLanguage();
    SAESCommonLanguageController saescommonLang;
    saescommonLang.InitializeLanguage();
    SAESFunctionalityLanguageController saesfuncLang;
    saesfuncLang.InitializeLanguage();
    SAESHardwareLanguageController saeshwLang;
    saeshwLang.InitializeLanguage();
}
