/**
 * @file   EmlChecksumException.hxx
 * @brief  Declaration of EmlChecksumException class.
 * @author manuel.arguelles
 * @date   Feb 12, 2018
 */

#ifndef EML_CHECKSUM_EXCEPTION_HXX
#define EML_CHECKSUM_EXCEPTION_HXX

#include <System/Exception/BaseException.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Exceptions
        {
            namespace Voting
            {
                namespace Eml
                {
                    /**
                     * @class  EmlChecksumException
                     * @brief  Exception when checksum calculation fails.
                     * @author manuel.arguelles
                     * @date   Feb 12, 2018
                     */
                    class EmlChecksumException : public Smartmatic::System::Exception::BaseException
                    {
                        public:

                            /**
                             * @brief  Creates an instance of the exception.
                             * @author manuel.arguelles
                             * @date   Feb 12, 2018
                             * @param  message The exception message.
                             * @param  code    The exception code.
                             * @param  logger  The logger.
                             */
                            EmlChecksumException(std::string message, std::string code,
                                                 Smartmatic::Log::ISMTTLog* logger = NULL);
                    };

                } /* namespace Eml */
            } /* namespace Voting */
        } /* namespace Exceptions */
    } /* namespace SAES */
} /* namespace Smartmatic */


#endif /* EML_CHECKSUM_EXCEPTION_HXX */
