/**
 * @file	AuditLogPrintDocument.h
 * @brief	Declares the audit log print document class.
 * @author	Youssef.tourkmani
 * @date	31/10/2012
 */

#ifndef AUDITLOGPRINTDOCUMENT_H_
#define AUDITLOGPRINTDOCUMENT_H_

#include <Voting/ElectoralConfiguration.hxx>
#include "Printing/LogPrintDocument.h"

namespace Smartmatic
{

    namespace SAES
    {

        namespace Printing
        {

            /**
             * @class	AuditLogPrintDocument
             * @brief	Audit log print document.
             * @author	Youssef.tourkmani
             * @date	31/10/2012
             */
            class AuditLogPrintDocument : public LogPrintDocument
            {
                public:

                    /**
                     * @fn	AuditLogPrintDocument::AuditLogPrintDocument(Smartmatic::SAES::Log::LogReader* reader,
                     * 			Smartmatic::SAES::Voting::ElectoralConfiguration * electoralConfiguration);
                     * @brief	Constructor.
                     * @author	Youssef.tourkmani
                     * @date	31/10/2012
                     * @param [in,out]	reader									If non-null, the reader.
                     * @param [in,out]	electoralConfiguration	If non-null, the electoral configuration.
                     */
                    AuditLogPrintDocument ( Smartmatic::SAES::Log::LogReader * reader,
                                            Smartmatic::SAES::Voting::ElectoralConfiguration * electoralConfiguration );
                    /**
                     * @fn	virtual AuditLogPrintDocument::~AuditLogPrintDocument();
                     * @brief	Destructor.
                     * @author	Youssef.tourkmani
                     * @date	31/10/2012
                     */
                    virtual ~AuditLogPrintDocument();

                protected:

                    /**
                     * @fn	virtual std::string AuditLogPrintDocument::GetLogDocName ();
                     * @brief	Gets log document name.
                     * @author	Youssef.tourkmani
                     * @date	31/10/2012
                     * @return	The log document name.
                     */
                    virtual std::string GetLogDocName ();

            };

        }

    }

}

#endif /* AUDITLOGPRINTDOCUMENT_H_ */
