/**
 * @file HelpPrinting.hxx
 * @brief Header class barcode config printing
 * @date 29/03/2012
 * @author Yadickson Soto
 */

#ifndef HELPPRINTING_HXX_
#define HELPPRINTING_HXX_

#include <gtkmm.h>
#include <Printing/IBasePrintDocument.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace SAES
    {
        namespace Printing
        {
            /**
             * @class	HelpPrinting
             * @brief	Class barcode config printing.
             * @author	Yadickson Soto
             * @see BasePrintDocument
             * @date	29/03/2012
             */
            class HelpPrinting : public IBasePrintDocument
            {
                public:
                    /**
                     * @fn	HelpPrinting::HelpPrinting(std::string file);
                     * @brief	Class constructor.
                     * @author	Yadickson Soto
                     * @date	29/03/2012
                     * @param	file	fine name.
                     */
                    explicit HelpPrinting ( const std::string& file );
                    /**
                     * @fn	virtual HelpPrinting::~HelpPrinting();
                     * @brief	Class destructor.
                     * @author	Yadickson Soto
                     * @date	29/03/2012
                     */
                    virtual ~HelpPrinting();
                    /**
                     * @fn	void HelpPrinting::Print();
                     * @brief	Method print doc.
                     * @author	Yadickson Soto
                     * @date	29/03/2012
                     */
                    void Print();

                    /**
                     * @fn	void HelpPrinting::setClient (PrintDocumentClient * client);
                     * @brief	set the client of the print document.
                     * @author	Yadickson Soto
                     * @date	30/11/2012
                     * @param	client	If non-null, the client.
                     */

                    void setClient ( PrintDocumentClient * client );

                private:

                    std::string file; ///< file name
                    PrintDocumentClient * client; ///< client
                    static Smartmatic::Log::ISMTTLog * logger; ///< logger
            };
        }
    }
}

#endif /* BARCODECONFIGPRINTING_HXX_ */
