/**
 * @file	TimeoutPrintDocument.h
 * @brief	Declares the timeout print document class.
 * @author	Youssef.tourkmani
 * @date	31/10/2012
 */


#ifndef _TIMEOUT_PRINT_DOCUMENT_H_
#define _TIMEOUT_PRINT_DOCUMENT_H_
#include "Printing/BasePrintDocument.h"
#include <Voting/ElectoralConfiguration.hxx>
#include "Configuration/s-a-e-s-conf-manager.h"

namespace Smartmatic
{
    namespace SAES
    {
        namespace Printing
        {
            /**
             * @class	TimeoutPrintDocument
             * @brief	Timeout print document.
             * @author	Eduardo.campione
             * @date	28/04/2011
             */

            class TimeoutPrintDocument : public BasePrintDocument
            {
                public:

                    /**
                     * @fn	TimeoutPrintDocument::TimeoutPrintDocument (Smartmatic::SAES::Voting::ElectoralConfiguration * electoralConfiguration,
                     * 			Glib::ustring voteCode);
                     * @brief	Constructor.
                     * @author	Eduardo.campione
                     * @date	28/04/2011
                     * @param	electoralConfiguration	The electoral configuration.
                     * @param	voteCode								The vote code.
                     */

                    TimeoutPrintDocument ( Smartmatic::SAES::Voting::ElectoralConfiguration * electoralConfiguration, Glib::ustring voteCode );
                protected:

                    /**
                     * @fn	void TimeoutPrintDocument::PrintDoc();
                     * @brief	Print document.
                     * @author	Eduardo.campione
                     * @date	28/04/2011
                     */

                    void PrintDoc();

                    /**
                     * @fn	void TimeoutPrintDocument::BeginPrint();
                     * @brief	Begins a print.
                     * @author	Eduardo.campione
                     * @date	28/04/2011
                     */

                    void BeginPrint();

                    /**
                     * @fn	void TimeoutPrintDocument::EndPrint();
                     * @brief	Ends a print.
                     * @author	Eduardo.campione
                     * @date	28/04/2011
                     */

                    void EndPrint();
                private:
                    Smartmatic::SAES::Voting::ElectoralConfiguration * _electoralConfiguration; ///< The electoral configuration
                    Glib::ustring _voteCode;	///< The vote code
                    Smartmatic::SAES::Configuration::ConfigurationTimeout _configurationTimeoutPrinting;	///< The configuration timeout printing
            };
        }
    }
}

#endif // _TIMEOUT_PRINT_DOCUMENT_H_
