/**
 * @file   ElectionAudioResourcesManager.hxx
 * @brief  Declaration of ElectionAudioResourcesManager class.
 * @author manuel.arguelles
 * @date   Oct 12, 2017
 */

#ifndef ELECTION_AUDIO_RESOURCES_MANAGER_HXX
#define ELECTION_AUDIO_RESOURCES_MANAGER_HXX

#include <Resources/string-resources-manager-base.h>
#include <Runtime/Environment/saes-directories.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Resources
        {

            /**
             * @class  ElectionAudioResourcesManager
             * @brief  Audio resources for the election.
             * @author manuel.arguelles
             * @date   Oct 12, 2017
             */
            class ElectionAudioResourcesManager : public StringResourcesManagerBase
            {
                public:

                    /**
                     * @brief  Gets the instance of the class.
                     * @author manuel.arguelles
                     * @date   Oct 12, 2017
                     * @param  externalResource Returns the given resource
                     * instead of creating a new one. (For unit test)
                     * @return The instance of the class.
                     */
                    static ElectionAudioResourcesManager* getInstance(ElectionAudioResourcesManager* externalResource = NULL);

                    /**
                     * @brief  Initialize the object.
                     * @author manuel.arguelles
                     * @date   Oct 12, 2017
                     * @param  directories The saes directories object.
                     * @param  type        The base path type.
                     */
                    void init(SAES::Runtime::Environment::SaesDirectories* directories,
                              SAES::Common::Configuration::BasePathType type = SAES::Common::Configuration::BasePathType::CONFIGURATION_LIVE);

                    /**
                     * @brief  Returns the file name of the resource.
                     * @author manuel.arguelles
                     * @date   Oct 12, 2017
                     * @return The file name of the resource.
                     */
                    virtual std::string& getFileName();

                    /**
                     * @brief  Returns the path where the resources are.
                     * @author manuel.arguelles
                     * @date   Oct 12, 2017
                     * @return The absolute path of the resources directory.
                     */
                    virtual std::string& getFullFolderPath();

                    /**
                     * @brief   Gets a resource.
                     * @author  marcel.mancini
                     * @date    Jan 31, 2018
                     * @param   key The key.
                     * @return  The resource.
                     */
                    virtual std::string getResource ( const std::string & key );


                private:

                    /**
                     * @brief  Creates an instance of the class.
                     * @author manuel.arguelles
                     * @date   Oct 12, 2017
                     */
                    ElectionAudioResourcesManager();

                    /**
                     * @brief  Destroys an instance of the class.
                     * @author manuel.arguelles
                     * @date   Oct 12, 2017
                     */
                    virtual ~ElectionAudioResourcesManager();

                private:

                    std::string m_fileName;
                    std::string m_folderPath;
                    static ElectionAudioResourcesManager* m_instance;
            };

        } /* namespace Resources */
    } /* namespace SAES */
} /* namespace Smartmatic */

#endif /* ELECTION_AUDIO_RESOURCES_MANAGER_HXX */
