/**
 * @file   GeneralAudioResourcesManager.hxx
 * @brief  Declaration of GeneralAudioResourcesManager class.
 * @author manuel.arguelles
 * @date   Oct 12, 2017
 */

#ifndef GENERAL_AUDIO_RESOURCES_MANAGER_HXX
#define GENERAL_AUDIO_RESOURCES_MANAGER_HXX

#include <Resources/string-resources-manager-base.h>
#include <Runtime/Environment/saes-directories.h>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Resources
        {

            /**
             * @class  GeneralAudioResourcesManager
             * @brief  Audio resources for the election.
             * @author manuel.arguelles
             * @date   Oct 12, 2017
             */
            class GeneralAudioResourcesManager : public StringResourcesManagerBase
            {
                public:

                    /**
                     * @brief  Destroys an instance of the class.
                     * @author manuel.arguelles
                     * @date   Oct 12, 2017
                     */
                    virtual ~GeneralAudioResourcesManager();


                public:

                    /**
                     * @brief  Gets the instance of the class.
                     * @author manuel.arguelles
                     * @date   Oct 12, 2017
                     * @param  externalResource Returns the given resource
                     * instead of creating a new one. (For unit test)
                     * @return The instance of the class.
                     */
                    static GeneralAudioResourcesManager* getInstance(GeneralAudioResourcesManager* externalResource = NULL);

                    /**
                     * @brief  Initialize the object.
                     * @author manuel.arguelles
                     * @date   Oct 12, 2017
                     * @param  directories The saes directories object.
                     * @param  type        The base path type.
                     */
                    void init(SAES::Runtime::Environment::SaesDirectories* directories,
                              SAES::Common::Configuration::BasePathType type = SAES::Common::Configuration::BasePathType::CONFIGURATION_LIVE);

                    /**
                     * @brief  Returns the file name of the resource.
                     * @author manuel.arguelles
                     * @date   Oct 12, 2017
                     * @return The file name of the resource.
                     */
                    virtual std::string& getFileName();

                    /**
                     * @brief  Returns the path where the resources are.
                     * @author manuel.arguelles
                     * @date   Oct 12, 2017
                     * @return The absolute path of the resources directory.
                     */
                    virtual std::string& getFullFolderPath();

                protected:

                    /**
                     * @brief  Creates an instance of the class.
                     * @author manuel.arguelles
                     * @date   Oct 12, 2017
                     */
                    GeneralAudioResourcesManager();


                    /**
                     * @brief  Override of base Initialize method.
                     * @author manuel.arguelles
                     * @date   Dec 19, 2017
                     */
                    virtual void Initialize();

                private:

                    std::string m_fileName;
                    std::string m_folderPath;
                    static GeneralAudioResourcesManager* m_instance;
                    static Smartmatic::Log::ISMTTLog* m_logger;
            };

        } /* namespace Resources */
    } /* namespace SAES */
} /* namespace Smartmatic */

#endif /* GENERAL_AUDIO_RESOURCES_MANAGER_HXX */
