/**
 * @file	election-string-resources-manager.h
 * @brief	Declares the election string resources manager class.
 * @author	Youssef.tourkmani
 * @date	31/10/2012
 */


#ifndef _ELECTION_STRING_RESOURCES_MANAGER_H_
#define _ELECTION_STRING_RESOURCES_MANAGER_H_

#include "Resources/string-resources-manager-base.h"
#include "Runtime/Environment/saes-directories.h"

namespace Smartmatic
{
    namespace SAES
    {
        namespace Resources
        {
            /**
             * @class	ElectionStringResourcesManager
             * @brief	Manager for election string resources.
             * @author	Eduardo.campione
             * @date	28/04/2011
             * 				@see StringResourcesManagerBase
             */

            class ElectionStringResourcesManager: public StringResourcesManagerBase
            {
                public:

                    /**
                     * @fn	static ElectionStringResourcesManager* ElectionStringResourcesManager::getInstance( ElectionStringResourcesManager * externResource = NULL );
                     * @brief	Gets the current Election String Resources Manager.
                     * @author	Yadickson Soto
                     * @date	22/11/2013
                     * @param externResource extern resource only to unit test
                     * @return	instance the Election String Resources Manager.
                     */

                    static ElectionStringResourcesManager * getInstance ( ElectionStringResourcesManager * externResource = NULL );

                    /**
                     * @fn	void ElectionStringResourcesManager::init(Smartmatic::SAES::Runtime::Environment::SaesDirectories * saesDir,
                     * 			Smartmatic::SAES::Common::Configuration::BasePathType type = Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM);
                     * @brief	Initialises this object.
                     * @author	Eduardo.campione
                     * @date	28/04/2011
                     * @param	saesDir	The saes dir.
                     * @param	type	 	(optional) the type.
                     */

                    void init ( Smartmatic::SAES::Runtime::Environment::SaesDirectories * saesDir,
                                Smartmatic::SAES::Common::Configuration::BasePathType type = Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM );
                protected:

                    /**
                     * @fn	ElectionStringResourcesManager::ElectionStringResourcesManager();
                     * @brief	Default constructor.
                     * @author	Eduardo.campione
                     * @date	28/04/2011
                     */
                    ElectionStringResourcesManager();

                    /**
                     * @fn	virtual ElectionStringResourcesManager::~ElectionStringResourcesManager();
                     * @brief	Class destructor.
                     * @author	Yadickson Soto
                     * @date	16/02/2012
                     */
                    virtual ~ElectionStringResourcesManager();

                private:

                    /**
                     * @fn	std::string & ElectionStringResourcesManager::getFileName();
                     * @brief	Gets the file name.
                     * @author	Eduardo.campione
                     * @date	28/04/2011
                     * @return	The file name.
                     */

                    std::string & getFileName();

                    /**
                     * @fn	std::string & ElectionStringResourcesManager::getFullFolderPath();
                     * @brief	Gets the full folder path.
                     * @author	Eduardo.campione
                     * @date	28/04/2011
                     * @return	The full folder path.
                     */

                    std::string & getFullFolderPath();
                    std::string fileName;   ///< Filename of the file
                    std::string folderPath; ///< Full pathname of the folder file

                    static ElectionStringResourcesManager * singleton_instance; ///< The singleton instance of the Election String Resources Manager
            };
        }
    }
}

#endif // _ELECTION_STRING_RESOURCES_MANAGER_H_
