/**
 * @file CardDataFactory.hxx
 * @brief Header Card Data Factory Class
 * @date 29/04/2013
 * @author Yadickson Soto
 */

#ifndef CARD_DATA_FACTORY_HXX_
#define CARD_DATA_FACTORY_HXX_

#include <Voting/CardData/card-data-schema.hxx>
#include <System/SafeBuffer.h>
#include <Voting/IDManager/BallotIDManager.hxx>
#include <Voting/IDManager/SessionIDManager.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Voting
        {
            class OperationStatus;

            namespace CardData
            {
                /**
                 * @class CardDataFactory
                 * @brief Card Data Factory
                 * @date 29/04/2013
                 * @author Yadickson Soto
                 */
                class CardDataFactory
                {
                    public:

                        /**
                         * @fn static Card_data * createCardData( const Smartmatic::SAES::Voting::VotingDevice::Logical_voter_group & logicalVoterGroup,
                         *                                 Smartmatic::SAES::Voting::OperationStatus * operationStatus,
                         *                                 Smartmatic::SAES::Voting::SessionIDManager * sessionIDManager = Smartmatic::SAES::Voting::SessionIDManager::getInstance(),
                         *                                 Smartmatic::SAES::Voting::BallotIDManager * ballotIDManager = Smartmatic::SAES::Voting::BallotIDManager::getInstance() );
                         * @brief Method create card data
                         * @date 29/04/2013
                         * @author Yadickson Soto
                         * @param logicalVoterGroup logical voter group
                         * @param operationStatus The operation status
                         * @param sessionIDManager The session IDManager
                         * @param ballotIDManager The ballot IDManager
                         * @return new card data
                         */
                        static Card_data createCardData ( const Smartmatic::SAES::Voting::VotingDevice::Logical_voter_group & logicalVoterGroup,
                                                          Smartmatic::SAES::Voting::OperationStatus * operationStatus,
                                                          Smartmatic::SAES::Voting::SessionIDManager * sessionIDManager = Smartmatic::SAES::Voting::SessionIDManager::getInstance(),
                                                          Smartmatic::SAES::Voting::BallotIDManager * ballotIDManager = Smartmatic::SAES::Voting::BallotIDManager::getInstance() );

                        /**
                         * @fn static bool bufferToCardData ( const Smartmatic::System::SafeBuffer & bufferIn, Card_data & cardData );
                         * @brief Method create card data from buffer
                         * @date 29/04/2013
                         * @author Yadickson Soto
                         * @param bufferIn buffer in data vote
                         * @param cardData new card data
                         * @return true if create card data is success full
                         */
                        static bool bufferToCardData ( const Smartmatic::System::SafeBuffer & bufferIn, Card_data & cardData );

                        /**
                         * @fn static bool cardDataToBuffer ( Card_data & cardData, Smartmatic::System::SafeBuffer & bufferOut );
                         * @brief Method getter buffer from card data
                         * @date 29/04/2013
                         * @author Yadickson Soto
                         * @param cardData input card data
                         * @param bufferOut buffer out
                         * @return true if card data is success full
                         */
                        static bool cardDataToBuffer ( Card_data & cardData, Smartmatic::System::SafeBuffer & bufferOut );
                };
            }
        }
    }
}
#endif /* CARD_DATA_FACTORY_HXX_ */
