/**
 * @file BallotIDManager.hxx
 * @brief Header class to generate and verify ballot id
 * @date 08/05/2013
 * @author Yadickson Soto
 */

#ifndef BALLOTIDMANAGER_HXX_
#define BALLOTIDMANAGER_HXX_

#include <Voting/IDManager/IDManager.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Voting
        {
            /**
             * @class BallotIDManager
             * @brief Class to generate and verify ballot id, use IDManager
             * @date 08/05/2013
             * @author Yadickson Soto
             * @see IDManager
             */
            class BallotIDManager : private IDManager
            {
                protected:
                    /**
                     * @fn BallotIDManager();
                     * @brief Class constructor
                     * @date 08/05/2013
                     * @author Yadickson Soto
                     */
                    BallotIDManager();

                    static BallotIDManager * instance; ///< instance of the class

                public:
                    /**
                     * @fn virtual ~BallotIDManager();
                     * @brief Class destructor
                     * @date 08/05/2013
                     * @author Yadickson Soto
                     */
                    virtual ~BallotIDManager();
                    /**
                     * @fn virtual std::string getID();
                     * @brief Getter new ballot id, use method IDManager::generate
                     * @date 08/05/2013
                     * @author Yadickson Soto
                     * @return new ballot id
                     * @see IDManager
                     */
                    virtual std::string getID();
                    /**
                     * @fn bool verifyID( const std::string & ballotId );
                     * @brief Verify if the ballot id is valid.
                     * @date 08/05/2013
                     * @author Yadickson Soto
                     * @param ballotId ballot id to verify
                     * @return	true if ballot id is valid
                     * @see IDManager
                     */
                    bool verifyID ( const std::string & ballotId );
                    /**
                     * @fn     void removeID( const std::string & ballotId );
                     * @brief  Remove the ballot id.
                     * @date   08/08/2022
                     * @author manuel.arguelles
                     * @param  ballotId The ballot ID to remove.
                     * @return true if the ballot ID was present.
                     */
                    bool removeID ( const std::string & ballotId );
                    /**
                     * @fn static BallotIDManager * getInstance();
                     * @brief Getter instance of class
                     * @date 08/05/2013
                     * @author Yadickson Soto
                     * @return instance of class
                     */
                    static BallotIDManager * getInstance();
            };

        } /* namespace Voting */
    } /* namespace SAES */
} /* namespace Smartmatic */
#endif /* BALLOTIDMANAGER_HXX_ */
