/**
 * @file PVContestWrapper.hxx
 * @brief Header PV Contest Wrapper
 * @date 05/06/2013
 * @author Yadickson Soto
 */

#ifndef PV_CONTEST_WRAPPER_HXX_
#define PV_CONTEST_WRAPPER_HXX_

#include <list>
#include <map>
#include <string>
#include <Voting/PBReports/pvform-schema.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Voting
        {
            namespace Election
            {
                class Contest;
            }

            namespace PBReports
            {
                /**
                 * @class PVContestWrapper
                 * @brief PV Contest Wrapper, this class manage pv contest to used in pvform
                 * @date 05/06/2013
                 * @author Yadickson Soto
                 */
                class PVContestWrapper
                {

                    public:

                        /**
                         * @brief Getter method: intance of class
                         * @author Yadickson Soto
                         * @date 05/06/2013
                         * @return intance of class
                         */
                        static PVContestWrapper * getInstance();

                        /**
                         * @brief Class destructor
                         * @date 05/06/2013
                         * @author Yadickson Soto
                         */
                        virtual ~PVContestWrapper();

                    public:

                        /**
                         * @brief init class, call clear method
                         * @date 05/06/2013
                         * @author Yadickson Soto
                         */
                        void init();

                        /**
                         * @brief clear all list and map contest
                         * @date 05/06/2013
                         * @author Yadickson Soto
                         */
                        void clear();

                        /**
                         * @brief set current contest, if no exists create new pb contest in memory
                         * @author Yadickson Soto
                         * @date 05/06/2013
                         * @param contest contest to add, set code - customcode and other properties of pb contest
                         */
                        void setContest(const Voting::Election::Contest* contest);

                        /**
                         * @brief Getter method: contest by custom code
                         * @author Yadickson Soto
                         * @date 05/06/2013
                         * @param customCode custom code of contest
                         * @return contest
                         */
                        Contest* getContest(const std::string& customCode);

                        /**
                         * @brief Getter method: pb contest list
                         * @author Yadickson Soto
                         * @date 05/06/2013
                         * @return pb contest list
                         */
                        std::list<Contest*>& getContestList();

                    private:

                        /**
                         * @fn PvContestWrapper();
                         * @brief Class constructor
                         * @date 05/06/2013
                         * @author Yadickson Soto
                         */
                        PVContestWrapper();

                    private:

                        static PVContestWrapper* instance; ///< instance of class
                        std::list<Contest*> contestList; ///< contest list
                        std::map<std::string, Contest*> contestMap; ///< contest map
                };

            } /* namespace PBReports */
        } /* namespace Voting */
    } /* namespace SAES */
} /* namespace Smartmatic */
#endif /* PV_CONTEST_WRAPPER_HXX_ */
