/**
 * @file	VoteStatistic.hxx
 * @brief	vote statistic class.
 * @author	Youssef.tourkmani
 * @date	31/10/2012
 */

#ifndef VOTESTATISTIC_HXX_
#define VOTESTATISTIC_HXX_

namespace Smartmatic
{
    namespace SAES
    {
        namespace Voting
        {
            namespace PBReports
            {
                /**
                 * @class	VoteStatistic
                 * @brief	Vote statistic.
                 * @author	Youssef.tourkmani
                 * @date	31/10/2012
                 */
                class VoteStatistic
                {
                    public:
                        /**
                         * @fn	VoteStatistic::VoteStatistic();
                         * @brief	Default constructor.
                         * @author	Youssef.tourkmani
                         * @date	31/10/2012
                         */
                        VoteStatistic();
                        /**
                         * @fn	virtual VoteStatistic::~VoteStatistic();
                         * @brief	Destructor.
                         * @author	Youssef.tourkmani
                         * @date	31/10/2012
                         */
                        virtual ~VoteStatistic();

                        /**
                         * @fn	void VoteStatistic::clearAll();
                         * @brief	Clears all.
                         * @author	Youssef.tourkmani
                         * @date	31/10/2012
                         */
                        void clearAll();
                        /**
                         * @fn	void VoteStatistic::clearAllNotDuplicate();
                         * @brief	Clears all not duplicate.
                         * @author	Youssef.tourkmani
                         * @date	31/10/2012
                         */
                        void clearAllNotDuplicate();

                        /**
                         * @fn	unsigned int VoteStatistic::getTotalVotes();
                         * @brief	Gets total votes.
                         * @author	Youssef.tourkmani
                         * @date	31/10/2012
                         * @return	The total votes.
                         */
                        unsigned int getTotalVotes();
                        /**
                         * @fn	unsigned int VoteStatistic::getOfficialVotes();
                         * @brief	Gets official votes.
                         * @author	Youssef.tourkmani
                         * @date	31/10/2012
                         * @return	The official votes.
                         */
                        unsigned int getOfficialVotes();
                        /**
                         * @fn	unsigned int VoteStatistic::getDemoVotes();
                         * @brief	Gets demo votes.
                         * @author	Youssef.tourkmani
                         * @date	31/10/2012
                         * @return	The demo votes.
                         */
                        unsigned int getDemoVotes();
                        /**
                         * @fn	unsigned int VoteStatistic::getDuplicatedVotes();
                         * @brief	Gets duplicated votes.
                         * @author	Youssef.tourkmani
                         * @date	31/10/2012
                         * @return	The duplicated votes.
                         */
                        unsigned int getDuplicatedVotes();
                        /**
                         * @fn	unsigned int VoteStatistic::getSimulateVotes();
                         * @brief	Gets simulate votes.
                         * @author	Youssef.tourkmani
                         * @date	31/10/2012
                         * @return	The simulate votes.
                         */
                        unsigned int getSimulateVotes();

                        /**
                         * @fn	void VoteStatistic::setTotalVotes(unsigned int totalVotes);
                         * @brief	Sets total votes.
                         * @author	Youssef.tourkmani
                         * @date	31/10/2012
                         * @param	totalVotes	The total votes.
                         */
                        void setTotalVotes ( unsigned int totalVotes );
                        /**
                         * @fn	void VoteStatistic::setOfficialVotes(unsigned int officialVotes);
                         * @brief	Sets official votes.
                         * @author	Youssef.tourkmani
                         * @date	31/10/2012
                         * @param	officialVotes	The official votes.
                         */
                        void setOfficialVotes ( unsigned int officialVotes );
                        /**
                         * @fn	void VoteStatistic::setDemoVotes(unsigned int demoVotes);
                         * @brief	Sets demo votes.
                         * @author	Youssef.tourkmani
                         * @date	31/10/2012
                         * @param	demoVotes	The demo votes.
                         */
                        void setDemoVotes ( unsigned int demoVotes );
                        /**
                         * @fn	void VoteStatistic::setDuplicatedVotes(unsigned int duplicatedVotes);
                         * @brief	Sets duplicated votes.
                         * @author	Youssef.tourkmani
                         * @date	31/10/2012
                         * @param	duplicatedVotes	The duplicated votes.
                         */
                        void setDuplicatedVotes ( unsigned int duplicatedVotes );
                        /**
                         * @fn	void VoteStatistic::setSimulateVotes(unsigned int simulateVotes);
                         * @brief	Sets simulate votes.
                         * @author	Youssef.tourkmani
                         * @date	31/10/2012
                         * @param	simulateVotes	The simulate votes.
                         */
                        void setSimulateVotes ( unsigned int simulateVotes );

                    private:
                        unsigned int totalVotes;	///< The total votes
                        unsigned int officialVotes; ///< The official votes
                        unsigned int demoVotes; ///< The demo votes
                        unsigned int duplicatedVotes;///< The duplicated votes
                        unsigned int simulateVotes;///< The simulated votes
                };
            }
        }
    }
}

#endif /* VOTESTATISITC_HXX_ */
