/**
 * @file	GeneratedImagesWrapper.hxx
 * @brief	generated images wrapper class.
 * @author	Youssef.tourkmani
 * @date	31/10/2012
 */

#ifndef __GENERATED_IMAGES_WRAPPER_H__
#define __GENERATED_IMAGES_WRAPPER_H__

#include <Voting/Screen/generated-images-schema.hxx>
#include <Voting/ElectoralConfiguration.hxx>
#include <System/Exception/CryptoException.hxx>
#include <System/Exception/SignedException.hxx>
#include <System/Exception/XmlException.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace SAES
    {
        namespace Voting
        {
            namespace Screen
            {
                /**
                 * @class	GeneratedImagesWrapper
                 * @brief	Generated images wrapper.
                 * @author	Juan.Delgado
                 * @date	15/07/2011
                 */

                class GeneratedImagesWrapper
                {
                    public:

                        /**
                         * @fn	GeneratedImagesWrapper::GeneratedImagesWrapper();
                         * @brief	Default constructor.
                         * @author	Juan.Delgado
                         * @date	15/07/2011
                         */

                        GeneratedImagesWrapper();

                        /**
                         * @fn	virtual GeneratedImagesWrapper::~GeneratedImagesWrapper();
                         * @brief	Destructor.
                         * @author	Juan.Delgado
                         * @date	15/07/2011
                         */

                        virtual ~GeneratedImagesWrapper();

                        /**
                         * @fn	void addBasicImage ( BasicImage & image );
                         * @brief	Method add image structure.
                         * @author	Yadickson Soto
                         * @date	19/03/2013
                         * @param	image new image
                         */
                        void addBasicImage ( BasicImage & image );

                        /**
                         * @fn	void addSelectionImage ( SelectionImage & image );
                         * @brief	Method add image structure.
                         * @author	Yadickson Soto
                         * @date	19/03/2013
                         * @param	image new image
                         */
                        void addSelectionImage ( SelectionImage & image );

                        /**
                         * @fn	void addCustomAttributeImage ( CustomAttributeImage & image );
                         * @brief	Method add image structure.
                         * @author	Yadickson Soto
                         * @date	19/03/2013
                         * @param	image new image
                         */
                        void addCustomAttributeImage ( CustomAttributeImage & image );

                        /**
                         * @fn	void addPartySelectionImage ( PartySelectionImage & image );
                         * @brief	Method add image structure.
                         * @author	Yadickson Soto
                         * @date	19/03/2013
                         * @param	image new image
                         */
                        void addPartySelectionImage ( PartySelectionImage & image );

                        /**
                         * @fn	void addBallotSelectionImage ( BallotSelectionImage & image );
                         * @brief	Method add image structure.
                         * @author	Yadickson Soto
                         * @date	19/03/2013
                         * @param	image new image
                         */
                        void addBallotSelectionImage ( BallotSelectionImage & image );

                        /**
                         * @fn	void GeneratedImagesWrapper::Persist(std::string folder) throw (Smartmatic::System::Exception::CryptoException,
                         * 			Smartmatic::System::Exception::SignedException, Smartmatic::System::Exception::XmlException);
                         * @brief	Persists.
                         * @author	Juan.Delgado
                         * @date	15/07/2011
                         * @exception	Smartmatic::System::Exception::CryptoException	Thrown when a crypto error condition
                         * 																														occurs.
                         * @exception	Smartmatic::System::Exception::SignedException	Thrown when a signed error condition
                         * 																														occurs.
                         * @exception	Smartmatic::System::Exception::XmlException			Thrown when an XML error condition
                         *
                         * @param 	electoral electoral configuration																											occurs.
                         * @param	folder	Folder name.
                         */

                        void Persist ( Smartmatic::SAES::Voting::ElectoralConfiguration * electoral, std::string folder )
                        throw ( Smartmatic::System::Exception::CryptoException,
                                Smartmatic::System::Exception::SignedException,
                                Smartmatic::System::Exception::XmlException );

                    private:

                        GeneratedImages generatedImages;	///<The generated images instance
                        GeneratedImages::ImageSequence images; ///< image sequence
                        GeneratedImages::ConfirmationImageSequence confirmationImages; ///< confirmation image sequence
                        GeneratedImages::CustomAttributeImageSequence customAttributeImages; ///< custom attribute image sequence
                        GeneratedImages::PartySelectionImageSequence partySelectionImages; ///< party selection image sequence
                        GeneratedImages::BallotSelectionImageSequence ballotSelectionImages; ///< ballot selection image sequence

                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
                };
            }
        }
    }
}

#endif /*__GENERATED_IMAGES_WRAPPER_H__*/
