/*
 * DiagnoseStepWrapper.cxx
 *
 *  Created on: 16/09/2013
 *      Author: soto
 */

#include "DiagnoseStepWrapper.hxx"
#include <System/Utils/StringUtils.hxx>

using namespace Smartmatic::SAES::Voting::Status;
using namespace Smartmatic::SAES::Common::Configuration;
using namespace Smartmatic::System::Utils;

DiagnoseStepWrapper::DiagnoseStepWrapper()
{

}

DiagnoseStepWrapper::~DiagnoseStepWrapper()
{

}

DiagnoseStep DiagnoseStepWrapper::createDiagnoseStep ( DeviceType type )
{
    DiagnoseStep step;

    switch ( type )
    {
        case Smartmatic::SAES::Common::Configuration::DeviceType::CONFIGURATION_BARCODE:
            step.setCode ( DiagnoseCode ( DiagnoseCode::VOTING_MACHINE_STATUS_B ) );
            break;

        case Smartmatic::SAES::Common::Configuration::DeviceType::CONFIGURATION_PRINTER:
            step.setCode ( DiagnoseCode ( DiagnoseCode::VOTING_MACHINE_STATUS_P ) );
            break;

        case Smartmatic::SAES::Common::Configuration::DeviceType::CONFIGURATION_ALARMBOX:
            step.setCode ( DiagnoseCode ( DiagnoseCode::VOTING_MACHINE_STATUS_A ) );
            break;

        case Smartmatic::SAES::Common::Configuration::DeviceType::CONFIGURATION_SMARTCARD:
            step.setCode ( DiagnoseCode ( DiagnoseCode::VOTING_MACHINE_STATUS_S ) );
            break;

        case Smartmatic::SAES::Common::Configuration::DeviceType::CONFIGURATION_TOUCHSCREENCALIBRATION:
            step.setCode ( DiagnoseCode ( DiagnoseCode::VOTING_MACHINE_STATUS_T ) );
            break;

        case Smartmatic::SAES::Common::Configuration::DeviceType::CONFIGURATION_FLASH:
            step.setCode ( DiagnoseCode ( DiagnoseCode::VOTING_MACHINE_STATUS_F ) );
            break;

        case Smartmatic::SAES::Common::Configuration::DeviceType::CONFIGURATION_P168A:
        case Smartmatic::SAES::Common::Configuration::DeviceType::CONFIGURATION_ABLED:
            step.setCode ( DiagnoseCode ( DiagnoseCode::VOTING_MACHINE_STATUS_AA ) );
            break;

        case Smartmatic::SAES::Common::Configuration::DeviceType::CONFIGURATION_EURN:
            step.setCode ( DiagnoseCode ( DiagnoseCode::VOTING_MACHINE_STATUS_EU ) );
            break;

        case Smartmatic::SAES::Common::Configuration::DeviceType::CONFIGURATION_MOUSE:
            step.setCode ( DiagnoseCode ( DiagnoseCode::VOTING_MACHINE_STATUS_M ) );
            break;

        case Smartmatic::SAES::Common::Configuration::DeviceType::CONFIGURATION_ETHERNET:
        case Smartmatic::SAES::Common::Configuration::DeviceType::CONFIGURATION_KEYBOARD:
        case Smartmatic::SAES::Common::Configuration::DeviceType::CONFIGURATION_USBSTORAGEMOUNTED:
        case Smartmatic::SAES::Common::Configuration::DeviceType::CONFIGURATION_UNKNOWN:
        default:
            step.setCode ( DiagnoseCode ( DiagnoseCode::VOTING_MACHINE_STATUS_X ) );
            break;
    }

    return step;
}

std::string DiagnoseStepWrapper::getDiagnoseStepString (
    const Smartmatic::SAES::Voting::Status::DiagnoseStep & step,
    const std::string & fieldSeparator,
    const std::string & interSeparator,
    const std::string & ok,
    const std::string & nok,
    const std::string & na )
{
    std::string text;

    if ( step.getCode() != DiagnoseCode ( DiagnoseCode::VOTING_MACHINE_STATUS_X ) )
    {
        text.append ( step.getCode() );

        if ( step.getCustomCode().present() )
        {
            text.append ( interSeparator );
            text.append ( step.getCustomCode().get() );
        }

        if ( step.getStatus().present() )
        {
            text.append ( interSeparator );

            switch ( step.getStatus().get() )
            {
                case VMStatus::VOTING_MACHINE_STATUS_OK:
                    text.append ( ok );
                    break;

                case VMStatus::VOTING_MACHINE_STATUS_NOTDIAGNOSED:
                    text.append ( na );
                    break;

                default:
                case VMStatus::VOTING_MACHINE_STATUS_RUN:
                case VMStatus::VOTING_MACHINE_STATUS_ERROR:
                    text.append ( nok );
                    break;

            }
        }

        if ( step.getValue().present() )
        {
            std::string value = step.getValue().get();

            value = StringUtils::replaceAll ( value, "\n", " " );
            value = StringUtils::replaceAll ( value, "\r", " " );
            value = StringUtils::replaceAll ( value, fieldSeparator, "\\" + fieldSeparator );
            value = StringUtils::replaceAll ( value, interSeparator, "\\" + interSeparator );

            text.append ( interSeparator );
            text.append ( value );
        }

        text.append ( fieldSeparator );
    }

    return text;
}
