/**
 * @file	ElectionStatusWrapper.hxx
 * @brief	election status wrapper class.
 * @author	Youssef.tourkmani
 * @date	31/10/2012
 */

#ifndef __ELECTION_STATUS_WRAPPER_H__
#define __ELECTION_STATUS_WRAPPER_H__

#include <string>
#include <list>
#include <Voting/Status/election-status-schema.hxx>


namespace Smartmatic
{
    namespace SAES
    {
        namespace Voting
        {
            class OperationStatus;

            namespace Status
            {
                /**
                 * @class	ElectionStatusWrapper
                 * @brief	Election status wrapper.
                 * @author	Eduardo.campione
                 * @date	28/04/2011
                 */

                class ElectionStatusWrapper
                {

                    public:

                        /**
                         * @fn	ElectionStatusWrapper::ElectionStatusWrapper(ElectionStatus & elecStatus);
                         * @brief	Constructor.
                         * @author	Eduardo.campione
                         * @date	28/04/2011
                         * @param	elecStatus	The elec status.
                         */

                        explicit ElectionStatusWrapper ( ElectionStatus & elecStatus );

                        /**
                         * @fn	ProcessStatus & ElectionStatusWrapper::getEletionState();
                         * @brief	Gets the eletion state.
                         * @author	Eduardo.campione
                         * @date	28/04/2011
                         * @return	The eletion state.
                         */

                        ProcessStatus  & getEletionState();

                        /**
                         * @fn	bool ElectionStatusWrapper::getSynchronizeVotes();
                         * @brief	Gets synchronize votes.
                         * @author	Youssef.tourkmani
                         * @date	31/10/2012
                         * @return	true if it succeeds, false if it fails.
                         */
                        bool getSynchronizeVotes();

                        /**
                         * @fn	void ElectionStatusWrapper::setSynchronizeVotes(bool value);
                         * @brief	Sets synchronize votes.
                         * @author	Youssef.tourkmani
                         * @date	31/10/2012
                         * @param	value	true to value.
                         */
                        void setSynchronizeVotes ( bool value );

                        /**
                         * @fn	ResultsPackageTransmissionStateConfiguration getResultsPackageTransmissionState();
                         * @brief	Gets results package transmission state.
                         * @author	Yadickson Soto
                         * @date	14/04/2014
                         * @return	the results package transmission state.
                         */
                        ResultsPackageTransmissionStateConfiguration getResultsPackageTransmissionState();

                        /**
                         * @fn	void setResultsPackageTransmissionState ( ResultsPackageTransmissionStateConfiguration state );
                         * @brief	Sets results package transmission state.
                         * @author	Yadickson Soto
                         * @date	14/04/2014
                         * @param	state The new state value.
                         */
                        void setResultsPackageTransmissionState ( ResultsPackageTransmissionStateConfiguration state );

                        /**
                         * @fn	void ElectionStatusWrapper::setEletionState(ProcessStatus newState);
                         * @brief	Sets an eletion state.
                         * @author	Eduardo.campione
                         * @date	28/04/2011
                         * @param	newState	State of the new.
                         */

                        void  setEletionState ( ProcessStatus newState );

                        /**
                         * @fn	void ElectionStatusWrapper::setElectionConfigurationReportPrinted(bool arg);
                         * @brief	Sets an election configuration report printed.
                         * @author	Eduardo.campione
                         * @date	28/04/2011
                         * @param	arg	if true print the report.
                         */

                        void setElectionConfigurationReportPrinted ( bool arg );

                        /**
                         * @fn	std::string & ElectionStatusWrapper::getStringStatus();
                         * @brief	Gets the string status.
                         * @author	Eduardo.campione
                         * @date	28/04/2011
                         * @return	The string status.
                         */

                        std::string & getStringStatus();

                        /**
                         * @fn	std::string & ElectionStatusWrapper::getOpeningCode();
                         * @brief	Gets the opening code.
                         * @author	Eduardo.campione
                         * @date	28/04/2011
                         * @return	The opening code.
                         */

                        std::string & getOpeningCode();

                        /**
                         * @fn	void ElectionStatusWrapper::setOpeningCode(std::string & openingCode);
                         * @brief	Sets the opening code.
                         * @author	Yadickson Soto
                         * @date	19/10/2011
                         * @param	openingCode	The opening code.
                         */

                        void setOpeningCode ( std::string & openingCode );

                        /**
                         * @fn	long long unsigned int & ElectionStatusWrapper::getVotersRegisteredInBook();
                         * @brief	Gets the voters registered in book.
                         * @author	Eduardo.campione
                         * @date	28/04/2011
                         * @return	The voters registered in book.
                         */

                        long long unsigned int & getVotersRegisteredInBook();

                        /**
                         * @fn	std::string & ElectionStatusWrapper::getOperationModeCode();
                         * @brief	Gets the operation mode code.
                         * @author	Eduardo.campione
                         * @date	28/04/2011
                         * @return	The operation mode code.
                         */

                        std::string & getOperationModeCode();

                        /**
                         * @fn	bool & ElectionStatusWrapper::getElectionConfigurationReportPrinted();
                         * @brief	Gets the election configuration report printed.
                         * @author	Eduardo.campione
                         * @date	28/04/2011
                         * @return	The election configuration report printed.
                         */

                        bool & getElectionConfigurationReportPrinted();

                        /**
                         * @fn	std::string ElectionStatusWrapper::getOpenElectionDate();
                         * @brief	Gets the open election date.
                         * @author	Eduardo.campione
                         * @date	28/04/2011
                         * @return	The open election date.
                         */

                        std::string	 getOpenElectionDate();

                        /**
                         * @fn	std::string ElectionStatusWrapper::getCloseElectionDate();
                         * @brief	Gets the close election date.
                         * @author	Eduardo.campione
                         * @date	28/04/2011
                         * @return	The close election date.
                         */

                        std::string	 getCloseElectionDate();

                        /**
                         * @fn	std::string ElectionStatusWrapper::getCloseVotingDate();
                         * @brief	Gets the close voting date.
                         * @author	Freddy.Gomez
                         * @date	02/05/2011
                         * @return	The close voting date.
                         */

                        std::string   getCloseVotingDate();

                        /**
                         * @fn	void setClosedElection ( bool closed );
                         * @brief	Sets the election is close.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @param	closed set closed election value, (true is closed).
                         */

                        void setClosedElection ( bool closed );

                        /**
                         * @fn	bool ElectionStatusWrapper::getClosedElection ();
                         * @brief	Gets the election is close.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	true if the election is close.
                         */

                        bool getClosedElection ();

                        /**
                         * @fn	void ElectionStatusWrapper::setOpenElectionDate(std::string openDate);
                         * @brief	Set the open election time.
                         * @author	Freddy.Gomez
                         * @date	02/05/2011
                         * @param	openDate	Date of the open.
                         */

                        void setOpenElectionDate ( std::string openDate );

                        /**
                         * @fn	void ElectionStatusWrapper::setCloseElectionDate(std::string closeElectionDate);
                         * @brief	Sets the close election date.
                         * @author	Freddy.Gomez
                         * @date	02/05/2011
                         * @param	closeElectionDate	Date of the close election.
                         */

                        void setCloseElectionDate ( std::string closeElectionDate );

                        /**
                         * @fn	void ElectionStatusWrapper::setCloseVotingDate(std::string closeVotingDate);
                         * @brief	Sets the close voting date.
                         * @author	Freddy.Gomez
                         * @date	02/05/2011
                         * @param	closeVotingDate	Date of the close voting.
                         */

                        void setCloseVotingDate ( std::string closeVotingDate );

                        /**
                         * @fn	virtual ElectionStatusWrapper::~ElectionStatusWrapper();
                         * @brief	Finaliser.
                         * @author	Eduardo.campione
                         * @date	28/04/2011
                         */

                        virtual ~ElectionStatusWrapper();

                    protected:

                        friend class Smartmatic::SAES::Voting::OperationStatus;

                        /**
                         * @fn	ElectionStatus & ElectionStatusWrapper::getElectionStatus();
                         * @brief	Gets the election status.
                         * @author	Eduardo.campione
                         * @date	28/04/2011
                         * @return	The election status.
                         */

                        ElectionStatus & getElectionStatus();

                    private:

                        ElectionStatus status;	///< The status
                };
            }
        }
    }
}

#endif /*__ELECTION_STATUS_WRAPPER_H__*/
