/**
 * @file HashVoteManager.cxx
 * @brief Body Hash vote manager
 * @date 31/05/2013
 * @author Yadickson Soto
 */

#include "HashVoteManager.hxx"
#include <System/IO/File.h>
#include <System/IO/Path.h>
#include <Voting/Vote/VoteWrapper.hxx>

using namespace Smartmatic::SAES::Voting::Vote;
using namespace Smartmatic::System::IO;

HashVoteManager::HashVoteManager()
{

}

HashVoteManager::~HashVoteManager()
{
    clear();
}

void HashVoteManager::processVote ( const Smartmatic::SAES::Voting::Vote::Vote & vote )
{
    std::string filename = VoteWrapper::getFileName ( vote );
    std::string hash = getHash ( filename );

    list.push_back ( filename );
    map [ filename ] = hash;
}

bool HashVoteManager::validateVote ( const std::string & filename )
{
    if ( map.find ( filename ) != map.end() )
    {
        std::string hash;
        hash = map [ filename ];
        return hash == getHash ( filename );
    }

    return false;
}

std::list < std::string > & HashVoteManager::getFileNameList()
{
    return list;
}

void HashVoteManager::clear()
{
    list.clear();
    map.clear();
}

std::string HashVoteManager::getHash ( const std::string & filename )
{
    Smartmatic::SAES::Runtime::Environment::SaesDirectories directories;
    std::string fullPath = Path::Combine ( filename, directories.getVotesFolderFullPath() );
    Smartmatic::System::SafeBuffer buffer;
    File::getInstance()->getHashFile ( fullPath, buffer );
    return buffer.GetBase64Data();
}
