/**
 * @file VoteFactory.cxx
 * @brief Body Vote Factory Class
 * @date 24/04/2013
 * @author Yadickson Soto
 */

#include "VoteFactory.hxx"

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

using namespace Smartmatic::SAES::Voting::Vote;

VoteFactory::VoteFactory()
{

}

VoteFactory::~VoteFactory()
{

}

Vote * VoteFactory::createVote( )
{
    Vote * vote = new Vote();

    vote->setCode ( "x" );
    vote->setLogicalVoterGroup ( "x" );
    vote->setVotingDeviceCode ( "x" );
    vote->setMode ( VoteMode::VOTE_O );
    vote->setBallotID ( "x" );
    vote->setSessionID ( "x" );

    Vote::SSequence seq;
    vote->setSelections ( seq );

    return vote;
}

Vote * VoteFactory::createVote ( Smartmatic::SAES::Voting::CardData::Card_data & cardData )
{
    Vote * vote = createVote();

    vote->setBallotID ( cardData.getBallotID() );
    vote->setSessionID ( cardData.getSessionID() );

    return vote;
}

bool VoteFactory::bufferToVote ( const Smartmatic::System::SafeBuffer & bufferIn, Vote *& vote )
{
    if ( vote != NULL )
    {
        delete vote;
        vote = NULL;
    }

    bool validate = false;

    try
    {
        std::string data;
        data.append ( ( const char * ) bufferIn.GetData(), bufferIn.GetSize() );
        std::istringstream istr ( data );

        Vote tmpVote = ( * ( Smartmatic::SAES::Voting::Vote::parseV ( istr, Smartmatic::SAES::Voting::VoteTypes::Flags::dont_validate ) ) );
        vote = new Vote ( tmpVote );

        validate = true;
    }
    catch ( ... )
    {

    }

    return validate;
}

bool VoteFactory::voteToBuffer ( Vote * vote, Smartmatic::System::SafeBuffer & bufferOut )
{
    bool validate = false;
    bufferOut.Clear();

    try
    {
        if ( vote != NULL )
        {
            std::ostringstream str;
            VoteTypes::NamespaceInfomap mapv;
            mapv[""].name = NAMESPACE_VOTING_VOTE;
            mapv[""].schema = "";

            serializeV ( str, *vote, mapv, "UTF-8", Smartmatic::SAES::Voting::VoteTypes::Flags::dont_validate );

            bufferOut.AddData ( str.str() );
            validate = true;
        }
    }
    catch ( ... )
    {

    }

    return validate;
}
