/**
 * @file VoteFactory.hxx
 * @brief Header Vote Factory Class
 * @date 24/04/2013
 * @author Yadickson Soto
 */

#ifndef VOTEFACTORY_HXX_
#define VOTEFACTORY_HXX_

#include <Voting/CardData/card-data-schema.hxx>
#include <Voting/Vote/vote-schema.hxx>
#include <System/SafeBuffer.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Voting
        {
            namespace Vote
            {
                /**
                 * @class VoteFactory
                 * @brief Vote Factory
                 * @date 24/04/2013
                 * @author Yadickson Soto
                 */
                class VoteFactory
                {
                    private:

                        /**
                         * @fn VoteFactory ();
                         * @brief Class constructor
                         * @date 24/04/2013
                         * @author Yadickson Soto
                         */
                        VoteFactory ();

                    public:

                        /**
                         * @fn virtual ~VoteFactory();
                         * @brief Class destructor
                         * @date 24/04/2013
                         * @author Yadickson Soto
                         */
                        virtual ~VoteFactory();

                        /**
                         * @fn static Vote * createVote();
                         * @brief Method create vote
                         * @date 29/04/2013
                         * @author Yadickson Soto
                         * @return new vote
                         */
                        static Vote * createVote();

                        /**
                         * @fn static Vote * createVote( Smartmatic::SAES::Voting::CardData::Card_data & cardData );
                         * @brief Method create vote from card data
                         * @date 21/05/2013
                         * @author Yadickson Soto
                         * @param cardData card data with ballot id an session id
                         * @return new vote
                         */
                        static Vote * createVote ( Smartmatic::SAES::Voting::CardData::Card_data & cardData );

                        /**
                         * @fn static bool bufferToVote( const Smartmatic::System::SafeBuffer & bufferIn, Vote *& vote );
                         * @brief Method create vote from buffer
                         * @date 29/04/2013
                         * @author Yadickson Soto
                         * @param bufferIn buffer in data vote
                         * @param vote new vote
                         * @return true if create vote is success full
                         */
                        static bool bufferToVote ( const Smartmatic::System::SafeBuffer & bufferIn, Vote *& vote );

                        /**
                         * @fn static bool voteToBuffer( Vote * vote, Smartmatic::System::SafeBuffer & bufferOut );
                         * @brief Method getter buffer from vote
                         * @date 29/04/2013
                         * @author Yadickson Soto
                         * @param vote input vote
                         * @param bufferOut buffer out
                         * @return true if vote is success full
                         */
                        static bool voteToBuffer ( Vote * vote, Smartmatic::System::SafeBuffer & bufferOut );
                };
            } /* namespace Vote */
        } /* namespace Voting */
    } /* namespace SAES */
} /* namespace Smartmatic */
#endif /* VOTEFACTORY_HXX_ */
