/*
 * VoteMaxCalculate.cxx
 *
 *  Created on: 02/08/2013
 *      Author: soto
 */

#include "VoteMaxCalculate.hxx"
#include <Configuration/s-a-e-s-conf-manager.h>
#include <Voting/ElectoralConfiguration.hxx>

using namespace Smartmatic::SAES::Voting::Vote;
using namespace Smartmatic::SAES::Configuration;

VoteMaxCalculate::VoteMaxCalculate (	Smartmatic::SAES::Voting::ElectoralConfiguration * electoralConfiguration )
    : electoralConfiguration ( electoralConfiguration )
{
    maxList = 0;
    maxBallotOptions = 0;
}

VoteMaxCalculate::~VoteMaxCalculate()
{

}

bool VoteMaxCalculate::isSimpleLayout()
{
    LayoutContestConfiguration & layout ( SAESConfigurationManager::getInstance()->getLayoutContestConfiguration() );
    return layout.getLayoutContestType() == LayoutContestType::CONFIGURATION_SIMPLE;
}

void VoteMaxCalculate::calculate ()
{
    maxList = 0;
    maxBallotOptions = electoralConfiguration->getMaxBallotOptionsByVote();
    maxLineBallotOptions = electoralConfiguration->getMaxBallotOptionByContestCode();

    if ( isSimpleLayout() )
    {
        calculateBySimpleLayout ();
    }
    else
    {
        calculateByTruncateLayout ();
    }
}

void VoteMaxCalculate::calculateBySimpleLayout ()
{
    try
    {
        std::map < std::string, int >::iterator it;

        for ( it = maxLineBallotOptions.begin();
                it != maxLineBallotOptions.end();
                ++it )
        {
            std::string contestCode = ( *it ).first;
            std::list < Smartmatic::SAES::Voting::Election::Party * > & partys = electoralConfiguration->getListPartyByContestCode ( contestCode );
            std::list < Smartmatic::SAES::Voting::Election::Party * >::iterator itp;
            int mList = 0;

            for ( itp = partys.begin();
                    itp != partys.end();
                    ++itp )
            {
                std::string partyCode = ( *itp )->getCode();
                int countList;
                countList = electoralConfiguration->getCountListBallotOptionByContestParty ( contestCode, partyCode );

                if ( countList > mList )
                {
                    mList = countList;
                }

                if ( countList > maxList )
                {
                    maxList = countList;
                }
            }

            maxLineListOptions[contestCode] = mList;
            maxLineBallotOptions[contestCode] -= mList;
        }
    }
    catch ( ... )
    {

    }
}

void VoteMaxCalculate::calculateByTruncateLayout ()
{
    maxBallotOptions = 0;

    try
    {
        std::map < std::string, int >::iterator it;

        for ( it = maxLineBallotOptions.begin();
                it != maxLineBallotOptions.end();
                ++it )
        {
            std::string contestCode = ( *it ).first;
            std::list < Smartmatic::SAES::Voting::Election::Party * > & partys = electoralConfiguration->getListPartyByContestCode ( contestCode );
            std::list < Smartmatic::SAES::Voting::Election::Party * >::iterator itp;
            int value = maxLineBallotOptions[contestCode];
            int mList = 0;
            bool found = false;

            for ( itp = partys.begin();
                    itp != partys.end();
                    ++itp )
            {
                std::string partyCode = ( *itp )->getCode();
                int countList, countPrincipal, countStandIn;
                int total;
                electoralConfiguration->getCountBallotOptionByContestParty ( contestCode, partyCode, countList, countPrincipal, countStandIn );
                total = countList + countPrincipal + countStandIn;

                if ( countList > mList )
                {
                    mList = countList;
                }

                if ( countList > maxList )
                {
                    maxList = countList;
                }

                if ( !found && value == total && countPrincipal % 2 != 0 && countStandIn % 2 != 0 )
                {
                    value++;
                    found = true;
                }
            }

            maxLineListOptions[contestCode] = mList;
            value -= mList;
            value = ( value % 2 != 0 ? value + 1 : value );
            maxLineBallotOptions[contestCode] = value / 2;
        }

        std::list <Smartmatic::SAES::Voting::Election::Contest_group * > & contestGroups ( electoralConfiguration->getContestGroups() );
        std::list <Smartmatic::SAES::Voting::Election::Contest_group * >::iterator c;

        for ( c = contestGroups.begin ();
                c != contestGroups.end ();
                ++c )
        {
            Smartmatic::SAES::Voting::Election::Contest_group::Contest_codeSequence & seq ( ( *c )->getContest_code() );
            Smartmatic::SAES::Voting::Election::Contest_group::Contest_codeIterator itseq;
            int max = 0;

            for ( itseq = seq.begin();
                    itseq != seq.end();
                    ++itseq )
            {
                max += maxLineBallotOptions[ ( *itseq )];
            }

            if ( max > maxBallotOptions )
            {
                maxBallotOptions = max;
            }
        }
    }
    catch ( ... )
    {

    }
}

int VoteMaxCalculate::getMaxLineListOptionsByContestCode ( std::string contestCode )
{
    return maxLineListOptions [ contestCode ];
}

int VoteMaxCalculate::getMaxLineBallotOptionsByContestCode ( std::string contestCode )
{
    return maxLineBallotOptions [ contestCode ];
}

int VoteMaxCalculate::getMaxList ()
{
    return maxList;
}

int VoteMaxCalculate::getMaxBallotOptions ()
{
    return maxBallotOptions;
}
