/*
 * VoteMaxCalculate.hxx
 *
 *  Created on: 02/08/2013
 *      Author: soto
 */

#ifndef VOTEMAXCALCULATE_HXX_
#define VOTEMAXCALCULATE_HXX_

#include <string>
#include <map>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Voting
        {

            class ElectoralConfiguration;

            namespace Vote
            {

                class VoteMaxCalculate
                {

                    protected:

                        virtual bool isSimpleLayout();

                        /**
                         * @fn	void calculateBySimpleLayout();
                         * @brief	Method calculate max ballot by simple layout.
                         * @author	Yadickson Soto yadickson.soto@smartmatic.com
                         * @date	29-07-2011
                         */
                        void calculateBySimpleLayout ();

                        /**
                         * @fn	void calculateByTruncateLayout();
                         * @brief	Method calculate max ballot by truncate layout.
                         * @author	Yadickson Soto yadickson.soto@smartmatic.com
                         * @date	29-07-2011
                         */
                        void calculateByTruncateLayout ();

                    public:

                        explicit VoteMaxCalculate ( Smartmatic::SAES::Voting::ElectoralConfiguration * electoralConfiguration );

                        virtual ~VoteMaxCalculate();

                        /**
                         * @fn	void calculate();
                         * @brief	Calculate max contest and candidate by contest to vote.
                         * @author	Yadickson Soto
                         * @date	31/10/2012
                         */
                        void calculate ();

                        int getMaxLineListOptionsByContestCode ( std::string contestCode );

                        int getMaxLineBallotOptionsByContestCode ( std::string contestCode );

                        int getMaxList ();

                        int getMaxBallotOptions ();

                    private:

                        Smartmatic::SAES::Voting::ElectoralConfiguration * electoralConfiguration; ///< electoral configuration
                        int maxList; ///<max list count
                        int maxBallotOptions; ///< max ballot option count

                        std::map < std::string, int > maxLineListOptions; ///< map max line list options
                        std::map < std::string, int > maxLineBallotOptions; ///< map max line ballot options
                };

            } /* namespace Vote */
        } /* namespace Voting */
    } /* namespace SAES */
} /* namespace Smartmatic */
#endif /* VOTEMAXCALCULATE_HXX_ */
