/**
 * @file VoteOptimizedSigned.hxx
 * @brief Header class for signed and validate vote optimized
 * @date 21/05/2013
 * @author Yadickson Soto
 */

#ifndef VOTEOPTIMIZEDSIGNED_HXX_
#define VOTEOPTIMIZEDSIGNED_HXX_

#include <System/SafeBuffer.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Voting
        {
            namespace Vote
            {
                /**
                 * @class VoteOptimizedSigned
                 * @brief Class for signed and validate vote optimized
                 * @date 21/05/2013
                 * @author Yadickson Soto
                 */
                class VoteOptimizedSigned
                {
                    public:
                        /**
                         * @fn VoteOptimizedSigned();
                         * @brief Class constructor
                         * @date 21/05/2013
                         * @author Yadickson Soto
                         */
                        VoteOptimizedSigned();
                        /**
                         * @fn virtual ~VoteOptimizedSigned();
                         * @brief Class destructor
                         * @date 21/05/2013
                         * @author Yadickson Soto
                         */
                        virtual ~VoteOptimizedSigned();
                        /**
                         * @fn virtual bool validateBuffer ( Smartmatic::System::SafeBuffer & buffer );
                         * @brief Method for validate signed input vote optimized buffer
                         * @date 21/05/2013
                         * @author Yadickson Soto
                         * @param 	buffer input buffer to validate
                         * @return true if validate is successful
                         */
                        virtual bool validateBuffer ( Smartmatic::System::SafeBuffer & buffer );
                        /**
                         * @fn virtual bool signedBuffer ( Smartmatic::System::SafeBuffer & buffer );
                         * @brief Method for signed buffer vote optimized buffer
                         * @date 21/05/2013
                         * @author Yadickson Soto
                         * @param 	buffer input and output buffer to signed
                         * @return true if signed is successful
                         */
                        virtual bool signedBuffer ( Smartmatic::System::SafeBuffer & buffer );
                };
            }
        }
    }
}
#endif /* VOTEOPTIMIZEDSIGNED_HXX_ */
