/**
 * @file CustomAttributeDefinitionWrapper.cxx
 * @brief Body class tool for manager custom attribute definition
 * @date 30/04/2013
 * @author Yadickson Soto
 */

#include "CustomAttributeDefinitionWrapper.hxx"
#include <Resources/election-string-resources-manager.h>
#include <System/Utils/StringUtils.hxx>

using namespace Smartmatic::SAES::Voting::VotingDevice;
using namespace Smartmatic::SAES::Resources;
using namespace Smartmatic::System::Utils;

/**
 * @brief method sort custom attributes
 * @param c1 custom attribute one
 * @param c2 custom attribute two
 * @return true is c1 < c2
 * @date 13/11/2012
 * @author Yadickson Soto
 */
static bool sortCustomAttributes ( Custom_attribute_definition_value c1, Custom_attribute_definition_value c2 )
{
    std::string t1 = ElectionStringResourcesManager::getInstance()->getResource ( c1.getValue() );
    std::string t2 = ElectionStringResourcesManager::getInstance()->getResource ( c2.getValue() );
    return ( t1.compare ( t2 ) < 0 );
}

CustomAttributeDefinitionWrapper::CustomAttributeDefinitionWrapper ()
{

}

CustomAttributeDefinitionWrapper::~CustomAttributeDefinitionWrapper()
{

}

void CustomAttributeDefinitionWrapper::sortByLanguage ( Smartmatic::SAES::Voting::VotingDevice::Custom_attribute_definition & customAttribute, const std::string & language )
{
    Custom_attribute_definition_values::Custom_attribute_definition_valueSequence newList;
    Custom_attribute_definition_values::Custom_attribute_definition_valueSequence list = customAttribute.getCustom_attribute_definition_values().getCustom_attribute_definition_value();
    Custom_attribute_definition_values::Custom_attribute_definition_valueIterator it;

    for ( it = list.begin(); it != list.end(); ++it )
    {
        std::string lang = ( ( *it ).getLanguage().present() ? ( *it ).getLanguage().get() : " " );
        lang = StringUtils::toUpper ( lang );

        if ( StringUtils::toUpper ( language ).compare ( lang ) == 0 )
        {
            newList.push_back ( *it );
            list.erase ( it );
            break;
        }
    }

    for ( it = list.begin(); it != list.end(); ++it )
    {
        newList.push_back ( *it );
    }

    Custom_attribute_definition_values values;
    values.setCustom_attribute_definition_value ( newList );
    customAttribute.setCustom_attribute_definition_values ( values );
}

void CustomAttributeDefinitionWrapper::sortAlphabetically ( Smartmatic::SAES::Voting::VotingDevice::Custom_attribute_definition & customAttribute )
{
    std::list < Custom_attribute_definition_value > list;
    std::list < Custom_attribute_definition_value >::iterator it;

    Custom_attribute_definition_values::Custom_attribute_definition_valueSequence newList;

    for ( it = list.begin(); it != list.end(); ++it )
    {
        list.push_back ( *it );
    }

    list.sort ( sortCustomAttributes );

    for ( it = list.begin(); it != list.end(); ++it )
    {
        newList.push_back ( *it );
    }

    Custom_attribute_definition_values values;
    values.setCustom_attribute_definition_value ( newList );
    customAttribute.setCustom_attribute_definition_values ( values );
}
