/**
 * @file CustomAttributeDefinitionWrapper.hxx
 * @brief Header class tool for manager custom attribute definition
 * @date 30/04/2013
 * @author Yadickson Soto
 */

#ifndef CUSTOMATTRIBUTEDEFINITIONWRAPPER_HXX_
#define CUSTOMATTRIBUTEDEFINITIONWRAPPER_HXX_

#include <Voting/VotingDevice/voting-devices-schema.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Voting
        {
            namespace VotingDevice
            {
                /**
                 * @class CustomAttributeDefinitionWrapper
                 * @brief class tool for manager custom attribute definition
                 * @date 30/04/2013
                 * @author Yadickson Soto
                 */
                class CustomAttributeDefinitionWrapper
                {
                    private:

                        /**
                         * @fn CustomAttributeDefinitionWrapper ();
                         * @brief Class constructor
                         * @date 30/04/2013
                         * @author Yadickson Soto
                         */
                        CustomAttributeDefinitionWrapper ();

                    public:

                        /**
                         * @fn virtual ~CustomAttributeDefinitionWrapper();
                         * @brief Class destructor
                         * @date 30/04/2013
                         * @author Yadickson Soto
                         */
                        virtual ~CustomAttributeDefinitionWrapper();

                        /**
                         * @fn static void sortByLanguage ( Smartmatic::SAES::Voting::VotingDevice::Custom_attribute_definition & customAttribute, const std::string & language = "" );
                         * @brief Method to sort custom attribute by user language selection. For example, in a context of custom attribute used for Senate, this can be used as follows: if user has selected French as his language, French Senate will come first.
                         * @date 30/04/2013
                         * @author Yadickson Soto
                         * @param customAttribute custom attribute definition to sort
                         * @param language language to hold in first place
                         */
                        static void sortByLanguage ( Smartmatic::SAES::Voting::VotingDevice::Custom_attribute_definition & customAttribute, const std::string & language = "" );

                        /**
                         * @fn static void sortAlphabetically ( Smartmatic::SAES::Voting::VotingDevice::Custom_attribute_definition & customAttribute );
                         * @brief Method sort custom attribute alphabetically
                         * @date 30/04/2013
                         * @author Yadickson Soto
                         * @param customAttribute custom attribute definition to sort
                         */
                        static void sortAlphabetically ( Smartmatic::SAES::Voting::VotingDevice::Custom_attribute_definition & customAttribute );
                };
            } /* namespace VotingDevice */
        } /* namespace Voting */
    } /* namespace SAES */
} /* namespace Smartmatic */
#endif /* CUSTOMATTRIBUTEDEFINITIONWRAPPER_HXX_ */
