/**
 * @file MockElectoralConfiguration.hxx
 * @date 21/03/2014
 * @author Yadickson Soto
 */

#ifndef MOCK_ELECTORAL_CONFIGURATION_HXX_
#define MOCK_ELECTORAL_CONFIGURATION_HXX_

#include <string>
#include <map>
#include <list>
#include <Voting/ElectoralConfiguration.hxx>

class MockElectoralConfiguration : public Smartmatic::SAES::Voting::ElectoralConfiguration
{
    public:

        struct ElectoralNames
        {
            ElectoralNames ( const std::string & firstName, const std::string & lastName, const std::string & initial )
            {
                this->firstName = firstName;
                this->lastName = lastName;
                this->initial = initial;
            }

            std::string firstName;
            std::string lastName;
            std::string initial;
        };

        MockElectoralConfiguration ()
        {

        }

        virtual ~MockElectoralConfiguration ()
        {
            std::map <std::string, std::map<std::string, typeEligibleOption * > >::iterator itm;

            for ( itm = eoByBallotOptionCodeMap.begin();
                    itm != eoByBallotOptionCodeMap.end();
                    ++itm )
            {
                std::map<std::string, typeEligibleOption * >::iterator it;
                std::map<std::string, typeEligibleOption * > & map ( itm->second );

                for ( it = map.begin();
                        it != map.end();
                        ++it )
                {
                    delete ( it->second );
                }
            }

            std::map <std::string, typeContestClass * >::iterator ccit;

            for ( ccit = contestClassMap.begin();
                    ccit != contestClassMap.end();
                    ++ccit )
            {
                if ( ccit->second != NULL )
                {
                    delete ( ccit->second );
                }
            }

            std::map <std::string, typeContest * >::iterator cit;

            for ( cit = contestMap.begin();
                    cit != contestMap.end();
                    ++cit )
            {
                if ( cit->second != NULL )
                {
                    delete ( cit->second );
                }
            }

            std::list < Smartmatic::SAES::Voting::Election::Contest * >::iterator itc;

            for ( itc = contestList.begin();
                    itc != contestList.end();
                    ++itc )
            {
                if ( *itc != NULL )
                {
                    delete ( *itc );
                }
            }
        }

        virtual std::list < Smartmatic::SAES::Voting::Election::Contest * > & getContestList()
        {
            return contestList;
        }

        virtual Smartmatic::SAES::Voting::Election::Contest * getContestByCode ( std::string code )
        {
            return contestMap[code];
        }

        virtual Smartmatic::SAES::Voting::Election::Contest_class * getContestClassByCode ( const std::string & code )
        {
            return contestClassMap[code];
        }

        virtual Smartmatic::SAES::Voting::Election::Eligible_option * getEligibleOptionFromBallotOptionCode ( const std::string & contestCode, const std::string & ballotOptionCode )
        {
            return eoByBallotOptionCodeMap[contestCode][ballotOptionCode];
        }

        virtual void getBallotOptionNames ( const Smartmatic::SAES::Voting::Election::Eligible_option * eligible, std::string & firstName, std::string & lastName, std::string & initialFirstName )
        {
            if ( !nameList.empty() )
            {
                ElectoralNames & names ( * ( nameList.begin() ) );

                firstName = names.firstName;
                lastName = names.lastName;
                initialFirstName = names.initial;

                nameList.pop_front();
            }
        }

        virtual void setEligibleOptionsListByContestParty( std::map <std::string, std::map < std::string, std::list < typeEligibleOption * > > > mapList )
        {
            mapEligibleOptionsListByContestParty = mapList;
        }

        virtual void setEligibleOptionsPrincipalByContestParty( std::map <std::string, std::map < std::string, std::list < typeEligibleOption * > > > mapPrincipal )
        {
            mapEligibleOptionsPrincipalByContestParty = mapPrincipal;
        }

        virtual void setEligibleOptionsStandInByContestParty( std::map <std::string, std::map < std::string, std::list < typeEligibleOption * > > > mapStandIn )
        {
            mapEligibleOptionsStandInByContestParty = mapStandIn;
        }

        virtual void setPartyCodeByBallotOptionCode( std::map < std::string, std::string > partyByBallotOptionCode )
        {
            partyCodeByBallotOptionCode = partyByBallotOptionCode;
        }

        virtual void setMapContestParty( std::map < std::string, std::list < typeParty * > > contestPartyMap )
        {
            mapContestParty = contestPartyMap;
        }

        virtual void setMapContestCode( std::map < std::string, typeContest * > contestCodeMap )
        {
            contestMap = contestCodeMap;
        }

        virtual void setMapContestClass( std::map < std::string, typeContestClass * > mapContestClass )
        {
            contestClassMap = mapContestClass;
        }

        virtual void setContestGroupByCodeMap( std::map < std::string, typeContestGroup * > contestGroupByCodeMap )
        {
            mapContestGroupByCode = contestGroupByCodeMap;
        }

        virtual void setLogicalVoterGroupsList( std::list < typeLogicalVoterGroup * > logicalVoterGroupsList )
        {
            listLVG = logicalVoterGroupsList;
        }

        virtual std::string getPartyNameByExpectedConfirmationReference(const std::string& reference) const
        {
            return customCodeNameMap.at(reference);
        }

        virtual std::string getCandidateNameByExpectedConfirmationReference(const std::string& reference) const
        {
            return customCodeNameMap.at(reference);
        }

        std::list < ElectoralNames > nameList;
        std::list < Smartmatic::SAES::Voting::Election::Contest * > contestList;
        std::map < std::string, Smartmatic::SAES::Voting::Election::Contest * > contestMap;
        std::map < std::string, std::map<std::string, typeEligibleOption * > > eoByBallotOptionCodeMap;
        std::map < std::string, typeContestClass * > contestClassMap;
        std::map < std::string, std::string > customCodeNameMap;
};

#endif /* MOCK_ELECTORAL_CONFIGURATION_HXX_ */
