#ifndef TEST_BALLOTID_CARDDATATEST
#define TEST_BALLOTID_CARDDATATEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Voting/IDManager/SessionIDManager.hxx>
#include <Voting/CardData/CardDataFactory.hxx>
#include <Voting/VotingDevice/LogicalVoterGroupFactory.hxx>
#include "MockSessionIDManager.hxx"

class SessionIDCardDataTest : public CPPUNIT_NS::TestFixture
{
    private:

        Smartmatic::SAES::Voting::VotingDevice::Logical_voter_group clvg;

    public:

        SessionIDCardDataTest ()
        {

        }

        void setUp()
        {
            clvg = Smartmatic::SAES::Voting::VotingDevice::LogicalVoterGroupFactory::createLogicalVoterGroup ();
        }

        void tearDown()
        {

        }

        void testValidateInsideSessionID()
        {
            MockSessionIDManager sessionManager;
            MOCKPP_CHAINER_FOR_EXT ( MockSessionIDManager, getID, ext ) getSID_mock ( &sessionManager );

            getSID_mock.stubs()
            .will ( new MOCKPP_NS::ReturnStub< std::string > ( "session-id" ) );

            Smartmatic::SAES::Voting::CardData::Card_data cardData;
            cardData = Smartmatic::SAES::Voting::CardData::CardDataFactory::createCardData ( clvg, NULL, &sessionManager );
            CPPUNIT_ASSERT ( false == cardData.getSessionID().empty() );
        }

        void testValidateSessionIDWithManager()
        {
            MockSessionIDManager sessionManager;
            MOCKPP_CHAINER_FOR_EXT ( MockSessionIDManager, getID, ext ) getSID_mock ( &sessionManager );

            getSID_mock.stubs()
            .will ( new MOCKPP_NS::ReturnStub< std::string > ( "session-id" ) );

            Smartmatic::SAES::Voting::CardData::Card_data cardData;
            cardData = Smartmatic::SAES::Voting::CardData::CardDataFactory::createCardData ( clvg, NULL, &sessionManager );
            CPPUNIT_ASSERT ( true == sessionManager.verifyID ( NULL, cardData.getSessionID() ) );
        }

        void testValidateSessionIDVerifyTwoTime()
        {
            MockSessionIDManager sessionManager;
            MOCKPP_CHAINER_FOR_EXT ( MockSessionIDManager, getID, ext ) getSID_mock ( &sessionManager );

            getSID_mock.stubs()
            .will ( new MOCKPP_NS::ReturnStub< std::string > ( "session-id" ) );

            Smartmatic::SAES::Voting::CardData::Card_data cardData;
            cardData = Smartmatic::SAES::Voting::CardData::CardDataFactory::createCardData ( clvg, NULL, &sessionManager );
            CPPUNIT_ASSERT ( true == sessionManager.verifyID ( NULL, cardData.getSessionID() ) );
            CPPUNIT_ASSERT ( true == sessionManager.verifyID ( NULL, cardData.getSessionID() ) );
        }

        CPPUNIT_TEST_SUITE ( SessionIDCardDataTest );
        CPPUNIT_TEST ( testValidateInsideSessionID );
        CPPUNIT_TEST ( testValidateSessionIDWithManager );
        CPPUNIT_TEST ( testValidateSessionIDVerifyTwoTime );
        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_BALLOTID_CARDDATATEST */
