#ifndef TEST_VALIDATECARDDATATEST
#define TEST_VALIDATECARDDATATEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Voting/CardData/CardDataFactory.hxx>
#include <Voting/CardData/CardDataValidate.hxx>
#include <Voting/CardData/card-data-wrapper.h>
#include <Voting/VotingDevice/LogicalVoterGroupFactory.hxx>
#include "MockSessionIDManager.hxx"

class ValidateCardDataTest : public CPPUNIT_NS::TestFixture
{
    private:

        Smartmatic::SAES::Voting::CardData::Card_data cardData;
        Smartmatic::SAES::Voting::VotingDevice::Logical_voter_group clvg;

    public:

        ValidateCardDataTest ()
        {

        }

        void setUp()
        {
            MockSessionIDManager sessionManager;
            MOCKPP_CHAINER_FOR_EXT ( MockSessionIDManager, getID, ext ) getSID_mock ( &sessionManager );

            getSID_mock.stubs()
            .will ( new MOCKPP_NS::ReturnStub< std::string > ( "session-id" ) );

            clvg = Smartmatic::SAES::Voting::VotingDevice::LogicalVoterGroupFactory::createLogicalVoterGroup ( );
            cardData = Smartmatic::SAES::Voting::CardData::CardDataFactory::createCardData ( clvg, NULL, &sessionManager );
        }

        void tearDown()
        {

        }

        void testValidateCreateCardDataNotUsed()
        {
            bool result = cardData.getCard_status() == Smartmatic::SAES::Voting::CardData::Card_status::CARD_DATA_NOT_USED;
            CPPUNIT_ASSERT ( true == result );
        }

        void testValidateCreateCardDataOfficial()
        {
            bool result = cardData.getCard_type() == Smartmatic::SAES::Voting::CardData::Card_type::CARD_DATA_OFFICIAL_VOTE_CARD;
            CPPUNIT_ASSERT ( true == result );
        }

        void testValidateStructureCardData()
        {
            bool result = Smartmatic::SAES::Voting::CardData::CardDataValidate::validateStructure ( cardData );
            CPPUNIT_ASSERT ( true == result );
        }

        void testCardDataToBuffer()
        {
            Smartmatic::System::SafeBuffer buffer;
            bool result = Smartmatic::SAES::Voting::CardData::CardDataFactory::cardDataToBuffer ( cardData, buffer );

            CPPUNIT_ASSERT ( true == result );
            CPPUNIT_ASSERT ( 0 != buffer.GetSize() );
            CPPUNIT_ASSERT ( NULL != buffer.GetData() );
        }

        void testRegressionCardData()
        {
            Smartmatic::System::SafeBuffer buffer;

            bool resultOne;
            bool resultTwo;

            resultOne = Smartmatic::SAES::Voting::CardData::CardDataFactory::cardDataToBuffer ( cardData, buffer );
            resultTwo = Smartmatic::SAES::Voting::CardData::CardDataFactory::bufferToCardData ( buffer, cardData );

            CPPUNIT_ASSERT ( true == resultOne );
            CPPUNIT_ASSERT ( true == resultTwo );
        }

        void testMarkUsedCardData()
        {
            Smartmatic::SAES::Voting::CardData::CardDataWrapper::markUsed ( cardData );
            bool used = cardData.getCard_status() == Smartmatic::SAES::Voting::CardData::Card_status::CARD_DATA_USED;

            CPPUNIT_ASSERT ( true == cardData.getBallotID().empty() );
            CPPUNIT_ASSERT ( true == cardData.getSessionID().empty() );
            CPPUNIT_ASSERT ( true == used );
        }

        CPPUNIT_TEST_SUITE ( ValidateCardDataTest );
        CPPUNIT_TEST ( testValidateCreateCardDataNotUsed );
        CPPUNIT_TEST ( testValidateCreateCardDataOfficial );
        CPPUNIT_TEST ( testValidateStructureCardData );
        CPPUNIT_TEST ( testCardDataToBuffer );
        CPPUNIT_TEST ( testRegressionCardData );
        CPPUNIT_TEST ( testMarkUsedCardData );
        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_VALIDATECARDDATATEST */
