#ifndef EML_FILE_INFO_TEST_H
#define EML_FILE_INFO_TEST_H

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Voting/Eml/EmlFileInfo.hxx>
#include <tests/MockSaesConfigurationManager.hxx>
#include <Configuration/s-a-e-s-conf-manager.h>
#include <System/Exception/FileSystemException.hxx>

class EmlFileInfoTest : public CPPUNIT_NS::TestFixture
{
    public:

        EmlFileInfoTest()
        {
        }

        virtual ~EmlFileInfoTest()
        {
        }

    public:

        void testGetInputContestFileName()
        {
            namespace EFileInfo = Smartmatic::SAES::Voting::Eml::EmlFileInfo;

            CPPUNIT_ASSERT(
                EFileInfo::getInputContestFileName("EU212122") == "DL21212_EU.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getInputContestFileName("CK543211") == "DC54321_CK.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getInputContestFileName("SE541232") == "DL54123_SE.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getInputContestFileName("VL135423") == "DC13542_VL.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getInputContestFileName("WL123455") == "DC12345_WL.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getInputContestFileName("BR112251") == "DR11225_BR.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getInputContestFileName("DE555552") == "DG55555_DE.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getInputContestFileName("PR332213") == "DD33221_PR.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getInputContestFileName("CG222215") == "DM22221_CG.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getInputContestFileName("DI333331") == "DI33333_DI.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getInputContestFileName("CS121252") == "DM12125_CS.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getInputContestFileName("INVALID") == "_.EML");
        }

        void testGetOutputContestFileName()
        {
            namespace EFileInfo = Smartmatic::SAES::Voting::Eml::EmlFileInfo;
            namespace Conf      = Smartmatic::SAES::Configuration;
            MockSaesConfigurationManager mockedSaesConfigurationManager;

            Conf::SAESConfigurationManager::getInstance(&mockedSaesConfigurationManager);

            CPPUNIT_ASSERT(
                EFileInfo::getOutputContestFileName("EU212122", "00", "", "") == "V0021212_EU.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getOutputContestFileName("CK543211", "00", "", "") == "V0054321_CK.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getOutputContestFileName("SE541232", "00", "", "") == "V0054123_SE.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getOutputContestFileName("VL135423", "00", "", "") == "V0013542_VL.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getOutputContestFileName("WL123455", "00", "", "") == "V0012345_WL.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getOutputContestFileName("BR112251", "00", "", "") == "V0011225_BR.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getOutputContestFileName("DE555552", "00", "", "") == "V0055555_DE.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getOutputContestFileName("PR332213", "00", "", "") == "V0033221_PR.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getOutputContestFileName("CG222215", "00", "", "") == "V0022221_CG.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getOutputContestFileName("DI333331", "00", "", "") == "V0033333_DI.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getOutputContestFileName("CS121252", "00", "", "") == "V0012125_CS.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getOutputContestFileName("INVALID", "00", "", "") == "V00_.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getOutputContestFileName("EU212122", "0", "", "") == "V021212_EU.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getOutputContestFileName("CK543211", "0", "", "") == "V054321_CK.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getOutputContestFileName("SE541232", "0", "", "") == "V054123_SE.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getOutputContestFileName("VL135423", "0", "", "") == "V013542_VL.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getOutputContestFileName("WL123455", "0", "", "") == "V012345_WL.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getOutputContestFileName("BR112251", "0", "", "") == "V011225_BR.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getOutputContestFileName("DE555552", "0", "", "") == "V055555_DE.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getOutputContestFileName("PR332213", "0", "", "") == "V033221_PR.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getOutputContestFileName("CG222215", "0", "", "") == "V022221_CG.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getOutputContestFileName("DI333331", "0", "", "") == "V033333_DI.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getOutputContestFileName("CS121252", "0", "", "") == "V012125_CS.EML");
            CPPUNIT_ASSERT(
                EFileInfo::getOutputContestFileName("INVALID", "0", "", "") == "V0_.EML");

        }

        void testLoadEmlFromFile()
        {
            namespace EFileInfo = Smartmatic::SAES::Voting::Eml::EmlFileInfo;

            CPPUNIT_ASSERT_THROW(EFileInfo::loadEmlFromFile("invalid_file.eml"),
                                 Smartmatic::System::Exception::FileSystemException);

        }

        void testLoadEmlFromFileEmpty()
        {
            namespace EFileInfo = Smartmatic::SAES::Voting::Eml::EmlFileInfo;

            CPPUNIT_ASSERT_NO_THROW(EFileInfo::loadEmlFromFile("230.EML"));
        }

        CPPUNIT_TEST_SUITE(EmlFileInfoTest);

        CPPUNIT_TEST(testGetInputContestFileName);
        CPPUNIT_TEST(testGetOutputContestFileName);
        CPPUNIT_TEST(testLoadEmlFromFile);
        CPPUNIT_TEST(testLoadEmlFromFileEmpty);

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* EML_FILE_INFO_TEST_H */
