#ifndef EML_INFO_TEST_H
#define EML_INFO_TEST_H

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Voting/Eml/EmlInfo.hxx>

class EmlInfoTest : public CPPUNIT_NS::TestFixture
{
    public:

        EmlInfoTest()
        {
        }

        void setUp()
        {
        }

        void tearDown()
        {
        }

        void testGetElectionType()
        {
            std::map<std::string, std::string> customCodeTypeMap;

            customCodeTypeMap["BR210041"] = "BR";
            customCodeTypeMap["INVALID"] = "";
            customCodeTypeMap["EU212122"] = "EU";
            customCodeTypeMap["CK210013"] = "CK";
            customCodeTypeMap["VL120115"] = "VL";

            for (std::map<std::string, std::string>::iterator it = customCodeTypeMap.begin();
                 it != customCodeTypeMap.end();
                 ++it)
            {
                CPPUNIT_ASSERT_EQUAL(it->second, Smartmatic::SAES::Voting::Eml::EmlInfo::getElectionType(it->first));
            }
        }

        void testGetInputNisCode()
        {
            std::map<std::string, std::string> customCodeTypeMap;

            customCodeTypeMap["BR210041"] = "21004";
            customCodeTypeMap["INVALID"] = "";
            customCodeTypeMap["EU212122"] = "21212";
            customCodeTypeMap["CK210013"] = "21001";
            customCodeTypeMap["VL120115"] = "12011";

            for (std::map<std::string, std::string>::iterator it = customCodeTypeMap.begin();
                 it != customCodeTypeMap.end();
                 ++it)
            {
                CPPUNIT_ASSERT_EQUAL(it->second, Smartmatic::SAES::Voting::Eml::EmlInfo::getInputNisCode(it->first));
            }
        }

        void testGetOutputNisCode()
        {
            std::string customCode    = "BR210011";
            std::string nisCode       = "21004";
            std::string emptyNisCode  = "";
            std::string expected      = "21004";
            std::string emptyExpected = "21001";

            CPPUNIT_ASSERT_EQUAL(
                expected,
                Smartmatic::SAES::Voting::Eml::EmlInfo::getOutputNisCode(customCode, nisCode));

            CPPUNIT_ASSERT_EQUAL(
                emptyExpected,
                Smartmatic::SAES::Voting::Eml::EmlInfo::getOutputNisCode(customCode, emptyNisCode));
        }

        void testGetLanguage()
        {
            std::map<std::string, std::string> customCodeLangMap;

            customCodeLangMap["BR210041"] = "1";
            customCodeLangMap["INVALID"] = "";
            customCodeLangMap["EU212122"] = "2";
            customCodeLangMap["CK210013"] = "3";
            customCodeLangMap["VL120115"] = "5";

            for (std::map<std::string, std::string>::iterator it = customCodeLangMap.begin();
                 it != customCodeLangMap.end();
                 ++it)
            {
                CPPUNIT_ASSERT_EQUAL(it->second, Smartmatic::SAES::Voting::Eml::EmlInfo::getLanguage(it->first));
            }

        }

        void testGetTotalVotesSelectionCategory()
        {
            std::map<std::string, std::string> customCodeLangMap;

            customCodeLangMap["BR210041"] = "210041";
            customCodeLangMap["INVALID"] = "";
            customCodeLangMap["EU212122"] = "212122";
            customCodeLangMap["CK210013"] = "210013";
            customCodeLangMap["VL120115"] = "120115";

            for (std::map<std::string, std::string>::iterator it = customCodeLangMap.begin();
                 it != customCodeLangMap.end();
                 ++it)
            {
                CPPUNIT_ASSERT_EQUAL(
                    it->second,
                    Smartmatic::SAES::Voting::Eml::EmlInfo::getTotalVotesSelectionCategory(it->first));
            }
        }

        void testGetLinguisticRegime()
        {
            std::map<std::string, int> customCodeLangMap;

            customCodeLangMap["BR210042"] = 2;
            customCodeLangMap["INVALID"] = 0;
            customCodeLangMap["EU212121"] = 1;
            customCodeLangMap["CK210013"] = 3;
            customCodeLangMap["VL120115"] = 5;

            for (std::map<std::string, int>::iterator it = customCodeLangMap.begin();
                 it != customCodeLangMap.end();
                 ++it)
            {
                CPPUNIT_ASSERT_EQUAL(
                    it->second,
                    Smartmatic::SAES::Voting::Eml::EmlInfo::getLinguisticRegime(it->first));
            }

        }

        void testGetEventQualifier()
        {
            std::string emlFilename = "V00121013_CK.EML";
            std::string expected = "V00121013";

            CPPUNIT_ASSERT_EQUAL(
                expected,
                Smartmatic::SAES::Voting::Eml::EmlInfo::getEventQualifier(emlFilename));
        }

        void testGetElectionIdentifierId()
        {
            std::map<std::string, std::string> electionIdentifierIdMap;

            electionIdentifierIdMap["INVALID"] = "";
            electionIdentifierIdMap["EU212122"] = "1";
            electionIdentifierIdMap["CK210013"] = "2";
            electionIdentifierIdMap["SE210321"] = "3";
            electionIdentifierIdMap["WL210042"] = "4";
            electionIdentifierIdMap["PR210041"] = "5";
            electionIdentifierIdMap["CG210043"] = "6";
            electionIdentifierIdMap["VL120115"] = "7";
            electionIdentifierIdMap["DI910941"] = "8";
            electionIdentifierIdMap["CS210045"] = "9";
            electionIdentifierIdMap["BR210041"] = "10";
            electionIdentifierIdMap["DE210325"] = "12";

            for (std::map<std::string, std::string>::iterator it = electionIdentifierIdMap.begin();
                 it != electionIdentifierIdMap.end();
                 ++it)
            {
                CPPUNIT_ASSERT_EQUAL(
                    it->second,
                    Smartmatic::SAES::Voting::Eml::EmlInfo::getElectionIdentifierId(it->first));
            }
        }

        void testGetElectionIdentifierName()
        {
            std::map<std::string, std::string> electionIdentifierNameMap;

            electionIdentifierNameMap["INVALID"] = "";
            electionIdentifierNameMap["EU212122"] = "Europees Parlement";
            electionIdentifierNameMap["CK210013"] = "Chambre";
            electionIdentifierNameMap["SE210321"] = "Sénat";
            electionIdentifierNameMap["WL210042"] = "Waals Parlement";
            electionIdentifierNameMap["PR210041"] = "Conseils provinciaux";
            electionIdentifierNameMap["CG210043"] = "Conseils communaux";
            electionIdentifierNameMap["VL120115"] = "Parlement flamand";
            electionIdentifierNameMap["DI910941"] = "Conseil de district";
            electionIdentifierNameMap["CS210045"] = "Conseil CPAS";
            electionIdentifierNameMap["BR210041"] = "Parlement de la Région de Bruxelles-Capitale";
            electionIdentifierNameMap["DE210325"] = "Parlement de la Communauté germanophone";

            for (std::map<std::string, std::string>::iterator it = electionIdentifierNameMap.begin();
                 it != electionIdentifierNameMap.end();
                 ++it)
            {
                CPPUNIT_ASSERT_EQUAL(
                    it->second,
                    Smartmatic::SAES::Voting::Eml::EmlInfo::getElectionIdentifierName(it->first));
            }

        }

        void testGetOutputNisCodeByFile()
        {
            std::string emlFilename = "V00121013_BR.EML";
            std::string expected = "21013";

            CPPUNIT_ASSERT_EQUAL(expected, Smartmatic::SAES::Voting::Eml::EmlInfo::getOutputNisCode(emlFilename));
        }

        CPPUNIT_TEST_SUITE(EmlInfoTest);

        CPPUNIT_TEST(testGetElectionType);
        CPPUNIT_TEST(testGetInputNisCode);
        CPPUNIT_TEST(testGetOutputNisCode);
        CPPUNIT_TEST(testGetLanguage);
        CPPUNIT_TEST(testGetTotalVotesSelectionCategory);
        CPPUNIT_TEST(testGetLinguisticRegime);
        CPPUNIT_TEST(testGetEventQualifier);
        CPPUNIT_TEST(testGetElectionIdentifierId);
        CPPUNIT_TEST(testGetElectionIdentifierName);
        CPPUNIT_TEST(testGetOutputNisCodeByFile);

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* EML_INFO_TEST_H */
