#ifndef TEST_BALLOTID_MANAGER_TEST
#define TEST_BALLOTID_MANAGER_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Voting/IDManager/BallotIDManager.hxx>

class BallotIDManagerTest : public CPPUNIT_NS::TestFixture
{
    private:

        Smartmatic::SAES::Voting::BallotIDManager * idManager;

    public:

        BallotIDManagerTest ()
        {
            idManager = NULL;
        }

        void setUp()
        {
            idManager = Smartmatic::SAES::Voting::BallotIDManager::getInstance();
        }

        void tearDown()
        {
            if ( idManager )
            {
                delete idManager;
                idManager = NULL;
            }
        }

        void testGeneration()
        {
            std::string uuid = idManager->getID();
            CPPUNIT_ASSERT ( false == uuid.empty() );
        }

        void testVerifyNotID()
        {
            CPPUNIT_ASSERT ( false == idManager->verifyID ( "XXYY" ) );
        }

        void testGenerationAndVerify()
        {
            std::string uuid = idManager->getID();
            CPPUNIT_ASSERT ( true == idManager->verifyID ( uuid ) );
        }

        void testGenerationAndVerifyCheckRemove()
        {
            std::string uuid = idManager->getID();
            CPPUNIT_ASSERT ( true == idManager->verifyID ( uuid ) );
            CPPUNIT_ASSERT ( true == idManager->removeID ( uuid ) );
            CPPUNIT_ASSERT ( false == idManager->verifyID ( uuid ) );
        }

        CPPUNIT_TEST_SUITE ( BallotIDManagerTest );
        CPPUNIT_TEST ( testGeneration );
        CPPUNIT_TEST ( testVerifyNotID );
        CPPUNIT_TEST ( testGenerationAndVerify );
        CPPUNIT_TEST ( testGenerationAndVerifyCheckRemove );
        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_BALLOTID_MANAGER_TEST */
