#ifndef TEST_ID_MANAGER_TEST
#define TEST_ID_MANAGER_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Voting/IDManager/IDManager.hxx>

class IDManagerTest : public CPPUNIT_NS::TestFixture
{
    private:

        Smartmatic::SAES::Voting::IDManager * idManager;

    public:

        IDManagerTest ()
        {
            idManager = NULL;
        }

        void setUp()
        {
            idManager = new Smartmatic::SAES::Voting::IDManager();
        }

        void tearDown()
        {
            if ( idManager )
            {
                delete idManager;
                idManager = NULL;
            }
        }

        void testGeneration()
        {
            std::string uuid = idManager->generate();

            CPPUNIT_ASSERT ( false == uuid.empty() );
        }

        void testGenerationAndAddOneInternalList()
        {
            ( void ) idManager->generate();

            CPPUNIT_ASSERT ( 1 == idManager->size() );
        }

        void testGenerationAndAddTwoInternalList()
        {
            ( void ) idManager->generate();
            ( void ) idManager->generate();

            CPPUNIT_ASSERT ( 2 == idManager->size() );
        }

        void testGenerationAndClear()
        {
            ( void ) idManager->generate();
            idManager->clear();

            CPPUNIT_ASSERT ( 0 == idManager->size() );
        }

        void testFindNotUUID()
        {
            CPPUNIT_ASSERT ( false == idManager->find ( "xxyy" ) );
        }

        void testRemoveNotUUID()
        {
            CPPUNIT_ASSERT ( false == idManager->remove ( "xxyy" ) );
        }

        void testGenerationAndFind()
        {
            std::string uuid = idManager->generate();
            CPPUNIT_ASSERT ( true == idManager->find ( uuid ) );
        }

        void testGenerationAndRemove()
        {
            std::string uuid = idManager->generate();
            CPPUNIT_ASSERT ( 1 == idManager->size () );
            CPPUNIT_ASSERT ( true == idManager->remove ( uuid ) );
            CPPUNIT_ASSERT ( 0 == idManager->size () );
        }

        CPPUNIT_TEST_SUITE ( IDManagerTest );
        CPPUNIT_TEST ( testGeneration );
        CPPUNIT_TEST ( testGenerationAndAddOneInternalList );
        CPPUNIT_TEST ( testGenerationAndAddTwoInternalList );
        CPPUNIT_TEST ( testGenerationAndClear );
        CPPUNIT_TEST ( testFindNotUUID );
        CPPUNIT_TEST ( testRemoveNotUUID );
        CPPUNIT_TEST ( testGenerationAndFind );
        CPPUNIT_TEST ( testGenerationAndRemove );
        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_ID_MANAGER_TEST */
