#ifndef DIAGNOSE_STEP_TEST_H_
#define DIAGNOSE_STEP_TEST_H_

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Voting/Status/DiagnoseStepWrapper.hxx>

class DiagnoseStepTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::SAES::Voting::Status::DiagnoseStepWrapper DiagnoseStepWrapper;
        typedef Smartmatic::SAES::Voting::Status::DiagnoseStep DiagnoseStep;
        typedef Smartmatic::SAES::Voting::Status::DiagnoseCode DiagnoseCode;
        typedef Smartmatic::SAES::Common::Configuration::DeviceType DeviceType;
        typedef Smartmatic::SAES::Voting::Status::VMStatus VMStatus;

    public:

        DiagnoseStepTest ()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testCreateDefaultDiagnoseStep()
        {
            DiagnoseCode result;
            DiagnoseCode expected = DiagnoseCode::VOTING_MACHINE_STATUS_X;

            DiagnoseStep step = DiagnoseStepWrapper::createDiagnoseStep();
            result = step.getCode();

            CPPUNIT_ASSERT ( expected == result );
        }

        void testCreateAlarmBoxDiagnoseStep()
        {
            DiagnoseCode result;
            DiagnoseCode expected = DiagnoseCode::VOTING_MACHINE_STATUS_A;

            DiagnoseStep step = DiagnoseStepWrapper::createDiagnoseStep ( DeviceType::CONFIGURATION_ALARMBOX );
            result = step.getCode();

            CPPUNIT_ASSERT ( expected == result );
        }

        void testCreateBarcodeReaderDiagnoseStep()
        {
            DiagnoseCode result;
            DiagnoseCode expected = DiagnoseCode::VOTING_MACHINE_STATUS_B;

            DiagnoseStep step = DiagnoseStepWrapper::createDiagnoseStep ( DeviceType::CONFIGURATION_BARCODE );
            result = step.getCode();

            CPPUNIT_ASSERT ( expected == result );
        }

        void testCreatePrinterDiagnoseStep()
        {
            DiagnoseCode result;
            DiagnoseCode expected = DiagnoseCode::VOTING_MACHINE_STATUS_P;

            DiagnoseStep step = DiagnoseStepWrapper::createDiagnoseStep ( DeviceType::CONFIGURATION_PRINTER );
            result = step.getCode();

            CPPUNIT_ASSERT ( expected == result );
        }

        void testCreateSmartcardReaderDiagnoseStep()
        {
            DiagnoseCode result;
            DiagnoseCode expected = DiagnoseCode::VOTING_MACHINE_STATUS_S;

            DiagnoseStep step = DiagnoseStepWrapper::createDiagnoseStep ( DeviceType::CONFIGURATION_SMARTCARD );
            result = step.getCode();

            CPPUNIT_ASSERT ( expected == result );
        }

        void testCreateTouchScreenDiagnoseStep()
        {
            DiagnoseCode result;
            DiagnoseCode expected = DiagnoseCode::VOTING_MACHINE_STATUS_T;

            DiagnoseStep step = DiagnoseStepWrapper::createDiagnoseStep ( DeviceType::CONFIGURATION_TOUCHSCREENCALIBRATION );
            result = step.getCode();

            CPPUNIT_ASSERT ( expected == result );
        }

        void testCreateFlashDiagnoseStep()
        {
            DiagnoseCode result;
            DiagnoseCode expected = DiagnoseCode::VOTING_MACHINE_STATUS_F;

            DiagnoseStep step = DiagnoseStepWrapper::createDiagnoseStep ( DeviceType::CONFIGURATION_FLASH );
            result = step.getCode();

            CPPUNIT_ASSERT ( expected == result );
        }

        void testResultEmptyDiagnoseStep()
        {
            std::string result;
            DiagnoseStep step = DiagnoseStepWrapper::createDiagnoseStep();

            result = DiagnoseStepWrapper::getDiagnoseStepString ( step, ",", ":", "OK", "NOK" );

            CPPUNIT_ASSERT ( true == result.empty() );
        }

        void testResultAlarmBoxDiagnoseStepOk()
        {
            std::string result;
            std::string expected = "A:OK,";

            DiagnoseStep step = DiagnoseStepWrapper::createDiagnoseStep ( DeviceType::CONFIGURATION_ALARMBOX );
            step.setStatus ( VMStatus::VOTING_MACHINE_STATUS_OK );

            result = DiagnoseStepWrapper::getDiagnoseStepString ( step, ",", ":", "OK", "NOK" );

            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( true == ( result.compare ( expected ) == 0 ) );
        }

        void testResultAlarmBoxDiagnoseStepNOk()
        {
            std::string result;
            std::string expected = "A:NOK,";

            DiagnoseStep step = DiagnoseStepWrapper::createDiagnoseStep ( DeviceType::CONFIGURATION_ALARMBOX );
            step.setStatus ( VMStatus::VOTING_MACHINE_STATUS_ERROR );

            result = DiagnoseStepWrapper::getDiagnoseStepString ( step, ",", ":", "OK", "NOK" );

            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( true == ( result.compare ( expected ) == 0 ) );
        }

        void testResultBarcodeReaderDiagnoseStepOk()
        {
            std::string result;
            std::string expected = "B:OK,";

            DiagnoseStep step = DiagnoseStepWrapper::createDiagnoseStep ( DeviceType::CONFIGURATION_BARCODE );
            step.setStatus ( VMStatus::VOTING_MACHINE_STATUS_OK );

            result = DiagnoseStepWrapper::getDiagnoseStepString ( step, ",", ":", "OK", "NOK" );

            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( true == ( result.compare ( expected ) == 0 ) );
        }

        void testResultBarcodeReaderDiagnoseStepNOk()
        {
            std::string result;
            std::string expected = "B:NOK,";

            DiagnoseStep step = DiagnoseStepWrapper::createDiagnoseStep ( DeviceType::CONFIGURATION_BARCODE );
            step.setStatus ( VMStatus::VOTING_MACHINE_STATUS_ERROR );

            result = DiagnoseStepWrapper::getDiagnoseStepString ( step, ",", ":", "OK", "NOK" );

            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( true == ( result.compare ( expected ) == 0 ) );
        }

        void testResultBarcodeReaderDiagnoseStepNA()
        {
            std::string result;
            std::string expected = "B:N/A,";

            DiagnoseStep step = DiagnoseStepWrapper::createDiagnoseStep ( DeviceType::CONFIGURATION_BARCODE );
            step.setStatus ( VMStatus::VOTING_MACHINE_STATUS_NOTDIAGNOSED );

            result = DiagnoseStepWrapper::getDiagnoseStepString ( step, ",", ":", "OK", "NOK", "N/A" );

            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( true == ( result.compare ( expected ) == 0 ) );
        }

        void testResultPrinterDiagnoseStepOk()
        {
            std::string result;
            std::string expected = "P:OK,";

            DiagnoseStep step = DiagnoseStepWrapper::createDiagnoseStep ( DeviceType::CONFIGURATION_PRINTER );
            step.setStatus ( VMStatus::VOTING_MACHINE_STATUS_OK );

            result = DiagnoseStepWrapper::getDiagnoseStepString ( step, ",", ":", "OK", "NOK" );

            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( true == ( result.compare ( expected ) == 0 ) );
        }

        void testResultPrinterDiagnoseStepNOk()
        {
            std::string result;
            std::string expected = "P:NOK,";

            DiagnoseStep step = DiagnoseStepWrapper::createDiagnoseStep ( DeviceType::CONFIGURATION_PRINTER );
            step.setStatus ( VMStatus::VOTING_MACHINE_STATUS_ERROR );

            result = DiagnoseStepWrapper::getDiagnoseStepString ( step, ",", ":", "OK", "NOK" );

            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( true == ( result.compare ( expected ) == 0 ) );
        }

        void testResultSmartcardReaderDiagnoseStepOk()
        {
            std::string result;
            std::string expected = "S:OK,";

            DiagnoseStep step = DiagnoseStepWrapper::createDiagnoseStep ( DeviceType::CONFIGURATION_SMARTCARD );
            step.setStatus ( VMStatus::VOTING_MACHINE_STATUS_OK );

            result = DiagnoseStepWrapper::getDiagnoseStepString ( step, ",", ":", "OK", "NOK" );

            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( true == ( result.compare ( expected ) == 0 ) );
        }

        void testResultSmartcardReaderDiagnoseStepNOk()
        {
            std::string result;
            std::string expected = "S:NOK,";

            DiagnoseStep step = DiagnoseStepWrapper::createDiagnoseStep ( DeviceType::CONFIGURATION_SMARTCARD );
            step.setStatus ( VMStatus::VOTING_MACHINE_STATUS_ERROR );

            result = DiagnoseStepWrapper::getDiagnoseStepString ( step, ",", ":", "OK", "NOK" );

            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( true == ( result.compare ( expected ) == 0 ) );
        }

        void testResultTouchScreenDiagnoseStepOk()
        {
            std::string result;
            std::string expected = "T:OK,";

            DiagnoseStep step = DiagnoseStepWrapper::createDiagnoseStep ( DeviceType::CONFIGURATION_TOUCHSCREENCALIBRATION );
            step.setStatus ( VMStatus::VOTING_MACHINE_STATUS_OK );

            result = DiagnoseStepWrapper::getDiagnoseStepString ( step, ",", ":", "OK", "NOK" );

            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( true == ( result.compare ( expected ) == 0 ) );
        }

        void testResultTouchScreenDiagnoseStepNOk()
        {
            std::string result;
            std::string expected = "T:NOK,";

            DiagnoseStep step = DiagnoseStepWrapper::createDiagnoseStep ( DeviceType::CONFIGURATION_TOUCHSCREENCALIBRATION );
            step.setStatus ( VMStatus::VOTING_MACHINE_STATUS_ERROR );

            result = DiagnoseStepWrapper::getDiagnoseStepString ( step, ",", ":", "OK", "NOK" );

            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( true == ( result.compare ( expected ) == 0 ) );
        }

        void testResultWithCustomRemarkStep()
        {
            std::string result;
            std::string expected = "R:Hello\\, this is a custom remark. Smartmatic Labs\\, C.A.,";

            DiagnoseCode code ( DiagnoseCode::VOTING_MACHINE_STATUS_R );
            DiagnoseStep step ( code );
            step.setValue ( "Hello, this is a custom remark.\nSmartmatic Labs, C.A." );

            result = DiagnoseStepWrapper::getDiagnoseStepString ( step, ",", ":" );

            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( true == ( result.compare ( expected ) == 0 ) );
        }

        void testResultWithCheckListStep()
        {
            std::string result;
            std::string expected = "C:ABC:1,";

            DiagnoseCode code ( DiagnoseCode::VOTING_MACHINE_STATUS_C );
            DiagnoseStep step ( code );
            step.setCustomCode ( "ABC" );
            step.setValue ( "1" );

            result = DiagnoseStepWrapper::getDiagnoseStepString ( step, ",", ":" );

            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( true == ( result.compare ( expected ) == 0 ) );
        }

        CPPUNIT_TEST_SUITE ( DiagnoseStepTest );

        CPPUNIT_TEST ( testCreateDefaultDiagnoseStep );
        CPPUNIT_TEST ( testCreateAlarmBoxDiagnoseStep );
        CPPUNIT_TEST ( testCreateBarcodeReaderDiagnoseStep );
        CPPUNIT_TEST ( testCreatePrinterDiagnoseStep );
        CPPUNIT_TEST ( testCreateSmartcardReaderDiagnoseStep );
        CPPUNIT_TEST ( testCreateTouchScreenDiagnoseStep );
        CPPUNIT_TEST ( testCreateFlashDiagnoseStep );

        CPPUNIT_TEST ( testResultEmptyDiagnoseStep );

        CPPUNIT_TEST ( testResultAlarmBoxDiagnoseStepOk );
        CPPUNIT_TEST ( testResultAlarmBoxDiagnoseStepNOk );

        CPPUNIT_TEST ( testResultBarcodeReaderDiagnoseStepOk );
        CPPUNIT_TEST ( testResultBarcodeReaderDiagnoseStepNOk );
        CPPUNIT_TEST ( testResultBarcodeReaderDiagnoseStepNA );

        CPPUNIT_TEST ( testResultPrinterDiagnoseStepOk );
        CPPUNIT_TEST ( testResultPrinterDiagnoseStepNOk );

        CPPUNIT_TEST ( testResultSmartcardReaderDiagnoseStepOk );
        CPPUNIT_TEST ( testResultSmartcardReaderDiagnoseStepNOk );

        CPPUNIT_TEST ( testResultTouchScreenDiagnoseStepOk );
        CPPUNIT_TEST ( testResultTouchScreenDiagnoseStepNOk );

        CPPUNIT_TEST ( testResultWithCustomRemarkStep );
        CPPUNIT_TEST ( testResultWithCheckListStep );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* DIAGNOSE_STEP_TEST_H_ */
