/**
 * @file	LogCryptoBase64.cxx
 * @brief	Implementation of the class that contains the cryptographic methods for logs.
 * @author	Youssef.tourkmani
 * @date	30/10/2012
 */

#include "LogCryptoBase64.hxx"
#include <System/Encoding/Base64Encoder.h>
#include <Configuration/SaesCommonConfiguration-schema.hxx>

using namespace Smartmatic::SAES::Log;
using namespace Smartmatic::System;
using namespace Smartmatic::System::Encoding;
using namespace Smartmatic::SAES::Common::Configuration;

LogCryptoBase64::LogCryptoBase64()
    : Smartmatic::Log::ICryptoLayoutTransformer ( CryptoType ( CryptoType::CONFIGURATION_BASE64 ) )
{
}

std::string LogCryptoBase64::encode ( std::string & line )
{
    std::string result;
    std::stringstream ss;

    SafeBuffer buffer(line);
    Base64Encoder::ConvertToBase64 ( buffer, result );

    ss << result;
    ss << std::endl;
    return ss.str();
}

std::string LogCryptoBase64::decode ( std::string & line )
{
    std::string ss;
    SafeBuffer buffer;

    if ( Base64Encoder::ConvertFromBase64 ( line, buffer ) )
    {
        ss.assign ( ( const char * ) buffer.GetData(), buffer.GetSize() );
        ss.resize ( buffer.GetSize() );
    }

    return ss;
}
