/**
 * @file	LogCryptoGlobal.cxx
 * @brief	Implementation of the mediator that exposes the cryptographic methods for logs.
 * @author	Youssef.tourkmani
 * @date	30/10/2012
 */

#include "LogCryptoGlobal.hxx"
#include <Security/Encryption.hxx>

using namespace Smartmatic::SAES::Log;
using namespace Smartmatic::System;
using namespace Smartmatic::System::Exception;
using namespace Smartmatic::SAES::Security;
using namespace Smartmatic::SAES::Common::Configuration;

LogCryptoGlobal::LogCryptoGlobal()
    : Smartmatic::Log::ICryptoLayoutTransformer ( CryptoType ( CryptoType::CONFIGURATION_GLOBAL ) )
{
}

std::string LogCryptoGlobal::encode ( std::string & line )
{
    std::stringstream ss;

    try
    {
        ss << Encryption::getInstance()->cryptoStringToB64 ( line, Smartmatic::SAES::Common::Configuration::KeyType::CONFIGURATION_INIT_KEY );
        ss << std::endl;
    }
    catch ( CryptoException & ex )
    {

    }

    return ss.str();
}

std::string LogCryptoGlobal::decode ( std::string & line )
{
    std::stringstream ss;

    try
    {
        ss << Encryption::getInstance()->decryptoB64ToString ( line, Smartmatic::SAES::Common::Configuration::KeyType::CONFIGURATION_INIT_KEY );
        ss << std::endl;
    }
    catch ( CryptoException & ex )
    {

    }

    return ss.str();
}
