/**
 * @file	LogPage.h
 * @brief	Declaration of the entity that represent a log page that contains the lines and index associated.
 * @author	Youssef.tourkmani
 * @date	30/10/2012
 */

#ifndef _LOGPAGE_H_
#define _LOGPAGE_H_
#include <vector>
#include <Log/LogLine.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Log
        {
            /**
             * @class	LogPage
             * @brief	Container that retrieves more the information concerning to a log page.
             * @author	Cesar.bonilla
             * @date	4/28/2011
             */

            class LogPage
            {
                public:

                    /**
                     * @fn	LogPage::LogPage()
                     * @brief	Default constructor initializes an instance of the LogPage class.
                     * @author	Cesar.bonilla
                     * @date	4/28/2011
                     */

                    LogPage();

                    /**
                     * @fn	LogPage::LogPage(LogPage & logPage);
                     * @brief	Copy constructor initializes an instance of the LogPage class.
                     * @author	Cesar.bonilla
                     * @date	4/28/2011
                     * @param	logPage	The reference to log page to be copy.
                     */

                    LogPage ( const LogPage & logPage );

                    /**
                     * @fn	LogPage::LogPage( unsigned int pageNumber, const std::vector<LogLine>& vectorPage );
                     * @brief	Constructor initializes an instance of the LogPage class.
                     * @author	Cesar.bonilla
                     * @date	4/28/2011
                     * @param	pageNumber	The page number.
                     * @param	vectorPage	The vector which contains the lines of the page.
                     */

                    LogPage ( unsigned int pageNumber, const std::vector<LogLine>& vectorPage );

                    /**
                     * @fn	unsigned int LogPage::getPageNumber();
                     * @brief	Gets the page number.
                     * @author	Cesar.bonilla
                     * @date	4/28/2011
                     * @return	The page number.
                     */

                    unsigned int getPageNumber() const;

                    /**
                     * @fn	std::vector<LogLine> LogPage::getPage();
                     * @brief	Gets the vector which contains the lines of the page.
                     * @author	Cesar.bonilla
                     * @date	4/28/2011
                     * @return	The page.
                     */

                    std::vector<LogLine> getPage() const;

                    LogPage & operator = ( const LogPage & obj );

                protected:

                private:
                    unsigned int pageNumber;	///< The page number
                    std::vector<LogLine> vectorPage;	///< The vector which contains the lines of the page.
            };
        }
    }
}

#endif // _LOGPAGE_H_
