/**
 * @file	CheckFilesPresence.cxx
 * @brief	check files presence class.
 * @author	Youssef.tourkmani
 * @date	30/10/2012
 */

#include "CheckFilesPresence.hxx"
#include <System/IO/Directory.h>
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::Operation::Initiator;
using namespace Smartmatic::SAES::Runtime::Environment;
using namespace Smartmatic::System::IO;
using namespace Smartmatic::Log;

ISMTTLog * CheckFilesPresence::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Operation.Initiator.CheckingFilePresence", GETTEXT_PACKAGE );

CheckFilesPresence::CheckFilesPresence ( Runtime::Environment::SaesDirectories * directories,
        Smartmatic::SAES::Common::Configuration::BasePathType type )
    : ICheckCondition ( N_ ( "Smartmatic.SAES.Operation.Initiator.CheckFilesPresence.CheckingFilePresence" ) )
{
    this->directories = directories;
    this->type = type;
}

CheckFilesPresence::~CheckFilesPresence()
{
}

TestStatus::Tests CheckFilesPresence::check()
{
    bool success = false;
    std::string electionFile = directories->getElectionFileFullPath ( type );
    std::string deviceParametersFile = directories->getDeviceParametersFileFullPath ( type );
    std::string votingDeviceFile = directories->getVotingDeviceFileFullPath ( type );
    std::string secretKeyFile = directories->getSecretKeyFileFullPath ( type );
    std::string machineKeysFile = directories->getMachineKeysFileFullPath ( type );
    std::string languageFile = directories->getLanguageLocalFileFullPath ( type );
    std::string nationalityFile = directories->getNationalityDefinitionTypeFileFullPath ( type );

    if ( !Directory::getInstance()->FileExists ( electionFile ) )
    {
        logger->Debug ( "ERROR - load file " + electionFile );
    }
    else if ( !Directory::getInstance()->FileExists ( deviceParametersFile ) )
    {
        logger->Debug ( "ERROR - load file " + deviceParametersFile );
    }
    else if ( !Directory::getInstance()->FileExists ( votingDeviceFile ) )
    {
        logger->Debug ( "ERROR - load file " + votingDeviceFile );
    }
    else if ( !Directory::getInstance()->FileExists ( secretKeyFile ) )
    {
        logger->Debug ( "ERROR - load file " + secretKeyFile );
    }
    else if ( !Directory::getInstance()->FileExists ( machineKeysFile ) )
    {
        logger->Debug ( "ERROR - load file " + machineKeysFile );
    }
    else if ( !Directory::getInstance()->FileExists ( languageFile ) )
    {
        logger->Debug ( "ERROR - load file " + languageFile );
    }
    else if ( !Directory::getInstance()->FileExists ( nationalityFile ) )
    {
        logger->Debug ( "ERROR - load file " + nationalityFile );
    }
    else
    {
        success = true;
    }

    std::string line = "CheckingFilePresence result = ";
    logger->Debug ( line.append ( success ? "Success" : "Failed" ) );

    if ( !success )
    {
        logger->Audit ( N_ ( "Smartmatic.SAES.Operation.Initiator.CheckingFilePresenceFailed" ) );
    }

    return ( success ? TestStatus::Passed : TestStatus::Failed );
}
