/**
 * @file	CheckFilesPresence.hxx
 * @brief	check files presence class.
 * @author	Youssef.tourkmani
 * @date	30/10/2012
 */

#ifndef _CHECK_FILES_PRESENCE_H_
#define _CHECK_FILES_PRESENCE_H_

#include "ICheckCondition.hxx"
#include <Runtime/Environment/saes-directories.h>
#include <Log/ISMTTLog.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Operation
        {
            namespace Initiator
            {
                /**
                 * @class	CheckFilesPresence
                 * @brief	Class for check condition files presence.
                 * @author	Yadickson Soto
                 * @date	03-03-2011
                 */
                class CheckFilesPresence: public ICheckCondition
                {
                    public:
                        /**
                         * @fn	CheckFilesPresence::CheckFilesPresence(Smartmatic::SAES::Runtime::Environment::SaesDirectories *directories,
                         * 			Smartmatic::SAES::Common::Configuration::BasePathType type = Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM);
                         * @brief	Class constructor.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         * @param	directories	directories configuration.
                         * @param	type			 	(optional) the type.
                         */
                        CheckFilesPresence ( Smartmatic::SAES::Runtime::Environment::SaesDirectories * directories,
                                             Smartmatic::SAES::Common::Configuration::BasePathType type = Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM );

                        /**
                         * @fn	virtual CheckFilesPresence::~CheckFilesPresence();
                         * @brief	Destructor.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         */
                        virtual ~CheckFilesPresence();

                        /**
                         * @fn	virtual TestStatus::Tests CheckFilesPresence::check ();
                         * @brief	Method for getter status test.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         * @return	identifi of test.
                         */
                        virtual TestStatus::Tests check ();

                    private:
                        Smartmatic::SAES::Runtime::Environment::SaesDirectories * directories; ///< The directories
                        Smartmatic::SAES::Common::Configuration::BasePathType type; ///< The type
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                };
            }
        }
    }
}

#endif // _CHECK_FILES_PRESENCE_H_
