/**
 * @file	CheckFlashPresence.hxx
 * @brief	check flash presence class.
 * @author	Youssef.tourkmani
 * @date	30/10/2012
 */

#ifndef _CHECK_FLASH_PRESENCE_H_
#define _CHECK_FLASH_PRESENCE_H_

#include "ICheckCondition.hxx"
#include <Log/ISMTTLog.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Operation
        {
            namespace Initiator
            {
                /**
                 * @class	CheckFlashPresence
                 * @brief	Class for check condition files presence.
                 * @author	Yadickson Soto
                 * @date	03-03-2011
                 * @see ICheckCondition
                 */
                class CheckFlashPresence: public ICheckCondition
                {
                    public:
                        /**
                         * @fn	CheckFlashPresence::CheckFlashPresence(bool infinity = true);
                         * @brief	Class constructor.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         * @param	infinity	flag infinity check.
                         */
                        explicit CheckFlashPresence ( bool infinity = true );

                        /**
                         * @fn	virtual CheckFlashPresence::~CheckFlashPresence();
                         * @brief	Class destructor.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         */
                        virtual ~CheckFlashPresence();

                        /**
                         * @fn	virtual TestStatus::Tests CheckFlashPresence::check ();
                         * @brief	Method for getter status test.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         * @return	status of test.
                         */
                        virtual TestStatus::Tests check ();

                    private:
                        bool infinity; ///< flag infinity check
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                };
            }
        }
    }
}

#endif // _CHECK_FILES_PRESENCE_H_
