/**
 * @file	CheckFlashStructure.hxx
 * @brief	check flash structure class.
 * @author	Youssef.tourkmani
 * @date	30/10/2012
 */

#ifndef _CHECK_FLASH_STRUCTURE_H_
#define _CHECK_FLASH_STRUCTURE_H_

#include "ICheckCondition.hxx"
#include <Runtime/Environment/saes-directories.h>
#include <Log/ISMTTLog.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Operation
        {
            namespace Initiator
            {
                /**
                 * @class	CheckFlashStructure
                 * @brief	Class for check condition files presence.
                 * @author	Yadickson Soto
                 * @date	03-03-2011
                 */
                class CheckFlashStructure: public ICheckCondition
                {
                    public:
                        /**
                         * @fn	CheckFlashStructure::CheckFlashStructure(Smartmatic::SAES::Runtime::Environment::SaesDirectories & directories,
                         * 			Smartmatic::SAES::Common::Configuration::BasePathType type = Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_FLASH);
                         * @brief	Class constructor.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         * @param	directories	directories configuration.
                         * @param	type			 	type base path.
                         */
                        CheckFlashStructure ( Smartmatic::SAES::Runtime::Environment::SaesDirectories & directories,
                                              Smartmatic::SAES::Common::Configuration::BasePathType type =
                                                  Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_FLASH );

                        /**
                         * @fn	virtual CheckFlashStructure::~CheckFlashStructure();
                         * @brief	Class destructor.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         */
                        virtual ~CheckFlashStructure();

                        /**
                         * @fn	virtual TestStatus::Tests CheckFlashStructure::check ();
                         * @brief	Method for getter status test.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         * @return	status of test.
                         */
                        virtual TestStatus::Tests check ();

                    private:
                        Smartmatic::SAES::Runtime::Environment::SaesDirectories directories; /**< directories configuration*/
                        Smartmatic::SAES::Common::Configuration::BasePathType type; ///< type base path
                        static Smartmatic::Log::ISMTTLog * logger; /**< logger*/
                };
            }
        }
    }
}

#endif // _CHECK_FLASH_STRUCTURE_H_
