/**
 * @file	CheckForUsedMemory.h
 * @brief Implementation of the class that contains the file verifications such as ElectionStatus,
 * IncidentReport ,Statistics and others.
 * @author	Youssef.tourkmani
 * @date	30/10/2012
 */

#ifndef CHECKFORUSEDMEMORY_H_
#define CHECKFORUSEDMEMORY_H_

#include "ICheckCondition.hxx"
#include <Runtime/Environment/saes-directories.h>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Operation
        {
            namespace Initiator
            {
                /**
                 * @class	CheckForUsedMemoryCondition
                 * @brief	Class validator to verify if the following files exists: <tt>ElectionStatus</tt>, <tt>IncidentReport</tt>, <tt>Statistics</tt>
                 * and others.
                 * @author	Youssef.tourkmani
                 * @date	30/10/2012
                 */
                class CheckForUsedMemoryCondition: public ICheckCondition
                {
                    public:

                        /**
                         * @fn	CheckForUsedMemoryCondition::CheckForUsedMemoryCondition( Smartmatic::SAES::Runtime::Environment::SaesDirectories * directories,
                         * 			Smartmatic::SAES::Common::Configuration::BasePathType type = Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM);
                         * @brief	Default constructor initializes an instance of the CheckForUsedMemoryCondition class.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         * @param [in,out] directories The reference to environment context of the directories hierarchy.
                         * @param	type (optional) The type is the selection of the primary hierarchy which contains the file resources.
                         */
                        CheckForUsedMemoryCondition (
                            Smartmatic::SAES::Runtime::Environment::SaesDirectories * directories,
                            Smartmatic::SAES::Common::Configuration::BasePathType type =
                                Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM );

                        /**
                         * @fn	virtual CheckForUsedMemoryCondition::~CheckForUsedMemoryCondition();
                         * @brief	Finalizes the instance of the CheckForUsedMemoryCondition class.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         */
                        virtual ~CheckForUsedMemoryCondition();

                        /**
                         * @fn	TestStatus::Tests CheckForUsedMemoryCondition::check();
                         * @brief	Checks if  at least one the files, described in the environment context, exists.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         * @return	<tt>TestStatus::Passed</tt> if exists at least one the files; otherwise <tt>TestStatus::Failed</tt>.
                         */
                        TestStatus::Tests check();

                    private:
                        Smartmatic::SAES::Runtime::Environment::SaesDirectories * directories; ///< The pointer reference to environment context of the directory hierarchy.
                        Smartmatic::SAES::Common::Configuration::BasePathType type; ///< The base selection of the primary hierarchy.
                        static Smartmatic::Log::ISMTTLog * logger; ///< The reference pointer of a logger instance.
                };
            }
        }
    }
}

#endif /* CHECKFORUSEDMEMORY_H_ */
