/**
 * @file	CheckResourceFiles.cxx
 * @brief	Implementation of the class that contains the verify authenticity  for the directories SaesData, ElectoralImages and it's mirrors.
 * @author	Yadickson Soto
 * @date	31/10/2012
 */

#include "CheckResourceFiles.hxx"
#include <Log/SMTTLogManager.h>
#include <Security/XmlSecResource.hxx>
#include <System/IO/File.h>
#include <Configuration/s-a-e-s-common-conf-manager.h>
#include <list>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::Operation::Initiator;
using namespace Smartmatic::Log;
using namespace Smartmatic::System::IO;
using namespace Smartmatic::SAES::Security;
using namespace Smartmatic::SAES::Common::Configuration;

ISMTTLog * CheckResourceFiles::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Operation.Initiator.CheckResourceFiles", GETTEXT_PACKAGE );

CheckResourceFiles::CheckResourceFiles ( Runtime::Environment::SaesDirectories * directories,
        Smartmatic::SAES::Common::Configuration::BasePathType type )
    : ICheckCondition ( N_ ( "Smartmatic.SAES.Operation.Initiator.CheckResourceFiles.CheckResourceFiles" ) )
{
    this->directories = directories;
    this->type = type;
}

CheckResourceFiles::CheckResourceFiles ( Runtime::Environment::SaesDirectories * directories,
                                         Smartmatic::SAES::Common::Configuration::BasePathType type,
                                         const std::string& message)
    : ICheckCondition ( message )
{
    this->directories = directories;
    this->type = type;
}

CheckResourceFiles::~CheckResourceFiles()
{
}

TestStatus::Tests CheckResourceFiles::check()
{
    bool success = true;

    if ( SAESCommonConfigurationManager::getInstance()->isVerifyExternElements() )
    {
        logger->Debug ( "Check resource files" );

        std::string file = directories->getSignatureResourceFileFullPath ( type );
        success = validate ( file );

        std::string line = "CheckResourceFiles result = ";
        logger->Debug ( line.append ( success ? "Success" : "Failed" ) );

        if ( !success )
        {
            logger->Audit ( N_ ( "Smartmatic.SAES.Operation.Initiator.CheckResourceFiles.ErrorSignedElectoralResources" ) );
        }
    }

    return ( success ? TestStatus::Passed : TestStatus::Failed );
}

bool CheckResourceFiles::validate ( const std::string & file )
{
    bool validate = false;

    try
    {
        logger->Debug("Search file : " + file);

        if (File::getInstance()->canOpenFile(file))
        {
            const std::string signatureFile    = directories->getSignatureResourceFileFullPath(type);
            const std::string directoryToCheck = directories->getLocalSaesDataFolderFullPath(type);

            logger->Debug ( "Validate resources in path : " + directoryToCheck );
            validate = XmlSecResource::getInstance()->validateResource ( directoryToCheck, signatureFile,
                       Smartmatic::SAES::Security::Encryption::EXTERNAL_FILE,
                       Smartmatic::SAES::Common::Configuration::KeyType::CONFIGURATION_SECRET_KEY );

            logger->Debug ( "Validate electoral resources " + std::string ( validate ? "success" : "fail" ) );
        }
        else
        {
            logger->Debug ( "File " + file + " not found." );
        }
    }
    catch ( ... )
    {

    }

    return validate;
}
