/**
 * @file   CheckSaesLocalResourceFiles.cxx
 * @brief  Implementation of CheckSaesLocalResourceFiles class.
 * @author manuel.arguelles
 * @date   Mar 23, 2018
 */

#include "CheckSaesLocalResourceFiles.hxx"
#include <Configuration/s-a-e-s-common-conf-manager.h>
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Runtime/Environment/saes-directories.h>
#include <Security/XmlSecResource.hxx>
#include <string>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Common::Configuration;
using namespace Smartmatic::SAES::Common;
using namespace Smartmatic::SAES::Operation::Initiator;
using namespace Smartmatic::SAES::Runtime::Environment;
using namespace Smartmatic::SAES::Security;

ISMTTLog* CheckSaesLocalResourceFiles::m_logger = SMTTLogManager::GetLogger(
    "Smartmatic.SAES.Operation.Initiator.CheckSaesLocalResourceFiles",
    GETTEXT_PACKAGE);

CheckSaesLocalResourceFiles::CheckSaesLocalResourceFiles(Configuration::BasePathType type)
    : ICheckCondition(N_("Smartmatic.SAES.Operation.Initiator.CheckSAESLocalResourceFiles.CheckSAESLocalResourceFiles"))
{
    m_type = type;
}

CheckSaesLocalResourceFiles::~CheckSaesLocalResourceFiles()
{
}

TestStatus::Tests CheckSaesLocalResourceFiles::check()
{
    bool success = true;

    if (SAESCommonConfigurationManager::getInstance()->getSecurityConfiguration().getVerifySAESLocalFolder())
    {
        SaesDirectories directories;
        std::string path = directories.getLocalBasePath(m_type);
        std::string file = directories.getSignatureSaesLocalFileFullPath(m_type);

        m_logger->Debug("Check SAESLocal resource files in " + m_type);

        try
        {
            success = XmlSecResource::getInstance()->validateResource(
                path,
                file,
                Encryption::INSTALL_FILE,
                KeyType::CONFIGURATION_SECURITY_KEY);
        }
        catch (...)
        {
            success = false;
            m_logger->Audit(N_("Smartmatic.SAES.Operation.Initiator.CheckSAESLocalResourceFiles.ErrorCheckSAESLocalFolder"));
        }
    }

    return (success ? TestStatus::Passed : TestStatus::Failed);
}
