/**
 * @file	ICheckCondition.hxx
 * @brief	Declaration of the interface that groups the checking tasks such as CheckFlashPresence, CheckFilesPresence, CheckDirectoryStructure,
 * CheckForUsedMemoryCondition and others.
 * @author	Youssef.tourkmani
 * @date	30/10/2012
 */

#ifndef _ICHECK_CONDITION_H_
#define _ICHECK_CONDITION_H_

#include <string>
#include "InitializationStatus.hxx"

namespace Smartmatic
{
    namespace SAES
    {
        namespace Operation
        {
            namespace Initiator
            {
                /**
                 * @class	ICheckCondition
                 * @brief	Abstract class for check condition.
                 * @author	Yadickson Soto
                 * @date	03-03-2011
                 */
                class ICheckCondition
                {
                    public:
                        /**
                         * @fn	ICheckCondition::ICheckCondition ( std::string msg );
                         * @brief	Default constructor initializes an instance of the ICheckCondition class.
                         * @author	Yadickson Soto
                         * @date	15/11/2012
                         * @param	msg		The message associated to the task.
                         */
                        explicit ICheckCondition ( const std::string& msg );

                        /**
                         * @fn	virtual ICheckCondition::~ICheckCondition();
                         * @brief	Finalizes the instance of the ICheckCondition class.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         */
                        virtual ~ICheckCondition();
                        /**
                         * @fn	std::string ICheckCondition::getMessage();
                         * @brief	Gets the message associated to the task.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         * @return	Copy of the message associated to the task.
                         */
                        std::string getMessage();
                        /**
                         * @fn	virtual TestStatus::Tests ICheckCondition::check () = 0;
                         * @brief	Task checking. This method is implemented by childs in the hirearchy.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         * @return	Status response of the checking tasks.
                         */
                        virtual TestStatus::Tests check () = 0;

                    private:

                        std::string message; ///< String value associated to the task.
                };
            }
        }
    }
}

#endif // _ICHECK_CONDITION_H_
