/**
 * @file	InitializationStatus.hxx
 * @brief	initialization status class.
 * @author	Youssef.tourkmani
 * @date	30/10/2012
 */

#ifndef _INITIALIZATION_RESULT_H_
#define _INITIALIZATION_RESULT_H_

#include <string>
#include <map>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Operation
        {
            namespace Initiator
            {
                namespace TestStatus
                {
                    /**
                     * @enum	Tests
                     * @brief	Values that represent Tests.
                     */
                    enum Tests
                    {
                        Passed,
                        Failed,
                        NotTested,
                        BlockDevice
                    };
                }

                /**
                 * @class	InitializationStatus
                 * @brief	Initialization status.
                 * @author	Cesar.bonilla
                 * @date	4/28/2011
                 */

                class InitializationStatus
                {
                    public:

                        /**
                         * @fn	InitializationStatus::InitializationStatus();
                         * @brief	Default constructor.
                         * @author	Cesar.bonilla
                         * @date	4/28/2011
                         */

                        InitializationStatus();

                        /**
                         * @fn  InitializationStatus::InitializationStatus();
                         * @brief  Copy constructor.
                         * @author eduardo.fernandez
                         * @date   21/01/2019
                         * @param  initializationStatus
                         */
                        InitializationStatus(const InitializationStatus& initializationStatus);

                        /**
                         * @fn	virtual InitializationStatus::~InitializationStatus();
                         * @brief	Finaliser.
                         * @author	Cesar.bonilla
                         * @date	4/28/2011
                         */

                        virtual ~InitializationStatus();

                        /**
                         * @fn	TestStatus::Tests getStatus();
                         * @brief	Gets the status.
                         * @author	Yadickson Soto
                         * @date	16/11/2012
                         * @return	sattus
                         */

                        TestStatus::Tests getStatus();

                        /**
                         * @fn	std::string InitializationStatus::getMessage();
                         * @brief	Gets the message.
                         * @author	Cesar.bonilla
                         * @date	4/28/2011
                         * @return	The message.
                         */

                        std::string getMessage();

                        /**
                         * @fn	void setStatus ( TestStatus::Tests status );
                         * @brief	Sets the status.
                         * @author	Yadickson Soto
                         * @date	16/11/2012
                         * @param	status	the status.
                         */

                        void setStatus ( TestStatus::Tests status );

                        /**
                         * @fn	void InitializationStatus::setMessage(std::string msg);
                         * @brief	Sets a message.
                         * @author	Cesar.bonilla
                         * @date	4/28/2011
                         * @param	msg	The message.
                         */

                        void setMessage ( std::string msg );

                        /**
                         * @fn	void InitializationStatus::setFooterMessage(std::string msg);
                         * @brief	Sets a footer message.
                         * @author	Gabriel.Jaimes
                         * @date	7/28/2022
                         * @param	msg	The message.
                         */

                        void setFooterMessage ( std::string msg );

                        /**
                         * @fn	std::string InitializationStatus::getFooterMessage();
                         * @brief	Gets the footer message.
                         * @author	Gabriel.Jaimes
                         * @date	7/28/2022
                         * @return	The message.
                         */

                        std::string getFooterMessage();

                        /**
                         * @fn	InitializationStatus operator = ( const InitializationStatus & obj );
                         * @brief	Operator equal
                         * @author	yadickson Soto
                         * @date	19/06/2013
                         * @param	obj	Object
                         * @return	return object
                         */

                        InitializationStatus & operator = ( const InitializationStatus & obj );

                    private:

                        TestStatus::Tests status; ///< The status
                        std::string message;///< The message
                        std::string footerMessage;///< The footer message
                };
            }
        }
    }
}


#endif // _INITIALIZATION_RESULT_H_
