/**
 * @file	DeviceMonitorFactory.cxx
 * @brief	Implementation of the monitor of devices factory
 * @author	Yadickson Soto
 * @date	28/05/2014
 */

#include "DeviceMonitorFactory.hxx"
#include <Configuration/DeviceTypeMonitorConfigurationManager.hxx>
#include <Operation/Monitor/UdevMonitor.hxx>
#include <Operation/Monitor/SimulatorMonitor.hxx>

using namespace Smartmatic::SAES::Common::Operation::Monitor;
using namespace Smartmatic::SAES::Common::Configuration;

DeviceMonitorInterface * DeviceMonitorFactory::getMonitor()
{
    if ( DeviceTypeMonitorConfigurationManager::getInstance()->simulationEnabled() )
    {
        return getSimulatorMonitor();
    }
    else
    {
        return getUdevMonitor();
    }
}

DeviceMonitorInterface * DeviceMonitorFactory::getUdevMonitor()
{
    return new UdevMonitor();
}

DeviceMonitorInterface * DeviceMonitorFactory::getSimulatorMonitor()
{
    return new SimulatorMonitor ( DeviceTypeMonitorConfigurationManager::getInstance()->getSimulatorFilePath() );
}
