/**
 * @file MonitorInfo.cxx
 * @brief Body for the MonitorInfo class to save action and properties.
 * @date 11/12/2012
 * @author Yadickson Soto
 */

#include "MonitorInfo.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

using namespace Smartmatic::SAES::Common::Operation::Monitor;
using namespace Smartmatic::Log;

ISMTTLog * MonitorInfo::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Common.Operation.Monitor.MonitorInfo", GETTEXT_PACKAGE );

MonitorInfo::MonitorInfo ( bool action )
    : action ( action )
{

}

MonitorInfo::~MonitorInfo()
{

}

void MonitorInfo::push ( const std::string & name, const std::string & value )
{
    if ( !name.empty() && !value.empty() )
    {
        infoMap [ name ] = value;
    }
}

const std::string MonitorInfo::getValue ( const std::string & name ) const
{
    if ( infoMap.find ( name ) == infoMap.end() )
    {
        return "";
    }

    return infoMap.at ( name );
}

bool MonitorInfo::isAdded()
{
    return action;
}

void MonitorInfo::viewInfo()
{
    std::map < std::string, std::string >::iterator it;

    logger->Debug ( " ------------ " );

    for ( it = infoMap.begin();
            it != infoMap.end();
            ++it )
    {
        logger->Debug ( ( *it ).first + " : " + ( *it ).second );
    }
}
