/**
 * @file SimulatorMonitor.hxx
 * @brief Header for the SimulatorMonitor class which interacts with the file interface to make events for plug and unplug devices.
 * @date 04/06/2015
 * @author Yadickson Soto
 */

#ifndef SIMULATOR_MONITOR_HXX_
#define SIMULATOR_MONITOR_HXX_

#include <Operation/Monitor/DeviceMonitorInterface.hxx>
#include <System/SafeBuffer.h>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Common
        {
            namespace Operation
            {
                namespace Monitor
                {
                    /**
                     * @class	SimulatorMonitor
                     * @brief   SimulatorMonitor class which interacts with the file interface to make events for plug and unplug devices.
                     * @author	Yadickson Soto
                     * @date	04/06/2015
                     */
                    class SimulatorMonitor : public DeviceMonitorInterface
                    {
                        public:

                            /**
                             * @fn SimulatorMonitor ();
                             * @brief Class constructor
                             * @date 04/06/2015
                             * @author Yadickson Soto
                             * @param file the file path to get the device
                             */
                            explicit SimulatorMonitor ( const std::string & file );

                            /**
                             * @brief Class destructor
                             * @date 04/06/2015
                             * @author Yadickson Soto
                             */
                            virtual ~SimulatorMonitor();

                            /**
                             * @fn virtual bool initialize();
                             * @brief Initializes the simulator establishing the context.
                             * @date 04/06/2015
                             * @author Yadickson Soto
                             */
                            virtual bool initialize();

                            /**
                             * @fn virtual void dispose();
                             * @brief Dispose the simulator context.
                             * @date 04/06/2015
                             * @author Yadickson Soto
                             */
                            virtual void dispose();

                            /**
                             * @fn virtual Smartmatic::System::SafeList < MonitorInfo * > searchDevices();
                             * @brief Method to search all devices by subsystem and device type
                             * @date 04/06/2015
                             * @author Yadickson Soto
                             * @return list found devices
                             */
                            virtual Smartmatic::System::SafeList < MonitorInfo * > searchDevices ();

                            /**
                             * @fn virtual Smartmatic::System::SafeList < MonitorInfo * > searchDevices();
                             * @brief Method to search for all devices
                             * @date 04/06/2015
                             * @author Yadickson Soto
                             * @return list event devices
                             */
                            virtual Smartmatic::System::SafeList < MonitorInfo * > eventDevices();

                            /**
                             * @fn void setProperty ( const std::string & buffer, MonitorInfo * info );
                             * @brief Set property to info
                             * @date 04/06/2015
                             * @author Yadickson Soto
                             * @param buffer property parameter separated by ":"
                             * @param info info to set parameter name:value
                             */
                            void setProperty ( const std::string & buffer, MonitorInfo * info );

                        private:

                            std::string file; ///< The file path to gets the event devices
                            static Smartmatic::Log::ISMTTLog * logger;  ///< logger
                    };
                }
            }
        }
    }
}

#endif /* SIMULATOR_MONITOR_HXX_ */
