/**
 * @file UdevMonitor.hxx
 * @brief Header for the UdevMonitor class which interacts with the UDEV daemon.
 * @date 11/12/2012
 * @author Yadickson Soto
 */

#ifndef UDEV_MONITOR_HXX_
#define UDEV_MONITOR_HXX_

#include <string>
#include <libudev.h>
#include <Operation/Monitor/DeviceMonitorInterface.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Common
        {
            namespace Operation
            {
                namespace Monitor
                {
                    /**
                     * @class	UdevMonitor
                     * @brief   UdevMonitor class which interacts with the UDEV daemon.
                     * @author	Yadickson Soto
                     * @date	21/05/2015
                     */
                    class UdevMonitor : public DeviceMonitorInterface
                    {
                        public:

                            /**
                             * @brief Class constructor
                             * @date 21/05/2015
                             * @author Yadickson Soto
                             */
                            UdevMonitor ();

                            /**
                             * @brief Class destructor
                             * @date 21/05/2015
                             * @author Yadickson Soto
                             */
                            virtual ~UdevMonitor();

                            /**
                             * @fn virtual bool initialize();
                             * @brief Initializes the UDEV daemon establishing the context.
                             * @date 21/05/2015
                             * @author Yadickson Soto
                             */
                            virtual bool initialize();

                            /**
                             * @fn virtual void dispose();
                             * @brief Dispose the UDEV daemon context.
                             * @date 21/05/2015
                             * @author Yadickson Soto
                             */
                            virtual void dispose();

                            /**
                             * @fn virtual Smartmatic::System::SafeList < MonitorInfo * > searchDevices();
                             * @brief Method to search all devices by subsystem and device type
                             * @date 21/05/2015
                             * @author Yadickson Soto
                             * @return list found devices
                             */
                            virtual Smartmatic::System::SafeList < MonitorInfo * > searchDevices ();

                            /**
                             * @fn virtual Smartmatic::System::SafeList < MonitorInfo * > searchDevices();
                             * @brief Method to search for all devices
                             * @date 21/05/2015
                             * @author Yadickson Soto
                             * @return list event devices
                             */
                            virtual Smartmatic::System::SafeList < MonitorInfo * > eventDevices();

                        protected:

                            /**
                             * @fn virtual void addMonitorInfo ( struct udev_device *dev, Smartmatic::System::SafeList < MonitorInfo * > & list );
                             * @brief Method to make Monitor info from udev device
                             * @date 21/05/2015
                             * @author Yadickson Soto
                             * @param dev udev device
                             * @param list to fill
                             */
                            virtual void addMonitorInfo ( struct udev_device * dev, Smartmatic::System::SafeList < MonitorInfo * > & list );

                        private:

                            struct udev * context; ///< udev context
                            struct udev_monitor * monitor; ///< udev monitor
                            int handle; ///< udev handle file descriptor for the monitor
                            static Smartmatic::Log::ISMTTLog * logger;  ///< logger
                    };
                }
            }
        }
    }
}

#endif /* UDEV_MONITOR_HXX_ */
