/**
 * @file	PrintDocumentResult.cpp
 * @brief	Implements the print document result class.
 * @author	Youssef.tourkmani
 * @date	30/10/2012
 */

#include "PrintDocumentResult.h"

using namespace Smartmatic::SAES::Printing;

PrintDocumentResult::PrintDocumentResult()
    : wasSuccess(false)
    , printingResult(PrintDocumentResult::PRINTING_NONE)
    , printerStatusNotifierResult(PrinterStatusNotifier::PSTATE_NONE)
{
}

PrintDocumentResult::PrintDocumentResult ( const PrintDocumentResult & object )
    : wasSuccess(object.wasSuccess)
    , printerStatusDetail(object.printerStatusDetail)
    , printingResult(object.printingResult)
    , printerStatusNotifierResult(object.printerStatusNotifierResult)
{
}

PrintDocumentResult::~PrintDocumentResult()
{

}

PrintDocumentResult::PrintDocumentResult ( bool success, const std::string & printerStatus, PrintDocumentResult::PrintingResultEnum printResult, PrinterStatusNotifier::PhysicalStateEnumType printerStatusNotifier )
    : wasSuccess(success)
    , printerStatusDetail(printerStatus)
    , printingResult(printResult)
    , printerStatusNotifierResult(printerStatusNotifier)
{
}

void PrintDocumentResult::setResult ( bool wasOk, const std::string & printerStatus, PrintDocumentResult::PrintingResultEnum printResult, PrinterStatusNotifier::PhysicalStateEnumType printerStatusNotifier )
{
    this->wasSuccess = wasOk;
    this->printerStatusDetail = printerStatus;
    this->printingResult = printResult;
    this->printerStatusNotifierResult = printerStatusNotifier;
}

bool PrintDocumentResult::getSuccess()
{
    return wasSuccess;
}

std::string PrintDocumentResult::getPrinterStatusDetail()
{
    return printerStatusDetail;
}

PrintDocumentResult::PrintingResultEnumType PrintDocumentResult::getPrintingResult()
{
    return printingResult;
}

PrinterStatusNotifier::PhysicalStateEnumType PrintDocumentResult::getPrinterStatusNotifierResult()
{
    return printerStatusNotifierResult;
}

PrintDocumentResult & PrintDocumentResult::operator= ( const PrintDocumentResult & obj )
{
    this->wasSuccess = obj.wasSuccess;
    this->printerStatusDetail.assign(obj.printerStatusDetail);
    this->printingResult = obj.printingResult;
    this->printerStatusNotifierResult = obj.printerStatusNotifierResult;
    return *this;  // Return a reference to myself.
}
