/**
 * @file	DirectoryManager.hxx
 * @brief	directory manager class.
 * @author	Youssef.tourkmani
 * @date	30/10/2012
 */


#ifndef __DIRECTORY_MANAGER_H__
#define __DIRECTORY_MANAGER_H__

#include "saes-directories.h"
#include <string>
#include <Log/ISMTTLog.h>
#include <Security/Encryption.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Runtime
        {
            namespace Environment
            {
                /**
                 * @class	DirectoryManager
                 * @brief	Class manager directory and files to backup
                 * @since 15-03-2011.
                 * @author	Yadickson Soto &lt;yadickson.soto@smartmatic.com&gt;
                 * @date	30/10/2012
                 */
                class DirectoryManager
                {
                    public:
                        /**
                         * @fn	DirectoryManager::DirectoryManager( Smartmatic::SAES::Runtime::Environment::SaesDirectories & directories );
                         * @brief	Class constructor.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         * @param	directories	class directories.
                         */
                        explicit DirectoryManager ( Smartmatic::SAES::Runtime::Environment::SaesDirectories & directories );
                        /**
                         * @fn	virtual DirectoryManager::~DirectoryManager();
                         * @brief	Class destructor.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         */
                        virtual ~DirectoryManager();
                        /**
                         * @fn	bool DirectoryManager::backup (bool copyDomToFlash);
                         * @brief	method for backup directory.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         * @param	copyDomToFlash	true to copy dom to flash.
                         * @return	true if success.
                         */
                        bool backup ( bool copyDomToFlash );
                        /**
                         * @fn	void DirectoryManager::createMachineIdFile(std::string machineId, bool force = false);
                         * @brief	method for create backup file.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         * @param	machineId	Identifier for the machine.
                         * @param	force		 	(optional) the force.
                         */
                        void createMachineIdFile ( std::string machineId, bool force = false );
                        /**
                         * @fn	bool DirectoryManager::validateMachineIdFile( const std::string& machineId );
                         * @brief	method for validate backup file.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         * @param	machineId	Identifier for the machine.
                         * @return	true if success.
                         */
                        bool validateMachineIdFile ( const std::string& machineId );
                        /**
                         * @fn	static bool DirectoryManager::copyDir ( std::string origDir, std::string destDir,
                         * 			bool removeDestDir = true );
                         * @brief	method for copy directory.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         * @param	origDir			 	orig directory name.
                         * @param	destDir			 	dest directory name.
                         * @param	removeDestDir	remove destine dir.
                         * @return	true if success.
                         */
                        static bool copyDir ( std::string origDir, std::string destDir, bool removeDestDir = true );
                        /**
                         * @fn	bool DirectoryManager::validateMachineIdFileDOMFlash();
                         * @brief	method for validate machineId in DOM and Flash.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         * @return	true if success.
                         */
                        bool validateMachineIdFileDOMFlash();

                    private:
                        static Smartmatic::Log::ISMTTLog * logger; /**< logger*/
                        Smartmatic::SAES::Runtime::Environment::SaesDirectories directories; /**< saes directories*/

                };
            }
        }
    }
}

#endif /*__DIRECTORY_MANAGER_H__*/
