/**
 * @file	SaesInstallDirectories.hxx
 * @brief	saes install directories class.
 * @author	Youssef.tourkmani
 * @date	30/10/2012
 */


#ifndef SAESINSTALLDIRECTORIES_HXX_
#define SAESINSTALLDIRECTORIES_HXX_

#include <Runtime/Environment/saes-directories.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Runtime
        {
            namespace Environment
            {
                /**
                 * @class	SaesInstallDirectories
                 * @brief	Saes install directories.
                 * @author	Youssef.tourkmani
                 * @date	30/10/2012
                 */
                class SaesInstallDirectories : public SaesDirectories
                {
                    public:

                        /**
                         * @fn	SaesInstallDirectories::SaesInstallDirectories();
                         * @brief	Default constructor.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         */
                        SaesInstallDirectories();
                        /**
                         * @fn	virtual SaesInstallDirectories::~SaesInstallDirectories();
                         * @brief	Destructor.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         */
                        virtual ~SaesInstallDirectories();

                        /**
                         * @fn	virtual void SaesInstallDirectories::setWorkingPath( std::string workingPath );
                         * @brief	Sets working path.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         * @param	workingPath	Full pathname of the working file.
                         */
                        virtual void setWorkingPath ( std::string workingPath );
                        /**
                         * @fn	virtual void SaesInstallDirectories::setProgramUnitName( std::string programUnitName );
                         * @brief	Sets program unit name.
                         * @author	Youssef.tourkmani
                         * @date	30/10/2012
                         * @param	programUnitName	Name of the program unit.
                         */
                        virtual void setProgramUnitName ( std::string programUnitName );

                        /**
                         * @fn	virtual std::string SaesDirectories::getElectoralImagesFullFolderPath(Smartmatic::SAES::Common::Configuration::BasePathType type = Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM);
                         * @brief	Gets the full absolute path to the electoral images.
                         * @author	Yadickson Soto
                         * @date	15/04/2014
                         * @param	type	Type of BasePath to use for constructing the full path
                         * @return	The electoral images full folder path.
                         */

                        virtual std::string getElectoralImagesFullFolderPath ( Smartmatic::SAES::Common::Configuration::BasePathType type =
                                    Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM );

                    protected:
                        std::string workingPath;	///< Full pathname of the working file
                        std::string programUnitName;	///< Name of the program unit
                };
            }
        }
    }
}

#endif /* SAESINSTALLDIRECTORIES_HXX_ */
