/**
 * @file SaesProgramUnitDirectories.hxx
 * @brief Header class saes directories for up structure
 * @date 14/11/2011
 * @author Yadickson Soto
 */

#ifndef SAESPROGRAMUNITDIRECTORIES_HXX_
#define SAESPROGRAMUNITDIRECTORIES_HXX_

#include <Runtime/Environment/SaesInstallDirectories.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Runtime
        {
            namespace Environment
            {
                /**
                 * @class	SaesProgramUnitDirectories
                 * @brief	Class saes directories for up structure.
                 * @author	Yadickson Soto
                 * @see SaesInstallDirectories
                 * @date	14/11/2011
                 */
                class SaesProgramUnitDirectories : public SaesInstallDirectories
                {
                    public:
                        /**
                         * @fn	SaesProgramUnitDirectories::SaesProgramUnitDirectories();
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	14/11/2011
                         */
                        SaesProgramUnitDirectories();

                        /**
                         * @fn	virtual SaesProgramUnitDirectories::~SaesProgramUnitDirectories();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	14/11/2011
                         */
                        virtual ~SaesProgramUnitDirectories();

                        /**
                         * @fn	virtual std::string SaesProgramUnitDirectories::getWorkingDirectoryFolderName();
                         * @brief	Method getter working directory folder name.
                         * @author	Yadickson Soto
                         * @date	14/11/2011
                         * @return	working directory folder name.
                         */
                        virtual std::string getWorkingDirectoryFolderName();

                        /**
                         * @fn	virtual std::string SaesProgramUnitDirectories::getElectionFileFullPath( Smartmatic::SAES::Common::Configuration::BasePathType type = Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM );
                         * @brief	Method getter election file full path.
                         * @author	Yadickson Soto
                         * @date	14/11/2011
                         * @param	type	base path type.
                         * @return	election file full path.
                         */
                        virtual std::string getElectionFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type =
                                    Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM );

                        /**
                         * @fn	virtual std::string SaesDirectories::getDeviceParametersFileFullPath(Smartmatic::SAES::Common::Configuration::BasePathType type = Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM);
                         * @brief	Gets the device parameters file full path.
                         * @author	angel.ramirez
                         * @date	05/07/2022
                         * @param	type	The type.
                         * @return	The device parameters file full path.
                         */
                        virtual std::string
                        getDeviceParametersFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type =
                            Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM );

                    private:

                        /**
                         * @fn	std::string SaesProgramUnitDirectories::getProgramUnitNamePath();
                         * @brief	Method getter program unit name path.
                         * @author	Yadickson Soto
                         * @date	14/11/2011
                         * @return	program unit name path.
                         */
                        std::string getProgramUnitNamePath();

                        /**
                         * @fn	std::string SaesProgramUnitDirectories::getProgramUnitPath( Smartmatic::SAES::Common::Configuration::BasePathType type = Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM );
                         * @brief	Method getter program unit path.
                         * @author	Yadickson Soto
                         * @date	14/11/2011
                         * @param	type	base path type.
                         * @return	program unit path.
                         */
                        std::string getProgramUnitPath ( Smartmatic::SAES::Common::Configuration::BasePathType type =
                                                             Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM );
                };
            }
        }
    }
}
#endif /* SAESPROGRAMUNITDIRECTORIES_HXX_ */
