/**
 * @file	SaesTempValidatorDirectories.cxx
 * @brief	saes temporary validator directories.
 * @author	Yadickson Soto
 * @date	12/11/2012
 */

#include "SaesTempValidatorDirectories.hxx"
#include <System/IO/Path.h>

using namespace Smartmatic::SAES::Runtime::Environment;
using namespace Smartmatic::System::IO;

SaesTempValidatorDirectories::SaesTempValidatorDirectories ( const std::string& pathresult )
    : SaesDirectories()
    , pathresult(pathresult)
{
}

SaesTempValidatorDirectories::~SaesTempValidatorDirectories()
{
}

std::string SaesTempValidatorDirectories::getDevicePath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return "/tmp";
}

std::string SaesTempValidatorDirectories::getDocsFolderFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getResultFolderWorking ( type ), Path::Combine ( foldername, DocsFolder ) );
}

std::string SaesTempValidatorDirectories::getEmlFolderFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getResultFolderWorking ( type ), Path::Combine ( foldername, EmlFolder ) );
}

std::string SaesTempValidatorDirectories::getResultFolderWorking ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getDevicePath ( type ), pathresult );
}

std::string SaesTempValidatorDirectories::getResultFolderFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( SaesDirectories::getDevicePath ( type ), pathresult );
}

void SaesTempValidatorDirectories::setFolderCenter ( const std::string& foldername )
{
    this->foldername = foldername;
}

std::string SaesTempValidatorDirectories::getEmlFilesFolderFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( SaesDirectories::getDevicePath ( type ), EmlFilesFolder ) ;
}
