/**
 * @file	SaesTempValidatorDirectories.hxx
 * @brief	saes temporary validator directories.
 * @author	Yadickson Soto
 * @date	12/11/2012
 */

#ifndef SAESTEMPVALIDATORDIRECTORIES_HXX_
#define SAESTEMPVALIDATORDIRECTORIES_HXX_

#include <Runtime/Environment/saes-directories.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Runtime
        {
            namespace Environment
            {
                /**
                 * @class	SaesTempValidatorDirectories
                 * @brief	Saes temporary validator directories.
                 * @author	Yadickson Soto
                 * @date	12/11/2012
                 */
                class SaesTempValidatorDirectories : public SaesDirectories
                {
                    public:

                        /**
                         * @fn	SaesTempValidatorDirectories::SaesTempValidatorDirectories( const std::string& pathresult );
                         * @brief	Default constructor.
                         * @author	Yadickson Soto
                         * @date	12/11/2012
                         * @param 	pathresult path result codi, pv and transmission packages
                         */
                        explicit SaesTempValidatorDirectories ( const std::string& pathresult );
                        /**
                         * @fn	virtual SaesTempValidatorDirectories::~SaesTempValidatorDirectories();
                         * @brief	Destructor.
                         * @author	Yadickson Soto
                         * @date	12/11/2012
                         */
                        virtual ~SaesTempValidatorDirectories();

                        /**
                         * @fn	virtual std::string SaesTempValidatorDirectories::getDevicePath ( Smartmatic::SAES::Common::Configuration::BasePathType type = Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM );
                         * @brief	Gets a base path.
                         * @author	Yadickson Soto
                         * @date	12/11/2012
                         * @param	type	The type.
                         * @return	The base path.
                         */

                        virtual std::string getDevicePath ( Smartmatic::SAES::Common::Configuration::BasePathType type =
                                                                Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM );
                        /**
                         * @fn	std::string getDocsFolderFullPath(Smartmatic::SAES::Common::Configuration::BasePathType type = Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM);
                         * @brief	Gets the documents folder full path.
                         * @author	Cesar.bonilla
                         * @date	4/28/2011
                         * @param	type	The type.
                         * @return	The documents folder full path.
                         */

                        virtual std::string getDocsFolderFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type =
                                    Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM );

                        /**
                         * @brief	method getter codi folder.
                         * @author	Youssef.tourkmani
                         * @date	10/05/2012
                         * @param	type	The type.
                         * @return	eml folder full path.
                         */
                        virtual std::string getEmlFolderFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type =
                                    Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM );
                        /**
                         * @brief	Method getter codi files folder full path.
                         * @author	Yadickson Soto
                         * @date	14/02/2012
                         * @param	type	base path type.
                         * @return	eml files folder full path.
                         */
                        virtual std::string getEmlFilesFolderFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type =
                                    Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM );

                        void setFolderCenter ( const std::string& foldername );

                        std::string getResultFolderWorking ( Smartmatic::SAES::Common::Configuration::BasePathType type =
                                Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM );

                        std::string getResultFolderFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type =
                                Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM );

                    private:

                        std::string pathresult; ///< path result
                        std::string foldername; ///< folder name
                };
            }
        }
    }
}

#endif /* SAESTEMPVALIDATORDIRECTORIES_HXX_ */
