/**
 * @file XmlFileSignature.hxx
 * @brief Header class for XML files signatures.
 * @author	Eduardo Fernández
 * @date	04/12/2018
 */

#ifndef XML_FILE_SIGNATURE_HXX
#define XML_FILE_SIGNATURE_HXX

#include <System/SafeBuffer.h>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Security
        {
            /**
             * @class	XmlFileSignature
             * @brief	Class for XML files signatures.
             * @author	Eduardo Fernández
             * @date	04/12/2018
             */
            class XmlFileSignature
            {
                public:

                    /**
                     * @fn XmlFileSignature();
                     * @brief Class constructor.
                     * @author Eduardo Fernández
                     * @date   04/12/2018
                     */
                    XmlFileSignature();

                    /**
                     * @fn	~XmlFileSignature();
                     * @brief	Class destructor.
                     * @author	Eduardo Fernández
                     * @date	04/12/2018
                     */
                    ~XmlFileSignature();

                public:

                    /**
                     * @fn XmlFileSignature();
                     * @brief Class constructor.
                     * @author Eduardo Fernández
                     * @date   04/12/2018
                     * @param  xmlFileBuffer Buffer of the file containing the signature.
                     * @param  mustBeValidated Whether the file's signature must be validated.
                     */
                    void validateSignatureCertificate(const System::SafeBuffer& xmlFileBuffer, const bool mustBeValidated);

                private:

                    static Smartmatic::Log::ISMTTLog *m_logger;
            };
        }
    }
}

#endif /* XML_FILE_SIGNATURE_HXX */
