#ifndef TEST_JAVA_CARD_OPERATIONS_TEST
#define TEST_JAVA_CARD_OPERATIONS_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Card/JavaCardOperations.hxx>
#include <System/Utils/StringUtils.hxx>
#include "MockConnectionBehavior.hxx"
#include "StoreMockConnectionBehavior.hxx"

class JavaCardOperationsTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::SAES::Card::JavaCardOperations JavaCardOperations;
        typedef Smartmatic::System::SafeBuffer SafeBuffer;
        typedef Smartmatic::System::Utils::StringUtils StringUtils;

    public:

        JavaCardOperationsTest ()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testVerifyGlobalPIN()
        {
            MockConnectionBehavior mock;
            JavaCardOperations commands ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockConnectionBehavior, sendCommandWithResponse, ext ) sendCommandWithResponse_mock ( &mock );

            unsigned char arrayFail1[] = { 0x00, 0x90, 0x00 };
            unsigned char arrayFail2[] = { 0x01, 0x91, 0x00 };
            unsigned char arrayFail3[] = { 0x01, 0x90, 0x01 };
            unsigned char arraySuccess[] = { 0x01, 0x90, 0x00 };

            sendCommandWithResponse_mock
            .expects ( MOCKPP_NS::exactly ( 5 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer () ),
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer ( arrayFail1, sizeof ( arrayFail1 ) ) ),
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer ( arrayFail2, sizeof ( arrayFail2 ) ) ),
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer ( arrayFail3, sizeof ( arrayFail3 ) ) ),
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer ( arraySuccess, sizeof ( arraySuccess ) ) ) ) );

            CPPUNIT_ASSERT ( false == commands.verifyGlobalPIN ( SafeBuffer ( "1" ) ) );
            CPPUNIT_ASSERT ( false == commands.verifyGlobalPIN ( SafeBuffer ( "2" ) ) );
            CPPUNIT_ASSERT ( false == commands.verifyGlobalPIN ( SafeBuffer ( "3" ) ) );
            CPPUNIT_ASSERT ( false == commands.verifyGlobalPIN ( SafeBuffer ( "4" ) ) );
            CPPUNIT_ASSERT ( true == commands.verifyGlobalPIN ( SafeBuffer ( "5" ) ) );

            mock.verify();
        }

        void testVerifyPasswordPIN()
        {
            MockConnectionBehavior mock;
            JavaCardOperations commands ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockConnectionBehavior, sendCommandWithResponse, ext ) sendCommandWithResponse_mock ( &mock );

            unsigned char arrayFail1[] = { 0x00, 0x90, 0x00 };
            unsigned char arrayFail2[] = { 0x01, 0x91, 0x00 };
            unsigned char arrayFail3[] = { 0x01, 0x90, 0x01 };
            unsigned char arraySuccess[] = { 0x01, 0x90, 0x00 };

            sendCommandWithResponse_mock
            .expects ( MOCKPP_NS::exactly ( 5 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer () ),
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer ( arrayFail1, sizeof ( arrayFail1 ) ) ),
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer ( arrayFail2, sizeof ( arrayFail2 ) ) ),
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer ( arrayFail3, sizeof ( arrayFail3 ) ) ),
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer ( arraySuccess, sizeof ( arraySuccess ) ) ) ) );

            CPPUNIT_ASSERT ( false == commands.verifyPasswordPIN ( SafeBuffer ( "1" ) ) );
            CPPUNIT_ASSERT ( false == commands.verifyPasswordPIN ( SafeBuffer ( "2" ) ) );
            CPPUNIT_ASSERT ( false == commands.verifyPasswordPIN ( SafeBuffer ( "3" ) ) );
            CPPUNIT_ASSERT ( false == commands.verifyPasswordPIN ( SafeBuffer ( "4" ) ) );
            CPPUNIT_ASSERT ( true == commands.verifyPasswordPIN ( SafeBuffer ( "5" ) ) );

            mock.verify();
        }

        void testSetPasswordPIN()
        {
            MockConnectionBehavior mock;
            JavaCardOperations commands ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockConnectionBehavior, sendCommand, ext ) sendCommand_mock ( &mock );

            sendCommand_mock
            .expects ( MOCKPP_NS::exactly ( 2 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        MOCKPP_NS::returnValue <bool> ( false ),
                        MOCKPP_NS::returnValue <bool> ( true ) ) );

            CPPUNIT_ASSERT ( false == commands.setPasswordPIN ( SafeBuffer ( "1" ) ) );
            CPPUNIT_ASSERT ( true == commands.setPasswordPIN ( SafeBuffer ( "2" ) ) );

            mock.verify();
        }

        void testSetPasswordFile()
        {
            MockConnectionBehavior mock;
            JavaCardOperations commands ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockConnectionBehavior, sendCommand, ext ) sendCommand_mock ( &mock );

            sendCommand_mock
            .expects ( MOCKPP_NS::exactly ( 2 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        MOCKPP_NS::returnValue <bool> ( false ),
                        MOCKPP_NS::returnValue <bool> ( true ) ) );

            CPPUNIT_ASSERT ( false == commands.setPasswordFile ( SafeBuffer ( "1" ) ) );
            CPPUNIT_ASSERT ( true == commands.setPasswordFile ( SafeBuffer ( "2" ) ) );

            mock.verify();
        }

        void testGetPasswordFile()
        {
            MockConnectionBehavior mock;
            JavaCardOperations commands ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockConnectionBehavior, sendCommandWithResponse, ext ) sendCommandWithResponse_mock ( &mock );

            sendCommandWithResponse_mock
            .expects ( MOCKPP_NS::exactly ( 4 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer () ),
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer ( "01234567890123456789012345678901234567890123456x" ) ),
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer ( "01234567890123456789012345678901234567890123456x89ab" ) ),
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer ( "01234567890123456789012345678901234567890123456x89" ) ) ) );

            CPPUNIT_ASSERT ( 0 == commands.getPasswordFile().GetSize() );
            CPPUNIT_ASSERT ( 0 == commands.getPasswordFile().GetSize() );
            CPPUNIT_ASSERT ( 0 == commands.getPasswordFile().GetSize() );
            CPPUNIT_ASSERT ( SafeBuffer ( "01234567890123456789012345678901234567890123456x" ) == commands.getPasswordFile() );

            mock.verify();
        }

        void testOpenWrite()
        {
            MockConnectionBehavior mock;
            JavaCardOperations commands ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockConnectionBehavior, sendCommand, ext ) sendCommand_mock ( &mock );

            sendCommand_mock
            .expects ( MOCKPP_NS::exactly ( 2 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        MOCKPP_NS::returnValue <bool> ( false ),
                        MOCKPP_NS::returnValue <bool> ( true ) ) );

            CPPUNIT_ASSERT ( false == commands.openWrite () );
            CPPUNIT_ASSERT ( true == commands.openWrite () );

            mock.verify();
        }

        void testContinueWrite()
        {
            MockConnectionBehavior mock;
            JavaCardOperations commands ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockConnectionBehavior, sendCommand, ext ) sendCommand_mock ( &mock );

            sendCommand_mock
            .expects ( MOCKPP_NS::exactly ( 2 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        MOCKPP_NS::returnValue <bool> ( false ),
                        MOCKPP_NS::returnValue <bool> ( true ) ) );

            CPPUNIT_ASSERT ( false == commands.continueWrite ( SafeBuffer () ) );
            CPPUNIT_ASSERT ( true == commands.continueWrite ( SafeBuffer () ) );

            mock.verify();
        }

        void testCloseWrite()
        {
            MockConnectionBehavior mock;
            JavaCardOperations commands ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockConnectionBehavior, sendCommand, ext ) sendCommand_mock ( &mock );

            sendCommand_mock
            .expects ( MOCKPP_NS::exactly ( 2 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        MOCKPP_NS::returnValue <bool> ( false ),
                        MOCKPP_NS::returnValue <bool> ( true ) ) );

            CPPUNIT_ASSERT ( false == commands.closeWrite () );
            CPPUNIT_ASSERT ( true == commands.closeWrite () );

            mock.verify();
        }

        void testAbortWrite()
        {
            MockConnectionBehavior mock;
            JavaCardOperations commands ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockConnectionBehavior, sendCommand, ext ) sendCommand_mock ( &mock );

            sendCommand_mock
            .expects ( MOCKPP_NS::exactly ( 2 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        MOCKPP_NS::returnValue <bool> ( false ),
                        MOCKPP_NS::returnValue <bool> ( true ) ) );

            CPPUNIT_ASSERT ( false == commands.abortWrite () );
            CPPUNIT_ASSERT ( true == commands.abortWrite () );

            mock.verify();
        }

        void testOpenRead()
        {
            MockConnectionBehavior mock;
            JavaCardOperations commands ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockConnectionBehavior, sendCommandWithResponse, ext ) sendCommandWithResponse_mock ( &mock );

            unsigned char arrayFail1[] = { 0x00, 0x01, 0x91, 0x00 };
            unsigned char arrayFail2[] = { 0x00, 0x01, 0x90, 0x01 };
            unsigned char arraySizeZero[] = { 0x00, 0x00, 0x90, 0x00 };
            unsigned char arraySizeOne[] = { 0x00, 0x01, 0x90, 0x00 };
            unsigned char arraySizeFive[] = { 0x00, 0x05, 0x90, 0x00 };

            sendCommandWithResponse_mock
            .expects ( MOCKPP_NS::exactly ( 7 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer () ),
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer ( "abcde" ) ),
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer ( arrayFail1, sizeof ( arrayFail1 ) ) ),
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer ( arrayFail2, sizeof ( arrayFail2 ) ) ),
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer ( arraySizeZero, sizeof ( arraySizeZero ) ) ),
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer ( arraySizeOne, sizeof ( arraySizeOne ) ) ),
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer ( arraySizeFive, sizeof ( arraySizeFive ) ) ) ) );


            CPPUNIT_ASSERT ( 0 == commands.openRead() );
            CPPUNIT_ASSERT ( 0 == commands.openRead() );
            CPPUNIT_ASSERT ( 0 == commands.openRead() );
            CPPUNIT_ASSERT ( 0 == commands.openRead() );
            CPPUNIT_ASSERT ( 0 == commands.openRead() );
            CPPUNIT_ASSERT ( 1 == commands.openRead() );
            CPPUNIT_ASSERT ( 5 == commands.openRead() );

            mock.verify();
        }

        void testContinueRead()
        {
            MockConnectionBehavior mock;
            JavaCardOperations commands ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockConnectionBehavior, sendCommandWithResponse, ext ) sendCommandWithResponse_mock ( &mock );

            unsigned char arrayFail1[] = { 0x00, 0x01, 0x31, 0x32, 0x91, 0x00 };
            unsigned char arrayFail2[] = { 0x00, 0x01, 0x31, 0x32, 0x90, 0x01 };
            unsigned char arraySizeZero[] = { 0x00, 0x00, 0x31, 0x32, 0x90, 0x00 };
            unsigned char arraySizeOne[] = { 0x00, 0x01, 0x31, 0x32, 0x90, 0x00 };
            unsigned char arraySizeFive[] = { 0x00, 0x05, 0x31, 0x32, 0x90, 0x00 };

            sendCommandWithResponse_mock
            .expects ( MOCKPP_NS::exactly ( 8 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer () ),
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer ( "0123456789" ) ),
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer ( "1234xx" ) ),
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer ( arrayFail1, sizeof ( arrayFail1 ) ) ),
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer ( arrayFail2, sizeof ( arrayFail2 ) ) ),
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer ( arraySizeZero, sizeof ( arraySizeZero ) ) ),
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer ( arraySizeOne, sizeof ( arraySizeOne ) ) ),
                        new MOCKPP_NS::ReturnStub<SafeBuffer> ( SafeBuffer ( arraySizeFive, sizeof ( arraySizeFive ) ) ) ) );


            unsigned int left;

            CPPUNIT_ASSERT ( 0 == commands.continueRead ( 2, left ).GetSize() );
            CPPUNIT_ASSERT ( 0 == left );

            CPPUNIT_ASSERT ( 0 == commands.continueRead ( 2, left ).GetSize() );
            CPPUNIT_ASSERT ( 0 == left );

            CPPUNIT_ASSERT ( 0 == commands.continueRead ( 2, left ).GetSize() );
            CPPUNIT_ASSERT ( 0 == left );

            CPPUNIT_ASSERT ( 0 == commands.continueRead ( 2, left ).GetSize() );
            CPPUNIT_ASSERT ( 0 == left );

            CPPUNIT_ASSERT ( 0 == commands.continueRead ( 2, left ).GetSize() );
            CPPUNIT_ASSERT ( 0 == left );

            CPPUNIT_ASSERT ( 2 == commands.continueRead ( 2, left ).GetSize() );
            CPPUNIT_ASSERT ( 0 == left );

            CPPUNIT_ASSERT ( 2 == commands.continueRead ( 2, left ).GetSize() );
            CPPUNIT_ASSERT ( 1 == left );

            CPPUNIT_ASSERT ( 2 == commands.continueRead ( 2, left ).GetSize() );
            CPPUNIT_ASSERT ( 5 == left );

            mock.verify();
        }

        void testCommandVerifyGlobalPIN()
        {
            StoreMockConnectionBehavior mock;
            JavaCardOperations commands ( &mock );

            unsigned char arraySuccess[] = { 0x01, 0x90, 0x00 };

            mock.response = SafeBuffer ( arraySuccess, sizeof ( arraySuccess ) );

            CPPUNIT_ASSERT ( true == commands.verifyGlobalPIN ( SafeBuffer ( "1" ) ) );
            CPPUNIT_ASSERT ( NULL != mock.commandWithResponse.GetData() );

            std::vector <unsigned char> vector ( mock.commandWithResponse.GetData(), mock.commandWithResponse.GetData() + mock.commandWithResponse.GetSize() );
            std::string expected = "80-f1-00-00-01-31-01";

            CPPUNIT_ASSERT ( expected == StringUtils::arrayHexToString ( vector, "", "-" ) );
        }

        void testCommandVerifyPasswordPIN()
        {
            StoreMockConnectionBehavior mock;
            JavaCardOperations commands ( &mock );

            unsigned char arraySuccess[] = { 0x01, 0x90, 0x00 };

            mock.response = SafeBuffer ( arraySuccess, sizeof ( arraySuccess ) );

            CPPUNIT_ASSERT ( true == commands.verifyPasswordPIN ( SafeBuffer ( "2" ) ) );
            CPPUNIT_ASSERT ( NULL != mock.commandWithResponse.GetData() );

            std::vector <unsigned char> vector ( mock.commandWithResponse.GetData(), mock.commandWithResponse.GetData() + mock.commandWithResponse.GetSize() );
            std::string expected = "80-f2-00-00-01-32-01";

            CPPUNIT_ASSERT ( expected == StringUtils::arrayHexToString ( vector, "", "-" ) );
        }

        void testCommandSetPasswordPIN()
        {
            StoreMockConnectionBehavior mock;
            JavaCardOperations commands ( &mock );

            CPPUNIT_ASSERT ( true == commands.setPasswordPIN ( SafeBuffer ( "1" ) ) );
            CPPUNIT_ASSERT ( NULL != mock.command.GetData() );

            std::vector <unsigned char> vector ( mock.command.GetData(), mock.command.GetData() + mock.command.GetSize() );
            std::string expected = "80-f3-00-00-01-31";

            CPPUNIT_ASSERT ( expected == StringUtils::arrayHexToString ( vector, "", "-" ) );
        }

        void testCommandSetPasswordFile()
        {
            StoreMockConnectionBehavior mock;
            JavaCardOperations commands ( &mock );

            CPPUNIT_ASSERT ( true == commands.setPasswordFile ( SafeBuffer ( "2" ) ) );
            CPPUNIT_ASSERT ( NULL != mock.command.GetData() );

            std::vector <unsigned char> vector ( mock.command.GetData(), mock.command.GetData() + mock.command.GetSize() );
            std::string expected = "80-f5-00-00-01-32";

            CPPUNIT_ASSERT ( expected == StringUtils::arrayHexToString ( vector, "", "-" ) );
        }

        void testCommandOpenWrite()
        {
            StoreMockConnectionBehavior mock;
            JavaCardOperations commands ( &mock );

            CPPUNIT_ASSERT ( true == commands.openWrite() );
            CPPUNIT_ASSERT ( NULL != mock.command.GetData() );

            std::vector <unsigned char> vector ( mock.command.GetData(), mock.command.GetData() + mock.command.GetSize() );
            std::string expected = "80-f7-01-00";

            CPPUNIT_ASSERT ( expected == StringUtils::arrayHexToString ( vector, "", "-" ) );
        }

        void testCommandContinueWrite()
        {
            StoreMockConnectionBehavior mock;
            JavaCardOperations commands ( &mock );

            CPPUNIT_ASSERT ( true == commands.continueWrite ( SafeBuffer ( "1" ) ) );
            CPPUNIT_ASSERT ( NULL != mock.command.GetData() );

            std::vector <unsigned char> vector ( mock.command.GetData(), mock.command.GetData() + mock.command.GetSize() );
            std::string expected = "80-f7-02-00-01-31";

            CPPUNIT_ASSERT ( expected == StringUtils::arrayHexToString ( vector, "", "-" ) );
        }

        void testCommandCloseWrite()
        {
            StoreMockConnectionBehavior mock;
            JavaCardOperations commands ( &mock );

            CPPUNIT_ASSERT ( true == commands.closeWrite() );
            CPPUNIT_ASSERT ( NULL != mock.command.GetData() );

            std::vector <unsigned char> vector ( mock.command.GetData(), mock.command.GetData() + mock.command.GetSize() );
            std::string expected = "80-f7-02-01-00";

            CPPUNIT_ASSERT ( expected == StringUtils::arrayHexToString ( vector, "", "-" ) );
        }

        void testCommandAbortWrite()
        {
            StoreMockConnectionBehavior mock;
            JavaCardOperations commands ( &mock );

            CPPUNIT_ASSERT ( true == commands.abortWrite() );
            CPPUNIT_ASSERT ( NULL != mock.command.GetData() );

            std::vector <unsigned char> vector ( mock.command.GetData(), mock.command.GetData() + mock.command.GetSize() );
            std::string expected = "80-f7-03-00";

            CPPUNIT_ASSERT ( expected == StringUtils::arrayHexToString ( vector, "", "-" ) );
        }

        void testCommandOpenRead()
        {
            StoreMockConnectionBehavior mock;
            JavaCardOperations commands ( &mock );

            commands.openRead();
            CPPUNIT_ASSERT ( NULL != mock.commandWithResponse.GetData() );

            std::vector <unsigned char> vector ( mock.commandWithResponse.GetData(), mock.commandWithResponse.GetData() + mock.commandWithResponse.GetSize() );
            std::string expected = "80-f8-01-00-02";

            CPPUNIT_ASSERT ( expected == StringUtils::arrayHexToString ( vector, "", "-" ) );
        }

        void testCommandContinueRead()
        {
            StoreMockConnectionBehavior mock;
            JavaCardOperations commands ( &mock );

            unsigned int left;

            commands.continueRead ( 4, left );
            CPPUNIT_ASSERT ( NULL != mock.commandWithResponse.GetData() );
            CPPUNIT_ASSERT ( 0 == left );

            std::vector <unsigned char> vector ( mock.commandWithResponse.GetData(), mock.commandWithResponse.GetData() + mock.commandWithResponse.GetSize() );
            std::string expected = "80-f8-00-00-06";

            CPPUNIT_ASSERT ( expected == StringUtils::arrayHexToString ( vector, "", "-" ) );
        }

        CPPUNIT_TEST_SUITE ( JavaCardOperationsTest );

        CPPUNIT_TEST ( testVerifyGlobalPIN );
        CPPUNIT_TEST ( testVerifyPasswordPIN );
        CPPUNIT_TEST ( testSetPasswordPIN );
        CPPUNIT_TEST ( testSetPasswordFile );
        CPPUNIT_TEST ( testGetPasswordFile );
        CPPUNIT_TEST ( testOpenWrite );
        CPPUNIT_TEST ( testContinueWrite );
        CPPUNIT_TEST ( testCloseWrite );
        CPPUNIT_TEST ( testAbortWrite );
        CPPUNIT_TEST ( testOpenRead );
        CPPUNIT_TEST ( testContinueRead );

        CPPUNIT_TEST ( testCommandVerifyGlobalPIN );
        CPPUNIT_TEST ( testCommandVerifyPasswordPIN );
        CPPUNIT_TEST ( testCommandSetPasswordPIN );
        CPPUNIT_TEST ( testCommandSetPasswordFile );
        CPPUNIT_TEST ( testCommandOpenWrite );
        CPPUNIT_TEST ( testCommandContinueWrite );
        CPPUNIT_TEST ( testCommandCloseWrite );
        CPPUNIT_TEST ( testCommandAbortWrite );
        CPPUNIT_TEST ( testCommandOpenRead );
        CPPUNIT_TEST ( testCommandContinueRead );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_JAVA_CARD_OPERATIONS_TEST */
