/**
 * @file   MockKeyManager.hxx
 * @brief  Declaration of Mock class for the Key Manager
 * @author manuel.arguelles
 * @date   Aug 31, 2017
 */

#ifndef MOCK_KEY_MANAGER_HXX
#define MOCK_KEY_MANAGER_HXX

#include <Configuration/key-type-schema.hxx>
#include <Security/KeyManager.hxx>
#include <System/Encoding/Base64Encoder.h>
#include <System/SafeBuffer.h>
#include <System/Security/Crypto.hxx>

/**
 * @class  MockKeyManager
 * @brief  Mock class for the Key Manager.
 * @author manuel.arguelles
 * @date   Aug 31, 2017
 */
class MockKeyManager : public Smartmatic::SAES::Common::Security::KeyManager
{
    public:

        /**
         * @brief  Constructor of the mocked object.
         * @author manuel.arguelles
         * @date   Aug 31, 2017
         */
        MockKeyManager()
            : KeyManager(Smartmatic::System::Security::Crypto::KEY_AES_256,
                         Smartmatic::System::Security::Crypto::Crypto::MODE_AES_CBC)
        {
            Smartmatic::System::SafeBuffer initKey;

            Smartmatic::System::Encoding::Base64Encoder::ConvertFromBase64(
                "+DrhkiXyXx4v5jY3sUhZv9GSBr5xDdU7ZlEVrn/qPEI=",
                initKey);

            addKeyByType(
                initKey,
                Smartmatic::SAES::Common::Configuration::KeyType::CONFIGURATION_INIT_KEY);
        }

        /**
         * @brief  Destroys the mocked object.
         * @author manuel.arguelles
         * @date   Aug 31, 2017
         */
        virtual ~MockKeyManager()
        {
        }

};

#endif /* MOCK_KEY_MANAGER_HXX */
