#ifndef TEST_DEVICE_TYPE_MONITOR_TEST
#define TEST_DEVICE_TYPE_MONITOR_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <tests/MockDeviceTypeMonitor.hxx>
#include "MockCheckDeviceStatusMonitor.hxx"

class DeviceTypeMonitorTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::SAES::Common::Configuration::DeviceType DeviceType;

    public:

        DeviceTypeMonitorTest ()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testGetDeviceTypeP168A()
        {
            DeviceType expected ( DeviceType::CONFIGURATION_P168A );
            MockDeviceTypeMonitor deviceType ( expected );

            MOCKPP_CHAINER_FOR_EXT ( MockDeviceTypeMonitor, added, ext ) added_mock ( &deviceType );
            MOCKPP_CHAINER_FOR_EXT ( MockDeviceTypeMonitor, removed, ext ) removed_mock ( &deviceType );

            added_mock
            .expects ( MOCKPP_NS::never() );

            removed_mock
            .expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( expected == deviceType.getType() );

            deviceType.verify();
        }

        void testGetDeviceTypeFlash()
        {
            DeviceType expected ( DeviceType::CONFIGURATION_FLASH );
            MockDeviceTypeMonitor deviceType ( expected );

            MOCKPP_CHAINER_FOR_EXT ( MockDeviceTypeMonitor, added, ext ) added_mock ( &deviceType );
            MOCKPP_CHAINER_FOR_EXT ( MockDeviceTypeMonitor, removed, ext ) removed_mock ( &deviceType );

            added_mock
            .expects ( MOCKPP_NS::never() );

            removed_mock
            .expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( expected == deviceType.getType() );

            deviceType.verify();
        }

        void testAddNodeFirstTimeNotFoundTrue()
        {
            MockDeviceTypeMonitor deviceType ( DeviceType::CONFIGURATION_UNKNOWN );

            MOCKPP_CHAINER_FOR_EXT ( MockDeviceTypeMonitor, added, ext ) added_mock ( &deviceType );
            MOCKPP_CHAINER_FOR_EXT ( MockDeviceTypeMonitor, removed, ext ) removed_mock ( &deviceType );

            added_mock
            .expects ( MOCKPP_NS::never() );

            removed_mock
            .expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( true == deviceType.addNode ( "abcd" ) );

            deviceType.verify();
        }

        void testAddNodeSecondTimeNotFoundFalse()
        {
            MockDeviceTypeMonitor deviceType ( DeviceType::CONFIGURATION_UNKNOWN );

            MOCKPP_CHAINER_FOR_EXT ( MockDeviceTypeMonitor, added, ext ) added_mock ( &deviceType );
            MOCKPP_CHAINER_FOR_EXT ( MockDeviceTypeMonitor, removed, ext ) removed_mock ( &deviceType );

            added_mock
            .expects ( MOCKPP_NS::never() );

            removed_mock
            .expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( true == deviceType.addNode ( "abcd" ) );
            CPPUNIT_ASSERT ( false == deviceType.addNode ( "abcd" ) );

            deviceType.verify();
        }

        void testRemoveNodeFirstTimeFoundFalse()
        {
            MockDeviceTypeMonitor deviceType ( DeviceType::CONFIGURATION_UNKNOWN );

            MOCKPP_CHAINER_FOR_EXT ( MockDeviceTypeMonitor, added, ext ) added_mock ( &deviceType );
            MOCKPP_CHAINER_FOR_EXT ( MockDeviceTypeMonitor, removed, ext ) removed_mock ( &deviceType );

            added_mock
            .expects ( MOCKPP_NS::never() );

            removed_mock
            .expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( false == deviceType.removeNode ( "abcd" ) );

            deviceType.verify();
        }

        void testAddAndRemoveFoundTrue()
        {
            MockDeviceTypeMonitor deviceType ( DeviceType::CONFIGURATION_UNKNOWN );

            MOCKPP_CHAINER_FOR_EXT ( MockDeviceTypeMonitor, added, ext ) added_mock ( &deviceType );
            MOCKPP_CHAINER_FOR_EXT ( MockDeviceTypeMonitor, removed, ext ) removed_mock ( &deviceType );

            added_mock
            .expects ( MOCKPP_NS::never() );

            removed_mock
            .expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( true == deviceType.addNode ( "abcd" ) );
            CPPUNIT_ASSERT ( true == deviceType.removeNode ( "abcd" ) );

            deviceType.verify();
        }

        void testGetNumberOfDevicesFirstTime()
        {
            MockDeviceTypeMonitor deviceType ( DeviceType::CONFIGURATION_UNKNOWN );

            MOCKPP_CHAINER_FOR_EXT ( MockDeviceTypeMonitor, added, ext ) added_mock ( &deviceType );
            MOCKPP_CHAINER_FOR_EXT ( MockDeviceTypeMonitor, removed, ext ) removed_mock ( &deviceType );

            added_mock
            .expects ( MOCKPP_NS::never() );

            removed_mock
            .expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( 0 == deviceType.getNumberOfDevices() );

            deviceType.verify();
        }

        void testGetNumberOfDevicesIfAddNode()
        {
            MockDeviceTypeMonitor deviceType ( DeviceType::CONFIGURATION_UNKNOWN );

            MOCKPP_CHAINER_FOR_EXT ( MockDeviceTypeMonitor, added, ext ) added_mock ( &deviceType );
            MOCKPP_CHAINER_FOR_EXT ( MockDeviceTypeMonitor, removed, ext ) removed_mock ( &deviceType );

            added_mock
            .expects ( MOCKPP_NS::never() );

            removed_mock
            .expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( true == deviceType.addNode ( "abcd" ) );
            CPPUNIT_ASSERT ( 1 == deviceType.getNumberOfDevices() );

            deviceType.verify();
        }

        void testGetNumberOfDevicesIfAddAndRemoveNode()
        {
            MockDeviceTypeMonitor deviceType ( DeviceType::CONFIGURATION_UNKNOWN );

            MOCKPP_CHAINER_FOR_EXT ( MockDeviceTypeMonitor, added, ext ) added_mock ( &deviceType );
            MOCKPP_CHAINER_FOR_EXT ( MockDeviceTypeMonitor, removed, ext ) removed_mock ( &deviceType );

            added_mock
            .expects ( MOCKPP_NS::never() );

            removed_mock
            .expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( true == deviceType.addNode ( "abcd" ) );
            CPPUNIT_ASSERT ( true == deviceType.removeNode ( "abcd" ) );
            CPPUNIT_ASSERT ( 0 == deviceType.getNumberOfDevices() );

            deviceType.verify();
        }

        void testCheckDeviceMountedDefaultValue()
        {
            MockDeviceTypeMonitor deviceType ( DeviceType::CONFIGURATION_UNKNOWN );

            MOCKPP_CHAINER_FOR_EXT ( MockDeviceTypeMonitor, added, ext ) added_mock ( &deviceType );
            MOCKPP_CHAINER_FOR_EXT ( MockDeviceTypeMonitor, removed, ext ) removed_mock ( &deviceType );
            MOCKPP_CHAINER_FOR_EXT ( MockDeviceTypeMonitor, getDeviceMounted, ext ) getDeviceMounted_mock ( &deviceType );

            added_mock
            .expects ( MOCKPP_NS::never() );

            removed_mock
            .expects ( MOCKPP_NS::never() );

            getDeviceMounted_mock
            .expects ( MOCKPP_NS::once () )
            .will ( new MOCKPP_NS::ReturnStub < std::string > ( "device" ) );

            CPPUNIT_ASSERT ( "device" == deviceType.getDeviceMounted ( "device", "custom" ) );

            deviceType.verify();
        }

        CPPUNIT_TEST_SUITE ( DeviceTypeMonitorTest );

        CPPUNIT_TEST ( testGetDeviceTypeP168A );
        CPPUNIT_TEST ( testGetDeviceTypeFlash );

        CPPUNIT_TEST ( testAddNodeFirstTimeNotFoundTrue );
        CPPUNIT_TEST ( testAddNodeSecondTimeNotFoundFalse );

        CPPUNIT_TEST ( testRemoveNodeFirstTimeFoundFalse );
        CPPUNIT_TEST ( testAddAndRemoveFoundTrue );

        CPPUNIT_TEST ( testGetNumberOfDevicesFirstTime );
        CPPUNIT_TEST ( testGetNumberOfDevicesIfAddNode );
        CPPUNIT_TEST ( testGetNumberOfDevicesIfAddAndRemoveNode );

        CPPUNIT_TEST ( testCheckDeviceMountedDefaultValue );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_DEVICE_POOL_TEST */
