/**
 * @file	AlarmConfigurationManager.hxx
 * @brief	Declaration of the alarms configuration manager.
 * @author	Yadickson Soto
 * @date	14/07/2015
 */

#ifndef _ALARM_CONFIGURATION_MANAGER_HXX_
#define _ALARM_CONFIGURATION_MANAGER_HXX_

#include <string>
#include <Configuration/alarms-configuration-schema.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Functionality
        {
            namespace Configuration
            {
                /**
                 * @class	AlarmConfigurationManager
                 * @brief	The alarms configuration manager.
                 * @author	Yadickson Soto
                 * @date	14/07/2015
                 */
                class AlarmConfigurationManager
                {
                    public:

                        /**
                         * @fn	static AlarmConfigurationManager * getInstance( AlarmConfigurationManager * externManager = NULL );
                         * @brief	Gets the current Smartcard Configuration Manager.
                         * @author	Yadickson Soto
                         * @date	14/07/2015
                         * @param 	externManager external manager to unit test
                         * @return	instance of the class.
                         */
                        static AlarmConfigurationManager * getInstance ( AlarmConfigurationManager * externManager = NULL );

                        /**
                         * @fn Smartmatic::SAES::Functionality::Configuration::Alarm::AlarmCommandsSequence getCommandsOfAlarm ( const AlarmEnum & typeOfAlarm );
                         * @brief Gets the commands of the alarm.
                         * @author Yadickson Soto
                         * @date 14/07/2015
                         * @param typeOfAlarm	Type of the alarm.
                         * @return The commands of alarm.
                         */
                        Smartmatic::SAES::Functionality::Configuration::Alarm::AlarmCommandsSequence getCommandsOfAlarm ( const AlarmEnum & typeOfAlarm );

                        /**
                         * @fn AlarmCategoryEnum getCategoryOfAlarm ( const AlarmEnum & typeOfAlarm );
                         * @brief Gets the category of the alarm.
                         * @author Yadickson Soto
                         * @date 14/07/2015
                         * @param typeOfAlarm Type of the alarm.
                         * @return The category of alarm.
                         */
                        AlarmCategoryEnum getCategoryOfAlarm ( const AlarmEnum & typeOfAlarm );

                        /**
                         * @fn AlarmBehaviorEnum getBehaviorOfAlarm ( const AlarmEnum & typeOfAlarm );
                         * @brief Gets the behavior of the alarm.
                         * @author Yadickson Soto
                         * @date 14/07/2015
                         * @param typeOfAlarm	Type of the alarm.
                         * @return The behavior of alarm.
                         */
                        AlarmBehaviorEnum getBehaviorOfAlarm ( const AlarmEnum & typeOfAlarm );

                        /**
                         * @fn	virtual ~AlarmConfigurationManager();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	14/07/2015
                         */
                        virtual ~AlarmConfigurationManager();

                    protected:

                        /**
                         * @fn	AlarmConfigurationManager();
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	14/07/2015
                         */
                        AlarmConfigurationManager();

                        /**
                         * @fn	virtual AlarmsConfiguration & getAlarmsConfiguration ();
                         * @brief	Gets a reference to the common context of the alarms configuration.
                         * @author	Yadickson Soto
                         * @date	14/07/2015
                         * @return	The reference to the common context of the alarms configuration device
                         */
                        virtual AlarmsConfiguration & getAlarmsConfiguration ();

                    private:

                        static AlarmConfigurationManager * instance; ///< The pointer to the singleton instance of the alarms configuration manager
                };
            }
        }
    }
}

#endif // _ALARM_CONFIGURATION_MANAGER_HXX_
