/**
 * @file	PrinterControllerConfigurationManager.cxx
 * @brief	Implementation of the printer controller configuration manager.
 * @author	Yadickson Soto
 * @date	23/04/2014
 */

#include "PrinterControllerConfigurationManager.hxx"
#include "s-a-e-s-functionality-conf-manager.h"

using namespace Smartmatic::SAES::Functionality::Configuration;

PrinterControllerConfigurationManager * PrinterControllerConfigurationManager::instance = NULL;

PrinterControllerConfigurationManager::PrinterControllerConfigurationManager()
{

}

PrinterControllerConfigurationManager::~PrinterControllerConfigurationManager()
{
    instance = NULL;
}

bool PrinterControllerConfigurationManager::shouldSkipPrinter()
{
    return getPrinterControllerConfiguration().getSkipPrinter().present() ? getPrinterControllerConfiguration().getSkipPrinter().get() : false;
}

unsigned int PrinterControllerConfigurationManager::getTimeoutPrint()
{
    return getPrinterControllerConfiguration().getTimeoutPrint().present() ? getPrinterControllerConfiguration().getTimeoutPrint().get() : 2;
}

std::string PrinterControllerConfigurationManager::getResultPrintFile()
{
    return getPrinterControllerConfiguration().getResultPrintFile().present() ? getPrinterControllerConfiguration().getResultPrintFile().get() : "";
}

std::string PrinterControllerConfigurationManager::getStatusPrintFile()
{
    return getPrinterControllerConfiguration().getStatusPrintFile().present() ? getPrinterControllerConfiguration().getStatusPrintFile().get() : "";
}

PrinterControllerConfiguration & PrinterControllerConfigurationManager::getPrinterControllerConfiguration ()
{
    if ( ! SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->getPrinterControllerConfiguration().present() )
    {
        PrinterControllerConfiguration config;
        SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->setPrinterControllerConfiguration ( config );
    }

    return SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->getPrinterControllerConfiguration().get();
}

PrinterControllerConfigurationManager * PrinterControllerConfigurationManager::getInstance ( PrinterControllerConfigurationManager * externManager )
{
    if ( ! instance )
    {
        instance = ( externManager == NULL ? new PrinterControllerConfigurationManager() : externManager );
    }

    return instance;
}
