/**
 * @file	functionality-manager.hpp
 *
 * @brief	Declares the functionality manager class.
 */

namespace Smartmatic
{
    namespace Functionality
    {

        template <class TMenuOptionDescriptor>
        FunctionalityManager<TMenuOptionDescriptor>::FunctionalityManager()
        {
            pntr = NULL;
            forceExit = false;
            signalNextFunctionality.connect ( sigc::mem_fun ( *this, &FunctionalityManager<TMenuOptionDescriptor>::onExecuteNext ) );
        }

        template <class TMenuOptionDescriptor>
        FunctionalityManager<TMenuOptionDescriptor>::~FunctionalityManager()
        {
            functionalities.clear();
        }

        template <class TMenuOptionDescriptor>
        void FunctionalityManager<TMenuOptionDescriptor>::ExecuteOptionList ( const std::list<TMenuOptionDescriptor> & descriptors )
        {
            this->descriptors = descriptors;
            forceExit = true;
            ExecuteNext();
        }

        template <class TMenuOptionDescriptor>
        void FunctionalityManager<TMenuOptionDescriptor>::AddOptionList ( const std::list<TMenuOptionDescriptor> & descriptors )
        {
            this->descriptors.insert ( this->descriptors.end() , descriptors.begin(), descriptors.end() );
        }

        template <class TMenuOptionDescriptor>
        bool FunctionalityManager<TMenuOptionDescriptor>::ExecuteOptionSelected ( TMenuOptionDescriptor menuDesc )
        {
            bool result = false;

            pntr = NULL;
            typename MapFunctionality::iterator it;

            for ( it = functionalities.begin();
                    it != functionalities.end();
                    it++ )
            {
                if ( it->first == menuDesc )
                {
                    pntr = it->second;
                    break;
                }
            }

            if ( pntr != NULL )
            {
                if ( pntr->CanExecute() )
                {
                    pntr->Do();
                }
                else
                {
                    pntr->DisplayUnableMessage();
                }
            }

            return result;
        }

        template <class TMenuOptionDescriptor>
        void FunctionalityManager<TMenuOptionDescriptor>::Register ( Functionality<TMenuOptionDescriptor> * funct )
        {
            if ( funct != NULL )
            {
                TMenuOptionDescriptor option = funct->GetMenuOptionType();
                funct->ExecutionFinishedSigc.connect ( sigc::mem_fun ( this, &FunctionalityManager::ExecuteNextFunctionality ) );
                functionalities.insert ( std::pair<TMenuOptionDescriptor, Functionality<TMenuOptionDescriptor>* > ( option, funct ) );
            }
        }

        template <class TMenuOptionDescriptor>
        void FunctionalityManager<TMenuOptionDescriptor>::onExecuteNextFunctionality()
        {
            signalNextFunctionality.emit();
        }

        template <class TMenuOptionDescriptor>
        void FunctionalityManager<TMenuOptionDescriptor>::ExecuteNextFunctionality()
        {
            if ( forceExit )
            {
                unsigned int time = 0;

                if ( pntr && pntr->isRunning() )
                {
                    time = 2000;
                }

                Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &FunctionalityManager<TMenuOptionDescriptor>::onExecuteNextFunctionality ), time );
            }
        }

        template <class TMenuOptionDescriptor>
        void FunctionalityManager<TMenuOptionDescriptor>::onExecuteNext()
        {
            Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &FunctionalityManager<TMenuOptionDescriptor>::ExecuteNext ), 0 );
        }

        template <class TMenuOptionDescriptor>
        void FunctionalityManager<TMenuOptionDescriptor>::ExecuteNext()
        {
            if ( forceExit && pntr )
            {
                if ( pntr->isRunning() )
                {
                    pntr->ExitFunctionality();
                }

                pntr = NULL;
            }

            if ( this->descriptors.empty() == false )
            {
                ExecuteOptionSelected ( descriptors.front() );
                this->descriptors.pop_front();
            }
        }
    }
}
