/**
 * @file	saes-functionality-manager.h
 * @brief	Declares the saes functionality manager class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#ifndef _SAES_FUNCTIONALITY_MANAGER_H_
#define _SAES_FUNCTIONALITY_MANAGER_H_

#include <Functionalities/functionality-manager.h>
#include "Functionalities/functionality.h"
#include <Configuration/menu-option-type-schema.hxx>

namespace Smartmatic
{
    namespace	SAES
    {

        namespace	Functionality
        {
            /**
             * @class SaesFunctionalityManager
             * @brief Manager for SAES functionalities.
             * @author Youssef.tourkmani
             * @date 01/11/2012
             */

            class SaesFunctionalityManager: public Smartmatic::Functionality::FunctionalityManager < Smartmatic::SAES::Functionality::Configuration::MenuOptionType >
            {
                public:

                    /**
                     * @fn static SaesFunctionalityManager * SaesFunctionalityManager::getInstance();
                     * @brief Gets the current SAES Functionality Manager.
                     * @author Youssef.tourkmani
                     * @date 01/11/2012
                     * @return A pointer to the current instance of the SaesFunctionalityManager.
                     * Returns NULL if the method fails.
                     */

                    static SaesFunctionalityManager * getInstance();

                    /**
                     * @fn SaesFunctionalityManager::~SaesFunctionalityManager()
                     * @brief Finalizes an instance of the SaesFunctionalityManager class.
                     * @author Youssef.tourkmani
                     * @date 01/11/2012
                     */

                    virtual ~SaesFunctionalityManager();

                    /**
                     * @fn void AddRunningSelectedModeForPM();
                     * @brief Add all running selected mode in execute list operation for PM.
                     * @author Yadickson Soto
                     * @date 24/05/2013
                     */
                    void AddRunningSelectedModeForPM();

                    /**
                     * @brief  Add all running selected mode in execute list operation for VM.
                     * @author manuel.arguelles
                     * @date   Jun 15, 2017
                     */
                    void AddRunningSelectedModeForVM();

                private:

                    /**
                     * @fn SaesFunctionalityManager::SaesFunctionalityManager()
                     * @brief Default constructor for the SaesFunctionalityManager class.
                     * @author Youssef.tourkmani
                     * @date 01/11/2012
                     */

                    SaesFunctionalityManager();

                    static SaesFunctionalityManager * singleton_instance; ///< The singleton instance

            };
        }
    }
}

#endif // _SAES_FUNCTIONALITY_MANAGER_H_
