/**
 * @file PMachineAuthenticator.hxx
 * @brief Declaration of the PMachineAuthenticator class.
 * @author Youssef.tourkmani
 * @date 01/11/2012
 */

#ifndef _PMACHINE_AUTHENTICATOR_H_
#define _PMACHINE_AUTHENTICATOR_H_

#include "IAuthenticator.hxx"
#include <Log/ISMTTLog.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Operation
        {
            namespace Authenticator
            {
                /**
                 * @class PMachineAuthenticator
                 * @brief Represents a president machine authenticator.
                 * @author Yadickson Soto &lt;yadickson.soto@smartmatic.com&gt;
                 * @date 03-03-2011
                 */

                class PMachineAuthenticator: public IAuthenticator
                {
                    public:

                        /**
                         * @fn PMachineAuthenticator::PMachineAuthenticator ();
                         * @brief Default constructor for the PMachineAuthenticator class.
                         * @author Youssef.tourkmani
                         * @date 01/11/2012
                         */

                        PMachineAuthenticator ();

                        /**
                         * @fn virtual PMachineAuthenticator::~PMachineAuthenticator();
                         * @brief Finalizes an instance of the PMachineAuthenticator class.
                         * @author Youssef.tourkmani
                         * @date 01/11/2012
                         */
                        virtual ~PMachineAuthenticator();

                        /**
                         * @fn virtual AuthenticationResultType PMachineAuthenticator::validate ( std::string password );
                         * @brief Validates a given password.
                         * @author Youssef.tourkmani
                         * @date 01/11/2012
                         * @param password password to validate.
                         * @return Response for the validation of the given password.
                         */

                        virtual AuthenticationResultType validate ( std::string password );

                        /**
                         * @fn bool PMachineAuthenticator::ValidateRole ( const std::string& password );
                         * @brief Validates if the given password match the password for the menu.
                         * @author Youssef.tourkmani
                         * @date 01/11/2012
                         * @param password The password to validate.
                         * @return true if the given password match the password for the menu. Otherwise, false.
                         */

                        bool ValidateRole ( const std::string& password );

                        /**
                         * @fn virtual void PMachineAuthenticator::dispose();
                         * @brief Disposes this instance of the PMachineAuthenticator class,
                         * cleaning up any resources it uses.
                         * @author Youssef.tourkmani
                         * @date 01/11/2012
                         */

                        virtual void dispose();

                        static Smartmatic::Log::ISMTTLog * logger;  ///< logger
                };
            }
        }
    }
}

#endif // _PMACHINE_AUTHENTICATOR_H_
