/**
 * @file   IOBSmartcardReaderPowerManager.cxx
 * @brief  Implementation of IOBSmartcardReaderPowerManager class.
 * @author eduardo.fernandez
 * @date   Jan 2, 2018
 */

#include "IOBSmartcardReaderPowerManager.hxx"
#include <Configuration/SmartcardConfigurationManager.hxx>
#include <Configuration/s-a-e-s-common-conf-manager.h>
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Operation/Devices/IOBController.hxx>
#include <pcscd/PCSCDManager.hxx>
#include <unistd.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif
#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Common::Configuration;
using namespace Smartmatic::SAES::Operation::Devices;
using namespace Smartmatic::SAES::PCSCD;

ISMTTLog* IOBSmartcardReaderPowerManager::m_logger = SMTTLogManager::GetLogger(
    "Smartmatic.SAES.Card.IOBSmartcardReaderPowerManager",
    GETTEXT_PACKAGE);

IOBSmartcardReaderPowerManager::IOBSmartcardReaderPowerManager()
{
}

IOBSmartcardReaderPowerManager::~IOBSmartcardReaderPowerManager()
{
}

void IOBSmartcardReaderPowerManager::doReaderPowerCycle()
{
    if (!SmartcardConfigurationManager::getInstance()->getForceRestartSmartcardReader() &&
        !SmartcardConfigurationManager::getInstance()->getForceRestartPCSCD())
    {
        m_logger->Debug("PCSCD restart and power cycle are disabled, so no corrective action is applied.");
        return;
    }

    if (SmartcardConfigurationManager::getInstance()->getForceRestartPCSCD())
    {
        m_logger->Debug("Stop PCSCD");

        PCSCDManager::stop(true);

        sleep(SmartcardConfigurationManager::getInstance()->getWaitStopPCSCD());
    }

    if (SmartcardConfigurationManager::getInstance()->getForceRestartSmartcardReader())
    {
        m_logger->Debug("Restart smartcard reader");

        callRestartSmartcard();

        sleep(SmartcardConfigurationManager::getInstance()->getDelayAfterOn());
    }

    if (SmartcardConfigurationManager::getInstance()->getForceRestartPCSCD())
    {
        m_logger->Debug("Start PCSCD");

        PCSCDManager::start(true);

        sleep(SmartcardConfigurationManager::getInstance()->getWaitStartPCSCD());
    }

    m_powerCycledSignal.emit();
}

void IOBSmartcardReaderPowerManager::callRestartSmartcard(bool)
{
    callPowerOffSmartcard();

    usleep(100000);

    callPowerOnSmartcard();
}

void IOBSmartcardReaderPowerManager::callPowerOffSmartcard()
{
    IOBController* controller = IOBController::getInstance();

    controller->disableSmartCardReader();
}

void IOBSmartcardReaderPowerManager::callPowerOnSmartcard()
{
    IOBController* controller = IOBController::getInstance();

    controller->enableSmartCardReader();
}

IOBSmartcardReaderPowerManager::PowerCycledSignal IOBSmartcardReaderPowerManager::signalPowerCycled()
{
    return m_powerCycledSignal;
}
