/**
 * @file   PDBSmartcardReaderPowerManager.cxx
 * @brief  Implementation of PDBSmartcardReaderPowerManager class.
 * @author manuel.arguelles
 * @date   Nov  1, 2017
 */

#include "PDBSmartcardReaderPowerManager.hxx"
#include <Configuration/SmartcardConfigurationManager.hxx>
#include <Configuration/s-a-e-s-common-conf-manager.h>
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Operation/Devices/PDBController.hxx>
#include <pcscd/PCSCDManager.hxx>
#include <unistd.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif
#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Common::Configuration;
using namespace Smartmatic::SAES::Operation::Devices;
using namespace Smartmatic::SAES::PCSCD;

ISMTTLog* PDBSmartcardReaderPowerManager::m_logger = SMTTLogManager::GetLogger(
    "Smartmatic.SAES.Card.PDBSmartcardReaderPowerManager",
    GETTEXT_PACKAGE);

PDBSmartcardReaderPowerManager::PDBSmartcardReaderPowerManager()
{
}

PDBSmartcardReaderPowerManager::~PDBSmartcardReaderPowerManager()
{
}

void PDBSmartcardReaderPowerManager::doReaderPowerCycle()
{
    if (!SmartcardConfigurationManager::getInstance()->getForceRestartSmartcardReader() &&
        !SmartcardConfigurationManager::getInstance()->getForceRestartPCSCD())
    {
        m_logger->Debug("PCSCD restart and power cycle are disabled, so no corrective action is applied.");
        return;
    }

    if (SmartcardConfigurationManager::getInstance()->getForceRestartPCSCD())
    {
        m_logger->Debug("Stop PCSCD");

        PCSCDManager::stop(true);

        sleep(SmartcardConfigurationManager::getInstance()->getWaitStopPCSCD());
    }

    if (SmartcardConfigurationManager::getInstance()->getForceRestartSmartcardReader())
    {
        m_logger->Debug("Restart smartcard reader");

        callRestartSmartcard();

        sleep(SmartcardConfigurationManager::getInstance()->getDelayAfterOn());
    }

    if (SmartcardConfigurationManager::getInstance()->getForceRestartPCSCD())
    {
        m_logger->Debug("Start PCSCD");

        PCSCDManager::start(true);

        sleep(SmartcardConfigurationManager::getInstance()->getWaitStartPCSCD());
    }

    m_powerCycledSignal.emit();
}

void PDBSmartcardReaderPowerManager::callRestartSmartcard(bool)
{
    callPowerOffSmartcard();

    usleep(500000);

    callPowerOnSmartcard();
}

void PDBSmartcardReaderPowerManager::callPowerOffSmartcard()
{
    PDBController* controller = PDBController::getInstance();

    controller->disableSmartCardReader();
}

void PDBSmartcardReaderPowerManager::callPowerOnSmartcard()
{
    PDBController* controller = PDBController::getInstance();

    controller->enableSmartCardReader();
}

PDBSmartcardReaderPowerManager::PowerCycledSignal PDBSmartcardReaderPowerManager::signalPowerCycled()
{
    return m_powerCycledSignal;
}
