/**
 * @file   PDBSmartcardReaderPowerManager.hxx
 * @brief  Declaration of PDBSmartcardReaderPowerManager class.
 * @author manuel.arguelles
 * @date   Nov  1, 2017
 */

#ifndef PDB_SMARTCARD_READER_POWER_MANAGER_HXX
#define PDB_SMARTCARD_READER_POWER_MANAGER_HXX

#include <Card/ISmartcardReaderPowerManager.hxx>
#include <memory>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Operation
        {
            namespace Devices
            {
                /**
                 * @class  PDBSmartcardReaderPowerManager
                 * @brief  Handles the power of the smartcard reader.
                 * @author manuel.arguelles
                 * @date   Nov  1, 2017
                 */
                class PDBSmartcardReaderPowerManager : public SAES::Card::ISmartcardReaderPowerManager
                {
                    public:

                        /**
                         * @brief  Creates an instance of the class.
                         * @author manuel.arguelles
                         * @date   Nov  1, 2017
                         */
                        PDBSmartcardReaderPowerManager();

                        /**
                         * @brief  Destroys an instance of the class.
                         * @author manuel.arguelles
                         * @date   Nov  1, 2017
                         */
                        ~PDBSmartcardReaderPowerManager();

                    public:

                        /**
                         * @brief  Restart the reader with a full power cycle.
                         * @author manuel.arguelles
                         * @date   Nov  1, 2017
                         */
                        virtual void doReaderPowerCycle();

                        /**
                         * @brief  Restarts the reader.
                         * @author manuel.arguelles
                         * @date   Nov  1, 2017
                         * @param  background If the operation should be done asynchronous.
                         */
                        virtual void callRestartSmartcard(bool background = false);

                        /**
                         * @brief  Powers off the reader.
                         * @author manuel.arguelles
                         * @date   Nov  1, 2017
                         */
                        virtual void callPowerOffSmartcard();

                        /**
                         * @brief  Powers on the reader.
                         * @author manuel.arguelles
                         * @date   Nov  1, 2017
                         */
                        virtual void callPowerOnSmartcard();

                        /**
                         * @brief  Emitted when the power was cycled.
                         * @author manuel.arguelles
                         * @date   Nov 11, 2017
                         */
                        virtual PowerCycledSignal signalPowerCycled();

                    private:

                        static Smartmatic::Log::ISMTTLog* m_logger;
                        PowerCycledSignal                 m_powerCycledSignal;
                };

            } /* namespace Devices */
        } /* namespace Operation */
    } /* namespace SAES */
} /* namespace Smartmatic */

#endif /* PDB_SMARTCARD_READER_POWER_MANAGER_HXX */
