/**
 * @file AbleDPolling.cxx
 * @brief Body class able-d monitor polling
 * @date 08/07/2015
 * @author Yadickson Soto
 */

#include "AbleDPolling.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Operation/Devices/P168AController.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

using namespace Smartmatic::SAES::Operation::Devices;
using namespace Smartmatic::SAES::HW::Operation;
using namespace Smartmatic::System;
using namespace Smartmatic::Log;

ISMTTLog * AbleDPolling::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Operation.Card.AbleDPolling", GETTEXT_PACKAGE );
AbleDPolling * AbleDPolling::instance = NULL;

AbleDPolling::AbleDPolling()
{
    signalAbleDPressButton.getSyncSignal().connect ( sigc::mem_fun ( *this, &AbleDPolling::onRawObject ) );
}

AbleDPolling::~AbleDPolling()
{
    instance = NULL;
}

void AbleDPolling::preStart ()
{
    logger->Debug ( "Start" );
}

bool AbleDPolling::process ()
{
    AbleDButtonState * state = P168AController::getInstance()->getAbleDButtonState();

    if ( state && state->isChanged() )
    {
        logger->Debug ( "Abled button pressed" );
        signalAbleDPressButton.emit ( state );
    }

    return true;
}

void AbleDPolling::postStop ()
{
    logger->Debug ( "Stop" );
}

void AbleDPolling::onRawObject ( void * object )
{
    AbleDButtonState * status = static_cast < AbleDButtonState * > ( object );
    getSignalPressButton().emit ( status );
}

AbleDPolling::SignalPressButton AbleDPolling::getSignalPressButton ()
{
    return pressButton;
}

AbleDPolling * AbleDPolling::getInstance()
{
    if ( !instance )
    {
        instance = new AbleDPolling();
    }

    return instance;
}
