/**
 * @file AlarmPolling.cxx
 * @brief Body class alarm box monitor polling
 * @date 07/06/2015
 * @author Yadickson Soto
 */

#include "AlarmPolling.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Operation/Devices/AlarmController.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

using namespace Smartmatic::SAES::Operation::Devices;
using namespace Smartmatic::System;
using namespace Smartmatic::Log;

ISMTTLog * AlarmPolling::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Operation.Card.AlarmPolling", GETTEXT_PACKAGE );
AlarmPolling * AlarmPolling::instance = NULL;

AlarmPolling::AlarmPolling()
{
    this->pressed = false;
    this->flagPause = false;
    signalAlarmBoxPressButton.getSyncSignal().connect ( sigc::mem_fun ( *this, &AlarmPolling::onRawObject ) );
}

AlarmPolling::~AlarmPolling()
{
    instance = NULL;
}

void AlarmPolling::preStart ()
{
    logger->Debug ( "Start" );
    AlarmController::getInstance()->shutDownAlarm();
}

bool AlarmPolling::process ()
{
    if ( !flagPause )
    {
        bool current = AlarmController::getInstance()->isButtonPressed();

        if ( current != pressed )
        {
            pressed = current;

            if ( pressed )
            {
                logger->Debug ( "Alarm box button pressed" );
                signalAlarmBoxPressButton.emit ( new AlarmButtonStatus ( PRESSED ) );
            }
            else
            {
                logger->Debug ( "Alarm box button released" );
                signalAlarmBoxPressButton.emit ( new AlarmButtonStatus ( RELEASED ) );
            }
        }
    }

    return true;
}

void AlarmPolling::postStop ()
{
    logger->Debug ( "Stop" );
    AlarmController::getInstance()->shutDownAlarm();
}

void AlarmPolling::onRawObject ( void * object )
{
    AlarmButtonStatus * status = static_cast < AlarmButtonStatus * > ( object );
    getSignalPressButton().emit ( *status );
    delete status;
}

void AlarmPolling::pause ()
{
    if ( isRunning() )
    {
        logger->Debug ( "Pause" );
        flagPause = true;
    }
}

void AlarmPolling::resume ()
{
    if ( isRunning() )
    {
        logger->Debug ( "Resume" );
        flagPause = false;
    }
}

AlarmPolling::SignalPressButton AlarmPolling::getSignalPressButton ()
{
    return pressButton;
}

AlarmPolling * AlarmPolling::getInstance()
{
    if ( !instance )
    {
        instance = new AlarmPolling();
    }

    return instance;
}
