/**
 * @file AbledDiagnosis.cxx
 * @brief Implementation of the AbledDiagnosis class.
 * @author eduardo.fernandez
 * @date 02/02/2018
 */

#include "AbledDiagnosis.hxx"
#include <Operation/Devices/A4517AbledController.hxx>
#include <Operation/MachineOperationManager.hxx>
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::Operation::AudioVoting;
using namespace Smartmatic::SAES::Operation::Devices;
using namespace Smartmatic::SAES::Operation::Diagnosis;
using namespace Smartmatic::SAES::Voting;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Voting::Status;

ISMTTLog * AbledDiagnosis::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Operation.Diagnosis.AbledDiagnosis", GETTEXT_PACKAGE );

AbledDiagnosis::AbledDiagnosis()
    : IDiagnosis ( Smartmatic::SAES::Common::Configuration::DeviceType::CONFIGURATION_ABLED )
{
    m_ableIsConnected = false;
    m_able20Connected = false;
    m_audioVotingCheckUtility = MachineOperationManager::getInstance()->getAudioVotingCheckUtility();

    if (m_audioVotingCheckUtility.ableIsConnected(true))
    {
        m_ableIsConnected = true;

        if (m_audioVotingCheckUtility.getAbledConnected() == AudioVotingCheckUtility::ABLED20)
        {
            m_able20Connected = true;
            setStatus(VMStatus::VOTING_MACHINE_STATUS_RUN);
        }
        else
        {
            setStatus(VMStatus::VOTING_MACHINE_STATUS_NOTDIAGNOSED);
        }
    }
    else
    {
        setStatus(VMStatus::VOTING_MACHINE_STATUS_NOTDIAGNOSED);
    }

    updateMessage();
}

AbledDiagnosis::~AbledDiagnosis()
{
}

void AbledDiagnosis::run()
{
    if (m_ableIsConnected == false)
    {
        m_ableIsConnected = m_audioVotingCheckUtility.ableIsConnected();
        m_able20Connected = m_audioVotingCheckUtility.getAbledConnected() == AudioVotingCheckUtility::ABLED20;
    }

    bool commandGetFwVersionResponds = A4517AbledController::getInstance()->getFWVersion().empty() == false;

    if ((m_ableIsConnected) && (m_able20Connected) && (commandGetFwVersionResponds))
    {
        setStatus(VMStatus::VOTING_MACHINE_STATUS_OK);
    }
    else if ((m_ableIsConnected) && (m_able20Connected) && (commandGetFwVersionResponds == false))
    {
        setStatus(VMStatus::VOTING_MACHINE_STATUS_ERROR);
    }
    else
    {
        setStatus(VMStatus::VOTING_MACHINE_STATUS_NOTDIAGNOSED);
    }
}

void AbledDiagnosis::updateMessage()
{
    setMessageFooter ( N_ ( "Smartmatic.SAES.Operation.Diagnosis.AbledDiagnosis.Info" ) );

    switch ( getStatus() )
    {
        default:
            break;

        case VMStatus::VOTING_MACHINE_STATUS_NOTDIAGNOSED:
            setMessage ( N_ ( "Smartmatic.SAES.Operation.Diagnosis.AbledDiagnosis.DeviceNotDiagnosed" ) );
            break;

        case VMStatus::VOTING_MACHINE_STATUS_RUN:
            setMessage ( N_ ( "Smartmatic.SAES.Operation.Diagnosis.AbledDiagnosis.InitializingDiagnostic" ) );
            break;

        case VMStatus::VOTING_MACHINE_STATUS_OK:
            setMessage ( N_ ( "Smartmatic.SAES.Operation.Diagnosis.AbledDiagnosis.DiagnosticSuccessful" ) );
            break;

        case VMStatus::VOTING_MACHINE_STATUS_ERROR:
            setMessage ( N_ ( "Smartmatic.SAES.Operation.Diagnosis.AbledDiagnosis.DiagnosticFailed" ) );
            break;
    }
}
