/**
 * @file CalibrationDiagnosis.hxx
 * @brief Declaration of the CalibrationDiagnosis class.
 * @author Youssef.tourkmani
 * @date 01/11/2012
 */

#ifndef CALIBRATIONDIAGNOSIS_HXX_
#define CALIBRATIONDIAGNOSIS_HXX_

#include "IDiagnosis.hxx"
#include "ICalibrationDiagnosis.hxx"

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace SAES
    {
        namespace Operation
        {
            namespace Diagnosis
            {
                /**
                 * @class CalibrationDiagnosis
                 * @brief Represents a touchscreen calibration diagnostic.
                 * @author Youssef.tourkmani
                 * @date 01/11/2012
                 */
                class CalibrationDiagnosis : public IDiagnosis, protected ICalibrationDiagnosis
                {
                    public:

                        /**
                         * @fn CalibrationDiagnosis::CalibrationDiagnosis ( int numberPoints, bool skipConditional = false );
                         * @brief Constructor for the CalibrationDiagnosis class.
                         * @author Yadickson Soto
                         * @date 11/10/2013
                         * @param numberPoints Number of points.
                         * @param skipConditional Skip calibration if file "skip-calibration-tool" if present
                         */

                        CalibrationDiagnosis ( int numberPoints, bool skipConditional = false );

                        /**
                         * @fn virtual CalibrationDiagnosis::~CalibrationDiagnosis();
                         * @brief Finalizes an instance of the CalibrationDiagnosis class.
                         * @author Youssef.tourkmani
                         * @date 01/11/2012
                         */

                        virtual ~CalibrationDiagnosis();

                    protected:

                        /**
                         * @fn virtual void CalibrationDiagnosis::run();
                         * @brief Runs the touchscreen calibration diagnostic.
                         * @author Yadickson Soto
                         * @date 28/09/2012
                         */

                        virtual void run();

                    private:

                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger

                    protected:

                        /**
                         * @fn virtual void CalibrationDiagnosis::updateMessage();
                         * @brief Updates the status message of this diagnostic.
                         * @author Youssef.tourkmani
                         * @date 01/11/2012
                         */

                        virtual void updateMessage();
                };
            }
        }
    }
}

#endif /* CALIBRATIONDIAGNOSIS_HXX_ */
