/*
 * EurnDiagnosis.cxx
 *
 *  Created on: Oct 25, 2017
 *      Author: juanvalera
 */

#include "EurnDiagnosis.hxx"
#include <Operation/Devices/EurnController.hxx>
#include <Log/SMTTLogManager.h>
#include <Operation/Devices/EurnController.hxx>
#include <Operation/Monitor/DeviceTypeMonitorPool.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::Operation::Devices;
using namespace Smartmatic::SAES::Operation::Diagnosis;
using namespace Smartmatic::SAES::Voting;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Voting::Status;
using namespace Smartmatic::SAES::Operation::Monitor;
using namespace Smartmatic::SAES::Common::Operation::Monitor;
using namespace Smartmatic::SAES::Common::Configuration;

ISMTTLog * EurnDiagnosis::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Operation.Diagnosis.EurnDiagnosis", GETTEXT_PACKAGE );

EurnDiagnosis::EurnDiagnosis()
    : IDiagnosis ( Smartmatic::SAES::Common::Configuration::DeviceType::CONFIGURATION_EURN )
{
    updateMessage();
}

EurnDiagnosis::~EurnDiagnosis()
{

}

void EurnDiagnosis::run()
{
    DeviceTypeMonitor * deviceTypeMonitor = DeviceTypeMonitorPool::getInstance()->getDeviceTypeMonitor ( DeviceType::CONFIGURATION_EURN );

    bool validate = deviceTypeMonitor != NULL && deviceTypeMonitor->getNumberOfDevices() > 0;

    if ( validate )
    {
        validate = EurnController::getInstance()->runDiagnosticSequence();
    }

    setStatus ( validate ? VMStatus::VOTING_MACHINE_STATUS_OK : VMStatus::VOTING_MACHINE_STATUS_ERROR );
}

void EurnDiagnosis::updateMessage()
{
    const std::string messageFooter = N_ ( "The system checks if the eUrn reader is correctly connected, please wait.");

    switch ( getStatus() )
    {
        default:
        case VMStatus::VOTING_MACHINE_STATUS_RUN:
            setMessageFooter ( messageFooter );
            setMessage ( N_ ( "Checking communication with eUrn." ) );
            break;

        case VMStatus::VOTING_MACHINE_STATUS_NOTDIAGNOSED:
            setMessageFooter ( messageFooter );
            setMessage ( N_ ( "Initialization of the diagnosis." ) );
            break;

        case VMStatus::VOTING_MACHINE_STATUS_OK:
            setMessageFooter ( messageFooter );
            setMessage ( N_ ( "Diagnostic successful" ) );
            break;

        case VMStatus::VOTING_MACHINE_STATUS_ERROR:
            setMessageFooter ( " " );
            setMessage ( N_ ( "Diagnostic failed" ) );
            break;
    }
}
