/**
 * @file PrinterDiagnosis.cxx
 * @brief Implementation of the PrinterDiagnosis class.
 * @date 20/10/2011
 * @author Yadickson Soto
 */

#include "PrinterDiagnosis.hxx"
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::Operation::Diagnosis;
using namespace Smartmatic::SAES::Operation::Devices;
using namespace Smartmatic::SAES::Operation::Printer;
using namespace Smartmatic::SAES::Voting;
using namespace Smartmatic::SAES::Printing;
using namespace Smartmatic::SAES::Common::Configuration;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Voting::Status;

ISMTTLog * PrinterDiagnosis::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Operation.Diagnosis.PrinterDiagnosis", GETTEXT_PACKAGE );

PrinterDiagnosis::PrinterDiagnosis ( const std::string& data, bool neop )
    : IDiagnosis ( Smartmatic::SAES::Common::Configuration::DeviceType::CONFIGURATION_PRINTER )
    , testPrinter(NULL)
    , printerController(new PrinterController())
    , m_data(data)
{
    printerController->getSignalOk().connect ( sigc::mem_fun ( *this, &PrinterDiagnosis::endPrint ) );
    printerController->getSignalError().connect ( sigc::mem_fun ( *this, &PrinterDiagnosis::errorPrint ) );

    setCheckNeop ( neop );
    updateMessage();
}

PrinterDiagnosis::~PrinterDiagnosis()
{
    if ( testPrinter )
    {
        delete testPrinter;
        testPrinter = NULL;
    }

    if ( printerController )
    {
        delete printerController;
        printerController = NULL;
    }
}

void PrinterDiagnosis::test()
{
    logger->Debug ( "Start Printing" );

    if ( testPrinter )
    {
        delete testPrinter;
        testPrinter = NULL;
    }

    testPrinter = new TestPrinting ( m_data );
    printerController->start ( testPrinter, neop, true );
}

void PrinterDiagnosis::run()
{

}

void PrinterDiagnosis::setCheckNeop ( bool neop )
{
    this->neop = neop;
}

void PrinterDiagnosis::updateMessage()
{
    setMessageFooter ( N_ ( "Smartmatic.SAES.Operation.Diagnosis.PrinterDiagnosis.Info" ) );

    switch ( getStatus() )
    {
        default:
        case VMStatus::VOTING_MACHINE_STATUS_NOTDIAGNOSED:
            setMessage ( N_ ( "Smartmatic.SAES.Operation.Diagnosis.PrinterDiagnosis.InitializingDiagnostic" ) );
            break;

        case VMStatus::VOTING_MACHINE_STATUS_RUN:
            setMessage ( N_ ( "Smartmatic.SAES.Operation.Diagnosis.PrinterDiagnosis.SendingFileToPrint" ) );
            break;

        case VMStatus::VOTING_MACHINE_STATUS_OK:
            setMessage ( N_ ( "Smartmatic.SAES.Operation.Diagnosis.PrinterDiagnosis.DiagnosticSuccessful" ) );
            break;

        case VMStatus::VOTING_MACHINE_STATUS_ERROR:
            setMessage ( errorMessage );
            break;
    }
}

void PrinterDiagnosis::endPrint()
{
    logger->Debug ( "Printing success" );
    setStatus ( VMStatus::VOTING_MACHINE_STATUS_OK );
    getSignalEnd().emit();
}

void PrinterDiagnosis::errorPrint ( const std::string& message )
{
    logger->Debug ( "Printing fail" );
    errorMessage = message;
    setStatus ( VMStatus::VOTING_MACHINE_STATUS_ERROR );
    getSignalEnd().emit();
}
