/**
 * @file SmartcardReaderDiagnosis.hxx
 * @brief Declaration of the SmartcardReaderDiagnosis class.
 * @author Youssef.tourkmani
 * @date 01/11/2012
 */

#ifndef SMARTCARDREADERDIAGNOSIS_HXX_
#define SMARTCARDREADERDIAGNOSIS_HXX_

#include "IDiagnosis.hxx"

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace SAES
    {
        namespace Operation
        {
            namespace Diagnosis
            {
                /**
                 * @class SmartcardReaderDiagnosis
                 * @brief Represents a diagnostic for the smartcard reader device.
                 * @author Youssef.tourkmani
                 * @date 01/11/2012
                 */

                class SmartcardReaderDiagnosis : public IDiagnosis
                {
                    public:

                        /**
                         * @fn SmartcardReaderDiagnosis::SmartcardReaderDiagnosis();
                         * @brief Default constructor for the SmartcardReaderDiagnosis class.
                         * @author Youssef.tourkmani
                         * @date 01/11/2012
                         */

                        SmartcardReaderDiagnosis();

                        /**
                         * @fn virtual SmartcardReaderDiagnosis::~SmartcardReaderDiagnosis();
                         * @brief Finalizes an instance of the SmartcardReaderDiagnosis class.
                         * @author Youssef.tourkmani
                         * @date 01/11/2012
                         */

                        virtual ~SmartcardReaderDiagnosis();

                    protected:

                        /**
                         * @fn virtual void SmartcardReaderDiagnosis::run();
                         * @brief Runs the smartcard reader device diagnostic.
                         * @author Yadickson Soto
                         * @date 28/09/2012
                         */

                        virtual void run();

                        /**
                         * @fn virtual void SmartcardReaderDiagnosis::updateMessage();
                         * @brief Updates the status message of this diagnostic.
                         * @author Youssef.tourkmani
                         * @date 01/11/2012
                         */

                        virtual void updateMessage();

                    private:

                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
                };
            }
        }
    }
}

#endif /* SMARTCARDREADERDIAGNOSIS_HXX_ */
