/**
 * @file FileKeyLoginManager.hxx
 * @brief Declaration of the file key login manager class.
 * @date 23/05/2013
 * @author Yadickson Soto
 */

#ifndef FILEKEYLOGINMANAGER_HXX_
#define FILEKEYLOGINMANAGER_HXX_

#include <string>
#include <Voting/VotingCenters/voting-centers-schema.hxx>
#include <Runtime/Environment/saes-directories.h>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Operation
        {
            class InstallMachine;

            class FileKeyLoginManager
            {
                public:

                    FileKeyLoginManager();
                    virtual ~FileKeyLoginManager();

                    bool authentication ( std::string & password , std::string & code, std::string & rnd);

                    virtual bool isInstall();
                    virtual bool loadOfficialKey();
                    virtual bool loadRecountKey();

                protected:

                    friend class InstallMachine;

                    virtual void setMode ( const Smartmatic::SAES::Voting::VotingCenters::RunningMode & mode );
                    virtual Smartmatic::SAES::Voting::VotingCenters::RunningMode getMode ();
                    virtual bool loadKey ( std::string keyFile, std::string upKeyFile );

                private:

                    std::string password; ///< password of user
                    std::string codeOfVotingCenter; ///< code of voting center
                    std::string rnd; ///< rnd string use to generate salt
                    Smartmatic::SAES::Voting::VotingCenters::VotingCenter votingCenter; ///< The voting center
                    Smartmatic::SAES::Runtime::Environment::SaesDirectories * dir; ///< saes directories
                    static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
            };
        } /* namespace Operation */
    } /* namespace SAES */
} /* namespace Smartmatic */
#endif /* FILEKEYLOGINMANAGER_HXX_ */
