/**
 * @file VMachineInitiator.hxx
 * @brief Declaration of the VMachineInitiator class.
 * @author Youssef.tourkmani
 * @date 01/11/2012
 */

#ifndef _VMACHINE_INITIATOR_H_
#define _VMACHINE_INITIATOR_H_

#include "IMachineInitiator.hxx"

namespace Smartmatic
{
    namespace SAES
    {
        namespace Operation
        {
            namespace Initiator
            {

                class CheckDirectoryStructure;
                class CheckFilesPresence;
                class CheckResourceFiles;
            }
        }
    }
}

namespace Smartmatic
{
    namespace SAES
    {
        namespace Operation
        {
            namespace Initiator
            {
                /**
                 * @class VMachineInitiator
                 * @brief Represents a voting machine initiator.
                 * @author Yadickson Soto &lt;yadickson.soto@smartmatic.com&gt;
                 * @date 03-03-2011
                 */

                class VMachineInitiator: public IMachineInitiator
                {

                    public:

                        /**
                         * @fn VMachineInitiator::VMachineInitiator ();
                         * @brief Default constructor for the VMachineInitiator class.
                         * @author Yadickson Soto &lt;yadickson.soto@smartmatic.com&gt;
                         * @date 03-03-2011
                         */

                        VMachineInitiator ();

                        /**
                         * @fn virtual VMachineInitiator::~VMachineInitiator ();
                         * @brief Finalizes an instance of the VMachineInitiator class.
                         * @author Yadickson Soto &lt;yadickson.soto@smartmatic.com&gt;
                         * @date 03-03-2011
                         */

                        virtual ~VMachineInitiator ();

                        /**
                         * @fn virtual void VMachineInitiator::dispose();
                         * @brief Disposes an instance of the VMachineInitiator class.
                         * @author Yadickson Soto &lt;yadickson.soto@smartmatic.com&gt;
                         * @date 03-03-2011
                         */

                        virtual void dispose();

                        /**
                         * @fn virtual bool VMachineInitiator::checkData();
                         * @brief Verifies that the data on the internal and external storage devices is correct.
                         * @author Yadickson Soto yadickson.soto@smartmatic.com
                         * @date 25/05/2011
                         * @return true if the data in the internal and external storage devices is correct. Otherwise,
                         * false.
                         */

                        virtual bool checkData();

                        /**
                         * @fn virtual int VMachineInitiator::getSuccessMessageTime();
                         * @brief Gets success message time.
                         * @author Youssef.tourkmani
                         * @date 01/11/2012
                         * @return The success message time.
                         */

                        virtual int getSuccessMessageTime();

                    protected:

                        /**
                         * @fn virtual Smartmatic::Log::ISMTTLog * getLogger();
                         * @brief Getter logger class
                         * @author Yadickson Soto yadickson.soto@smartmatic.com
                         * @date 09/09/2013
                         * @return logger
                         */
                        virtual Smartmatic::Log::ISMTTLog * getLogger();

                    private:

                        /**
                         * @fn	    virtual void preStart ();
                         * @brief	Callback from thread before start thread.
                         * @author	Yadickson Soto
                         * @date	03/08/2015
                         */
                        virtual void preStart ();

                        /**
                         * @fn	    virtual bool process ();
                         * @brief	Callback from thread any time.
                         * @author	Yadickson Soto
                         * @date	03/08/2015
                         * @return true for continue thread
                         */
                        virtual bool process ();

                        /**
                         * @fn bool VMachineInitiator::CheckConfigurationLoad();
                         * @brief Verifies that the machine configuration was loaded correctly.
                         * @author Yadickson Soto &lt;yadickson.soto@smartmatic.com&gt;
                         * @date 03-03-2011
                         * @return true if the configuration was loaded correctly. Otherwise, false.
                         */

                        bool CheckConfigurationLoad();

                        /**
                         * @brief  Removes the audio voting voices if the polling place is not
                         * configured for audio voting.
                         * @author manuel.arguelles
                         * @date   Jan 30, 2018
                         */
                        void removeUnusedAudioVotingVoices();

                    private:

                        CheckDirectoryStructure * dirCondition; ///< Conditional iterator.
                        CheckFilesPresence * filesCondition; ///< Conditional iterator.
                        CheckResourceFiles * resourceFiles; ///< Conditional iterator.

                        static Smartmatic::Log::ISMTTLog * logger; ///< logger
                };
            }
        }
    }
}

#endif // _VMACHINE_INITIATOR_H_
