/**
 * @file InstallMachine.hxx
 * @brief Header class install machine
 * @date 18/10/2011
 * @author Yadickson Soto
 */

#ifndef INSTALLMACHINE_HXX_
#define INSTALLMACHINE_HXX_

#include <Runtime/Environment/SaesInstallDirectories.hxx>
#include <Operation/FileKeyLoginManager.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Operation
        {
            /**
             * @class	InstallMachine
             * @brief	Install machine.
             * @author	Youssef.tourkmani
             * @date	01/11/2012
             */
            class InstallMachine
            {
                public:
                    /**
                     * @fn	InstallMachine::InstallMachine ( );
                     * @brief	Constructor.
                     * @author	Youssef.tourkmani
                     * @date	01/11/2012
                     */
                    InstallMachine ();
                    /**
                     * @fn	virtual InstallMachine::~InstallMachine();
                     * @brief	Destructor.
                     * @author	Youssef.tourkmani
                     * @date	01/11/2012
                     */
                    virtual ~InstallMachine();

                    /**
                     * @fn	bool InstallMachine::authentication ( std::string & center, std::string & password,
                     * 			bool centerCaseSensitive, Smartmatic::SAES::Runtime::Environment::SaesDirectories * saesDir,
                     * 			Smartmatic::SAES::Runtime::Environment::SaesInstallDirectories * installDir );
                     * @brief	Method authentication machine.
                     * @author	Yadickson Soto yadickson.soto@smartmatic.com
                     * @date	18/10/2011
                     * @param	center	center
                     * @param [in,out]	password								The password.
                     * @param	centerCaseSensitive								true to center case sensitive.
                     * @param [in,out]	saesDir		saes directory pointer to SAESLocal
                     * @param [in,out]	installDir	saes directory pointer to SAES
                     * @return	true is success.
                     */
                    bool authentication (
                        std::string & center,
                        std::string & password,
                        bool centerCaseSensitive,
                        Smartmatic::SAES::Runtime::Environment::SaesDirectories * saesDir,
                        Smartmatic::SAES::Runtime::Environment::SaesInstallDirectories * installDir );

                    /**
                     * @fn	bool InstallMachine::install();
                     * @brief	Installs this object.
                     * @author	Youssef.tourkmani
                     * @date	01/11/2012
                     * @return	true if it succeeds, false if it fails.
                     */
                    bool install();

                private:

                    /**
                     * @fn	bool InstallMachine::loadConfig ();
                     * @brief	Loads a configuration.
                     * @author	Yadickson Soto
                     * @date	24/05/2013
                     * @return	true if it succeeds, false if it fails.
                     */
                    bool loadConfig();

                    FileKeyLoginManager fileKeyManger; ///< file key authentication manager
                    Smartmatic::SAES::Runtime::Environment::SaesDirectories * saesDir; ///< saes directory pointer to SAESLocal
                    Smartmatic::SAES::Runtime::Environment::SaesInstallDirectories * installDir; ///< saes directory pointer to SAES
                    static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
            };
        }
    }
}

#endif /* INSTALLMACHINE_HXX_ */
