/**
 * @file LoginKeyManager.cxx
 * @brief Body login key manager class
 * @date 18/05/2013
 * @author Yadickson Soto
 */

#include "LoginKeyManager.hxx"
#include <Security/Passphrase.hxx>
#include <System/IO/File.h>
#include <Operation/MachineOperationManager.hxx>

using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::System;
using namespace Smartmatic::System::IO;
using namespace Smartmatic::SAES::Common::Security;
using namespace Smartmatic::SAES::Common::Configuration;

LoginKeyManager * LoginKeyManager::instance = NULL;

LoginKeyManager::LoginKeyManager()
{

}

LoginKeyManager::~LoginKeyManager()
{
    instance = NULL;
}

bool LoginKeyManager::read ( std::string & pass )
{
    std::string file;
    SafeBuffer buffer;

    file = MachineOperationManager::getInstance()->getSaesDirectories()->getLoginKeyFileName ();

    return File::getInstance()->openFileToBuffer ( file, buffer ) && Passphrase::getInstance()->getDecryptPassphrase ( buffer, pass );
}

bool LoginKeyManager::write ( )
{
    SafeBuffer buffer;
    bool validate = Passphrase::getInstance()->getCryptoPassphrase ( buffer );

    if ( validate )
    {
        std::string fileDOM = MachineOperationManager::getInstance()->getSaesDirectories()->getLoginKeyFileName ( BasePathType::CONFIGURATION_DOM );
        std::string fileFlash = MachineOperationManager::getInstance()->getSaesDirectories()->getLoginKeyFileName ( BasePathType::CONFIGURATION_FLASH );

        validate = validate && File::getInstance()->saveBufferToFile ( buffer, fileDOM ) && File::getInstance()->saveBufferToFile ( buffer, fileFlash );
    }

    return validate;
}

void LoginKeyManager::clear ( )
{
    std::string fileDOM = MachineOperationManager::getInstance()->getSaesDirectories()->getLoginKeyFileName ( BasePathType::CONFIGURATION_DOM );
    std::string fileFlash = MachineOperationManager::getInstance()->getSaesDirectories()->getLoginKeyFileName ( BasePathType::CONFIGURATION_FLASH );

    File::getInstance()->DeleteFile ( fileDOM );
    File::getInstance()->DeleteFile ( fileFlash );
}

LoginKeyManager * LoginKeyManager::getInstance()
{

    if ( !instance )
    {
        instance = new LoginKeyManager();
    }

    return instance;
}
