/**
 * @file LoginKeyManager.hxx
 * @brief Header login key manager class
 * @date 18/05/2013
 * @author Yadickson Soto
 */

#ifndef LOGINKEYMANAGER_HXX_
#define LOGINKEYMANAGER_HXX_

#include <string>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Operation
        {
            /**
             * @class LoginKeyManager
             * @brief login manager to getter password from login key file
             * @date 18/05/2013
             * @author Yadickson Soto
             */
            class LoginKeyManager
            {
                private:
                    /**
                     * @fn LoginKeyManager();
                     * @brief Class constructor
                     * @date 18/05/2013
                     * @author Yadickson Soto
                     */
                    LoginKeyManager();

                    static LoginKeyManager * instance; ///< instance of class

                public:
                    /**
                     * @fn virtual ~LoginKeyManager();
                     * @brief Class destructor
                     * @date 18/05/2013
                     * @author Yadickson Soto
                     */
                    virtual ~LoginKeyManager();
                    /**
                     * @fn bool read ( std::string & pass );
                     * @brief Getter method: plain passphrase from login key file
                     * @date 18/05/2013
                     * @author Yadickson Soto
                     * @param pass password string result
                     * @return true is login key file is found
                     */
                    bool read ( std::string & pass );
                    /**
                     * @fn bool write ();
                     * @brief Save method: save crypto plain passphrase to login key file in both USB
                     * @date 18/05/2013
                     * @author Yadickson Soto
                     * @return true is login key file is write successfully
                     */
                    bool write ();
                    /**
                     * @fn void clear ();
                     * @brief Delete method: clear the login key files in both USB
                     * @date 18/05/2013
                     * @author Yadickson Soto
                     */
                    void clear ();
                    /**
                     * @fn static LoginKeyManager * getInstance();
                     * @brief Getter method: instance of the class
                     * @date 18/05/2013
                     * @author Yadickson Soto
                     * @return instance of the class
                     */
                    static LoginKeyManager * getInstance();
            };
        } /* namespace Operation */
    } /* namespace SAES */
} /* namespace Smartmatic */
#endif /* LOGINKEYMANAGER_HXX_ */
