/**
 * @file MachineDate.hxx
 * @brief Header date machine class
 * @date 20/09/2012
 * @author Yadickson Soto
 */

#ifndef MachineDate_HXX_
#define MachineDate_HXX_

#include <string>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Operation
        {
            /**
             * @class	MachineDate
             * @brief	machine date class.
             * @author	Yadickson Soto
             * @date	20/09/2012
             */
            class MachineDate
            {
                private:
                    /**
                     * @fn	MachineDate::MachineDate();
                     * @brief	Class constructor.
                     * @author	Yadickson Soto
                     * @date	20/09/2012
                     */
                    MachineDate();

                    static Smartmatic::Log::ISMTTLog * logger;  ///< The logger

                public:
                    /**
                     * @fn	virtual MachineDate::~MachineDate();
                     * @brief	Class destructorer.
                     * @author	Yadickson Soto
                     * @date	20/09/2012
                     */
                    virtual ~MachineDate();
                    /**
                     * @fn	static std::string MachineDate::getMachineDate();
                     * @brief	Returns the date stored in the DiagnosticDateFile.
                     * @author	Yadickson Soto
                     * @date	20/09/2012
                     * @return	A string containing the date in format mm/yyyy. If an empty string is returned then,
                     * 					the date could not be retrieved succesfuly.
                     */
                    static std::string getMachineDate();
                    /**
                     * @fn	static void MachineDate::setMachineDate ( std::string & date );
                     * @brief	Set the machine date.
                     * @author	Yadickson Soto
                     * @date	20/09/2012
                     * @param [in,out]	date	The date.
                     * ### param	A						string containing the date to be set in format mm/yyyy.
                     */
                    static void setMachineDate ( std::string & date );
            };
        }
    }
}
#endif /* MachineDate_HXX_ */
