/**
 * @file AlarmMonitor.cxx
 * @brief Implementation of the AlarmMonitor class.
 * @date 06/07/2015
 * @author Yadickson Soto
 */

#include "AlarmMonitor.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Operation/Devices/AlarmController.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

using namespace Smartmatic::SAES::Operation::Monitor;
using namespace Smartmatic::SAES::Operation::Devices;
using namespace Smartmatic::Log;

ISMTTLog * AlarmMonitor::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Operation.AlarmMonitor", GETTEXT_PACKAGE );

AlarmMonitor::AlarmMonitor()
    : DeviceTypeMonitor ( Smartmatic::SAES::Common::Configuration::DeviceType::CONFIGURATION_ALARMBOX )
{

}

AlarmMonitor::~AlarmMonitor()
{

}

void AlarmMonitor::added ( const std::string & node )
{
    logger->Debug ( "Added " + node );
    AlarmController::getInstance()->open ( node );
}

void AlarmMonitor::removed ( const std::string & node )
{
    logger->Debug ( "Removed " + node );
    AlarmController::getInstance()->close ();
}

std::string AlarmMonitor::getDeviceMounted ( const std::string & node, const std::string & customNode )
{
    return customNode;
}
