/**
 * @file BCRMonitor.hxx
 * @brief Declaration of the BCRMonitor class.
 * @date 12/12/2012
 * @author Yadickson Soto
 */

#ifndef BCRMONITOR_HXX_
#define BCRMONITOR_HXX_

#include <Operation/Monitor/DeviceTypeMonitor.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace SAES
    {
        namespace Operation
        {
            namespace Monitor
            {
                /**
                 * @class BCRMonitor
                 * @brief Represents a barcode reader device monitor.
                 * @date 12/12/2012
                 * @author Yadickson Soto
                 */
                class BCRMonitor : public Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor
                {
                    public:

                        /**
                         * @fn BCRMonitor();
                         * @brief Default constructor for the BCRMonitor class.
                         * @date 12/12/2012
                         * @author Yadickson Soto
                         */

                        BCRMonitor();

                        /**
                         * @fn virtual ~BCRMonitor();
                         * @brief Finalizes an instance of the BCRMonitor class.
                         * @date 12/12/2012
                         * @author Yadickson Soto
                         */

                        virtual ~BCRMonitor();

                        /**
                         * @fn	virtual void added ( const std::string & node );
                         * @brief	Notifies that a barcode reader device was added to the machine.
                         * @author	Yadickson Soto
                         * @date	09/04/2014
                         * @param 	node event device path
                         */
                        virtual void added ( const std::string & node );

                        /**
                         * @fn	virtual void removed ( const std::string & node );
                         * @brief	Notifies that a barcode reader device was removed from the machine.
                         * @author	Yadickson Soto
                         * @date	09/04/2014
                         * @param 	node event device path
                         */
                        virtual void removed ( const std::string & node );

                    protected:

                        /**
                         * @fn	virtual std::string getDeviceMounted ( const std::string & node, const std::string & customNode );
                         * @brief	Gets when device mounted.
                         * @author	Yadickson Soto
                         * @date	09/07/2015
                         * @param 	node the node to check
                         * @param	customNode the custom node to check device
                         * @return  path device mounted
                         */
                        virtual std::string getDeviceMounted ( const std::string & node, const std::string & customNode );

                    private:

                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
                };
            }
        }
    }
}
#endif /* BCRMONITOR_HXX_ */
