/**
 * @file EthernetMonitor.hxx
 * @brief Implementation the Ethernet Monitor class.
 * @date 07/04/2014
 * @author Yadickson Soto
 */

#ifndef ETHERNETMONITOR_HXX_
#define ETHERNETMONITOR_HXX_

#include <Operation/Monitor/DeviceTypeMonitor.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Operation
        {
            namespace Monitor
            {
                /**
                 * @class EthernetMonitor
                 * @brief Represents the Ethernet Monitor class.
                 * @date 07/04/2014
                 * @author Yadickson Soto
                 */
                class EthernetMonitor : public Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor
                {
                    public:

                        /**
                         * @fn EthernetMonitor();
                         * @brief Default constructor.
                         * @date 08/06/2015
                         * @author Yadickson Soto
                         */
                        EthernetMonitor ();

                        /**
                         * @fn virtual ~EthernetMonitor();
                         * @brief Default destructor.
                         * @date 07/04/2014
                         * @author Yadickson Soto
                         */
                        virtual ~EthernetMonitor();

                        /**
                         * @fn	virtual void added ( const std::string & node );
                         * @brief	Notifies that an ethernet device was added to the machine.
                         * @author	Yadickson Soto
                         * @date	09/04/2014
                         * @param 	node event device path
                         */
                        virtual void added ( const std::string & node );

                        /**
                         * @fn	virtual void removed ( const std::string & node );
                         * @brief	Notifies that an ethernet device was removed from the machine.
                         * @author	Yadickson Soto
                         * @date	09/04/2014
                         * @param 	node event device path
                         */
                        virtual void removed ( const std::string & node );

                        /**
                         * @fn virtual std::string getInterface();
                         * @brief Gets the ethernet device name.
                         * @author Yadickson Soto
                         * @date 02/06/2015
                         */
                        virtual std::string getInterface();

                    protected:

                        /**
                         * @fn	virtual std::string getDeviceMounted ( const std::string & node, const std::string & customNode );
                         * @brief	Gets when device mounted.
                         * @author	Yadickson Soto
                         * @date	09/07/2015
                         * @param 	node the node to check
                         * @param	customNode the custom node to check device
                         * @return  path device mounted
                         */
                        virtual std::string getDeviceMounted ( const std::string & node, const std::string & customNode );

                        /**
                         * @fn	virtual unsigned int getNumberOfDevices();
                         * @brief	Gets the current number of devices detected in the instance.
                         * @author	Yadickson Soto
                         * @date	04/06/2015
                         * @return	the amount of the devices monitored.
                         */
                        virtual unsigned int getNumberOfDevices();

                        /**
                         * @fn	virtual bool checkDeviceChanged();
                         * @brief	Check the cabled network connection.
                         * @author	Yadickson Soto
                         * @date	03/06/2015
                         * @return true if cable is plugged
                         */
                        virtual bool checkDeviceChanged ();

                    private:

                        std::string file; ///< The device path file
                        std::string interface; ///< The device name
                        unsigned int countDevices; ///< The count devices connected
                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
                };

            } /* namespace Monitor */
        } /* namespace Operation */
    } /* namespace SAES */
} /* namespace Smartmatic */

#endif /* ETHERNETMONITOR_HXX_ */
