/**
 * @file FlashMonitor.cxx
 * @brief Implementation of the FlashMonitor class.
 * @date 12/12/2012
 * @author Yadickson Soto
 */

#include "FlashMonitor.hxx"
#include <Operation/CheckDataManager.hxx>
#include <Runtime/Environment/MemoryPathController.h>
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <System/Runtime/ProcessLauncher.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

using namespace Smartmatic::SAES::Operation::Monitor;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Runtime::Environment;
using namespace Smartmatic::System::Runtime;
using namespace Smartmatic::SAES::Common::Configuration;

static useconds_t QUARTER_OF_SECOND = 250000;

ISMTTLog * FlashMonitor::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Operation.FlashMonitor", GETTEXT_PACKAGE );

static void manualMount(const std::string& device)
{
    std::string mountCommand = "udevil mount " + device;

    ProcessLauncher::getInstance()->RunProcessThroughPipe(mountCommand);
}

FlashMonitor::FlashMonitor()
    : DeviceTypeMonitor ( DeviceType::CONFIGURATION_FLASH )
{

}

FlashMonitor::~FlashMonitor()
{

}

void FlashMonitor::added ( const std::string & node )
{
    logger->Debug ( "Added " + node );

    MemoryPathController::getInstance()->addPath ( node );

    SMTTLogManager::getInstance()->shutdown();
    SMTTLogManager::getInstance()->Reconfigure();

    logger->Debug ( "Reconfigure logger" );

    CheckDataManager::getInstance()->checkInsertion( getNumberOfDevices() );
}

void FlashMonitor::removed ( const std::string & node )
{
    logger->Debug ( "Removed " + node );

    MemoryPathController::getInstance()->removePath ( node );

    SMTTLogManager::getInstance()->shutdown();
    SMTTLogManager::getInstance()->Reconfigure();
}

std::string FlashMonitor::getDeviceMounted ( const std::string & node, const std::string & customNode )
{
    std::string path = node;

    if ( !customNode.empty() && node != customNode )
    {
        for ( int i = 0; i < 240; ++i )
        {
            struct stat fileStats;
            std::list < std::string > list;

            if ( stat (node.c_str(), &fileStats) != 0 )
            {
                logger->Debug ( "Device " + node + " disconnected while being mounted." );
                break;
            }

            list = ProcessLauncher::getInstance()->RunProcessThroughPipe ( customNode );

            if ( !list.empty() )
            {
                std::string tmp = ( * list.begin() );

                if ( !tmp.empty() && tmp != node )
                {
                    path = tmp;
                    logger->Debug ( "Found path " + path );
                    break;
                }
            }
            else if (i > 200)
            {
                logger->Debug ( "Manually mounting device: " + node );
                manualMount ( node );
            }

            usleep ( QUARTER_OF_SECOND );
        }
    }

    return path;
}
