/**
 * @file FlashMonitor.hxx
 * @brief Declaration of the FlashMonitor class.
 * @date 12/12/2012
 * @author Yadickson Soto
 */

#ifndef FLASHMONITOR_HXX_
#define FLASHMONITOR_HXX_

#include <Operation/Monitor/DeviceTypeMonitor.hxx>
#include <glibmm.h>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Operation
        {
            namespace Monitor
            {
                /**
                 * @class FlashMonitor
                 * @brief Represents a monitor for the external storage device.
                 * @date 12/12/2012
                 * @author Yadickson Soto
                 */
                class FlashMonitor : public Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor
                {
                    public:

                        /**
                         * @fn FlashMonitor();
                         * @brief Default constructor for the FlashMonitor class.
                         * @date 12/12/2012
                         * @author Yadickson Soto
                         */

                        FlashMonitor();

                        /**
                         * @fn virtual ~FlashMonitor();
                         * @brief Finalizes an instance of the FlashMonitor class.
                         * @date 12/12/2012
                         * @author Yadickson Soto
                         */

                        virtual ~FlashMonitor();

                        /**
                         * @fn	virtual void added ( const std::string & node );
                         * @brief	Notifies that a external storage device was added to the machine.
                         * @author	Yadickson Soto
                         * @date	09/04/2014
                         * @param 	node event device path
                         */
                        virtual void added ( const std::string & node );

                        /**
                         * @fn	virtual void removed ( const std::string & node );
                         * @brief	Notifies that a external storage device was removed from the machine.
                         * @author	Yadickson Soto
                         * @date	09/04/2014
                         * @param 	node event device path
                         */
                        virtual void removed ( const std::string & node );

                    protected:

                        /**
                         * @fn	virtual std::string getDeviceMounted ( const std::string & node, const std::string & customNode );
                         * @brief	Gets when device mounted.
                         * @author	Yadickson Soto
                         * @date	09/07/2015
                         * @param 	node the node to check
                         * @param	customNode the custom node to check device
                         * @return  path device mounted
                         */
                        virtual std::string getDeviceMounted ( const std::string & node, const std::string & customNode );

                    private:

                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
                };
            }
        }
    }
}

#endif /* FLASHMONITOR_HXX_ */
