/**
 * @file SmartcardMonitor.hxx
 * @brief Declaration of the SmartcardMonitor class.
 * @date 12/12/2012
 * @author Yadickson Soto
 */

#ifndef SMARTCARDMONITOR_HXX_
#define SMARTCARDMONITOR_HXX_

#include <Operation/Monitor/DeviceTypeMonitor.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Operation
        {
            namespace Monitor
            {

                /**
                 * @class SmartcardMonitor
                 * @brief Represents a smartcard reader device monitor.
                 * @date 12/12/2012
                 * @author Yadickson Soto
                 */
                class SmartcardMonitor : public Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor
                {
                    public:

                        /**
                         * @fn SmartcardMonitor();
                         * @brief Constructor for the SmartcardMonitor class.
                         * @date 12/12/2012
                         * @author Yadickson Soto
                         */
                        SmartcardMonitor();

                        /**
                         * @fn virtual ~SmartcardMonitor();
                         * @brief Finalizes an instance of the SmartcardMonitor class.
                         * @date 12/12/2012
                         * @author Yadickson Soto
                         */
                        virtual ~SmartcardMonitor();

                        /**
                         * @fn	virtual void added ( const std::string & node );
                         * @brief	Notifies that a smartcard reader device was added to the machine.
                         * @author	Yadickson Soto
                         * @date	09/04/2014
                         * @param 	node event device path
                         */
                        virtual void added ( const std::string & node );

                        /**
                         * @fn	virtual void removed ( const std::string & node );
                         * @brief	Notifies that a smartcard reader device was removed from the machine.
                         * @author	Yadickson Soto
                         * @date	09/04/2014
                         * @param 	node event device path
                         */
                        virtual void removed ( const std::string & node );

                    protected:

                        /**
                         * @fn	virtual std::string getDeviceMounted ( const std::string & node, const std::string & customNode );
                         * @brief	Gets when device mounted.
                         * @author	Yadickson Soto
                         * @date	09/07/2015
                         * @param 	node the node to check
                         * @param	customNode the custom node to check device
                         * @return  path device mounted
                         */
                        virtual std::string getDeviceMounted ( const std::string & node, const std::string & customNode );

                    private:

                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
                };

            }
        }
    }
}

#endif /* SMARTCARDMONITOR_HXX_ */
