/**
 * @file PersistSortFile.hxx
 * @brief Header class persist votes sort
 * @date 24/08/2011
 * @author Yadickson Soto
 */

#ifndef PERSISTSORTFILE_HXX_
#define PERSISTSORTFILE_HXX_

#include <string>
#include <list>
#include <Configuration/SaesCommonConfiguration-schema.hxx>
#include <Runtime/Environment/saes-directories.h>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Operation
        {
            /**
             * @class	PersistSortFile
             * @brief	Class persist votes sort.
             * @author	Yadickson Soto
             * @date	24/08/2011
             */
            class PersistSortFile
            {
                public:
                    /**
                     * @fn	PersistSortFile::PersistSortFile ( Smartmatic::SAES::Common::Configuration::BasePathType type,
                     * 			std::string markFile, bool sortFile );
                     * @brief	Class constructor.
                     * @author	Yadickson Soto
                     * @date	24/08/2011
                     * @param	type			basse path type.
                     * @param	markFile	mark file name.
                     * @param	sortFile	flag config sort files.
                     */
                    PersistSortFile ( Smartmatic::SAES::Common::Configuration::BasePathType type,
                                      std::string markFile,
                                      bool sortFile );

                    /**
                     * @fn	virtual PersistSortFile::~PersistSortFile();
                     * @brief	Class destructor.
                     * @author	Yadickson Soto
                     * @date	24/08/2011
                     */
                    virtual ~PersistSortFile();

                    /**
                     * @fn	std::string PersistSortFile::getFolder();
                     * @brief	Method getter folder votes name.
                     * @author	Yadickson Soto
                     * @date	24/08/2011
                     * @return	folder name full path.
                     */
                    std::string getFolder();

                    /**
                     * @fn	std::string PersistSortFile::getMarkFile();
                     * @brief	Method getter mark file name.
                     * @author	Yadickson Soto
                     * @date	24/08/2011
                     * @return	mark file name full path.
                     */
                    std::string getMarkFile();

                    /**
                     * @fn	bool PersistSortFile::isSortFile();
                     * @brief	Method getter is sort file votes.
                     * @author	Yadickson Soto
                     * @date	24/08/2011
                     * @return	true is sort file votes.
                     */
                    bool isSortFile();

                    /**
                     * @fn	void PersistSortFile::updateDate ( const std::string& date );
                     * @brief	Method update date for votes.
                     * @author	Yadickson Soto
                     * @date	24/08/2011
                     * @param	date	new date config.
                     */
                    void updateDate ( const std::string& date );

                    /**
                     * @fn	void PersistSortFile::addFile ( std::string file );
                     * @brief	Method add new file to sort.
                     * @author	Yadickson Soto
                     * @date	24/08/2011
                     * @param	file	new file to sort.
                     */
                    void addFile ( std::string file );

                    /**
                     * @fn	void PersistSortFile::persistFiles();
                     * @brief	Method persist file list.
                     * @author	Yadickson Soto
                     * @date	24/08/2011
                     */
                    void persistFiles();

                    /**
                     * @fn	bool PersistSortFile::recoverVotes();
                     * @brief	Method recover votes.
                     * @author	Yadickson Soto
                     * @date	24/08/2011
                     * @return	true is validate recover votes.
                     */
                    bool recoverVotes();

                private:

                    /**
                     * @fn	std::string PersistSortFile::getListFile();
                     * @brief	Method getter file list to sort.
                     * @author	Yadickson Soto
                     * @date	24/08/2011
                     * @return	string file list to sort, separate with space " ".
                     */
                    std::string getListFile();

                    /**
                     * @fn	void PersistSortFile::getVoteFile ( std::list <std::string> & listTmp );
                     * @brief	Method getter only tmp vote files.
                     * @author	Yadickson Soto
                     * @date	24/08/2011
                     * @param	listTmp	list vote files.
                     */
                    void getVoteFile ( std::list <std::string> & listTmp );

                    /**
                     * @fn	void PersistSortFile::validateVotes ( std::list <std::string> & listTmp );
                     * @brief	Method validate vote files.
                     * @author	Yadickson Soto
                     * @date	24/08/2011
                     * @param	listTmp	list vote files.
                     */
                    void validateVotes ( std::list <std::string> & listTmp );

                    /**
                     * @fn	void PersistSortFile::renameVotes ( std::list <std::string> & listTmp );
                     * @brief	Method rename valid vote files.
                     * @author	Yadickson Soto
                     * @date	24/08/2011
                     * @param	listTmp	list vote files.
                     */
                    void renameVotes ( std::list <std::string> & listTmp );

                    Smartmatic::SAES::Common::Configuration::BasePathType type; ///< base path type
                    std::string markFile; ///< mark file name
                    std::string date; ///< date for votes

                    bool sortFile; ///< flag sort files
                    std::list <std::string> files; ///< file list to sort
                    Smartmatic::SAES::Runtime::Environment::SaesDirectories directories; ///< directories
                    static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
            };
        }
    }
}

#endif /* PERSISTSORTFILE_HXX_ */
