/**
 * @file PrinterDiagnoseStatus.hxx
 * @brief Represents a printer device diagnostic status.
 * @date 08/01/2014
 * @author Yadickson Soto
 */

#ifndef PRINTERDIAGNOSESTATUS_HXX_
#define PRINTERDIAGNOSESTATUS_HXX_

#include <Voting/Status/VMStatusWrapper.hxx>
#include <Printing/PrinterStatusNotifier.h>
#include <Printing/PrintDocumentResult.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Operation
        {
            namespace Printer
            {
                /**
                 * @class PrinterDiagnoseStatus
                 * @brief Represents a printer device diagnostic status.
                 * @author Yadickson Soto
                 * @date 08/01/2014
                 */
                class PrinterDiagnoseStatus
                {
                    public:
                        /**
                         * @fn PrinterDiagnoseStatus ( Smartmatic::SAES::Voting::Status::VotingMachineStatusWrapper * vmStatus );
                         * @brief Class constructor.
                         * @param vmStatus voting machine status object
                         * @author Yadickson Soto
                         * @date 08/01/2014
                         */
                        explicit PrinterDiagnoseStatus ( Smartmatic::SAES::Voting::Status::VotingMachineStatusWrapper * vmStatus );
                        /**
                         * @fn virtual ~PrinterDiagnoseStatus();
                         * @brief Class destructorer.
                         * @author Yadickson Soto
                         * @date 08/01/2014
                         */
                        virtual ~PrinterDiagnoseStatus();
                        /**
                         * @fn void addPrinterStatusNotifier ( Smartmatic::SAES::Printing::PrinterStatusNotifier::PhysicalStateEnumType status );
                         * @brief Add status before printing process
                         * @param status status before printing process
                         * @author Yadickson Soto
                         * @date 08/01/2014
                         */
                        void addPrinterStatusNotifier ( Smartmatic::SAES::Printing::PrinterStatusNotifier::PhysicalStateEnumType status );
                        /**
                         * @fn void addPrintDocumentResult ( Smartmatic::SAES::Printing::PrintDocumentResult::PrintingResultEnumType status );
                         * @brief Add status after printing process
                         * @param status status after printing process
                         * @author Yadickson Soto
                         * @date 08/01/2014
                         */
                        void addPrintDocumentResult ( Smartmatic::SAES::Printing::PrintDocumentResult::PrintingResultEnumType status );
                        /**
                         * @fn void clear();
                         * @brief Clear printer diagnose status
                         * @author Yadickson Soto
                         * @date 08/01/2014
                         */
                        void clear();

                    private:

                        Smartmatic::SAES::Voting::Status::VotingMachineStatusWrapper * vmStatus; ///< voting machine status object
                };
            }
        }
    }
}
#endif /* PRINTERDIAGNOSESTATUS_HXX_ */
