/**
 * @file   AbledController.cxx
 * @brief  Implementation of Abled controller class.
 * @author manuel.arguelles
 * @date   Dec 21, 2017
 */

#include "AbledController.hxx"
#include <Operation/AbleDButtonState.hxx>
#include <Operation/Devices/Polling/AbleDPolling.hxx>
#include <Operation/Devices/Polling/A4517AbleDPolling.hxx>

using namespace Smartmatic::SAES::HW::Operation;
using namespace Smartmatic::SAES::Operation::Devices;
using namespace Smartmatic::SAES::Operation::AudioVoting;

static const unsigned int ABLED_POLLING_MS = 100;

AbledController::AbledController()
{
    AbleDPolling::getInstance()->getSignalPressButton().connect(
        sigc::mem_fun(*this, &AbledController::onButtonPressed));

    A4517AbleDPolling::getInstance()->getSignalPressButton().connect(
        sigc::mem_fun(*this, &AbledController::onButtonPressed));
}

AbledController::~AbledController()
{
}

void AbledController::start()
{
    AbleDPolling::getInstance()->start(ABLED_POLLING_MS);
    A4517AbleDPolling::getInstance()->start(ABLED_POLLING_MS);
}

void AbledController::stop()
{
    AbleDPolling::getInstance()->stop();
    A4517AbleDPolling::getInstance()->stop();
}

AbledController::UpButtonSignal AbledController::signalUpButton()
{
    return m_signalUpButton;
}

AbledController::DownButtonSignal AbledController::signalDownButton()
{
    return m_signalDownButton;
}

AbledController::LeftButtonSignal AbledController::signalLeftButton()
{
    return m_signalLeftButton;
}

AbledController::RightButtonSignal AbledController::signalRightButton()
{
    return m_signalRightButton;
}

AbledController::SelectButtonSignal AbledController::signalSelectButton()
{
    return m_signalSelectButton;
}

AbledController::HelpButtonSignal AbledController::signalHelpButton()
{
    return m_signalHelpButton;
}

AbledController::SpeedUpButtonSignal AbledController::signalSpeedUpButton()
{
    return m_signalSpeedUpButton;
}

AbledController::SpeedDownButtonSignal AbledController::signalSpeedDownButton()
{
    return m_signalSpeedDownButton;
}

AbledController::VolumeUpButtonSignal AbledController::signalVolumeUpButton()
{
    return m_signalVolumeUpButton;
}

AbledController::VolumeDownButtonSignal AbledController::signalVolumeDownButton()
{
    return m_signalVolumeDownButton;
}

void AbledController::onButtonPressed(SAES::HW::Operation::AbleDButtonState* state)
{
    AbleDButtonState::ButtonState active = state->PRESS;

    if (state->getStatus(state->RIGHT) == active)
    {
        m_signalRightButton.emit();
    }
    else if (state->getStatus(state->LEFT) == active)
    {
        m_signalLeftButton.emit();
    }
    else if (state->getStatus(state->DOWN) == active)
    {
        m_signalDownButton.emit();
    }
    else if (state->getStatus(state->UP) == active)
    {
        m_signalUpButton.emit();
    }
    else if (state->getStatus(state->SELECT) == active)
    {
        m_signalSelectButton.emit();
    }
    else if (state->getStatus(state->HELP) == active)
    {
        m_signalHelpButton.emit();
    }
    else if (state->getStatus(state->SPEED_UP) == active)
    {
        m_signalSpeedUpButton.emit();
    }
    else if (state->getStatus(state->SPEED_DOWN) == active)
    {
        m_signalSpeedDownButton.emit();
    }
    else if (state->getStatus(state->VOLUME_UP) == active)
    {
        m_signalVolumeUpButton.emit();
    }
    else if (state->getStatus(state->VOLUME_DOWN) == active)
    {
        m_signalVolumeDownButton.emit();
    }
}
