/**
 * @file   AudioVotingCheckUtility.hxx
 * @brief  Declaration of Audio voting check utility.
 * @author marcel.mancini
 * @date   Jan 23, 2018
 */

#ifndef AUDIO_VOTING_CHECK_UTILITY_HXX
#define AUDIO_VOTING_CHECK_UTILITY_HXX

#include <sigc++/sigc++.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Operation
        {
            namespace AudioVoting
            {
                /**
                 * @class  AudioVotingCheckUtility
                 * @brief  Class to verify initial conditions for audio voting experience.
                 * @author manuel.arguelles
                 * @date   Dec 21, 2017
                 */
                class AudioVotingCheckUtility
                {
                    public:

                        enum ABLED_CONNECTED
                        {
                            ABLED10,
                            ABLED20
                        };

                    public:

                        /**
                         * @brief  Create an instance of the class
                         * @author Marcel Mancini
                         * @date   23/01/2018
                         */
                        AudioVotingCheckUtility();

                        /**
                         * @brief  Destroy an instance of the class.
                         * @author Marcel Mancini
                         * @date   23/01/2018
                         */
                        ~AudioVotingCheckUtility();

                    public:

                        /**
                         * @brief  verify if the polling place is configured for audio voting.
                         * @author Marcel Mancini
                         * @date   23/01/2018
                         */
                        bool pollingPlaceConfiguredForAudioVoting();

                        /**
                         * @brief  verify if the able is connected.
                         * @author Marcel Mancini
                         * @date   23/01/2018
                         * @param  ignoreCache True if a query must be done even when the
                         * serial is already known.
                         */
                        bool ableIsConnected(bool ignoreCache = false);

                        /**
                         * @brief  verify if the voices of audio voting are present.
                         * @author Marcel Mancini
                         * @date   23/01/2018
                         */
                        bool voicesArePresent();

                        /**
                         * @brief  Removes the voices directory.
                         * @author manuel.arguelles
                         * @date   Jan 30, 2018
                         * @return True if the operation was successful, false if not.
                         */
                        bool removeVoices();

                        /**
                         * @brief  Gets currently connected abled.
                         * @author eduardo.fernandez
                         * @date   Feb 1, 2018
                         * @return Enum value related to currently connected abled.
                         */
                        AudioVotingCheckUtility::ABLED_CONNECTED getAbledConnected();

                    private:

                        AudioVotingCheckUtility::ABLED_CONNECTED m_abledConnected;
                };

            } /* namespace AudioVoting */
        } /* namespace Operation */
    } /* namespace SAES */
} /* namespace Smartmatic */

#endif /* AUDIO_VOTING_CHECK_UTILITY_HXX */
