/**
 * @file   AudioVotingResources.cxx
 * @brief  Implementation of AudioVotingResources class.
 * Provides different resources according to the able device in use.
 * @author manuel.arguelles
 * @date   Apr 12, 2018
 */

#include "AudioVotingResources.hxx"
#include <Operation/MachineOperationManager.hxx>
#include <Resources/GeneralAudioResourcesManager.hxx>
#include <Resources/GeneralAudioResourcesManager.hxx>
#include <System/Utils/StringUtils.hxx>

using namespace Smartmatic::SAES::Operation::AudioVoting;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::Resources;
using namespace Smartmatic::System::Utils;

AudioVotingResources::AudioVotingResources()
    : m_abledCheckUtility(MachineOperationManager::getInstance()->getAudioVotingCheckUtility())
    , m_generalAudioResources(GeneralAudioResourcesManager::getInstance())
    , m_abledType(AudioVotingCheckUtility::ABLED10)
{
    if (m_abledCheckUtility.ableIsConnected())
    {
        m_abledType = m_abledCheckUtility.getAbledConnected();
    }
}

AudioVotingResources::~AudioVotingResources()
{
}

std::string AudioVotingResources::getResource(const std::string& key)
{
    std::string resource;
    std::string keyWithAbled;

    keyWithAbled = getKeyByAbled(key);

    resource = m_generalAudioResources->getResource(keyWithAbled);

    if (resource == keyWithAbled)
    {
        resource = m_generalAudioResources->getResource(key);
    }

    return resource;
}

std::string AudioVotingResources::getKeyByAbled(
    const std::string& key)
{
    std::string prefix = (m_abledType == AudioVotingCheckUtility::ABLED10 ? ".Able1" : ".Able2");

    return StringUtils::replaceLast(key, ".", prefix);
}
