/**
 * @file   TextToSpeechFactory.cxx
 * @brief  Implementation of TextToSpeechFactory class.
 * @author manuel.arguelles
 * @date   Oct 11, 2017
 */

#include "TextToSpeechFactory.hxx"
#include "AudioVotingCheckUtility.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Runtime/Environment/saes-directories.h>
#include <System/Audio/AudioPlayer.hxx>
#include <System/Audio/MixerControl.hxx>
#include <System/Audio/TextToSpeech/NuanceVocalizer.hxx>
#include <System/Exception/TextToSpeechException.hxx>
#include <string>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

static const std::string USB_SOUND_DEVICE      = "USB";
static const std::string BUILD_IN_SOUND_DEVICE = "HDA";

using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Operation::AudioVoting;
using namespace Smartmatic::SAES::Runtime::Environment;
using namespace Smartmatic::System::Audio::TextToSpeech;
using namespace Smartmatic::System::Audio;
using namespace Smartmatic::System::Exception;

ISMTTLog* TextToSpeechFactory::logger = SMTTLogManager::GetLogger(
    "Smartmatic.SAES.Voting.TextToSpeechFactory",
    GETTEXT_PACKAGE);

ITextToSpeech* TextToSpeechFactory::createTextToSpeech()
{
    NuanceVocalizer* textToSpeech = NULL;

    try
    {
        AudioVotingCheckUtility checkUtility;
        SaesDirectories         directories;
        std::string             voiceFolder = directories.getTextToSpeechVoicesFolderFullPath();
        std::string             playbackDevice;

        if (checkUtility.ableIsConnected() && checkUtility.getAbledConnected() == AudioVotingCheckUtility::ABLED20)
        {
            MixerControl mixer(USB_SOUND_DEVICE);
            playbackDevice = mixer.getPlaybackDeviceName();
        }
        else
        {
            MixerControl mixer(BUILD_IN_SOUND_DEVICE);
            playbackDevice = mixer.getPlaybackDeviceName();
        }

        IAudioPlayer* audioPlayer = new AudioPlayer(playbackDevice);
        textToSpeech = new NuanceVocalizer(voiceFolder, audioPlayer);
    }
    catch (const TextToSpeechException&)
    {
        logger->Debug(_("Error creating text to speech interface"));
    }

    return textToSpeech;
}
