/*
 * AfterScanningVoteComplianceVerificator.hxx
 *
 *  Created on: Feb 09, 2018
 *      Author: eduardo.fernandez
 */

#ifndef AFTER_SCANNING_VOTE_COMPLIANCE_VERIFICATOR_HXX
#define AFTER_SCANNING_VOTE_COMPLIANCE_VERIFICATOR_HXX

#include <string>
#include <list>
#include <vector>
#include <map>
#include <Log/ISMTTLog.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Voting
        {
            class ElectoralConfiguration;

            namespace Vote
            {
                class Vote;
                class Selection;
            }
        }

        namespace Operation
        {
            namespace VoteCompliance
            {
                class VoteComplianceVerificationManager;

                /**
                 * @class	AfterScanningVoteComplianceVerificator
                 * @brief	Header class BeforePrintingVoteComplianceVerificator.
                 * @author	eduardo.fernandez
                 * @date	Feb 09, 2018
                 */
                class AfterScanningVoteComplianceVerificator
                {
                    public:

                        /**
                         * @fn	AfterScanningVoteComplianceVerificator::AfterScanningVoteComplianceVerificator ( Smartmatic::SAES::Voting::ElectoralConfiguration * electoralConfiguration );
                         * @brief	Class constructor.
                         * @param	electoralConfiguration	electoral configuration.
                         * @author	eduardo.fernandez
                         * @date	Feb 09, 2018
                         */
                        explicit AfterScanningVoteComplianceVerificator(Smartmatic::SAES::Voting::ElectoralConfiguration * electoralConfiguration);

                        /**
                         * @fn	virtual AfterScanningVoteComplianceVerificator::~AfterScanningVoteComplianceVerificator();
                         * @brief	Finalizer.
                         * @author	eduardo.fernandez
                         * @date	Feb 09, 2018
                         */
                        virtual ~AfterScanningVoteComplianceVerificator();


                        /**
                         * @fn  bool AfterScanningVoteComplianceVerificator::checkMinimumNumberOfScannings(const Smartmatic::SAES::Voting::Vote::Vote &scannedVote);
                         * @brief    Checks minimum number of scannings in the given scanned vote.
                         * @param    scannedVote Scanned vote containing the voter selections.
                         * @return   Whether the scanned vote satisfies the minimum number of scannings.
                         * @author   eduardo.fernandez
                         * @date     Feb 09, 2018
                         */
                        bool checkMinimumNumberOfScannings(const Smartmatic::SAES::Voting::Vote::Vote &scannedVote);

                        /**
                         * @fn  bool AfterScanningVoteComplianceVerificator::checkScanningsBelongToSameParty(const Smartmatic::SAES::Voting::Vote::Vote &scannedVote);
                         * @brief    Checks whether the given scanned vote's selections belong to the same party.
                         * @param    scannedVote Scanned vote containing the voter selections.
                         * @return   Whether the given scanned vote's selections belong to the same party.
                         * @author   eduardo.fernandez
                         * @date     Feb 09, 2018
                         */
                        bool checkScanningsBelongToSameParty(const Smartmatic::SAES::Voting::Vote::Vote &scannedVote);

                        /**
                         * @fn  bool AfterScanningVoteComplianceVerificator::checkScanningsApplicableToConstituency(const Smartmatic::SAES::Voting::Vote::Vote &scannedVote);
                         * @brief    Checks whether the given scanned vote's selections' party belong to the same contest.
                         * @param    scannedVote Scanned vote containing the voter selections.
                         * @return   Whether the given scanned vote's selections' party belong to the same contest.
                         * @author   eduardo.fernandez
                         * @date     Feb 09, 2018
                         */
                        bool checkScanningsApplicableToConstituency(const Smartmatic::SAES::Voting::Vote::Vote &scannedVote);

                        /**
                         * @fn  bool AfterScanningVoteComplianceVerificator::checkUniquenessInScannings(const Smartmatic::SAES::Voting::Vote::Vote &scannedVote);
                         * @brief    Checks whether the given scanned vote's selections are unique qithin the vote.
                         * @param    scannedVote Scanned vote containing the voter selections.
                         * @return   Whether the given scanned vote's selections' party belong to the same contest.
                         * @author   eduardo.fernandez
                         * @date     Feb 09, 2018
                         */
                        bool checkUniquenessInScannings(const Smartmatic::SAES::Voting::Vote::Vote &scannedVote);

                        /**
                         * @fn  bool AfterScanningVoteComplianceVerificator::checkCumulativeNumberOfScannings(const Smartmatic::SAES::Voting::Vote::Vote &scannedVote);
                         * @brief    Checks whether the cumulative number of scanned candidates are less than or equal
                         *           to the number of candidates registered on the party.
                         * @param    scannedVote Scanned vote containing the voter selections.
                         * @return   Whether the cumulative number of scanned candidates are less than or equal
                         *           to the number of candidates registered on the party.
                         * @author   eduardo.fernandez
                         * @date     Feb 09, 2018
                         */
                        bool checkCumulativeNumberOfScannings(const Smartmatic::SAES::Voting::Vote::Vote &scannedVote);

                    private:

                        static Smartmatic::Log::ISMTTLog * m_logger;	///< the logger
                        VoteComplianceVerificationManager * m_voteComplianceVerificationManager;
                };
            }
        }
    }
}

#endif /* AFTER_SCANNING_VOTE_COMPLIANCE_VERIFICATOR_HXX */
