/*
 * BeforePrintingVoteComplianceVerificator.cxx
 *
 *  Created on: Feb 07, 2018
 *      Author: eduardo.fernandez
 */

#include "BeforePrintingVoteComplianceVerificator.hxx"

#include "VoteComplianceVerificationManager.hxx"
#include <Configuration/s-a-e-s-functionality-conf-manager.h>
#include <Log/SMTTLogManager.h>
#include <Resources/election-string-resources-manager.h>
#include <Voting/Election/election-schema.hxx>
#include <Voting/ElectoralConfiguration.hxx>
#include <Voting/Vote/vote-schema.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::Functionality::Configuration;
using namespace Smartmatic::SAES::Operation::VoteCompliance;
using namespace Smartmatic::SAES::Resources;
using namespace Smartmatic::SAES::Voting::Election;
using namespace Smartmatic::SAES::Voting;
using namespace Smartmatic::Log;

ISMTTLog * BeforePrintingVoteComplianceVerificator::m_logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Operation.Voting.BeforePrintingVoteComplianceVerificator", GETTEXT_PACKAGE );

BeforePrintingVoteComplianceVerificator::BeforePrintingVoteComplianceVerificator ( ElectoralConfiguration *electoralConfiguration )
: m_voteComplianceVerificationManager(new VoteComplianceVerificationManager(electoralConfiguration))
{
}

BeforePrintingVoteComplianceVerificator::~BeforePrintingVoteComplianceVerificator()
{
}

bool BeforePrintingVoteComplianceVerificator::checkMinimumNumberOfSelections(const Vote::Vote &vote)
{
    bool success = true;

    if (SAESFunctionalityConfigurationManager::getInstance()->getBeforePrintingVoteComplianceVerificationConfiguration().getCheckMinimumNumberOfSelections())
    {
        success = m_voteComplianceVerificationManager->checkMinimumNumberOfSelections(vote);
    }

    return success;
}

bool BeforePrintingVoteComplianceVerificator::checkSelectionsBelongToSameParty(const Vote::Vote &vote)
{
    bool success = true;

    if (SAESFunctionalityConfigurationManager::getInstance()->getBeforePrintingVoteComplianceVerificationConfiguration().getCheckSelectionsBelongToSameParty())
    {
        success = m_voteComplianceVerificationManager->checkSelectionsBelongToSameParty(vote);
    }

    return success;
}

bool BeforePrintingVoteComplianceVerificator::checkSelectionsApplicableToConstituency(const Vote::Vote &vote)
{
    bool success = true;

    if (SAESFunctionalityConfigurationManager::getInstance()->getBeforePrintingVoteComplianceVerificationConfiguration().getCheckSelectionsApplicableToConstituency())
    {
        success = m_voteComplianceVerificationManager->checkSelectionsApplicableToConstituency(vote);
    }

    return success;
}

bool BeforePrintingVoteComplianceVerificator::checkUniquenessInSelections(const Vote::Vote &vote)
{
    bool success = true;

    if (SAESFunctionalityConfigurationManager::getInstance()->getBeforePrintingVoteComplianceVerificationConfiguration().getCheckUniquenessInSelections())
    {
        success = m_voteComplianceVerificationManager->checkUniquenessInSelections(vote);
    }

    return success;
}

bool BeforePrintingVoteComplianceVerificator::checkListHeaderResourceCorrectness(
    const Smartmatic::SAES::Voting::Vote::Vote &vote,
    std::map < std::string, std::map < std::string, std::string > > textToPrintMap)
{
    bool success = true;

    if (SAESFunctionalityConfigurationManager::getInstance()->getBeforePrintingVoteComplianceVerificationConfiguration().getCheckListHeaderResourceCorrectness())
    {
        success = m_voteComplianceVerificationManager->checkListHeaderResourceCorrectness(vote, textToPrintMap);
    }

    return success;
}

bool BeforePrintingVoteComplianceVerificator::checkCumulativeNumberOfSelections(const Vote::Vote &vote)
{
    bool success = true;

    if (SAESFunctionalityConfigurationManager::getInstance()->getBeforePrintingVoteComplianceVerificationConfiguration().getCheckCumulativeNumberOfSelections())
    {
        success = m_voteComplianceVerificationManager->checkCumulativeNumberOfSelections(vote);
    }

    return success;
}
