/**
 * @file	VotingState.cxx
 * @brief	voting state class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */

#include "VotingState.hxx"

using namespace Smartmatic::SAES::Operation::Voting;

VotingState::VotingState ( std::string code, std::string value, VotingState::TypeResponse response )
{
    this->code = code;
    this->value = value;
    this->response = response;
}

std::string VotingState::getCode()
{
    return code;
}

std::string VotingState::getValue()
{
    return value;
}

VotingState::TypeResponse VotingState::getResponse()
{
    return response;
}

void VotingState::addBallotOption ( const std::string& contestCode, const std::string& partyCode, const std::string& ballotOptionCode )
{
    ( mapContest[ contestCode ] ) [ partyCode ].remove ( ballotOptionCode );
    ( mapContest[ contestCode ] ) [ partyCode ].push_back ( ballotOptionCode );
}

void VotingState::removeContest ( const std::string& contestCode )
{
    mapContest.erase ( contestCode );
}

void VotingState::removeAllContest ()
{
    mapContest.clear();
}

void VotingState::removePartyByContest ( const std::string& contestCode, const std::string& partyCode )
{
    ( mapContest[ contestCode ] ).erase ( partyCode );
}

void VotingState::removeBallotOption ( const std::string& contestCode, const std::string& partyCode, const std::string& ballotOptionCode )
{
    ( mapContest[ contestCode ] ) [ partyCode ].remove ( ballotOptionCode );
}

void VotingState::addContestByContestGroup ( const std::string& contestGroupCode, const std::string& contestCode )
{
    ( mapContestGroup[ contestGroupCode ] ).remove ( contestCode );
    ( mapContestGroup[ contestGroupCode ] ).push_back ( contestCode );
}

void VotingState::removeContestByContestGroup ( const std::string& contestGroupCode, const std::string& contestCode )
{
    ( mapContestGroup[ contestGroupCode ] ).remove ( contestCode );
}

void VotingState::removeContestGroup ( const std::string& contestGroupCode )
{
    mapContestGroup.erase ( mapContestGroup.find ( contestGroupCode ) );
}

void VotingState::setLogicalVoterGroups ( ListLogicalVoterGroup logicalVoterGroups )
{
    this->logicalVoterGroups = logicalVoterGroups;
}

void VotingState::setCustomAttributeDefinitions ( const ListCustomAttributeDefinition& customAttributeDefinitions )
{
    this->customAttributeDefinitions = customAttributeDefinitions;
}

std::list < std::string > VotingState::getContests ()
{
    std::list < std::string > list;

    if ( mapContest.empty() )
    {
        return list;
    }

    MapContest::const_iterator it;

    for ( it = mapContest.begin(); it != mapContest.end(); ++it )
    {
        list.push_back ( it->first );
    }

    return list;
}

std::list < std::string > VotingState::getPartys ( const std::string& contestCode )
{
    std::list < std::string > list;

    if ( mapContest.empty() || mapContest.find ( contestCode ) == mapContest.end() )
    {
        return list;
    }

    MapList::const_iterator it;
    MapList temp = mapContest[ contestCode ];

    for ( it = temp.begin(); it != temp.end(); ++it )
    {
        list.push_back ( it->first );
    }

    return list;
}

std::list < std::string > VotingState::getBallotOptions (const std::string& contestCode,
                                                         const std::string& partyCode )
{
    ( ( mapContest[ contestCode ] ) [ partyCode ] ).sort();
    return ( mapContest[ contestCode ] ) [ partyCode ];
}

std::list < std::string > VotingState::getContestGroups ()
{
    MapList::const_iterator it;
    std::list < std::string > list;

    if ( mapContestGroup.empty() )
    {
        return list;
    }

    for ( it = mapContestGroup.begin(); it != mapContestGroup.end(); ++it )
    {
        list.push_back ( it->first );
    }

    return list;
}

std::list < std::string > VotingState::getContestsByContestGroup ( const std::string& contestGroupCode )
{
    return mapContestGroup[ contestGroupCode ];
}

std::list < std::string > VotingState::getAllContestsByContestGroup ()
{
    std::list < std::string > list;
    std::list < std::string > listContestGroup = getContestGroups ();
    std::list < std::string >::const_iterator it;

    for ( it = listContestGroup.begin(); it != listContestGroup.end(); ++it )
    {
        std::list < std::string > listC = getContestsByContestGroup ( *it );
        std::list < std::string >::iterator itC;

        for ( itC = listC.begin(); itC != listC.end(); ++itC )
        {
            list.remove ( ( *itC ) );
            list.push_back ( ( *itC ) );
        }
    }

    return list;
}

VotingState::ListLogicalVoterGroup VotingState::getLogicalVoterGroups ()
{
    return logicalVoterGroups;
}

VotingState::ListCustomAttributeDefinition VotingState::getCustomAttributeDefinitions ()
{
    return customAttributeDefinitions;
}

void VotingState::setContestByContestClass ( const std::list <std::string>& contest )
{
    this->contestByContestClass = contest;
}

std::list <std::string> VotingState::getContestByContestClass()
{
    return contestByContestClass;
}
