/**
 * @file ZipCodeManager.cxx
 * @brief Body serial machine class
 * @date 27/09/2012
 * @author Yadickson Soto
 */

#include "ZipCodeManager.hxx"
#include "MachineOperationManager.hxx"
#include <Log/SMTTLogManager.h>
#include <System/IO/File.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::Log;
using namespace Smartmatic::System::IO;
using namespace Smartmatic::SAES::Common::Configuration;
using namespace Smartmatic::System;

ISMTTLog * ZipCodeManager::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Operation.ZipCodeManager", GETTEXT_PACKAGE );
std::string ZipCodeManager::m_zipCode = "";

ZipCodeManager::ZipCodeManager()
{
}

ZipCodeManager::~ZipCodeManager()
{
}

std::string ZipCodeManager::getZipCode()
{
    std::string zipCode = m_zipCode;

    if (zipCode.empty())
    {
        Smartmatic::SAES::Runtime::Environment::SaesDirectories directories;
        std::string domPath = directories.getZipCodeFileFullPath();
        std::string flashPath = directories.getZipCodeFileFullPath ( BasePathType::CONFIGURATION_FLASH );
        std::string backupPath = directories.getZipCodeFileFullPath ( BasePathType::CONFIGURATION_BACKUP );

        File::getInstance()->readFile ( domPath, zipCode ) ||
            File::getInstance()->readFile ( flashPath, zipCode ) ||
            File::getInstance()->readFile ( backupPath, zipCode );
    }

    logger->Debug ( "Get zip code : " + zipCode );

    return zipCode;
}

void ZipCodeManager::setZipCode ( const std::string & zipCode, bool save )
{
    if ( save )
    {
        SafeBuffer buffer ( zipCode );
        Smartmatic::SAES::Runtime::Environment::SaesDirectories directories;
        std::string domPath = directories.getZipCodeFileFullPath();
        std::string flashPath = directories.getZipCodeFileFullPath ( BasePathType::CONFIGURATION_FLASH );
        std::string backupPath = directories.getZipCodeFileFullPath ( BasePathType::CONFIGURATION_BACKUP );

        File::getInstance()->saveBufferToFile ( buffer, domPath );
        File::getInstance()->saveBufferToFile ( buffer, flashPath );
        File::getInstance()->saveBufferToFile ( buffer, backupPath );
    }

    m_zipCode = zipCode;
    MachineOperationManager::getInstance()->getOperationStatus()->getVotingMachineStatusWrapper()->setZipCode ( zipCode );
}

