/**
 * @file ZipCodeManager.hxx
 * @brief Header zip code class
 * @date 27/09/2012
 * @author Yadickson Soto
 */

#ifndef ZIPCODEMANAGER_HXX_
#define ZIPCODEMANAGER_HXX_

#include <string>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace SAES
    {
        namespace Operation
        {
            /**
             * @class	ZipCodeManager
             * @brief	zip code class.
             * @author	Yadickson Soto
             * @date	27/09/2012
             */
            class ZipCodeManager
            {
                private:
                    /**
                     * @fn	ZipCodeManager::ZipCodeManager();
                     * @brief	Class constructor.
                     * @author	Yadickson Soto
                     * @date	27/09/2012
                     */
                    ZipCodeManager();

                    static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
                    static std::string m_zipCode;

                public:
                    /**
                     * @fn	virtual ZipCodeManager::~ZipCodeManager();
                     * @brief	Class destructor.
                     * @author	Yadickson Soto
                     * @date	27/09/2012
                     */
                    virtual ~ZipCodeManager();
                    /**
                     * @fn	static std::string ZipCodeManager::getZipCode();
                     * @brief	Method getter zip code.
                     * @author	Yadickson Soto
                     * @date	27/09/2012
                     * @return	zip code.
                     */
                    static std::string getZipCode();
                    /**
                     * @fn	static void ZipCodeManager::setZipCode ( const std::string & zipCode, bool save = true );
                     * @brief	Method setter zip code.
                     * @author	Yadickson Soto
                     * @date	27/09/2012
                     * @param	zipCode	zip code.
                     * @param	save	 	save is true.
                     */
                    static void setZipCode ( const std::string & zipCode, bool save = true );
            };
        }
    }
}

#endif /* ZIPCODEMANAGER_HXX_ */

