#ifndef TEST_ALARMS_CONF_MANAGER_TEST
#define TEST_ALARMS_CONF_MANAGER_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <tests/MockAlarmConfigurationManager.hxx>
#include <tests/MockSaesFunctionalityConfigurationManager.hxx>
#include <tests/MockConfigurationPersistenceManager.hxx>
#include <tests/MockProcessLauncher.hxx>
#include <tests/MockExitProcess.hxx>

class AlarmConfigurationManagerTest : public CPPUNIT_NS::TestFixture
{
    public:

        typedef Smartmatic::SAES::Functionality::Configuration::AlarmConfigurationManager AlarmConfigurationManager;
        typedef Smartmatic::SAES::Functionality::Configuration::AlarmCategoryEnum AlarmCategoryEnum;
        typedef Smartmatic::SAES::Functionality::Configuration::AlarmBehaviorEnum AlarmBehaviorEnum;
        typedef Smartmatic::SAES::Functionality::Configuration::AlarmsConfiguration AlarmsConfiguration;
        typedef Smartmatic::SAES::Functionality::Configuration::Alarm Alarm;
        typedef Smartmatic::SAES::Functionality::Configuration::AlarmEnum AlarmEnum;
        typedef Smartmatic::SAES::Functionality::Configuration::AlarmCommand AlarmCommand;
        typedef Smartmatic::SAES::Functionality::Configuration::AlarmCommandEnum AlarmCommandEnum;
        typedef Smartmatic::SAES::Functionality::Configuration::SAESFunctionalityConfigurationManager SAESFunctionalityConfigurationManager;
        typedef Smartmatic::SAES::Functionality::Configuration::PrinterControllerConfiguration PrinterControllerConfiguration;
        typedef Smartmatic::Configuration::ConfigurationPersistenceManager ConfigurationPersistenceManager;
        typedef Smartmatic::System::Runtime::ProcessLauncher ProcessLauncher;
        typedef Smartmatic::System::Runtime::ExitProcess ExitProcess;

        AlarmConfigurationManagerTest()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testGetDefaultConfiguration_ConfigurationIsEmpty()
        {
            MockConfigurationPersistenceManager manager;
            MockProcessLauncher launcher;
            MockExitProcess exitProcess;
            MockSaesFunctionalityConfigurationManager saesfunctionalityManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &manager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() )
            .will ( MOCKPP_NS::returnValue<int> ( 0 ) );

            MOCKPP_CHAINER_FOR ( MockExitProcess, exitProcess ) exitProcess_mock ( &exitProcess );

            exitProcess_mock
            .expects ( MOCKPP_NS::never() );

            ExitProcess::getInstance ( &exitProcess );
            ProcessLauncher::getInstance ( &launcher );
            ConfigurationPersistenceManager::getInstance ( &manager );
            SAESFunctionalityConfigurationManager::getInstance ( &saesfunctionalityManager );

            SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->getAlarmsConfiguration().reset();

            AlarmConfigurationManager * alarmManager = AlarmConfigurationManager::getInstance();

            CPPUNIT_ASSERT ( true == alarmManager->getCommandsOfAlarm ( "dummy" ).empty() );
            CPPUNIT_ASSERT ( AlarmCategoryEnum::CONFIGURATION_CRITICALALARM == alarmManager->getCategoryOfAlarm ( "dummy" ) );
            CPPUNIT_ASSERT ( AlarmBehaviorEnum::CONFIGURATION_GOAUTHENTICATION == alarmManager->getBehaviorOfAlarm ( "dummy" ) );

            manager.verify();
            launcher.verify();
            exitProcess.verify();

            delete alarmManager;
        }

        void testGetDefaultConfiguration_MockConfigurationIsEmpty()
        {
            MockAlarmConfigurationManager mock;
            AlarmConfigurationManager * alarmManager = AlarmConfigurationManager::getInstance ( &mock );

            CPPUNIT_ASSERT ( true == alarmManager->getCommandsOfAlarm ( "dummy" ).empty() );
            CPPUNIT_ASSERT ( AlarmCategoryEnum::CONFIGURATION_CRITICALALARM == alarmManager->getCategoryOfAlarm ( "dummy" ) );
            CPPUNIT_ASSERT ( AlarmBehaviorEnum::CONFIGURATION_GOAUTHENTICATION == alarmManager->getBehaviorOfAlarm ( "dummy" ) );
        }

        void testGetConfigurationValues()
        {
            MockAlarmConfigurationManager mock;
            AlarmConfigurationManager * alarmManager = AlarmConfigurationManager::getInstance ( &mock );

            AlarmsConfiguration::AlarmSequence seq;

            Alarm alarm ( AlarmCategoryEnum::CONFIGURATION_NOTALARM, AlarmBehaviorEnum::CONFIGURATION_WAIT, AlarmEnum::CONFIGURATION_CARDUSED );
            Alarm::AlarmCommandsSequence commands;
            AlarmCommand command ( AlarmCommandEnum::CONFIGURATION_BUZZER, 10, false );

            commands.push_back ( command );
            alarm.setAlarmCommands ( commands );

            seq.push_back ( alarm );

            mock.config.setAlarm ( seq );

            CPPUNIT_ASSERT ( true == alarmManager->getCommandsOfAlarm ( "dummy" ).empty() );
            CPPUNIT_ASSERT ( AlarmCategoryEnum::CONFIGURATION_CRITICALALARM == alarmManager->getCategoryOfAlarm ( "dummy" ) );
            CPPUNIT_ASSERT ( AlarmBehaviorEnum::CONFIGURATION_GOAUTHENTICATION == alarmManager->getBehaviorOfAlarm ( "dummy" ) );

            CPPUNIT_ASSERT ( 1 == alarmManager->getCommandsOfAlarm ( AlarmEnum::CONFIGURATION_CARDUSED ).size() );
            CPPUNIT_ASSERT ( AlarmCategoryEnum::CONFIGURATION_NOTALARM == alarmManager->getCategoryOfAlarm ( AlarmEnum::CONFIGURATION_CARDUSED ) );
            CPPUNIT_ASSERT ( AlarmBehaviorEnum::CONFIGURATION_WAIT == alarmManager->getBehaviorOfAlarm ( AlarmEnum::CONFIGURATION_CARDUSED ) );
        }

        CPPUNIT_TEST_SUITE ( AlarmConfigurationManagerTest );

        CPPUNIT_TEST ( testGetDefaultConfiguration_ConfigurationIsEmpty );
        CPPUNIT_TEST ( testGetDefaultConfiguration_MockConfigurationIsEmpty );
        CPPUNIT_TEST ( testGetConfigurationValues );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_ALARMS_CONF_MANAGER_TEST */
