/**
 * @file MockCardController.hxx
 * @date 28/05/2014
 * @author Yadickson Soto
 */

#ifndef MOCK_CARD_CONTROLLER_HXX_
#define MOCK_CARD_CONTROLLER_HXX_

#include <mockpp/mockpp.h>
#include <mockpp/chaining/ChainableMockObject.h>
#include <mockpp/chaining/ChainingMockObjectSupport.h>

#include <Operation/Devices/CardController.hxx>
#include <Operation/Security/CryptoSmartcard.hxx>

class MockCardController : public Smartmatic::SAES::Operation::Devices::CardController,
    public MOCKPP_NS::ChainableMockObject
{

    private:

        Smartmatic::System::SafeBuffer bufferWrite;

    public:
        MockCardController ( Smartmatic::SAES::Card::SmartcardInterface * smartcard = NULL )
            : Smartmatic::SAES::Operation::Devices::CardController ( smartcard )
            , MOCKPP_NS::ChainableMockObject ( MOCKPP_PCHAR ( "MockCardController" ), 0 )
            , MOCKPP_CONSTRUCT_MEMBERS_FOR_CHAINABLE_EXT1 ( open, ext )
            , MOCKPP_CONSTRUCT_MEMBERS_FOR_CHAINABLE0 ( test )
            , MOCKPP_CONSTRUCT_MEMBERS_FOR_CHAINABLE0 ( close )
            , MOCKPP_CONSTRUCT_MEMBERS_FOR_CHAINABLE0 ( isCardPresent )
        {

        }

        MOCKPP_CHAINABLE_EXT1 ( MockCardController,
                                bool, open, const std::string &,
                                bool, ext, const std::string * );

        MOCKPP_CHAINABLE0 ( MockCardController, bool, test );
        MOCKPP_CHAINABLE0 ( MockCardController, bool, close );
        MOCKPP_CHAINABLE0 ( MockCardController, bool, isCardPresent );

        virtual bool read ( Smartmatic::System::SafeBuffer & buffer, Smartmatic::SAES::Security::CryptoData & cryptoData )
        {
            buffer.Clear();
            buffer.AddData ( bufferWrite );
            return true;
        }

        virtual bool write ( Smartmatic::System::SafeBuffer & buffer, Smartmatic::SAES::Security::CryptoData & cryptoData )
        {
            bufferWrite.Clear();
            bufferWrite.AddData ( buffer );
            return true;
        }
};


#endif /* MOCK_CARD_CONTROLLER_HXX_ */
