#ifndef TEST_CALIBRATION_DIAGNOSIS_TEST
#define TEST_CALIBRATION_DIAGNOSIS_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include "ChainMockCalibrationDiagnosis.hxx"

class CalibrationDiagnosisTest : public CPPUNIT_NS::TestFixture
{

    public:

        CalibrationDiagnosisTest ()
        {
        }

        void setUp()
        {
        }

        void tearDown()
        {
        }

        void test_NotPenmountFile_SkipFalse_ExecuteFalse()
        {
            ChainMockCalibrationDiagnosis mockConfig ( false );

            MOCKPP_CHAINER_FOR ( ChainMockCalibrationDiagnosis, getPenmountFileConditional ) getPenmountFileConditional_mock ( &mockConfig );
            MOCKPP_CHAINER_FOR ( ChainMockCalibrationDiagnosis, getSkipCalibrationToolConditional ) getSkipCalibrationToolConditional_mock ( &mockConfig );
            MOCKPP_CHAINER_FOR ( ChainMockCalibrationDiagnosis, executeCalibrationTool ) executeCalibrationTool_mock ( &mockConfig );

            getPenmountFileConditional_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue ( false ) )
            .id ( MOCKPP_PCHAR ( "getPenmountFileConditional" ) );

            getSkipCalibrationToolConditional_mock
            .expects ( MOCKPP_NS::never() )
            .will ( MOCKPP_NS::returnValue ( false ) )
            .id ( MOCKPP_PCHAR ( "getSkipCalibrationToolConditional" ) );

            executeCalibrationTool_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue ( false ) )
            .id ( MOCKPP_PCHAR ( "executeCalibrationTool" ) );

            CPPUNIT_ASSERT ( false == mockConfig.calibrationTool() );

            mockConfig.verify();
        }

        void test_NotPenmountFile_SkipFalse_ExecuteTrue()
        {
            ChainMockCalibrationDiagnosis mockConfig ( false );

            MOCKPP_CHAINER_FOR ( ChainMockCalibrationDiagnosis, getPenmountFileConditional ) getPenmountFileConditional_mock ( &mockConfig );
            MOCKPP_CHAINER_FOR ( ChainMockCalibrationDiagnosis, getSkipCalibrationToolConditional ) getSkipCalibrationToolConditional_mock ( &mockConfig );
            MOCKPP_CHAINER_FOR ( ChainMockCalibrationDiagnosis, executeCalibrationTool ) executeCalibrationTool_mock ( &mockConfig );

            getPenmountFileConditional_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue ( false ) )
            .id ( MOCKPP_PCHAR ( "getPenmountFileConditional" ) );

            getSkipCalibrationToolConditional_mock
            .expects ( MOCKPP_NS::never() )
            .will ( MOCKPP_NS::returnValue ( false ) )
            .id ( MOCKPP_PCHAR ( "getSkipCalibrationToolConditional" ) );

            executeCalibrationTool_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue ( true ) )
            .id ( MOCKPP_PCHAR ( "executeCalibrationTool" ) );

            CPPUNIT_ASSERT ( true == mockConfig.calibrationTool() );

            mockConfig.verify();
        }

        void test_NotPenmountFile_SkipTrue_NotSkipCalibrationFile_File_ExecuteTrue()
        {
            ChainMockCalibrationDiagnosis mockConfig ( true );

            MOCKPP_CHAINER_FOR ( ChainMockCalibrationDiagnosis, getPenmountFileConditional ) getPenmountFileConditional_mock ( &mockConfig );
            MOCKPP_CHAINER_FOR ( ChainMockCalibrationDiagnosis, getSkipCalibrationToolConditional ) getSkipCalibrationToolConditional_mock ( &mockConfig );
            MOCKPP_CHAINER_FOR ( ChainMockCalibrationDiagnosis, executeCalibrationTool ) executeCalibrationTool_mock ( &mockConfig );

            getPenmountFileConditional_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue ( false ) )
            .id ( MOCKPP_PCHAR ( "getPenmountFileConditional" ) );

            getSkipCalibrationToolConditional_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue ( false ) )
            .id ( MOCKPP_PCHAR ( "getSkipCalibrationToolConditional" ) );

            executeCalibrationTool_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue ( true ) )
            .id ( MOCKPP_PCHAR ( "executeCalibrationTool" ) );

            CPPUNIT_ASSERT ( true == mockConfig.calibrationTool() );

            mockConfig.verify();
        }

        void test_NotPenmountFile_SkipTrue_PresentSkipCalibrationFile_File_ExecuteTrue()
        {
            ChainMockCalibrationDiagnosis mockConfig ( true );

            MOCKPP_CHAINER_FOR ( ChainMockCalibrationDiagnosis, getPenmountFileConditional ) getPenmountFileConditional_mock ( &mockConfig );
            MOCKPP_CHAINER_FOR ( ChainMockCalibrationDiagnosis, getSkipCalibrationToolConditional ) getSkipCalibrationToolConditional_mock ( &mockConfig );
            MOCKPP_CHAINER_FOR ( ChainMockCalibrationDiagnosis, executeCalibrationTool ) executeCalibrationTool_mock ( &mockConfig );

            getPenmountFileConditional_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue ( false ) )
            .id ( MOCKPP_PCHAR ( "getPenmountFileConditional" ) );

            getSkipCalibrationToolConditional_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue ( true ) )
            .id ( MOCKPP_PCHAR ( "getSkipCalibrationToolConditional" ) );

            executeCalibrationTool_mock
            .expects ( MOCKPP_NS::never() )
            .will ( MOCKPP_NS::returnValue ( true ) )
            .id ( MOCKPP_PCHAR ( "executeCalibrationTool" ) );

            CPPUNIT_ASSERT ( false == mockConfig.calibrationTool() );

            mockConfig.verify();
        }

        CPPUNIT_TEST_SUITE ( CalibrationDiagnosisTest );

        CPPUNIT_TEST ( test_NotPenmountFile_SkipFalse_ExecuteFalse );
        CPPUNIT_TEST ( test_NotPenmountFile_SkipFalse_ExecuteTrue );
        CPPUNIT_TEST ( test_NotPenmountFile_SkipTrue_NotSkipCalibrationFile_File_ExecuteTrue );
        CPPUNIT_TEST ( test_NotPenmountFile_SkipTrue_PresentSkipCalibrationFile_File_ExecuteTrue );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_CALIBRATION_DIAGNOSIS_TEST */
