#ifndef TEST_LOGIN_MANAGER_TEST
#define TEST_LOGIN_MANAGER_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include "ChainMockLoginManager.hxx"

class LoginManagerTest : public CPPUNIT_NS::TestFixture
{
    public:

        LoginManagerTest ()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testIsNotPasswordPresent()
        {
            std::string pass;
            ChainMockLoginManager mockLogin;

            MOCKPP_CHAINER_FOR_EXT ( ChainMockLoginManager, getOptPassword, ext ) optPassword_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR_EXT ( ChainMockLoginManager, getFilePassword, ext ) filePassword_mock ( &mockLogin );

            optPassword_mock
            .expects ( MOCKPP_NS::once() )
            .before ( MOCKPP_PCHAR ( "getFilePassword" ) )
            .will ( MOCKPP_NS::returnValue ( false ) )
            .id ( MOCKPP_PCHAR ( "getOptPassword" ) );

            filePassword_mock
            .expects ( MOCKPP_NS::once() )
            .after ( MOCKPP_PCHAR ( "getOptPassword" ) )
            .will ( MOCKPP_NS::returnValue ( false ) )
            .id ( MOCKPP_PCHAR ( "getFilePassword" ) );

            CPPUNIT_ASSERT ( false == mockLogin.getPassword ( pass ) );
            mockLogin.verify();
        }

        void testIsOptPasswordPresent()
        {
            std::string pass;
            ChainMockLoginManager mockLogin;

            MOCKPP_CHAINER_FOR_EXT ( ChainMockLoginManager, getOptPassword, ext ) optPassword_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR_EXT ( ChainMockLoginManager, getFilePassword, ext ) filePassword_mock ( &mockLogin );

            optPassword_mock
            .expects ( MOCKPP_NS::once() )
            .before ( MOCKPP_PCHAR ( "getFilePassword" ) )
            .will ( MOCKPP_NS::returnValue ( true ) )
            .id ( MOCKPP_PCHAR ( "getOptPassword" ) );

            filePassword_mock
            .expects ( MOCKPP_NS::never() )
            .after ( MOCKPP_PCHAR ( "getOptPassword" ) )
            .will ( MOCKPP_NS::returnValue ( false ) )
            .id ( MOCKPP_PCHAR ( "getFilePassword" ) );

            CPPUNIT_ASSERT ( true == mockLogin.getPassword ( pass ) );
            mockLogin.verify();
        }

        void testIsFilePasswordPresent()
        {
            std::string pass;
            ChainMockLoginManager mockLogin;

            MOCKPP_CHAINER_FOR_EXT ( ChainMockLoginManager, getOptPassword, ext ) optPassword_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR_EXT ( ChainMockLoginManager, getFilePassword, ext ) filePassword_mock ( &mockLogin );

            optPassword_mock
            .expects ( MOCKPP_NS::once() )
            .before ( MOCKPP_PCHAR ( "getFilePassword" ) )
            .will ( MOCKPP_NS::returnValue ( false ) )
            .id ( MOCKPP_PCHAR ( "getOptPassword" ) );

            filePassword_mock
            .expects ( MOCKPP_NS::once() )
            .after ( MOCKPP_PCHAR ( "getOptPassword" ) )
            .will ( MOCKPP_NS::returnValue ( true ) )
            .id ( MOCKPP_PCHAR ( "getFilePassword" ) );

            CPPUNIT_ASSERT ( true == mockLogin.getPassword ( pass ) );
            mockLogin.verify();
        }

        void testIsBothPasswordPresent()
        {
            std::string pass;
            ChainMockLoginManager mockLogin;

            MOCKPP_CHAINER_FOR_EXT ( ChainMockLoginManager, getOptPassword, ext ) optPassword_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR_EXT ( ChainMockLoginManager, getFilePassword, ext ) filePassword_mock ( &mockLogin );

            optPassword_mock
            .expects ( MOCKPP_NS::once() )
            .before ( MOCKPP_PCHAR ( "getFilePassword" ) )
            .will ( MOCKPP_NS::returnValue ( true ) )
            .id ( MOCKPP_PCHAR ( "getOptPassword" ) );

            filePassword_mock
            .expects ( MOCKPP_NS::never() )
            .after ( MOCKPP_PCHAR ( "getOptPassword" ) )
            .will ( MOCKPP_NS::returnValue ( true ) )
            .id ( MOCKPP_PCHAR ( "getFilePassword" ) );

            CPPUNIT_ASSERT ( true == mockLogin.getPassword ( pass ) );
            mockLogin.verify();
        }

        CPPUNIT_TEST_SUITE ( LoginManagerTest );
        CPPUNIT_TEST ( testIsNotPasswordPresent );
        CPPUNIT_TEST ( testIsOptPasswordPresent );
        CPPUNIT_TEST ( testIsFilePasswordPresent );
        CPPUNIT_TEST ( testIsBothPasswordPresent );
        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_LOGIN_MANAGER_TEST */
