/**
 * @file AutoBarcodeDiagnosisFunctionality.cxx
 * @brief Body auto barcode diagnosis functionality class
 * @date 20/06/2013
 * @author Yadickson Soto
 */

#include "AutoBarcodeDiagnosisFunctionality.hxx"
#include <Log/SMTTLogManager.h>
#include <Log/ISMTTLog.h>
#include <Configuration/s-a-e-s-functionality-conf-manager.h>
#include <Gui/Widgets/AbstractFactoryWidget.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::Functionality;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Environment;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;

ISMTTLog * AutoBarcodeDiagnosisFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.AutoBarcodeDiagnosisFunctionality", GETTEXT_PACKAGE );

AutoBarcodeDiagnosisFunctionality * AutoBarcodeDiagnosisFunctionality::current_instance = NULL;
AutoBarcodeDiagnosisFunctionality * AutoBarcodeDiagnosisFunctionality::getInstance()
{
    if ( !current_instance )
    {
        current_instance = new AutoBarcodeDiagnosisFunctionality();
    }

    return current_instance;
}

AutoBarcodeDiagnosisFunctionality::AutoBarcodeDiagnosisFunctionality()
{
    widget = NULL;
}

void AutoBarcodeDiagnosisFunctionality::deleteElements()
{
    if ( widget )
    {
        delete widget;
        widget = NULL;
    }
}

void AutoBarcodeDiagnosisFunctionality::Initialize()
{
    exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.AutoBarcodeDiagnosisFunctionality.ExitFunctionality" ) );
    widget->getSignalEnd().connect ( sigc::mem_fun ( this, &AutoBarcodeDiagnosisFunctionality::end ) );
    widget->initialize();
    disableExitButton();
}

Gtk::Widget * AutoBarcodeDiagnosisFunctionality::GetFrame()
{
    widget = AbstractFactoryWidget::createAutoBarcodeDiagnosisWidget();
    return widget;
}

std::string AutoBarcodeDiagnosisFunctionality::GetWindowTitle()
{
    return widget->getTitleText();
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType AutoBarcodeDiagnosisFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMAUTOBARCODEDIAGNOSISFUNCTIONALITY;
}

void AutoBarcodeDiagnosisFunctionality::Dispose()
{
}

void AutoBarcodeDiagnosisFunctionality::end()
{
    ExitFunctionality();
}

AutoBarcodeDiagnosisFunctionality::~AutoBarcodeDiagnosisFunctionality()
{
    deleteElements();
}

Smartmatic::Log::ISMTTLog * AutoBarcodeDiagnosisFunctionality::getLogger()
{
    return logger;
}

Glib::ustring AutoBarcodeDiagnosisFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.AutoBarcodeDiagnosisFunctionality.LogStartFunctionality" );
}

Glib::ustring AutoBarcodeDiagnosisFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.AutoBarcodeDiagnosisFunctionality.LogCloseFunctionality" );
}

bool AutoBarcodeDiagnosisFunctionality::ForceExecute()
{
    return true;
}
