/**
 * @file AutoDiagnosticFunctionality.cxx
 * @brief Body auto diagnostic functionality class
 * @date 24/09/2012
 * @author Yadickson Soto
 */

#include "AutoDiagnosticFunctionality.hxx"
#include <Log/SMTTLogManager.h>
#include <Log/ISMTTLog.h>
#include <Configuration/s-a-e-s-functionality-conf-manager.h>
#include <Gui/Widgets/AbstractFactoryWidget.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::Functionality;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Environment;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;

ISMTTLog * AutoDiagnosticFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.AutoDiagnosticFunctionality", GETTEXT_PACKAGE );

AutoDiagnosticFunctionality * AutoDiagnosticFunctionality::current_instance = NULL;
AutoDiagnosticFunctionality * AutoDiagnosticFunctionality::getInstance()
{
    if ( !current_instance )
    {
        current_instance = new AutoDiagnosticFunctionality();
    }

    return current_instance;
}

AutoDiagnosticFunctionality::AutoDiagnosticFunctionality()
{
    widget = NULL;
}

void AutoDiagnosticFunctionality::deleteElements()
{
    if ( widget )
    {
        delete widget;
        widget = NULL;
    }
}

void AutoDiagnosticFunctionality::Initialize()
{
    exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.AutoDiagnosticFunctionality.ExitFunctionality" ) );
    widget->getSignalEnd().connect ( sigc::mem_fun ( this, &AutoDiagnosticFunctionality::end ) );
    widget->start();
    disableExitButton();
}

Gtk::Widget * AutoDiagnosticFunctionality::GetFrame()
{
    widget = AbstractFactoryWidget::createAutomaticDiagnosticWidget();
    return widget;
}

std::string AutoDiagnosticFunctionality::GetWindowTitle()
{
    return widget->getTitleText();
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType AutoDiagnosticFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMAUTODIAGNOSTICFUNCTIONALITY;
}

void AutoDiagnosticFunctionality::Dispose()
{
}

void AutoDiagnosticFunctionality::end()
{
    ExitFunctionality();
}

AutoDiagnosticFunctionality::~AutoDiagnosticFunctionality()
{
    deleteElements();
}

Smartmatic::Log::ISMTTLog * AutoDiagnosticFunctionality::getLogger()
{
    return logger;
}

Glib::ustring AutoDiagnosticFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.AutoDiagnosticFunctionality.LogStartFunctionality" );
}

Glib::ustring AutoDiagnosticFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.AutoDiagnosticFunctionality.LogCloseFunctionality" );
}

bool AutoDiagnosticFunctionality::ForceExecute()
{
    return true;
}
