/**
 * @file CheckVoteFilesFunctionality.hxx
 * @brief Header class check vote files functionality
 * @date 15/06/2013
 * @author Yadickson Soto
 */

#ifndef CHECK_VOTE_FILES_FUNCTIONALITY_HXX_
#define CHECK_VOTE_FILES_FUNCTIONALITY_HXX_

#include <gtkmm.h>
#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/ValidateVotesWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	CheckVoteFilesFunctionality
                 * @brief	Class check CODI files functionality.
                 * @author	Yadickson Soto
                 * @date	15/06/2013
                 */
                class CheckVoteFilesFunctionality : public GraphicDisplayFunctionality
                {
                    private:
                        /**
                         * @fn	CheckVoteFilesFunctionality::CheckVoteFilesFunctionality();
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        CheckVoteFilesFunctionality();

                        /**
                         * @brief  Occurs when the functionality fails.
                         * @author manuel.arguelles
                         * @date   15/08/2022
                         */
                        void onError();

                        /**
                         * @brief  Checks if the functionality should be resumed.
                         * @author manuel.arguelles
                         * @date   15/08/2022
                         * @return True to continue checking; otherwise, false.
                         */
                        bool checkResume();

                        static CheckVoteFilesFunctionality * instance; ///< instance of class
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                        Smartmatic::SAES::GUI::Widgets::ValidateVotesWidget * widget; ///< validate votes
                        bool isInterrupted;

                    protected:

                        /**
                         * @fn	std::string CheckVoteFilesFunctionality::GetWindowTitle();
                         * @brief	Gets the window title.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	The window title.
                         */
                        std::string GetWindowTitle();
                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType CheckVoteFilesFunctionality::GetMenuOptionType();
                         * @brief	Gets the menu option type.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	The menu option type.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @fn	Gtk::Widget * CheckVoteFilesFunctionality::GetFrame();
                         * @brief	Gets the frame.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	null if it fails, else the frame.
                         */
                        Gtk::Widget * GetFrame();
                        /**
                         * @fn	void CheckVoteFilesFunctionality::Dispose();
                         * @brief	Dispose of this object, cleaning up any resources it uses.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        void Dispose();
                        /**
                         * @fn	void CheckVoteFilesFunctionality::Initialize();
                         * @brief	Initializes this object.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        void Initialize();
                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * CheckVoteFilesFunctionality::getLogger();
                         * @brief	Gets the logger.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	null if it fails, else the logger.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();
                        /**
                         * @fn	Glib::ustring CheckVoteFilesFunctionality::getStartLogMessage();
                         * @brief	Gets the start log message.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	The start log message.
                         */
                        Glib::ustring getStartLogMessage();
                        /**
                         * @fn	Glib::ustring CheckVoteFilesFunctionality::getFinishLogMessage();
                         * @brief	Gets the finish log message.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	The finish log message.
                         */
                        Glib::ustring getFinishLogMessage();
                        /**
                         * @fn	virtual void CheckVoteFilesFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual void deleteElements();
                        /**
                         * @fn	virtual void CheckVoteFilesFunctionality::block();
                         * @brief	method block functionality.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual void block();
                        /**
                         * @fn	virtual void CheckVoteFilesFunctionality::partial();
                         * @brief	method partial functionality.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual void partial();
                        /**
                         * @fn	virtual void CheckVoteFilesFunctionality::resume();
                         * @brief	method resume functionality.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual void resume();

                    public:
                        /**
                         * @fn	static CheckVoteFilesFunctionality * CheckVoteFilesFunctionality::getInstance();
                         * @brief	Method getter instance.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	instance of class.
                         */
                        static CheckVoteFilesFunctionality * getInstance();
                        /**
                         * @fn	virtual CheckVoteFilesFunctionality::~CheckVoteFilesFunctionality();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual ~CheckVoteFilesFunctionality();
                };
            }
        }
    }
}
#endif /* CHECK_VOTE_FILES_FUNCTIONALITY_HXX_ */
