/**
 * @file ClosingElectionStatusFunctionality.hxx
 * @brief Header class closing election status functionality
 * @author eduardo.fernandez
 * @date   11/12/2018
 */

#ifndef CLOSING_ELECTION_STATUS_FUNCTIONALITY_HXX
#define CLOSING_ELECTION_STATUS_FUNCTIONALITY_HXX

#include <gtkmm.h>
#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/ClosingElectionStatusWidget.h>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	ClosingElectionStatusFunctionality
                 * @brief	Class closing election status functionality.
                 * @author	eduardo.fernandez
                 * @date	11/12/2018
                 */
                class ClosingElectionStatusFunctionality : public GraphicDisplayFunctionality
                {
                    private:
                        /**
                         * @fn	ClosingElectionStatusFunctionality::ClosingElectionStatusFunctionality();
                         * @brief	Class constructor.
                         * @author	eduardo.fernandez
                         * @date	11/12/2018
                         */
                        ClosingElectionStatusFunctionality();

                        static ClosingElectionStatusFunctionality * instance; ///< instance of class
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                        Smartmatic::SAES::GUI::Widgets::ClosingElectionStatusWidget * widget; ///< closing election status

                    protected:

                        /**
                         * @fn	std::string ClosingElectionStatusFunctionality::GetWindowTitle();
                         * @brief	Gets the window title.
                         * @author  eduardo.fernandez
                         * @date    11/12/2018
                         * @return	The window title.
                         */
                        std::string GetWindowTitle();
                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType ClosingElectionStatusFunctionality::GetMenuOptionType();
                         * @brief	Gets the menu option type.
                         * @author  eduardo.fernandez
                         * @date    11/12/2018
                         * @return	The menu option type.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @fn	Gtk::Widget * ClosingElectionStatusFunctionality::GetFrame();
                         * @brief	Gets the frame.
                         * @author  eduardo.fernandez
                         * @date    11/12/2018
                         * @return	null if it fails, else the frame.
                         */
                        Gtk::Widget * GetFrame();
                        /**
                         * @fn	void ClosingElectionStatusFunctionality::Dispose();
                         * @brief	Dispose of this object, cleaning up any resources it uses.
                         * @author  eduardo.fernandez
                         * @date    11/12/2018
                         */
                        void Dispose();
                        /**
                         * @fn	void ClosingElectionStatusFunctionality::Initialize();
                         * @brief	Initializes this object.
                         * @author  eduardo.fernandez
                         * @date    11/12/2018
                         */
                        void Initialize();
                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * ClosingElectionStatusFunctionality::getLogger();
                         * @brief	Gets the logger.
                         * @author  eduardo.fernandez
                         * @date    11/12/2018
                         * @return	null if it fails, else the logger.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();
                        /**
                         * @fn	Glib::ustring ClosingElectionStatusFunctionality::getStartLogMessage();
                         * @brief	Gets the start log message.
                         * @author  eduardo.fernandez
                         * @date    11/12/2018
                         * @return	The start log message.
                         */
                        Glib::ustring getStartLogMessage();
                        /**
                         * @fn	Glib::ustring ClosingElectionStatusFunctionality::getFinishLogMessage();
                         * @brief	Gets the finish log message.
                         * @author  eduardo.fernandez
                         * @date    11/12/2018
                         * @return	The finish log message.
                         */
                        Glib::ustring getFinishLogMessage();
                        /**
                         * @fn	virtual void ClosingElectionStatusFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author  eduardo.fernandez
                         * @date    11/12/2018
                         */
                        virtual void deleteElements();
                        /**
                         * @fn	virtual void ClosingElectionStatusFunctionality::block();
                         * @brief	method block functionality.
                         * @author  eduardo.fernandez
                         * @date    11/12/2018
                         */
                        virtual void block();
                        /**
                         * @fn	virtual void ClosingElectionStatusFunctionality::partial();
                         * @brief	method partial functionality.
                         * @author  eduardo.fernandez
                         * @date    11/12/2018
                         */
                        virtual void partial();
                        /**
                         * @fn	virtual void ClosingElectionStatusFunctionality::resume();
                         * @brief	method resume functionality.
                         * @author  eduardo.fernandez
                         * @date    11/12/2018
                         */
                        virtual void resume();

                    public:
                        /**
                         * @fn	static ClosingElectionStatusFunctionality * ClosingElectionStatusFunctionality::getInstance();
                         * @brief	Method getter instance.
                         * @author  eduardo.fernandez
                         * @date    11/12/2018
                         * @return	instance of class.
                         */
                        static ClosingElectionStatusFunctionality * getInstance();
                        /**
                         * @fn	virtual ClosingElectionStatusFunctionality::~ClosingElectionStatusFunctionality();
                         * @brief	Class destructor.
                         * @author  eduardo.fernandez
                         * @date    11/12/2018
                         */
                        virtual ~ClosingElectionStatusFunctionality();
                };
            }
        }
    }
}
#endif /* CLOSING_ELECTION_STATUS_FUNCTIONALITY_HXX */
