/**
 * @file CustomizableCheckListDiagnoseFunctionality.hxx
 * @brief Header customizable check list diagnose functionality class
 * @date 17/09/2013
 * @author Yadickson Soto
 */

#ifndef CUSTOMIZABLE_CHECK_LIST_DIAGNOSE_HXX_
#define CUSTOMIZABLE_CHECK_LIST_DIAGNOSE_HXX_

#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/Diagnose/CheckListDiagnoseWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	CustomizableCheckListDiagnoseFunctionality
                 * @brief	Date setup functionality class.
                 * @author	Yadickson Soto
                 * @date	17/09/2013
                 */
                class CustomizableCheckListDiagnoseFunctionality : public GraphicDisplayFunctionality
                {
                    public:

                        /**
                         * @fn	virtual ~CustomizableCheckListDiagnoseFunctionality();
                         * @brief	Class destructorer.
                         * @author	Yadickson Soto
                         * @date	189/09/2012
                         */
                        virtual ~CustomizableCheckListDiagnoseFunctionality();
                        /**
                         * @fn	static CustomizableCheckListDiagnoseFunctionality * getInstance();
                         * @brief	Singleton instance getter.
                         * @author	Yadickson Soto
                         * @date	17/09/2013
                         * @return	instance of class.
                         */
                        static CustomizableCheckListDiagnoseFunctionality * getInstance();

                    protected:

                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * getLogger();
                         * @brief	Logger getter method.
                         * @author	Yadickson Soto
                         * @date	17/09/2013
                         * @return	logger.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();
                        /**
                         * @fn	Glib::ustring getStartLogMessage();
                         * @brief	Gets the logger starting message.
                         * @author	Yadickson Soto
                         * @date	17/09/2013
                         * @return	message.
                         */
                        Glib::ustring getStartLogMessage();
                        /**
                         * @fn	Glib::ustring getFinishLogMessage();
                         * @brief	Gets the logger ending message.
                         * @author	Yadickson Soto
                         * @date	17/09/2013
                         * @return	message.
                         */
                        Glib::ustring getFinishLogMessage();

                    private:

                        static CustomizableCheckListDiagnoseFunctionality * current_instance;  ///< The current instance
                        static Smartmatic::Log::ISMTTLog * logger; /**<logger*/ ///< The logger
                        Smartmatic::SAES::GUI::Widgets::CheckListDiagnoseWidget * widget; ///< The widget

                        /**
                         * @fn	CustomizableCheckListDiagnoseFunctionality();
                         * @brief	class constructor.
                         * @author	Yadickson Soto
                         * @date	17/09/2013
                         */
                        CustomizableCheckListDiagnoseFunctionality();
                        /**
                         * @fn	void Dispose();
                         * @brief	method dispose.
                         * @author	Yadickson Soto
                         * @date	17/09/2013
                         */
                        void Dispose();
                        /**
                         * @fn	void Initialize();
                         * @brief	method initialize.
                         * @author	Yadickson Soto
                         * @date	17/09/2013
                         */
                        void Initialize();
                        /**
                         * @fn	Gtk::Widget * GetFrame();
                         * @brief	Frame getter method.
                         * @author	Yadickson Soto
                         * @date	17/09/2013
                         * @return	new frame.
                         */
                        Gtk::Widget * GetFrame();
                        /**
                         * @fn	std::string GetWindowTitle();
                         * @brief	Window title getter method.
                         * @author	Yadickson Soto
                         * @date	17/09/2013
                         * @return	the window title.
                         */
                        std::string GetWindowTitle();
                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                         * @brief	Menu option type getter method.
                         * @author	Yadickson Soto
                         * @date	17/09/2013
                         * @return	the menu option type.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @fn	virtual void deleteElements();
                         * @brief	Deletes all elementss.
                         * @author	Yadickson Soto
                         * @date	17/09/2013
                         */
                        virtual void deleteElements();
                };
            }
        }
    }
}

#endif // CUSTOMIZABLE_CHECK_LIST_DIAGNOSE_HXX_
