/**
 * @file DeviceDiagnosticPrintFunctionality.cxx
 * @brief Body device diagnostic print functionality class
 * @date 19/09/2012
 * @author Yadickson Soto
 */

#include "DeviceDiagnosticPrintFunctionality.hxx"
#include <Log/SMTTLogManager.h>
#include <Log/ISMTTLog.h>
#include <Configuration/s-a-e-s-functionality-conf-manager.h>
#include <Gui/Widgets/AbstractFactoryWidget.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::Functionality;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Environment;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;

ISMTTLog * DeviceDiagnosticPrintFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.DeviceDiagnosticPrintFunctionality", GETTEXT_PACKAGE );

DeviceDiagnosticPrintFunctionality * DeviceDiagnosticPrintFunctionality::current_instance = NULL;
DeviceDiagnosticPrintFunctionality * DeviceDiagnosticPrintFunctionality::getInstance()
{
    if ( !current_instance )
    {
        current_instance = new DeviceDiagnosticPrintFunctionality();
    }

    return current_instance;
}

DeviceDiagnosticPrintFunctionality::DeviceDiagnosticPrintFunctionality()
{
    widget = NULL;
}

void DeviceDiagnosticPrintFunctionality::deleteElements()
{
    if ( widget )
    {
        delete widget;
        widget = NULL;
    }
}

void DeviceDiagnosticPrintFunctionality::Initialize()
{
    exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.DeviceDiagnosticPrintFunctionality.ExitFunctionality" ) );
    disableExitButton();
    widget->getSignalEnd().connect ( sigc::mem_fun ( this, &DeviceDiagnosticPrintFunctionality::endPrint ) );
    widget->start();
}

void DeviceDiagnosticPrintFunctionality::endPrint()
{
    enableExitButton();
    ExitFunctionality();
}

Gtk::Widget * DeviceDiagnosticPrintFunctionality::GetFrame()
{
    widget = AbstractFactoryWidget::createDeviceDiagnosticPrintWidget();
    return widget;
}

std::string DeviceDiagnosticPrintFunctionality::GetWindowTitle()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.DeviceDiagnosticPrintFunctionality.Title" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType DeviceDiagnosticPrintFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMDEVICEDIAGNOSTICPRINTFUNCTIONALITY;
}

void DeviceDiagnosticPrintFunctionality::Dispose()
{
}

DeviceDiagnosticPrintFunctionality::~DeviceDiagnosticPrintFunctionality()
{
    deleteElements();
}

Smartmatic::Log::ISMTTLog * DeviceDiagnosticPrintFunctionality::getLogger()
{
    return logger;
}

Glib::ustring DeviceDiagnosticPrintFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.DeviceDiagnosticPrintFunctionality.LogStartFunctionality" );
}

Glib::ustring DeviceDiagnosticPrintFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.DeviceDiagnosticPrintFunctionality.LogCloseFunctionality" );
}

bool DeviceDiagnosticPrintFunctionality::ShowWindowTitle()
{
    return false;
}
