/**
 * @file DeviceDiagnosticPrintFunctionality.hxx
 * @brief Header device diagnostic print functionality class
 * @date 19/09/2012
 * @author Yadickson Soto
 */

#ifndef _DEVICE_DIAGNOSTIC_PRINT_FUNCTIONALITY_H_
#define _DEVICE_DIAGNOSTIC_PRINT_FUNCTIONALITY_H_

#include <gtkmm.h>
#include <string>
#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/Diagnose/DeviceDiagnosticPrintWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	DeviceDiagnosticPrintFunctionality
                 * @brief	device diagnostic print functionality class.
                 * @author	Yadickson Soto
                 * @date	19/09/2012
                 */
                class DeviceDiagnosticPrintFunctionality : public GraphicDisplayFunctionality
                {
                    public:

                        /**
                         * @fn	virtual DeviceDiagnosticPrintFunctionality::~DeviceDiagnosticPrintFunctionality();
                         * @brief	class destructor.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         */
                        virtual ~DeviceDiagnosticPrintFunctionality();
                        /**
                         * @fn	static DeviceDiagnosticPrintFunctionality * DeviceDiagnosticPrintFunctionality::getInstance();
                         * @brief	Singleton instance getter method.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         * @return	instance of class.
                         */
                        static DeviceDiagnosticPrintFunctionality * getInstance();

                    protected:

                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * DeviceDiagnosticPrintFunctionality::getLogger();
                         * @brief	Logger getter method.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         * @return	logger.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();
                        /**
                         * @fn	Glib::ustring DeviceDiagnosticPrintFunctionality::getStartLogMessage();
                         * @brief	Gets the logger starting message.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         * @return	message.
                         */
                        Glib::ustring getStartLogMessage();
                        /**
                         * @fn	Glib::ustring DeviceDiagnosticPrintFunctionality::getFinishLogMessage();
                         * @brief	Gets the logger ending message.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         * @return	message.
                         */
                        Glib::ustring getFinishLogMessage();

                    private:

                        static DeviceDiagnosticPrintFunctionality * current_instance;  ///< The current instance
                        static Smartmatic::Log::ISMTTLog * logger; /**<logger*/ ///< The logger
                        Smartmatic::SAES::GUI::Widgets::DeviceDiagnosticPrintWidget * widget; ///< The widget

                        /**
                         * @fn	DeviceDiagnosticPrintFunctionality::DeviceDiagnosticPrintFunctionality();
                         * @brief	class constructor.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         */
                        DeviceDiagnosticPrintFunctionality();
                        /**
                         * @fn	void DeviceDiagnosticPrintFunctionality::Dispose();
                         * @brief	method dispose.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         */
                        void Dispose();
                        /**
                         * @fn	void DeviceDiagnosticPrintFunctionality::Initialize();
                         * @brief	method initialize.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         */
                        void Initialize();
                        /**
                         * @fn	Gtk::Widget * DeviceDiagnosticPrintFunctionality::GetFrame();
                         * @brief	Frame getter method.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         * @return	new frame.
                         */
                        Gtk::Widget * GetFrame();
                        /**
                         * @fn	std::string DeviceDiagnosticPrintFunctionality::GetWindowTitle();
                         * @brief	Window title getter method.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         * @return	the window title.
                         */
                        std::string GetWindowTitle();
                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType DeviceDiagnosticPrintFunctionality::GetMenuOptionType();
                         * @brief	Menu option type getter method.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         * @return	the menu option type.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @fn	virtual bool DeviceDiagnosticPrintFunctionality::ShowWindowTitle();
                         * @brief	Gets whether window title is visible.
                         * @author	Yadickson Soto
                         * @date	18/09/2012
                         * @return	true is show window title.
                         */
                        virtual bool ShowWindowTitle();
                        /**
                         * @fn	virtual void DeviceDiagnosticPrintFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	03/04/2012
                         */
                        virtual void deleteElements();
                        /**
                         * @fn	void DeviceDiagnosticPrintFunctionality::endPrint();
                         * @brief	method end print.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         */
                        void endPrint();
                };
            }
        }
    }
}

#endif // _DEVICE_DIAGNOSTIC_PRINT_FUNCTIONALITY_H_
