/*
 * EurnDiagnosisFunctionality.cxx
 *
 *  Created on: Nov 8, 2017
 *      Author: juanvalera
 */

#include "EurnDiagnosisFunctionality.hxx"
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::Functionality;
using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::GUI::Windows;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::Configuration;

ISMTTLog * EurnDiagnosisFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.EurnDiagnosisFunctionality", GETTEXT_PACKAGE );

EurnDiagnosisFunctionality::EurnDiagnosisFunctionality()
{
    eurnWidget = NULL;
}

EurnDiagnosisFunctionality * EurnDiagnosisFunctionality::current_instance = NULL;

EurnDiagnosisFunctionality * EurnDiagnosisFunctionality::getInstance()
{
    if ( !current_instance )
    {
        current_instance = new EurnDiagnosisFunctionality();
    }

    return current_instance;
}

EurnDiagnosisFunctionality::~EurnDiagnosisFunctionality()
{
    deleteElements();
}

void EurnDiagnosisFunctionality::deleteElements()
{
    if ( eurnWidget )
    {
        delete ( eurnWidget );
        eurnWidget = NULL;
    }
}

void EurnDiagnosisFunctionality::Initialize()
{
    connFinishDiagnosis.disconnect();
    connFinishDiagnosis = eurnWidget->getSignalEnd().connect ( sigc::mem_fun ( *this, &EurnDiagnosisFunctionality::endDiagnosis ) );
    eurnWidget->start();
}

void EurnDiagnosisFunctionality::endDiagnosis()
{
    enableExitButton();
    logger->Audit ( N_ ( "eUrn Diagnosis Executed" ) );
    ExitFunctionality();
}

Gtk::Widget * EurnDiagnosisFunctionality::GetFrame()
{
    eurnWidget = new Smartmatic::SAES::GUI::Widgets::EurnDiagnoseWidget ();
    return eurnWidget;
}

std::string EurnDiagnosisFunctionality::GetWindowTitle()
{
    return N_ ( "eUrn Diagnosis" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType EurnDiagnosisFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMEURNDIAGNOSISFUNCTIONALITY;
}

void EurnDiagnosisFunctionality::Dispose()
{
    eurnWidget->dispose();
    connFinishDiagnosis.disconnect();
}

Smartmatic::Log::ISMTTLog * EurnDiagnosisFunctionality::getLogger()
{
    return logger;
}
Glib::ustring EurnDiagnosisFunctionality::getStartLogMessage()
{
    return N_ ( "eUrn Diagnosis started" );
}

Glib::ustring EurnDiagnosisFunctionality::getFinishLogMessage()
{
    return N_ ( "eUrn Diagnosis finished" );
}
