/**
 * @file InfoLoginFunctionality.cxx
 * @brief Body class info login functionality
 * @date 27/05/2013
 * @author Yadickson Soto
 */

#include "InfoLoginFunctionality.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Gui/Widgets/AbstractFactoryWidget.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Log;
using namespace Smartmatic::Functionality;

ISMTTLog * InfoLoginFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.InfoLoginFunctionality", GETTEXT_PACKAGE );

InfoLoginFunctionality * InfoLoginFunctionality::instance = NULL;

InfoLoginFunctionality::InfoLoginFunctionality()
{
    infoMessage = NULL;
}

InfoLoginFunctionality::~InfoLoginFunctionality()
{
    deleteElements();
}

InfoLoginFunctionality * InfoLoginFunctionality::getInstance()
{
    if ( !instance )
    {
        instance = new InfoLoginFunctionality();
    }

    return instance;
}

std::string InfoLoginFunctionality::GetWindowTitle()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.InfoLoginFunctionality.Title" );
}

Smartmatic::Log::ISMTTLog * InfoLoginFunctionality::getLogger()
{
    return logger;
}

Glib::ustring InfoLoginFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.InfoLoginFunctionality.LogStartFunctionality" );
}

Glib::ustring InfoLoginFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.InfoLoginFunctionality.LogCloseFunctionality" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType InfoLoginFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMINFOLOGINFUNCTIONALITY;
}

Gtk::Widget * InfoLoginFunctionality::GetFrame()
{
    infoMessage = AbstractFactoryWidget::createVMInstallationConfirmation ();
    return infoMessage;
}

void InfoLoginFunctionality::Dispose()
{

}

void InfoLoginFunctionality::Initialize()
{
    infoMessage->getSignalEnd().connect ( sigc::mem_fun ( *this, &InfoLoginFunctionality::endFunctionality ) );

    exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.InfoLoginFunctionality.FinalMessage" ) );
    disableExitButton();
}

void InfoLoginFunctionality::endFunctionality()
{
    ExitFunctionality();
}

void InfoLoginFunctionality::deleteElements()
{
    if ( infoMessage )
    {
        delete infoMessage;
        infoMessage = NULL;
    }
}

void InfoLoginFunctionality::block()
{
    logger->Debug ( "Block functionality" );
}

void InfoLoginFunctionality::partial()
{
    logger->Debug ( "Partial functionality" );
}

void InfoLoginFunctionality::resume()
{
    logger->Debug ( "Resume functionality" );
}

void InfoLoginFunctionality::refresh()
{
    if ( infoMessage )
    {
        infoMessage->refresh();
    }
}
