/**
 * @file InitialCalibrationFunctionality.cxx
 * @brief Body initial calibration functionality class
 * @date 18/09/2012
 * @author Yadickson Soto
 */

#include "InitialCalibrationFunctionality.hxx"
#include <Log/SMTTLogManager.h>
#include <Log/ISMTTLog.h>
#include <Configuration/s-a-e-s-functionality-conf-manager.h>
#include <Environment/Configurations/base-language-controller.h>
#include <Gui/Widgets/AbstractFactoryWidget.hxx>
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::Functionality;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Environment;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;

ISMTTLog * InitialCalibrationFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.InitialCalibrationFunctionality", GETTEXT_PACKAGE );

InitialCalibrationFunctionality * InitialCalibrationFunctionality::current_instance = NULL;
InitialCalibrationFunctionality * InitialCalibrationFunctionality::getInstance()
{
    if ( !current_instance )
    {
        current_instance = new InitialCalibrationFunctionality();
    }

    return current_instance;
}

InitialCalibrationFunctionality::InitialCalibrationFunctionality()
{
    diagnostic = NULL;
}

void InitialCalibrationFunctionality::deleteElements()
{
    if ( diagnostic )
    {
        delete diagnostic;
        diagnostic = NULL;
    }
}

void InitialCalibrationFunctionality::Initialize()
{
    exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.InitialCalibrationFunctionality.ExitFunctionality" ) );

    disableExitButton();

    diagnostic->getSignalEnd().connect ( sigc::mem_fun ( *this, &InitialCalibrationFunctionality::ExitFunctionality ) );
    diagnostic->calibrate();
}

Gtk::Widget * InitialCalibrationFunctionality::GetFrame()
{
    diagnostic = AbstractFactoryWidget::createInitialCalibrationWidget();
    return diagnostic;
}

std::string InitialCalibrationFunctionality::GetWindowTitle()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.InitialCalibrationFunctionality.Title" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType InitialCalibrationFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMINITIALCALIBRATIONFUNCTIONALITY;
}

void InitialCalibrationFunctionality::Dispose()
{
}

InitialCalibrationFunctionality::~InitialCalibrationFunctionality()
{
    deleteElements();
}

Smartmatic::Log::ISMTTLog * InitialCalibrationFunctionality::getLogger()
{
    return logger;
}

Glib::ustring InitialCalibrationFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.InitialCalibrationFunctionality.LogStartFunctionality" );
}

Glib::ustring InitialCalibrationFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.InitialCalibrationFunctionality.LogCloseFunctionality" );
}

bool InitialCalibrationFunctionality::ShowWindowTitle()
{
    return BaseLanguageController::isSetLanguage();
}
