/**
 * @file LanguageInstallFunctionality.hxx
 * @brief Header language installation functionality class
 * @date 18/09/2012
 * @author Yadickson Soto
 */

#ifndef _LANGUAGE_INSTALLATION_FUNCTIONALITY_H_
#define _LANGUAGE_INSTALLATION_FUNCTIONALITY_H_

#include <gtkmm.h>
#include <string>
#include <Functionalities/graphic-display-functionality.h>
#include "Gui/Widgets/LanguageInstallWidget.hxx"

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	LanguageInstallFunctionality
                 * @brief	language installation functionality class.
                 * @author	Yadickson Soto
                 * @date	18/09/2012
                 */
                class LanguageInstallFunctionality : public GraphicDisplayFunctionality
                {
                    public:

                        /**
                         * @fn	virtual LanguageInstallFunctionality::~LanguageInstallFunctionality();
                         * @brief	class destructor.
                         * @author	Yadickson Soto
                         * @date	18/09/2012
                         */
                        virtual ~LanguageInstallFunctionality();
                        /**
                         * @fn	static LanguageInstallFunctionality * LanguageInstallFunctionality::getInstance();
                         * @brief	Singleton instance getter method.
                         * @author	Yadickson Soto
                         * @date	18/09/2012
                         * @return	instance of class.
                         */
                        static LanguageInstallFunctionality * getInstance();

                    protected:

                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * LanguageInstallFunctionality::getLogger();
                         * @brief	Logger getter method.
                         * @author	Yadickson Soto
                         * @date	18/09/2012
                         * @return	logger.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();
                        /**
                         * @fn	Glib::ustring LanguageInstallFunctionality::getStartLogMessage();
                         * @brief	Gets the logger starting message.
                         * @author	Yadickson Soto
                         * @date	18/09/2012
                         * @return	message.
                         */
                        Glib::ustring getStartLogMessage();
                        /**
                         * @fn	Glib::ustring LanguageInstallFunctionality::getFinishLogMessage();
                         * @brief	Gets the logger ending message.
                         * @author	Yadickson Soto
                         * @date	18/09/2012
                         * @return	message.
                         */
                        Glib::ustring getFinishLogMessage();

                    private:

                        static LanguageInstallFunctionality * current_instance;  ///< The current instance
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                        Smartmatic::SAES::GUI::Widgets::LanguageInstallWidget * changeLanguageWidget; ///< The change language widget

                        /**
                         * @fn	LanguageInstallFunctionality::LanguageInstallFunctionality();
                         * @brief	class constructor.
                         * @author	Yadickson Soto
                         * @date	18/09/2012
                         */
                        LanguageInstallFunctionality();
                        /**
                         * @fn	void LanguageInstallFunctionality::Dispose();
                         * @brief	method dispose.
                         * @author	Yadickson Soto
                         * @date	18/09/2012
                         */
                        void Dispose();
                        /**
                         * @fn	void LanguageInstallFunctionality::Initialize();
                         * @brief	method initialize.
                         * @author	Yadickson Soto
                         * @date	18/09/2012
                         */
                        void Initialize();
                        /**
                         * @fn	Gtk::Widget * LanguageInstallFunctionality::GetFrame();
                         * @brief	Frame getter method.
                         * @author	Yadickson Soto
                         * @date	18/09/2012
                         * @return	new frame.
                         */
                        Gtk::Widget * GetFrame();
                        /**
                         * @fn	std::string LanguageInstallFunctionality::GetWindowTitle();
                         * @brief	Window title getter method.
                         * @author	Yadickson Soto
                         * @date	18/09/2012
                         * @return	the window title.
                         */
                        std::string GetWindowTitle();
                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType LanguageInstallFunctionality::GetMenuOptionType();
                         * @brief	Menu option type getter method.
                         * @author	Yadickson Soto
                         * @date	18/09/2012
                         * @return	the menu option type.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @fn	void LanguageInstallFunctionality::onLanguageChange();
                         * @brief	method on language change.
                         * @author	Yadickson Soto
                         * @date	18/09/2012
                         */
                        void onLanguageChange();
                        /**
                         * @fn	virtual void LanguageInstallFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	03/04/2012
                         */
                        virtual void deleteElements();
                        /**
                         * @fn	virtual bool LanguageInstallFunctionality::ShowWindowTitle();
                         * @brief	Gets whether window title is visible.
                         * @author	Yadickson Soto
                         * @date	18/09/2012
                         * @return	true is show window title.
                         */
                        virtual bool ShowWindowTitle();

                };
            }
        }
    }
}

#endif // _LANGUAGE_INSTALLATION_FUNCTIONALITY_H_
