/**
 * @file MouseFunctionality.cxx
 * @brief Body mouse functionality class
 * @date 229/03/2019
 * @author eduardo.fernandez
 */

#include "MouseFunctionality.hxx"
#include <Log/SMTTLogManager.h>
#include <Log/ISMTTLog.h>
#include <Configuration/s-a-e-s-functionality-conf-manager.h>
#include <Operation/ZipCodeManager.hxx>
#include <Gui/Widgets/FactoryMethodWidget.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::Functionality;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Environment;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;

ISMTTLog * MouseFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.MouseFunctionality", GETTEXT_PACKAGE );

MouseFunctionality * MouseFunctionality::current_instance = NULL;
MouseFunctionality * MouseFunctionality::getInstance()
{
    if ( !current_instance )
    {
        current_instance = new MouseFunctionality();
    }

    return current_instance;
}

MouseFunctionality::MouseFunctionality()
{
    widget = NULL;
}

void MouseFunctionality::deleteElements()
{
    if ( widget )
    {
        delete widget;
        widget = NULL;
    }
}

void MouseFunctionality::Initialize()
{
    exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.MouseFunctionality.ExitFunctionality" ) );
    widget->initialize();
    disableExitButton();
    ExitFunctionality();
}

Gtk::Widget * MouseFunctionality::GetFrame()
{
    widget = FactoryMethodWidget::createMouseWidget();
    return widget;
}

std::string MouseFunctionality::GetWindowTitle()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.MouseFunctionality.Title" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType MouseFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMMOUSEFUNCTIONALITY;
}

void MouseFunctionality::Dispose()
{
}

MouseFunctionality::~MouseFunctionality()
{
    deleteElements();
}

Smartmatic::Log::ISMTTLog * MouseFunctionality::getLogger()
{
    return logger;
}

Glib::ustring MouseFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.MouseFunctionality.LogStartFunctionality" );
}

Glib::ustring MouseFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.MouseFunctionality.LogCloseFunctionality" );
}
