/**
 * @file ProcessStatusResultsShutdownFunctionality.cxx
 * @brief Body voting machine shutdown class
 * @date 08/11/2012
 * @author Yadickson Soto
 */

#include "ProcessStatusResultsShutdownFunctionality.hxx"
#include <Log/SMTTLogManager.h>
#include <Log/ISMTTLog.h>
#include <Configuration/s-a-e-s-functionality-conf-manager.h>
#include <Gui/Widgets/AbstractFactoryWidget.hxx>
#include <Voting/Status/VMProcessStatusWrapper.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::Functionality;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Environment;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::SAES::Voting::Status;

ISMTTLog * ProcessStatusResultsShutdownFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.ProcessStatusResultsShutdownFunctionality", GETTEXT_PACKAGE );

ProcessStatusResultsShutdownFunctionality * ProcessStatusResultsShutdownFunctionality::current_instance = NULL;
ProcessStatusResultsShutdownFunctionality * ProcessStatusResultsShutdownFunctionality::getInstance()
{
    if ( !current_instance )
    {
        current_instance = new ProcessStatusResultsShutdownFunctionality();
    }

    return current_instance;
}

ProcessStatusResultsShutdownFunctionality::ProcessStatusResultsShutdownFunctionality()
{
    widget = NULL;
}

void ProcessStatusResultsShutdownFunctionality::deleteElements()
{
    if ( widget )
    {
        delete widget;
        widget = NULL;
    }
}

void ProcessStatusResultsShutdownFunctionality::Initialize()
{
    exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.ProcessStatusResultsShutdownFunctionality.ExitFunctionality" ) );
    widget->getSignalEnd().connect ( sigc::mem_fun ( this, &ProcessStatusResultsShutdownFunctionality::end ) );

    if ( VMProcessStatusWrapper::getInstance()->isFail() )
    {
        widget->setImageError();
    }
    else
    {
        widget->setImageOk();
    }

    disableExitButton();
}

Gtk::Widget * ProcessStatusResultsShutdownFunctionality::GetFrame()
{
    widget = AbstractFactoryWidget::createIconShutdownWidget();
    return widget;
}

std::string ProcessStatusResultsShutdownFunctionality::GetWindowTitle()
{
    return widget->getTitleText();
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType ProcessStatusResultsShutdownFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMPROCESSSTATUSRESULTSSHUTDOWNFUNCTIONALITY;
}

void ProcessStatusResultsShutdownFunctionality::Dispose()
{
}

void ProcessStatusResultsShutdownFunctionality::end()
{
    ExitFunctionality();
}

ProcessStatusResultsShutdownFunctionality::~ProcessStatusResultsShutdownFunctionality()
{
    deleteElements();
}

Smartmatic::Log::ISMTTLog * ProcessStatusResultsShutdownFunctionality::getLogger()
{
    return logger;
}

Glib::ustring ProcessStatusResultsShutdownFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.ProcessStatusResultsShutdownFunctionality.LogStartFunctionality" );
}

Glib::ustring ProcessStatusResultsShutdownFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.ProcessStatusResultsShutdownFunctionality.LogCloseFunctionality" );
}

bool ProcessStatusResultsShutdownFunctionality::ShowWindowTitle()
{
    return false;
}

bool ProcessStatusResultsShutdownFunctionality::ForceExecute()
{
    return true;
}
