/*
 * RecountFunctionalityController.cpp
 *
 *  Created on: Feb 13, 2017
 *      Author: Juan Valera
 */

#include "RecountFunctionalityController.h"

#include <Log/SMTTLogManager.h>
#include <Log/ISMTTLog.h>
#include <Configuration/s-a-e-s-functionality-conf-manager.h>
#include <Gui/Widgets/FactoryMethodWidget.hxx>
#include "Resources/election-string-resources-manager.h"
#include <Resources/election-string-resources-manager.h>
#include <Voting/VotingDevice/voting-devices-schema.hxx>
#include <Operation/MachineOperationManager.hxx>
#include <Configuration/SaesGUIConfiguration-schema.hxx>
#include <Operation/Devices/Polling/BCRPolling.hxx>
#include <Operation/Devices/BCRController.hxx>
#include <Gui/Widgets/RecountWidget.h>
#include <Gui/Windows/VoteProcessWindow.hxx>
#include <Gui/Windows/BarcodeReconfigureWindow.hxx>
#include <Gui/Windows/DeviceMonitorWindow.hxx>
#include <Operation/Voting/VotingEnqueuer.hxx>


using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::Log;
using namespace Smartmatic::Environment;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::SAES::Operation::Devices;
using namespace Smartmatic::SAES::Voting::VotingDevice;
using namespace Smartmatic::SAES::Resources;
using namespace Smartmatic::SAES::GUI::Windows;
using namespace Smartmatic::SAES::Operation::Voting;

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate


ISMTTLog * loggerC = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.RecountFunctionalityController",	GETTEXT_PACKAGE );

RecountFunctionalityController::RecountFunctionalityController()
{
}

RecountFunctionalityController::RecountFunctionalityController(Smartmatic::SAES::GUI::Widgets::RecountWidget * widgetC)
{
    widget = widgetC;
}

RecountFunctionalityController::~RecountFunctionalityController()
{
}

Smartmatic::Log::ISMTTLog * RecountFunctionalityController::getLogger()
{
    return loggerC;
}

void RecountFunctionalityController::Stop()
{
    DeviceMonitorWindow::getInstance()->stop();
    VoteProcessWindow::getInstance()->stop();
    BarcodeReconfigureWindow::getInstance()->stop();
    BCRPolling::getInstance()->stop();
    std::list< std::pair<int, int> > deleteQueue;
    widget->GetForPersistence ( deleteQueue );

    MachineOperationManager::getInstance()->getRecountVoteStatistics()->Persist ( deleteQueue );
}

void RecountFunctionalityController::Initialize()
{
    getLogger()->Debug ( "Votes initialization starts >>>" );

    std::list< std::pair<int, int> > updates;
    std::list<std::string> updateSessionNames;
    bool res = MachineOperationManager::getInstance()->getRecountVoteStatistics()->GetUpdateQueue ( updates, updateSessionNames );
    std::stringstream ss;
    ss << "update queue with " << updates.size() << " size";
    getLogger()->Debug ( ss.str() );

    if ( res )
    {
        widget->Update ( updates, updateSessionNames );
    }
    else
    {
        getLogger()->Debug ( "EMPTY Update queue!" );
    }

    getLogger()->Debug ( "<<< Finished initialization of votes" );

    DeviceMonitorWindow::getInstance()->start();
    VoteProcessWindow::getInstance()->start();
    VoteProcessWindow::getInstance()->showNormalMode();

    BarcodeReconfigureWindow::getInstance()->start();

    BCRPolling::getInstance()->start ( 100 );

    VotingEnqueuer::getInstance()->enableSaveVote ( true );
    VotingEnqueuer::getInstance()->validateID ( false );
    VotingEnqueuer::getInstance()->resume ( );

    signalVote = VotingEnqueuer::getInstance()->getSignalVote().connect ( sigc::mem_fun ( *this, &RecountFunctionalityController::onSignalVote ) );
    signalStatusVote = VotingEnqueuer::getInstance()->getSignalStatus().connect ( sigc::mem_fun ( *this, &RecountFunctionalityController::onSignalState ) );
}

void RecountFunctionalityController::onSignalState ( Smartmatic::SAES::Operation::Voting::VotePersistence::PersistenceStatusVote status )
{
    if ( !widget )
    {
        return;
    }

    switch ( status )
    {
        case Smartmatic::SAES::Operation::Voting::VotePersistence::PERSISTENCE_VOTE_SUCCESS:
            {
                widget->SetVoteSuccess();
                std::list< std::pair<int, int> > updates;
                std::list<std::string> updateSessionNames;
                bool res = MachineOperationManager::getInstance()->getRecountVoteStatistics()->GetUpdateQueue ( updates,
                           updateSessionNames );

                if ( res )
                {
                    widget->Update ( updates, updateSessionNames );
                }
                else
                {
                    getLogger()->Debug ( "EMPTY Update queue!" );
                }
            }
            break;

        case Smartmatic::SAES::Operation::Voting::VotePersistence::PERSISTENCE_VOTE_FAIL:
            getLogger()->Debug ( "PERSISTENCE_VOTE_FAIL" );
            break;

        case Smartmatic::SAES::Operation::Voting::VotePersistence::PERSISTENCE_VOTE_DUPLICATE:
            getLogger()->Debug ( "PERSISTENCE_VOTE_DUPLICATE" );
            break;

        default:
            break;

    }

    if ( Smartmatic::SAES::Operation::Voting::VotePersistence::PERSISTENCE_VOTE_SUCCESS != status )
    {
        widget->SetVoteFailed();
    }
}

void RecountFunctionalityController::onSignalVote ( Smartmatic::SAES::Voting::Vote::Vote * vote )
{
    if ( !widget )
    {
        return;
    }

    int num = MachineOperationManager::getInstance()->getRecountVoteStatistics()->GetSessionNum ( vote->getSessionID() );
    std::string voter = MachineOperationManager::getInstance()->getRecountVoteStatistics()->GetVoter ( *vote );
    widget->SetVote ( num, vote->getCode(), vote->getSessionID(), vote->getBallotID(), ElectionStringResourcesManager::getInstance()->getResource ( voter ) );
}

void RecountFunctionalityController::pause()
{
    BCRPolling::getInstance()->pause();
}

void RecountFunctionalityController::resume()
{
    BCRPolling::getInstance()->resume();
}
