/**
 * @file RemoveUSBFunctionality.cxx
 * @brief Body class able diagnostic functionality
 * @date 05/09/2012
 * @author Yadickson Soto
 */

#include "RemoveUSBFunctionality.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Gui/Widgets/AbstractFactoryWidget.hxx>
#include <Gui/Windows/USBMonitorWindow.hxx>
#include <Operation/Monitor/DeviceTypeMonitorPool.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Log;
using namespace Smartmatic::Functionality;
using namespace Smartmatic::SAES::Runtime::Environment;
using namespace Smartmatic::SAES::Common::Operation::Monitor;
using namespace Smartmatic::SAES::GUI::Windows;
using namespace Smartmatic::SAES::Common::Configuration;
using namespace Smartmatic::SAES::Operation::Monitor;

ISMTTLog * RemoveUSBFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.RemoveUSBFunctionality", GETTEXT_PACKAGE );

RemoveUSBFunctionality * RemoveUSBFunctionality::instance = NULL;

RemoveUSBFunctionality::RemoveUSBFunctionality()
{
    removeUSBWidget = NULL;
}

RemoveUSBFunctionality::~RemoveUSBFunctionality()
{
    deleteElements();
}

RemoveUSBFunctionality * RemoveUSBFunctionality::getInstance()
{
    if ( !instance )
    {
        instance = new RemoveUSBFunctionality();
    }

    return instance;
}

std::string RemoveUSBFunctionality::GetWindowTitle()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.RemoveUSBFunctionality.Title" );
}

Smartmatic::Log::ISMTTLog * RemoveUSBFunctionality::getLogger()
{
    return logger;
}

Glib::ustring RemoveUSBFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.RemoveUSBFunctionality.LogStartFunctionality" );
}

Glib::ustring RemoveUSBFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.RemoveUSBFunctionality.LogCloseFunctionality" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType RemoveUSBFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMREMOVEUSBFUNCTIONALITY;
}

Gtk::Widget * RemoveUSBFunctionality::GetFrame()
{
    removeUSBWidget = AbstractFactoryWidget::createRemoveUSBWidget ();
    return removeUSBWidget;
}

void RemoveUSBFunctionality::Dispose()
{
    connRemoved.disconnect();
}

void RemoveUSBFunctionality::Initialize()
{
    USBMonitorWindow::getInstance()->stop();

    exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.RemoveUSBFunctionality.FinalMessage" ) );
    connRemoved.disconnect();

    unsigned int numberOfDevices = DeviceTypeMonitorPool::getInstance()->getNumberOfDevicesByType ( DeviceType::CONFIGURATION_FLASH );

    if ( numberOfDevices >= 1 )
    {
        removeUSBWidget->refresh();
        connRemoved.disconnect();
        connRemoved = DeviceTypeMonitorPool::getInstance()->getDeviceChangedSignal().connect ( sigc::mem_fun ( *this, &RemoveUSBFunctionality::deviceChange ) );
    }
    else
    {
        endFunctionality ();
    }
}

void RemoveUSBFunctionality::endFunctionality()
{
    connRemoved.disconnect();
    ExitFunctionality();
}

void RemoveUSBFunctionality::deviceChange ( Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor * deviceTypeMonitor )
{
    if ( deviceTypeMonitor != NULL &&
            deviceTypeMonitor->getType() == DeviceType::CONFIGURATION_FLASH &&
            deviceTypeMonitor->getNumberOfDevices() == 0 )
    {
        endFunctionality ();
    }
}

void RemoveUSBFunctionality::deleteElements()
{
    if ( removeUSBWidget )
    {
        delete removeUSBWidget;
        removeUSBWidget = NULL;
    }
}

void RemoveUSBFunctionality::block()
{
    logger->Debug ( "Block functionality" );
}

void RemoveUSBFunctionality::partial()
{
    logger->Debug ( "Partial functionality" );
}

void RemoveUSBFunctionality::resume()
{
    logger->Debug ( "Resume functionality" );
}

bool RemoveUSBFunctionality::ShowWindowTitle()
{
    return removeUSBWidget->isTitle();
}
