/**
 * @file   ReportPrintingVMFunctionality.cxx
 * @brief  Implementation of ReportPrintingVMFunctionality class.
 * @author manuel.arguelles
 * @date   Jun 13, 2017
 */

#include "ReportPrintingVMFunctionality.hxx"
#include <Configuration/menu-option-type-schema.hxx>
#include <Gui/Widgets/AbstractFactoryWidget.hxx>
#include <Gui/Widgets/ReportPrintingVMWidget.hxx>
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String)
#else
#define _(String) (String)
#endif

#define N_(String) (String)

using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::GUI::Widgets;

ISMTTLog* ReportPrintingVMFunctionality::m_logger = SMTTLogManager::GetLogger(
    "Smartmatic.SAES.GUI.Functionality.ReportPrintingVMFunctionality",
    GETTEXT_PACKAGE);

ReportPrintingVMFunctionality* ReportPrintingVMFunctionality::m_currentInstance = NULL;

ReportPrintingVMFunctionality::ReportPrintingVMFunctionality()
    : m_widget(NULL)
{
}

ReportPrintingVMFunctionality::~ReportPrintingVMFunctionality()
{
}

ReportPrintingVMFunctionality* ReportPrintingVMFunctionality::getInstance()
{
    if (!m_currentInstance)
    {
        m_currentInstance = new ReportPrintingVMFunctionality();
    }

    return m_currentInstance;
}

void ReportPrintingVMFunctionality::Dispose()
{
}

void ReportPrintingVMFunctionality::Initialize()
{
}

Gtk::Widget* ReportPrintingVMFunctionality::GetFrame()
{
    m_widget = AbstractFactoryWidget::createReportPrintingVMWidget();

    return m_widget;
}

std::string ReportPrintingVMFunctionality::GetWindowTitle()
{
    return _("Print the Election Report");
}

MenuOptionType ReportPrintingVMFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMREPORTPRINTINGVMFUNCTIONALITY;
}

Smartmatic::Log::ISMTTLog* ReportPrintingVMFunctionality::getLogger()
{
    return m_logger;
}

Glib::ustring ReportPrintingVMFunctionality::getStartLogMessage()
{
    return N_("Smartmatic.SAES.GUI.Functionality.ReportPrintingVMFunctionality.LogStartFunctionality");
}

Glib::ustring ReportPrintingVMFunctionality::getFinishLogMessage()
{
    return N_("Smartmatic.SAES.GUI.Functionality.ReportPrintingVMFunctionality.LogCloseFunctionality");
}

void ReportPrintingVMFunctionality::deleteElements()
{
    if (m_widget)
    {
        delete m_widget;
        m_widget = NULL;
    }
}
