/**
 * @file ReprintReportInstallFunctionality.hxx
 * @brief Header class printer report install functionality
 * @date 15/06/2013
 * @author Yadickson Soto
 */

#ifndef REPRINT_REPORT_INSTALL_FUNCTIONALITY_HXX_
#define REPRINT_REPORT_INSTALL_FUNCTIONALITY_HXX_

#include <gtkmm.h>
#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/ReportInstallWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	ReprintReportInstallFunctionality
                 * @brief	Class printer report install functionality.
                 * @author	Yadickson Soto
                 * @date	15/06/2013
                 */
                class ReprintReportInstallFunctionality : public GraphicDisplayFunctionality
                {
                    private:
                        /**
                         * @fn	ReprintReportInstallFunctionality::ReprintReportInstallFunctionality();
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        ReprintReportInstallFunctionality();

                        static ReprintReportInstallFunctionality * instance; ///< instance of class
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                        Smartmatic::SAES::GUI::Widgets::ReportInstallWidget * widget; ///< printer report install widget

                    protected:

                        /**
                         * @fn	std::string ReprintReportInstallFunctionality::GetWindowTitle();
                         * @brief	Gets the window title.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	The window title.
                         */
                        std::string GetWindowTitle();
                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType ReprintReportInstallFunctionality::GetMenuOptionType();
                         * @brief	Gets the menu option type.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	The menu option type.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @fn	Gtk::Widget * ReprintReportInstallFunctionality::GetFrame();
                         * @brief	Gets the frame.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	null if it fails, else the frame.
                         */
                        Gtk::Widget * GetFrame();
                        /**
                         * @fn	void ReprintReportInstallFunctionality::Dispose();
                         * @brief	Dispose of this object, cleaning up any resources it uses.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        void Dispose();
                        /**
                         * @fn	void ReprintReportInstallFunctionality::Initialize();
                         * @brief	Initializes this object.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        void Initialize();
                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * ReprintReportInstallFunctionality::getLogger();
                         * @brief	Gets the logger.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	null if it fails, else the logger.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();
                        /**
                         * @fn	Glib::ustring ReprintReportInstallFunctionality::getStartLogMessage();
                         * @brief	Gets the start log message.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	The start log message.
                         */
                        Glib::ustring getStartLogMessage();
                        /**
                         * @fn	Glib::ustring ReprintReportInstallFunctionality::getFinishLogMessage();
                         * @brief	Gets the finish log message.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	The finish log message.
                         */
                        Glib::ustring getFinishLogMessage();
                        /**
                         * @fn	virtual void ReprintReportInstallFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual void deleteElements();
                        /**
                         * @fn	virtual void ReprintReportInstallFunctionality::block();
                         * @brief	method block functionality.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual void block();
                        /**
                         * @fn	virtual void ReprintReportInstallFunctionality::partial();
                         * @brief	method partial functionality.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual void partial();
                        /**
                         * @fn	virtual void ReprintReportInstallFunctionality::resume();
                         * @brief	method resume functionality.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual void resume();

                    public:
                        /**
                         * @fn	static ReprintReportInstallFunctionality * ReprintReportInstallFunctionality::getInstance();
                         * @brief	Method getter instance.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	instance of class.
                         */
                        static ReprintReportInstallFunctionality * getInstance();
                        /**
                         * @fn	virtual ReprintReportInstallFunctionality::~ReprintReportInstallFunctionality();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual ~ReprintReportInstallFunctionality();
                };
            }
        }
    }
}
#endif /* REPRINT_REPORT_INSTALL_FUNCTIONALITY_HXX_ */
