/**
 * @file SearchAndMonitorDevicesFunctionality.cxx
 * @brief Body class search and mount device monitor pool functionality
 * @date 27/07/2015
 * @author Yadickson Soto
 */

#include "SearchAndMonitorDevicesFunctionality.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Log;
using namespace Smartmatic::Functionality;

ISMTTLog * SearchAndMonitorDevicesFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.SearchAndMonitorDevicesFunctionality", GETTEXT_PACKAGE );

SearchAndMonitorDevicesFunctionality * SearchAndMonitorDevicesFunctionality::instance = NULL;

SearchAndMonitorDevicesFunctionality::SearchAndMonitorDevicesFunctionality()
{
    widget = NULL;
}

SearchAndMonitorDevicesFunctionality::~SearchAndMonitorDevicesFunctionality()
{
    deleteElements();
}

SearchAndMonitorDevicesFunctionality * SearchAndMonitorDevicesFunctionality::getInstance()
{
    if ( !instance )
    {
        instance = new SearchAndMonitorDevicesFunctionality();
    }

    return instance;
}

std::string SearchAndMonitorDevicesFunctionality::GetWindowTitle()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.SearchAndMonitorDevicesFunctionality.Title" );
}

Smartmatic::Log::ISMTTLog * SearchAndMonitorDevicesFunctionality::getLogger()
{
    return logger;
}

Glib::ustring SearchAndMonitorDevicesFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.SearchAndMonitorDevicesFunctionality.LogStartFunctionality" );
}

Glib::ustring SearchAndMonitorDevicesFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.SearchAndMonitorDevicesFunctionality.LogCloseFunctionality" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType SearchAndMonitorDevicesFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMSEARCHANDMONITORDEVICESFUNCTIONALITY;
}

Gtk::Widget * SearchAndMonitorDevicesFunctionality::GetFrame()
{
    widget = new SearchAndMonitorDevicesWidget ();
    return widget;
}

void SearchAndMonitorDevicesFunctionality::Dispose()
{

}

void SearchAndMonitorDevicesFunctionality::Initialize()
{
    widget->initialize();
    exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.SearchAndMonitorDevicesFunctionality.FinalMessage" ) );
    disableExitButton();
    widget->getSignalEnd().connect ( sigc::mem_fun ( this, &SearchAndMonitorDevicesFunctionality::endSearch ) );
}

void SearchAndMonitorDevicesFunctionality::endSearch()
{
    enableExitButton();
    logger->Audit ( N_ ( "Smartmatic.SAES.GUI.Functionality.SearchAndMonitorDevicesFunctionality.AbleDiagnosisExecuted" ) );
    ExitFunctionality();
}

void SearchAndMonitorDevicesFunctionality::deleteElements()
{
    if ( widget )
    {
        delete widget;
        widget = NULL;
    }
}

void SearchAndMonitorDevicesFunctionality::block()
{
    logger->Debug ( "Block functionality" );
}

void SearchAndMonitorDevicesFunctionality::partial()
{
    logger->Debug ( "Partial functionality" );
}

void SearchAndMonitorDevicesFunctionality::resume()
{
    logger->Debug ( "Resume functionality" );
}

bool SearchAndMonitorDevicesFunctionality::ShowWindowTitle()
{
    return false;
}

bool SearchAndMonitorDevicesFunctionality::ForceExecute()
{
    return true;
}
