/**
 * @file SearchAndMonitorDevicesFunctionality.hxx
 * @brief Header class search and mount device monitor pool functionality
 * @date 27/07/2015
 * @author Yadickson Soto
 */

#ifndef SEARCH_AND_MONITOR_DEVICES_FUNCTIONALITY_HXX_
#define SEARCH_AND_MONITOR_DEVICES_FUNCTIONALITY_HXX_

#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/SearchAndMonitorDevicesWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	SearchAndMonitorDevicesFunctionality
                 * @brief	Class able diagnostic functionality.
                 * @author	Yadickson Soto
                 * @date	27/07/2015
                 */
                class SearchAndMonitorDevicesFunctionality : public GraphicDisplayFunctionality
                {
                    private:
                        /**
                         * @fn	SearchAndMonitorDevicesFunctionality::SearchAndMonitorDevicesFunctionality();
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	27/07/2015
                         */
                        SearchAndMonitorDevicesFunctionality();

                        static SearchAndMonitorDevicesFunctionality * instance; ///< instance of class
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                        Smartmatic::SAES::GUI::Widgets::SearchAndMonitorDevicesWidget * widget; ///< widget to show load devices

                    protected:

                        /**
                         * @fn	std::string SearchAndMonitorDevicesFunctionality::GetWindowTitle();
                         * @brief	Gets the window title.
                         * @author	Yadickson Soto
                         * @date	27/07/2015
                         * @return	The window title.
                         */
                        std::string GetWindowTitle();
                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType SearchAndMonitorDevicesFunctionality::GetMenuOptionType();
                         * @brief	Gets the menu option type.
                         * @author	Yadickson Soto
                         * @date	27/07/2015
                         * @return	The menu option type.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @fn	Gtk::Widget * SearchAndMonitorDevicesFunctionality::GetFrame();
                         * @brief	Gets the frame.
                         * @author	Yadickson Soto
                         * @date	27/07/2015
                         * @return	null if it fails, else the frame.
                         */
                        Gtk::Widget * GetFrame();
                        /**
                         * @fn	void SearchAndMonitorDevicesFunctionality::Dispose();
                         * @brief	Dispose of this object, cleaning up any resources it uses.
                         * @author	Yadickson Soto
                         * @date	27/07/2015
                         */
                        void Dispose();
                        /**
                         * @fn	void SearchAndMonitorDevicesFunctionality::Initialize();
                         * @brief	Initializes this object.
                         * @author	Yadickson Soto
                         * @date	27/07/2015
                         */
                        void Initialize();
                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * SearchAndMonitorDevicesFunctionality::getLogger();
                         * @brief	Gets the logger.
                         * @author	Yadickson Soto
                         * @date	27/07/2015
                         * @return	null if it fails, else the logger.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();
                        /**
                         * @fn	Glib::ustring SearchAndMonitorDevicesFunctionality::getStartLogMessage();
                         * @brief	Gets the start log message.
                         * @author	Yadickson Soto
                         * @date	27/07/2015
                         * @return	The start log message.
                         */
                        Glib::ustring getStartLogMessage();
                        /**
                         * @fn	Glib::ustring SearchAndMonitorDevicesFunctionality::getFinishLogMessage();
                         * @brief	Gets the finish log message.
                         * @author	Yadickson Soto
                         * @date	27/07/2015
                         * @return	The finish log message.
                         */
                        Glib::ustring getFinishLogMessage();
                        /**
                         * @fn	virtual void SearchAndMonitorDevicesFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	27/07/2015
                         */
                        virtual void deleteElements();
                        /**
                         * @fn	virtual void SearchAndMonitorDevicesFunctionality::block();
                         * @brief	method block functionality.
                         * @author	Yadickson Soto
                         * @date	27/07/2015
                         */
                        virtual void block();
                        /**
                         * @fn	virtual void SearchAndMonitorDevicesFunctionality::partial();
                         * @brief	method partial functionality.
                         * @author	Yadickson Soto
                         * @date	27/07/2015
                         */
                        virtual void partial();
                        /**
                         * @fn	virtual void SearchAndMonitorDevicesFunctionality::resume();
                         * @brief	method resume functionality.
                         * @author	Yadickson Soto
                         * @date	27/07/2015
                         */
                        virtual void resume();
                        /**
                         * @fn	void SearchAndMonitorDevicesFunctionality::endSearch();
                         * @brief	method end diagnosis.
                         * @author	Yadickson Soto
                         * @date	27/07/2015
                         */
                        void endSearch();
                        /**
                         * @fn	virtual bool LoginFunctionality::ShowWindowTitle();
                         * @brief	Gets whether window title is visible.
                         * @author	Yadickson Soto
                         * @date	27/07/2015
                         * @return	true is show window title.
                         */
                        virtual bool ShowWindowTitle();

                        /**
                         * @fn	virtual bool ForceExecute();
                         * @brief	Method force execute functionality
                         * @author	Yadickson Soto
                         * @date	27/07/2015
                         * @return	true if force execute
                         */
                        virtual bool ForceExecute();

                    public:
                        /**
                         * @fn	static SearchAndMonitorDevicesFunctionality * SearchAndMonitorDevicesFunctionality::getInstance();
                         * @brief	Method getter instance.
                         * @author	Yadickson Soto
                         * @date	27/07/2015
                         * @return	instance of class.
                         */
                        static SearchAndMonitorDevicesFunctionality * getInstance();
                        /**
                         * @fn	virtual SearchAndMonitorDevicesFunctionality::~SearchAndMonitorDevicesFunctionality();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	27/07/2015
                         */
                        virtual ~SearchAndMonitorDevicesFunctionality();
                };
            }
        }
    }
}
#endif /* SEARCH_AND_MONITOR_DEVICES_FUNCTIONALITY_HXX_ */
