/**
 * @file SerialNumberFunctionality.cxx
 * @brief Body serial number functionality class
 * @date 21/09/2012
 * @author Yadickson Soto
 */

#include "SerialNumberFunctionality.hxx"
#include <Log/SMTTLogManager.h>
#include <Log/ISMTTLog.h>
#include <Configuration/s-a-e-s-functionality-conf-manager.h>
#include <Operation/Devices/P168AController.hxx>
#include <Operation/Devices/PDBController.hxx>
#include <Gui/Widgets/FactoryMethodWidget.hxx>
#include <System/OptParser.hxx>
#include <System/Utils/StringUtils.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::System;
using namespace Smartmatic::System::Utils;
using namespace Smartmatic::Functionality;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::Operation::Devices;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Environment;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;

ISMTTLog * SerialNumberFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.SerialNumberFunctionality", GETTEXT_PACKAGE );

SerialNumberFunctionality * SerialNumberFunctionality::current_instance = NULL;
SerialNumberFunctionality * SerialNumberFunctionality::getInstance()
{
    if ( !current_instance )
    {
        current_instance = new SerialNumberFunctionality();
    }

    return current_instance;
}

SerialNumberFunctionality::SerialNumberFunctionality()
{
    widget = NULL;
    processSerial = true;

    signalGetDispatcher.getSyncSignal().connect ( sigc::mem_fun ( *this, &SerialNumberFunctionality::onGetSerial ) );
    signalSaveDispatcher.getSyncSignal().connect ( sigc::mem_fun ( *this, &SerialNumberFunctionality::onSaveSerial ) );
}

void SerialNumberFunctionality::deleteElements()
{
    if ( widget )
    {
        delete widget;
        widget = NULL;
    }
}

void SerialNumberFunctionality::Initialize()
{
    exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.SerialNumberFunctionality.ExitFunctionality" ) );
    widget->getSignalEnd().connect ( sigc::mem_fun ( this, &SerialNumberFunctionality::saveSerial ) );

    disableExitButton();

    processSerial = true;
    start ( 0 );
}

Gtk::Widget * SerialNumberFunctionality::GetFrame()
{
    widget = FactoryMethodWidget::createSerialNumberWidget();
    return widget;
}

std::string SerialNumberFunctionality::GetWindowTitle()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.SerialNumberFunctionality.Title" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType SerialNumberFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMSERIALNUMBERFUNCTIONALITY;
}

void SerialNumberFunctionality::Dispose()
{

}

bool SerialNumberFunctionality::process()
{
    if ( processSerial )
    {
        std::string machineModel;
        std::string serial;
        OptParser::getInstance()->getArg(OptParser::MACHINE_MODEL, machineModel);
        if (StringUtils::toUpper(machineModel) == "VM-A4517")
        {
            serial = PDBController::getInstance()->getSerialNumber();
        }
        else
        {
            serial = P168AController::getInstance()->getSerialNumber();
        }
        signalGetDispatcher.emit ( new std::string ( serial ) );
    }
    else
    {
        bool save = SAESGUIConfigurationManager::getInstance()->getSerialNumberConfiguration().getPersistence();
        std::string machineModel;
        OptParser::getInstance()->getArg(OptParser::MACHINE_MODEL, machineModel);
        if (StringUtils::toUpper(machineModel) == "VM-A4517")
        {
             PDBController::getInstance()->setSerialNumber( m_serial, save);
        }
        else
        {
             P168AController::getInstance()->setSerialNumber ( m_serial, save );
        }
        signalSaveDispatcher.emit ( NULL );
    }

    return false;
}

void SerialNumberFunctionality::onGetSerial ( void * object )
{
    std::string * serial = static_cast < std::string * > ( object );
    widget->setSerialNumber ( *serial );
    delete serial;
}

void SerialNumberFunctionality::onSaveSerial ( void * object )
{
    ExitFunctionality();
}

void SerialNumberFunctionality::saveSerial()
{
    m_serial = widget->getSerialNumber();

    processSerial = false;
    start ( 0 );
}

SerialNumberFunctionality::~SerialNumberFunctionality()
{
    deleteElements();
}

Smartmatic::Log::ISMTTLog * SerialNumberFunctionality::getLogger()
{
    return logger;
}

Glib::ustring SerialNumberFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.SerialNumberFunctionality.LogStartFunctionality" );
}

Glib::ustring SerialNumberFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.SerialNumberFunctionality.LogCloseFunctionality" );
}
