/**
 * @file SimulatorVotesFunctionality.hxx
 * @brief Header simulator votes functionality class
 * @date 05/10/2012
 * @author Yadickson Soto
 */

#ifndef _SIMULATOR_VOTES_FUNCTIONALITY_HXX
#define _SIMULATOR_VOTES_FUNCTIONALITY_HXX

#include <gtkmm.h>
#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/Voting/SimulatorVotesWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	SimulatorVotesFunctionality
                 * @brief	simulator votes functionality class.
                 * @author	Yadickson Soto
                 * @date	05/10/2012
                 */
                class SimulatorVotesFunctionality : public GraphicDisplayFunctionality
                {
                    public:

                        /**
                         * @fn	virtual SimulatorVotesFunctionality::~SimulatorVotesFunctionality();
                         * @brief	class destructor.
                         * @author	Yadickson Soto
                         * @date	05/10/2012
                         */
                        virtual ~SimulatorVotesFunctionality();
                        /**
                         * @fn	static SimulatorVotesFunctionality * SimulatorVotesFunctionality::getInstance();
                         * @brief	Singleton instance getter method.
                         * @author	Yadickson Soto
                         * @date	05/10/2012
                         * @return	instance of class.
                         */
                        static SimulatorVotesFunctionality * getInstance();

                    protected:

                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * SimulatorVotesFunctionality::getLogger();
                         * @brief	Logger getter method.
                         * @author	Yadickson Soto
                         * @date	05/10/2012
                         * @return	logger.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();
                        /**
                         * @fn	Glib::ustring SimulatorVotesFunctionality::getStartLogMessage();
                         * @brief	Gets the logger starting message.
                         * @author	Yadickson Soto
                         * @date	05/10/2012
                         * @return	message.
                         */
                        Glib::ustring getStartLogMessage();
                        /**
                         * @fn	Glib::ustring SimulatorVotesFunctionality::getFinishLogMessage();
                         * @brief	Gets the logger ending message.
                         * @author	Yadickson Soto
                         * @date	05/10/2012
                         * @return	message.
                         */
                        Glib::ustring getFinishLogMessage();
                        /**
                         * @fn	virtual void SimulatorVotesFunctionality::refresh();
                         * @brief	refresh widget method.
                         * @author	Yadickson Soto
                         * @date	05/10/2012
                         */
                        virtual void refresh();

                    private:

                        static SimulatorVotesFunctionality * current_instance;  ///< The current instance
                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
                        Smartmatic::SAES::GUI::Widgets::Voting::SimulatorVotesWidget * widget; ///< The widget

                        /**
                         * @fn	SimulatorVotesFunctionality::SimulatorVotesFunctionality();
                         * @brief	class constructor.
                         * @author	Yadickson Soto
                         * @date	05/10/2012
                         */
                        SimulatorVotesFunctionality();
                        /**
                         * @fn	void SimulatorVotesFunctionality::Dispose();
                         * @brief	method dispose.
                         * @author	Yadickson Soto
                         * @date	05/10/2012
                         */
                        void Dispose();
                        /**
                         * @fn	void SimulatorVotesFunctionality::Initialize();
                         * @brief	method initialize.
                         * @author	Yadickson Soto
                         * @date	05/10/2012
                         */
                        void Initialize();
                        /**
                         * @fn	Gtk::Widget * SimulatorVotesFunctionality::GetFrame();
                         * @brief	Frame getter method.
                         * @author	Yadickson Soto
                         * @date	05/10/2012
                         * @return	new frame.
                         */
                        Gtk::Widget * GetFrame();
                        /**
                         * @fn	virtual std::string SimulatorVotesFunctionality::GetWindowTitle();
                         * @brief	Window title getter method.
                         * @author	Yadickson Soto
                         * @date	05/10/2012
                         * @return	the window title.
                         */
                        virtual std::string GetWindowTitle();
                        /**
                         * @fn	virtual bool SimulatorVotesFunctionality::ShowWindowTitle();
                         * @brief	Gets whether window title is visible.
                         * @author	Yadickson Soto
                         * @date	05/10/2012
                         * @return	true is show window title.
                         */
                        virtual bool ShowWindowTitle();

                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType SimulatorVotesFunctionality::GetMenuOptionType();
                         * @brief	Menu option type getter method.
                         * @author	Yadickson Soto
                         * @date	05/10/2012
                         * @return	the menu option type.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @fn	void SimulatorVotesFunctionality::end();
                         * @brief	method end diagnostic.
                         * @author	Yadickson Soto
                         * @date	05/10/2012
                         */
                        void end();
                        /**
                         * @fn	virtual void SimulatorVotesFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	05/10/2012
                         */
                        virtual void deleteElements();
                };
            }
        }
    }
}

#endif // _SIMULATOR_VOTES_FUNCTIONALITY_HXX
