/**
 * @file SystemFilesIntegrityCheckFunctionality.cxx
 * @brief Body class system files integrity check functionality.
 * @date 15/01/2019
 * @author eduardo.fernandez
 */

#include "SystemFilesIntegrityCheckFunctionality.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Gui/Widgets/AbstractFactoryWidget.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Log;
using namespace Smartmatic::Functionality;
using namespace Smartmatic::SAES::Common::Operation::Monitor;
using namespace Smartmatic::SAES::GUI::Windows;

ISMTTLog * SystemFilesIntegrityCheckFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.SystemFilesIntegrityCheckFunctionality", GETTEXT_PACKAGE );

SystemFilesIntegrityCheckFunctionality * SystemFilesIntegrityCheckFunctionality::instance = NULL;

SystemFilesIntegrityCheckFunctionality::SystemFilesIntegrityCheckFunctionality()
{
    systemFilesIntegrityCheckWidget = NULL;
}

SystemFilesIntegrityCheckFunctionality::~SystemFilesIntegrityCheckFunctionality()
{
    deleteElements();
}

SystemFilesIntegrityCheckFunctionality * SystemFilesIntegrityCheckFunctionality::getInstance()
{
    if ( !instance )
    {
        instance = new SystemFilesIntegrityCheckFunctionality();
    }

    return instance;
}

std::string SystemFilesIntegrityCheckFunctionality::GetWindowTitle()
{
    return  systemFilesIntegrityCheckWidget->getTitleText();
}

Smartmatic::Log::ISMTTLog * SystemFilesIntegrityCheckFunctionality::getLogger()
{
    return logger;
}

Glib::ustring SystemFilesIntegrityCheckFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.SystemFilesIntegrityCheckFunctionality.LogStartFunctionality" );
}

Glib::ustring SystemFilesIntegrityCheckFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.SystemFilesIntegrityCheckFunctionality.LogCloseFunctionality" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType SystemFilesIntegrityCheckFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMSYSTEMFILESINTEGRITYCHECKFUNCTIONALITY;
}

Gtk::Widget * SystemFilesIntegrityCheckFunctionality::GetFrame()
{
    systemFilesIntegrityCheckWidget = AbstractFactoryWidget::createSystemFilesIntegrityCheckWidget ();
    return systemFilesIntegrityCheckWidget;
}

void SystemFilesIntegrityCheckFunctionality::Dispose()
{
}

void SystemFilesIntegrityCheckFunctionality::Initialize()
{
    systemFilesIntegrityCheckWidget->getSignalEnd().connect ( sigc::mem_fun ( this, &SystemFilesIntegrityCheckFunctionality::endFunctionality ) );
    systemFilesIntegrityCheckWidget->initialize();
}

void SystemFilesIntegrityCheckFunctionality::endFunctionality()
{
    ExitFunctionality();
}

void SystemFilesIntegrityCheckFunctionality::deleteElements()
{
    if ( systemFilesIntegrityCheckWidget )
    {
        delete systemFilesIntegrityCheckWidget;
        systemFilesIntegrityCheckWidget = NULL;
    }
}

void SystemFilesIntegrityCheckFunctionality::block()
{
    logger->Debug ( "Block functionality" );
}

void SystemFilesIntegrityCheckFunctionality::partial()
{
    logger->Debug ( "Partial functionality" );
}

void SystemFilesIntegrityCheckFunctionality::resume()
{
    logger->Debug ( "Resume functionality" );
}

bool SystemFilesIntegrityCheckFunctionality::ShowWindowTitle()
{
    return systemFilesIntegrityCheckWidget->isTitle();
}
