/**
 * @file   VotingMachineInstallationFunctionality.cxx
 * @brief  voting machine installation functionality class.
 * @author Youssef.tourkmani
 * @author manuel.arguelles
 * @date   01/11/2012
 */

#include "VotingMachineInstallationFunctionality.hxx"
#include <Log/SMTTLogManager.h>
#include <Operation/Devices/Polling/BCRPolling.hxx>
#include <Gui/Windows/BarcodeReconfigureWindow.hxx>
#include <Gui/Windows/VoteProcessWindow.hxx>
#include <Operation/MachineOperationManager.hxx>
#include <Gui/Widgets/AbstractFactoryWidget.hxx>
#include <Operation/CheckDataManager.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Gtk;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::GUI::Windows;
using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::Functionality;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Operation::Devices;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::GUI::Windows;
using namespace Smartmatic::SAES::GUI::Widgets;

ISMTTLog* VotingMachineInstallationFunctionality::logger = SMTTLogManager::GetLogger(
    "Smartmatic.SAES.GUI.Functionality.VotingMachineInstallationFunctionality",
    GETTEXT_PACKAGE);

VotingMachineInstallationFunctionality* VotingMachineInstallationFunctionality::current_instance = NULL;

VotingMachineInstallationFunctionality* VotingMachineInstallationFunctionality::getInstance()
{
    if ( !current_instance )
    {
        current_instance = new VotingMachineInstallationFunctionality();
    }

    return current_instance;
}


VotingMachineInstallationFunctionality::VotingMachineInstallationFunctionality()
{
    wizardWidget = NULL;
}

VotingMachineInstallationFunctionality::~VotingMachineInstallationFunctionality()
{
}

void VotingMachineInstallationFunctionality::deleteElements()
{
    if (wizardWidget)
    {
        delete (wizardWidget);
        wizardWidget = NULL;
    }
}

Widget* VotingMachineInstallationFunctionality::GetFrame()
{
    wizardWidget = AbstractFactoryWidget::createVotingMachineInstallationWizardWidget();
    return wizardWidget;
}

void VotingMachineInstallationFunctionality::onBeforeExit()
{
    BCRPolling::getInstance()->resume();
    VoteProcessWindow::getInstance()->start();
    BarcodeReconfigureWindow::getInstance()->start();
    Dispose();
}

void VotingMachineInstallationFunctionality::onFinish()
{
    exitWidget.setInfo(N_("Smartmatic.SAES.GUI.Functionality.VotingMachineInstallationFunctionality.VotingMachineInstalled"));
    logger->Audit(N_("Smartmatic.SAES.GUI.Functionality.VotingMachineInstallationFunctionality.VotingMachineInstallationSuccessfull"));
}

void VotingMachineInstallationFunctionality::HideOnFinish()
{
    Dispose();
    ExitFunctionality();
}

void VotingMachineInstallationFunctionality::Dispose()
{
    connHide.disconnect();
    connFinish.disconnect();
    wizardWidget->Dispose();

    if (SAESGUIConfigurationManager::getInstance()->getInstallationWizardConfiguration().getDeleteLoginKey())
    {
        CheckDataManager::getInstance()->clearSynchronize();
    }
}

void VotingMachineInstallationFunctionality::Initialize()
{
    exitWidget.setInfo(N_("Smartmatic.SAES.GUI.Functionality.VotingMachineInstallationFunctionality.NoVotingMachineInstalled"));
    disableExitButton();
    logger->Audit(N_("Smartmatic.SAES.GUI.Functionality.VotingMachineInstallationFunctionality.StartingVotingMachineInstallation"));
    wizardWidget->Initialize();
    connHide = wizardWidget->signalHide_detected.connect(sigc::mem_fun(*this, &VotingMachineInstallationFunctionality::HideOnFinish));
    connFinish = wizardWidget->signalFinish_detected.connect(sigc::mem_fun(*this, &VotingMachineInstallationFunctionality::onFinish));
}

std::string VotingMachineInstallationFunctionality::GetWindowTitle()
{
    return N_("Smartmatic.SAES.GUI.Functionality.VotingMachineInstallation");
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType VotingMachineInstallationFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMVOTINGMACHINEINSTALLATIONFUNCTIONALITY;
}

Smartmatic::Log::ISMTTLog * VotingMachineInstallationFunctionality::getLogger()
{
    return logger;
}

Glib::ustring VotingMachineInstallationFunctionality::getStartLogMessage()
{
    return N_("Smartmatic.SAES.GUI.Functionality.VotingMachineInstallationFunctionality.LogStartFunctionality");
}

Glib::ustring VotingMachineInstallationFunctionality::getFinishLogMessage()
{
    return N_("Smartmatic.SAES.GUI.Functionality.VotingMachineInstallationFunctionality.LogCloseFunctionality");
}

void VotingMachineInstallationFunctionality::refresh()
{
    BCRPolling::getInstance()->pause();
    VoteProcessWindow::getInstance()->stop();
    BarcodeReconfigureWindow::getInstance()->stop();
    GraphicDisplayFunctionality::refresh();
}
