/**
 * @file WizardFunctionality.cxx
 * @brief Body class wizard functionality
 * @date 17/10/2012
 * @author Yadickson Soto
 */

#include "WizardFunctionality.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Gui/Windows/VoteProcessWindow.hxx>
#include <Gui/Windows/BarcodeReconfigureWindow.hxx>
#include <Gui/Windows/DeviceMonitorWindow.hxx>
#include <Gui/Widgets/AbstractFactoryWidget.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Log;
using namespace Smartmatic::Functionality;
using namespace Smartmatic::SAES::GUI::Windows;

ISMTTLog * WizardFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.WizardFunctionality", GETTEXT_PACKAGE );

WizardFunctionality * WizardFunctionality::instance = NULL;

WizardFunctionality::WizardFunctionality()
{
    widget = NULL;
}

WizardFunctionality::~WizardFunctionality()
{
    deleteElements();
}

WizardFunctionality * WizardFunctionality::getInstance()
{
    if ( !instance )
    {
        instance = new WizardFunctionality();
    }

    return instance;
}

std::string WizardFunctionality::GetWindowTitle()
{
    return widget->getTitleText();
}

bool WizardFunctionality::ShowWindowTitle()
{
    return widget->isTitle();
}

Smartmatic::Log::ISMTTLog * WizardFunctionality::getLogger()
{
    return logger;
}

Glib::ustring WizardFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.WizardFunctionality.LogStartFunctionality" );
}

Glib::ustring WizardFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.WizardFunctionality.LogCloseFunctionality" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType WizardFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMWIZARDFUNCTIONALITY;
}

Gtk::Widget * WizardFunctionality::GetFrame()
{
    widget = AbstractFactoryWidget::createMachineWizardWidget();
    return widget;
}

void WizardFunctionality::Dispose()
{
    VoteProcessWindow::getInstance()->stop();
    BarcodeReconfigureWindow::getInstance()->stop();
    DeviceMonitorWindow::getInstance()->stop();
}

void WizardFunctionality::Initialize()
{
    VoteProcessWindow::getInstance()->start();
    BarcodeReconfigureWindow::getInstance()->start();
    DeviceMonitorWindow::getInstance()->start();
    exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.WizardFunctionality.ExitFunctionality" ) );
    widget->getSignalEnd().connect ( sigc::mem_fun ( this, &WizardFunctionality::end ) );
    widget->start();
    enableExitButton();
}

void WizardFunctionality::deleteElements()
{
    if ( widget )
    {
        delete widget;
        widget = NULL;
    }
}

bool WizardFunctionality::ShowHelp()
{
    return widget->isHelp();
}

void WizardFunctionality::end()
{
    ExitFunctionality();
}

Smartmatic::GUI::Widgets::StepWidget * WizardFunctionality::getHelpWidget()
{
    return widget->getHelpWidget();
}

void WizardFunctionality::refresh()
{
    widget->refresh();
    GraphicDisplayFunctionality::refresh();
}

void WizardFunctionality::onSetKey ( Smartmatic::GUI::Widgets::KeysActionsCode value )
{
    if ( widget )
    {
        widget->SetKey ( value );
    }
}
