/**
 * @file WizardFunctionality.hxx
 * @brief Header class wizard functionality
 * @date 17/10/2012
 * @author Yadickson Soto
 */

#ifndef WIZARDFUNCTIONALITY_HXX_
#define WIZARDFUNCTIONALITY_HXX_

#include <gtkmm.h>
#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/MachineWizardWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	WizardFunctionality
                 * @brief	Class wizard functionality.
                 * @author	Yadickson Soto
                 * @date	17/10/2012
                 */
                class WizardFunctionality : public GraphicDisplayFunctionality
                {
                    private:
                        /**
                         * @fn	WizardFunctionality::WizardFunctionality();
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         */
                        WizardFunctionality();

                        static WizardFunctionality * instance; ///< instance of class
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                        Smartmatic::SAES::GUI::Widgets::MachineWizardWidget * widget; ///< voting widget

                    protected:

                        /**
                         * @fn	std::string WizardFunctionality::GetWindowTitle();
                         * @brief	Gets the window title.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         * @return	The window title.
                         */
                        std::string GetWindowTitle();
                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType WizardFunctionality::GetMenuOptionType();
                         * @brief	Gets the menu option type.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         * @return	The menu option type.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @fn	Gtk::Widget * WizardFunctionality::GetFrame();
                         * @brief	Gets the frame.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         * @return	null if it fails, else the frame.
                         */
                        Gtk::Widget * GetFrame();
                        /**
                         * @fn	void WizardFunctionality::Dispose();
                         * @brief	Dispose of this object, cleaning up any resources it uses.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         */
                        void Dispose();
                        /**
                         * @fn	void WizardFunctionality::Initialize();
                         * @brief	Initializes this object.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         */
                        void Initialize();
                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * WizardFunctionality::getLogger();
                         * @brief	Gets the logger.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         * @return	null if it fails, else the logger.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();
                        /**
                         * @fn	Glib::ustring WizardFunctionality::getStartLogMessage();
                         * @brief	Gets the start log message.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         * @return	The start log message.
                         */
                        Glib::ustring getStartLogMessage();
                        /**
                         * @fn	Glib::ustring WizardFunctionality::getFinishLogMessage();
                         * @brief	Gets the finish log message.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         * @return	The finish log message.
                         */
                        Glib::ustring getFinishLogMessage();
                        /**
                         * @fn	virtual void WizardFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         */
                        virtual void deleteElements();
                        /**
                         * @fn	virtual bool WizardFunctionality::ShowWindowTitle();
                         * @brief	Gets whether window title is visible.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         * @return	true is show window title.
                         */
                        virtual bool ShowWindowTitle();
                        /**
                         * @fn	virtual bool WizardFunctionality::ShowHelp();
                         * @brief	getter is show help.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         * @return	true is show help.
                         */
                        virtual bool ShowHelp();
                        /**
                         * @fn	virtual Smartmatic::GUI::Widgets::StepWidget * WizardFunctionality::getHelpWidget();
                         * @brief	virtual method refresh.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         * @return	null if it fails, else the help widget.
                         */
                        virtual Smartmatic::GUI::Widgets::StepWidget * getHelpWidget();
                        /**
                         * @fn	virtual void WizardFunctionality::refresh();
                         * @brief	refresh widget method.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         */
                        virtual void refresh();
                        /**
                         * @fn	void WizardFunctionality::end();
                         * @brief	method end diagnostic.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         */
                        void end();
                        /**
                         * @fn	virtual void onSetKey ( Smartmatic::GUI::Widgets::KeysActionsCode value );
                         * @brief	virtual method setter key.
                         * @author	Yadickson Soto
                         * @date	20/11/2012
                         * @param	value	value key.
                         */
                        virtual void onSetKey ( Smartmatic::GUI::Widgets::KeysActionsCode value );

                    public:
                        /**
                         * @fn	static WizardFunctionality * WizardFunctionality::getInstance();
                         * @brief	Method getter instance.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         * @return	instance of class.
                         */
                        static WizardFunctionality * getInstance();
                        /**
                         * @fn	virtual WizardFunctionality::~WizardFunctionality();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         */
                        virtual ~WizardFunctionality();
                };
            }
        }
    }
}
#endif /* WIZARDFUNCTIONALITY_HXX_ */
