/**
 * @file ZipCodeFunctionality.cxx
 * @brief Body pm setup functionality class
 * @date 27/09/2012
 * @author Yadickson Soto
 */

#include "ZipCodeFunctionality.hxx"
#include <Log/SMTTLogManager.h>
#include <Log/ISMTTLog.h>
#include <Configuration/s-a-e-s-functionality-conf-manager.h>
#include <Operation/ZipCodeManager.hxx>
#include <Gui/Widgets/FactoryMethodWidget.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::Functionality;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Environment;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;

ISMTTLog * ZipCodeFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.ZipCodeFunctionality", GETTEXT_PACKAGE );

ZipCodeFunctionality * ZipCodeFunctionality::current_instance = NULL;
ZipCodeFunctionality * ZipCodeFunctionality::getInstance()
{
    if ( !current_instance )
    {
        current_instance = new ZipCodeFunctionality();
    }

    return current_instance;
}

ZipCodeFunctionality::ZipCodeFunctionality()
{
    widget = NULL;
}

void ZipCodeFunctionality::deleteElements()
{
    if ( widget )
    {
        delete widget;
        widget = NULL;
    }
}

void ZipCodeFunctionality::Initialize()
{
    exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.ZipCodeFunctionality.ExitFunctionality" ) );
    widget->getSignalEnd().connect ( sigc::mem_fun ( this, &ZipCodeFunctionality::saveZipCode ) );
    widget->initialize();
    disableExitButton();
    setZipCode();
}

Gtk::Widget * ZipCodeFunctionality::GetFrame()
{
    widget = FactoryMethodWidget::createZipCodeWidget();
    return widget;
}

std::string ZipCodeFunctionality::GetWindowTitle()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.ZipCodeFunctionality.Title" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType ZipCodeFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMZIPCODEFUNCTIONALITY;
}

void ZipCodeFunctionality::Dispose()
{
}

void ZipCodeFunctionality::setZipCode()
{
    widget->setZipCode ( ZipCodeManager::getZipCode() );
}

void ZipCodeFunctionality::saveZipCode()
{
    std::string zipCode = widget->getZipCode();
    ZipCodeManager::setZipCode ( zipCode );
    ExitFunctionality();
}

ZipCodeFunctionality::~ZipCodeFunctionality()
{
    deleteElements();
}

Smartmatic::Log::ISMTTLog * ZipCodeFunctionality::getLogger()
{
    return logger;
}

Glib::ustring ZipCodeFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.ZipCodeFunctionality.LogStartFunctionality" );
}

Glib::ustring ZipCodeFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.ZipCodeFunctionality.LogCloseFunctionality" );
}
