/**
 * @file	alarm-box-diagnosis-functionality.cc
 * @brief	alarm box diagnosis functionality class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#include "alarm-box-diagnosis-functionality.h"
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::Functionality;
using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::GUI::Windows;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::Configuration;

ISMTTLog * AlarmBoxDiagnosisFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.AlarmBoxDiagnosisFunctionality", GETTEXT_PACKAGE );

AlarmBoxDiagnosisFunctionality::AlarmBoxDiagnosisFunctionality()
{
    alarmWidget = NULL;
}

AlarmBoxDiagnosisFunctionality * AlarmBoxDiagnosisFunctionality::current_instance = NULL;

AlarmBoxDiagnosisFunctionality * AlarmBoxDiagnosisFunctionality::getInstance()
{
    if ( !current_instance )
    {
        current_instance = new AlarmBoxDiagnosisFunctionality();
    }

    return current_instance;
}

AlarmBoxDiagnosisFunctionality::~AlarmBoxDiagnosisFunctionality()
{
    deleteElements();
}

void AlarmBoxDiagnosisFunctionality::deleteElements()
{
    if ( alarmWidget )
    {
        delete ( alarmWidget );
        alarmWidget = NULL;
    }
}

void AlarmBoxDiagnosisFunctionality::Initialize()
{
    connFinishDiagnosis.disconnect();
    connFinishDiagnosis = alarmWidget->getSignalEnd().connect ( sigc::mem_fun ( *this, &AlarmBoxDiagnosisFunctionality::endDiagnosis ) );
    alarmWidget->start();
}

void AlarmBoxDiagnosisFunctionality::endDiagnosis()
{
    enableExitButton();
    logger->Audit ( N_ ( "Smartmatic.SAES.GUI.Functionality.AlarmBoxDiagnosisFunctionality.AlarmBoxDiagnosisExecuted" ) );
    ExitFunctionality();
}

Gtk::Widget * AlarmBoxDiagnosisFunctionality::GetFrame()
{
    alarmWidget = new Smartmatic::SAES::GUI::Widgets::AlarmBoxDiagnoseWidget ();
    return alarmWidget;
}

std::string AlarmBoxDiagnosisFunctionality::GetWindowTitle()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.AlarmBoxDiagnosisFunctionality.AlarmBoxDiagnosis" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType AlarmBoxDiagnosisFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMALARMBOXDIAGNOSISFUNCTIONALITY;
}

void AlarmBoxDiagnosisFunctionality::Dispose()
{
    alarmWidget->dispose();
    connFinishDiagnosis.disconnect();
}

Smartmatic::Log::ISMTTLog * AlarmBoxDiagnosisFunctionality::getLogger()
{
    return logger;
}
Glib::ustring AlarmBoxDiagnosisFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.AlarmBoxDiagnosisFunctionality.LogStartFunctionality" );
}

Glib::ustring AlarmBoxDiagnosisFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.AlarmBoxDiagnosisFunctionality.LogCloseFunctionality" );
}


