/**
 * @file	calibration-diagnosis-functionality.cc
 * @brief	calibration diagnosis functionality class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */

#include <Voting/OperationStatus.hxx>
#include "Functionalities/calibration-diagnosis-functionality.h"
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::Functionality;
using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::Voting;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::GUI::Windows;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::Configuration;

ISMTTLog * CalibrationDiagnosisFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.CalibrationDiagnosisFunctionality", GETTEXT_PACKAGE );
CalibrationDiagnosisFunctionality * CalibrationDiagnosisFunctionality::current_instance = NULL;

CalibrationDiagnosisFunctionality * CalibrationDiagnosisFunctionality::getInstance()
{
    if ( !current_instance )
    {
        current_instance = new CalibrationDiagnosisFunctionality();
    }

    return current_instance;
}

CalibrationDiagnosisFunctionality::CalibrationDiagnosisFunctionality()
{
    calibrationWidget = NULL;
}

CalibrationDiagnosisFunctionality::~CalibrationDiagnosisFunctionality()
{
    deleteElements();
}

void CalibrationDiagnosisFunctionality::Initialize()
{
    calibrationWidget->initialize();
    connOk = calibrationWidget->getSignalEnd().connect ( sigc::mem_fun ( *this, &CalibrationDiagnosisFunctionality::signalOkDetected ) );
}

void CalibrationDiagnosisFunctionality::signalOkDetected()
{
    ExitFunctionality();
}

Gtk::Widget * CalibrationDiagnosisFunctionality::GetFrame()
{
    calibrationWidget = new Smartmatic::SAES::GUI::Widgets::CalibrationDiagnosisWidget ();
    return calibrationWidget;
}

std::string CalibrationDiagnosisFunctionality::GetWindowTitle()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.CalibrationDiagnosisFunctionality.CalibrationDiagnosis" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType CalibrationDiagnosisFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMCALIBRATIONDIAGNOSISFUNCTIONALITY;
}

void CalibrationDiagnosisFunctionality::Dispose()
{
    calibrationWidget->dispose();
    connOk.disconnect();
}

Smartmatic::Log::ISMTTLog * CalibrationDiagnosisFunctionality::getLogger()
{
    return logger;
}
Glib::ustring CalibrationDiagnosisFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.CalibrationDiagnosisFunctionality.LogStartFunctionality" );
}

Glib::ustring CalibrationDiagnosisFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.CalibrationDiagnosisFunctionality.LogCloseFunctionality" );
}

void CalibrationDiagnosisFunctionality::deleteElements()
{
    if ( calibrationWidget != NULL )
    {
        delete ( calibrationWidget );
        calibrationWidget = NULL;
    }
}
