/**
 * @file	close-votation-functionality.cc
 * @brief	close votation functionality class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */

#include <Log/SMTTLogManager.h>
#include "close-votation-functionality.h"
#include <Voting/OperationStatus.hxx>
#include <Log/SMTTLogManager.h>
#include <Operation/MachineOperationManager.hxx>
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Gtk;
using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::Functionality;
using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Voting;
using namespace Smartmatic::SAES::Voting::Status;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::Configuration;

CloseVotationFunctionality * CloseVotationFunctionality::current_instance = NULL;

Smartmatic::Log::ISMTTLog * CloseVotationFunctionality::logger = Smartmatic::Log::SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.CloseVotationFunctionality", GETTEXT_PACKAGE );

CloseVotationFunctionality * CloseVotationFunctionality::getInstance()
{
    if ( !current_instance )
    {
        current_instance = new CloseVotationFunctionality();
    }

    return current_instance;
}

CloseVotationFunctionality::CloseVotationFunctionality()
{
    vbox = NULL;
    align = NULL;
    titleLabel = NULL;
    titleLabelID = NULL;
    closeVotationButton = NULL;
    externalFrame = NULL;
    confirmButton = NULL;
    cancelButton = NULL;
    buttonBox = NULL;
    labelConfirmation = NULL;
}

void CloseVotationFunctionality::deleteElements()
{
    if ( vbox )
    {
        delete vbox;
        vbox = NULL;
    }

    if ( align )
    {
        delete align;
        align = NULL;
    }

    if ( titleLabel )
    {
        delete titleLabel;
        titleLabel = NULL;
    }

    if ( titleLabelID )
    {
        delete titleLabelID;
        titleLabelID = NULL;
    }

    if ( closeVotationButton )
    {
        delete closeVotationButton;
        closeVotationButton = NULL;
    }

    if ( externalFrame )
    {
        delete externalFrame;
        externalFrame = NULL;
    }

    if ( confirmButton )
    {
        delete confirmButton;
        confirmButton = NULL;
    }

    if ( cancelButton )
    {
        delete cancelButton;
        cancelButton = NULL;
    }

    if ( buttonBox )
    {
        delete buttonBox;
        buttonBox = NULL;
    }

    if ( labelConfirmation )
    {
        delete labelConfirmation;
        labelConfirmation = NULL;
    }
}

CloseVotationFunctionality::~CloseVotationFunctionality()
{
    deleteElements();
}

void CloseVotationFunctionality::Initialize()
{
    exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.CloseVotationFunctionality.VotationWasNotClose" ) );
    enableExitButton();
}

void CloseVotationFunctionality::LoadAfterConfirmation()
{
    if ( closeVotationButton )
    {
        delete closeVotationButton;
    }

    closeVotationButton = new SmartmaticButton ( _ ( "Smartmatic.SAES.GUI.Functionality.CloseVotationFunctionality.CloseVotationButton" ) );
    closeVotationButton->signal_clicked().connect ( sigc::mem_fun ( this, &CloseVotationFunctionality::on_closeVotationButton_clicked ) );
    align->remove();
    externalFrame->remove();

    closeVotingExperience();
}

Gtk::Widget * CloseVotationFunctionality::GetFrame()
{
    align = new Alignment();
    externalFrame = new Frame();
    externalFrame->set_shadow_type ( Gtk::SHADOW_NONE );

    unsigned int totalOfficialActivacion = Smartmatic::SAES::Operation::MachineOperationManager::getInstance()->getActivatedCardStatistics()->getTotalOfficialActivated();
    unsigned int numberForConfirmation = SAESGUIConfigurationManager::getInstance()->getCloseVotationMinimumOfficialsActivationForConfirmation();
    std::string confirmationText;
    bool showConfirmation = false;

    if ( ( totalOfficialActivacion < numberForConfirmation && numberForConfirmation != 0 ) )
    {
        confirmationText = _ ( "Smartmatic.SAES.GUI.Functionality.CloseVotationFunctionality.CloseConfirmation" );
        showConfirmation = true;
    }
    else if ( SAESGUIConfigurationManager::getInstance()->getCloseVotationShowConfirmationMessageWhenClosing() )
    {
        confirmationText = _ ( "Smartmatic.SAES.GUI.Functionality.CloseVotationFunctionality.CloseConfirmationMessage" );
        showConfirmation = true;
    }

    if ( showConfirmation )
    {
        confirmButton = new SmartmaticButton ( _ ( "Smartmatic.SAES.GUI.Functionality.CloseVotationFunctionality.ConfirmButton" ) );
        confirmButton->signal_clicked().connect ( sigc::mem_fun ( *this, &CloseVotationFunctionality::on_confirmButton_clicked ) );
        confirmButton->set_size_request ( 170, 70 );
        confirmButton->SetButtonType ( SmartmaticButton::Ok );
        confirmButton->WidgetsPosition ( 5, 6, 0 );
        cancelButton = new SmartmaticButton ( _ ( "Smartmatic.SAES.GUI.Functionality.CloseVotationFunctionality.CancelButton" ) );
        cancelButton->signal_clicked().connect ( sigc::mem_fun ( *this, &CloseVotationFunctionality::on_cancelButton_clicked ) );
        cancelButton->set_size_request ( 170, 70 );
        cancelButton->SetButtonType ( SmartmaticButton::Cancel );
        cancelButton->WidgetsPosition ( 5, 6, 0 );
        buttonBox = new HButtonBox();
        buttonBox->set_size_request ( 300, 200 );
        buttonBox->set_layout ( BUTTONBOX_SPREAD );
        buttonBox->pack_start ( *cancelButton, false, false );
        buttonBox->pack_start ( *confirmButton, false, false );
        labelConfirmation = new Label ( confirmationText );
        labelConfirmation->set_size_request ( 980, 200 );
        Pango::FontDescription fontTitle = labelConfirmation->get_style()->get_font();
        fontTitle.set_size ( 20 * Pango::SCALE );
        fontTitle.set_weight ( Pango::WEIGHT_BOLD );
        labelConfirmation->modify_font ( fontTitle );
        labelConfirmation->set_alignment ( 0.5, 0.5 );
        vbox = new VBox();
        vbox->pack_start ( *labelConfirmation, false, false );
        vbox->pack_start ( *buttonBox, false, false );
        align->set ( 0.5, 0.5, 0, 0 );
        align->add ( *vbox );
        externalFrame->add ( *align );
        externalFrame->show_all_children();
        externalFrame->show();
    }
    else
    {
        LoadAfterConfirmation();
    }

    return externalFrame;
}

void CloseVotationFunctionality::on_confirmButton_clicked()
{
    LoadAfterConfirmation();
}

void CloseVotationFunctionality::on_cancelButton_clicked()
{
    ExitFunctionality();
}

void CloseVotationFunctionality::closeVotingExperience()
{
    logger->Debug ( "Execute close voting experience" );

    try
    {
        MachineOperationManager::getInstance()->closeVotingExperience();
        exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.CloseVotationFunctionality.VotationWasClose" ) );
    }
    catch ( ... )
    {
        exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.CloseVotationFunctionality.ErrorClosingVotation" ) );
    }

    enableExitButton();
    ExitFunctionality();
}

void CloseVotationFunctionality::on_closeVotationButton_clicked()
{
}

std::string CloseVotationFunctionality::GetWindowTitle()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.CloseVotationFunctionality.CloseVotation" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType CloseVotationFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMCLOSEVOTATIONFUNCTIONALITY;
}

void CloseVotationFunctionality::Dispose()
{

}

Smartmatic::Log::ISMTTLog * CloseVotationFunctionality::getLogger()
{
    return logger;
}
Glib::ustring CloseVotationFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.CloseVotationFunctionality.LogStartFunctionality" );
}

Glib::ustring CloseVotationFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.CloseVotationFunctionality.LogCloseFunctionality" );
}
