/**
 * @file	open-election-functionality.h
 * @brief	Declares the open election functionality class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#ifndef _OPEN_ELECTION_FUNCTIONALITY_H_


#define _OPEN_ELECTION_FUNCTIONALITY_H_

#include <gtkmm.h>
#include <string>
#include <Functionalities/graphic-display-functionality.h>
#include <Widgets/wizard-widget-manager.h>
#include <Widgets/wizard-widget-base.h>
#include <Log/ISMTTLog.h>
#include <Gui/Widgets/OpenElectionStatusWidget.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	OpenElectionFunctionality
                 * @brief	Open election functionality.
                 * @author	Youssef.tourkmani
                 * @date	01/11/2012
                 */
                class OpenElectionFunctionality: public GraphicDisplayFunctionality
                {

                    public:
                        /**
                         * @fn	virtual OpenElectionFunctionality::~OpenElectionFunctionality();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	10/05/2012
                         */
                        virtual ~OpenElectionFunctionality();

                        /**
                         * @fn	static OpenElectionFunctionality * OpenElectionFunctionality::getInstance();
                         * @brief	Gets the current.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	null if it fails, else.
                         */

                        static OpenElectionFunctionality * getInstance();

                    protected:

                        /**
                         * @fn	void OpenElectionFunctionality::finish();
                         * @brief	method finish functionality.
                         * @author	Yadickson Soto
                         * @date	10/05/2012
                         */
                        void finish();
                        /**
                         * @fn	void OpenElectionFunctionality::errorHappen();
                         * @brief	method error functionality.
                         * @author	Yadickson Soto
                         * @date	10/05/2012
                         */
                        void errorHappen();

                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * OpenElectionFunctionality::getLogger();
                         * @brief	Gets the logger.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	null if it fails, else the logger.
                         */

                        Smartmatic::Log::ISMTTLog * getLogger();

                        /**
                         * @fn	Glib::ustring OpenElectionFunctionality::getStartLogMessage();
                         * @brief	Gets the start log message.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The start log message.
                         */

                        Glib::ustring getStartLogMessage();

                        /**
                         * @fn	Glib::ustring OpenElectionFunctionality::getFinishLogMessage();
                         * @brief	Gets the finis ah log message.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The finis ah log message.
                         */

                        Glib::ustring getFinishLogMessage();

                    private:
                        Gtk::Frame * openFrame; ///< The open frame

                        Smartmatic::SAES::GUI::Widgets::OpenElectionStatusWidget * openElectionWidget; ///< open election widget

                        Smartmatic::GUI::Widgets::WizardWidgetManager * manager; ///< manage wizard
                        std::vector<Smartmatic::GUI::Widgets::WizardWidgetBase *> wizardVector; ///< wizard vector

                        /**
                         * @fn	void OpenElectionFunctionality::ShowMessage ( std::string message );
                         * @brief	Shows the message.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @param	message	The message.
                         */

                        void ShowMessage ( std::string message );

                        /**
                         * @fn	void OpenElectionFunctionality::ShowNote();
                         * @brief	Shows the note.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        void ShowNote();

                        /**
                         * @fn	OpenElectionFunctionality::OpenElectionFunctionality();
                         * @brief	Default constructor.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        OpenElectionFunctionality();


                        /**
                         * @fn	void OpenElectionFunctionality::Dispose();
                         * @brief	Dispose of this object, cleaning up any resources it uses.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        void Dispose();

                        /**
                         * @fn	void OpenElectionFunctionality::Initialize();
                         * @brief	Initia alize.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        void Initialize();

                        /**
                         * @fn	Gtk::Widget * OpenElectionFunctionality::GetFrame();
                         * @brief	Gets the frame.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	null if it fails, else the frame.
                         */

                        Gtk::Widget * GetFrame();

                        /**
                         * @fn	std::string OpenElectionFunctionality::GetWindowTitle();
                         * @brief	Gets the window title.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The window title.
                         */

                        std::string GetWindowTitle();

                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType OpenElectionFunctionality::GetMenuOptionType();
                         * @brief	Gets the menu option type.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The menu option type.
                         */

                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();

                        /**
                         * @fn	virtual void OpenElectionFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	03/04/2012
                         */
                        virtual void deleteElements();

                        static OpenElectionFunctionality * current_instance; ///< The current instance
                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
                };
            }
        }
    }
}




#endif // _OPEN_ELECTION_FUNCTIONALITY_H_
