/**
 * @file	s-c-reader-diagnosis-functionality.cc
 * @brief	reader diagnosis functionality class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#include <Voting/OperationStatus.hxx>
#include "s-c-reader-diagnosis-functionality.h"
#include <Log/SMTTLogManager.h>
#include <Configuration/SaesGUIConfiguration-schema.hxx>
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"
#include <Operation/MachineOperationManager.hxx>
#include <Card/SmartcardCodeManager.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::Voting;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::GUI::Windows;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::Functionality;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Card;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::Voting::Status;
using namespace Smartmatic::SAES::Common::Configuration;

ISMTTLog * SCReaderDiagnosisFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.SCReaderDiagnosisFunctionality", GETTEXT_PACKAGE );

SCReaderDiagnosisFunctionality * SCReaderDiagnosisFunctionality::current_instance = NULL;

SCReaderDiagnosisFunctionality * SCReaderDiagnosisFunctionality::getInstance()
{
    if ( !current_instance )
    {
        current_instance = new SCReaderDiagnosisFunctionality();
    }

    return current_instance;
}

SCReaderDiagnosisFunctionality::SCReaderDiagnosisFunctionality()
{
    readerWidget = NULL;
}

SCReaderDiagnosisFunctionality::~SCReaderDiagnosisFunctionality()
{
    deleteElements();
}

void SCReaderDiagnosisFunctionality::Initialize()
{
    SmartcardCodeManager::getInstance()->start ();

    readerWidget->start();
    connSCDiag.disconnect();
    connSCDiag = readerWidget->getSignalEnd().connect ( sigc::mem_fun ( this, &SCReaderDiagnosisFunctionality::on_SCDiagFinished ) );
}

void SCReaderDiagnosisFunctionality::on_SCDiagFinished()
{
    enableExitButton();
    logger->Audit ( N_ ( "Smartmatic.SAES.GUI.Functionality.SCReaderDiagnosisFunctionality.SmartcardReaderDiagnosisExecuted" ) );
    ExitFunctionality();
}

Gtk::Widget * SCReaderDiagnosisFunctionality::GetFrame()
{
    readerWidget = new Smartmatic::SAES::GUI::Widgets::SmartcardDiagnosisWidget ();
    return readerWidget;
}

std::string SCReaderDiagnosisFunctionality::GetWindowTitle()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.SCReaderDiagnosisFunctionality.SmartcardReaderDiagnosis" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType SCReaderDiagnosisFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMSCREADERDIAGNOSISFUNCTIONALITY;
}

void SCReaderDiagnosisFunctionality::Dispose()
{
    std::list < std::string > list ( SmartcardCodeManager::getInstance()->getCodes() );
    std::list < std::string >::const_iterator it;

    VotingMachineStatusWrapper * wrapper = MachineOperationManager::getInstance()->getOperationStatus()->getVotingMachineStatusWrapper();

    for ( it = list.begin();
            it != list.end();
            ++it )
    {
        wrapper->addStatusCode ( DeviceType::CONFIGURATION_SMARTCARD, ( *it ) );
    }

    SmartcardCodeManager::getInstance()->clear ();
    SmartcardCodeManager::getInstance()->stop ();

    connSCDiag.disconnect();

    if ( readerWidget )
    {
        readerWidget->dispose();
    }
}

Smartmatic::Log::ISMTTLog * SCReaderDiagnosisFunctionality::getLogger()
{
    return logger;
}

Glib::ustring SCReaderDiagnosisFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.SCReaderDiagnosisFunctionality.LogStartFunctionality" );
}

Glib::ustring SCReaderDiagnosisFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.SCReaderDiagnosisFunctionality.LogCloseFunctionality" );
}

void SCReaderDiagnosisFunctionality::deleteElements()
{
    if ( readerWidget )
    {
        delete readerWidget;
        readerWidget = NULL;
    }
}
