/**
 * @file	vote-demo-functionality.cc
 * @brief	vote demo functionality class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */

#include <sstream>
#include <Voting/OperationStatus.hxx>
#include <Voting/Status/ElectionStatusWrapper.hxx>
#include <Operation/MachineOperationManager.hxx>
#include "Configuration/s-a-e-s-conf-manager.h"
#include "Functionalities/vote-demo-functionality.h"
#include "Resources/election-string-resources-manager.h"
#include "Voting/CardData/card-data-wrapper.h"
#include <Operation/MachineOperationManager.hxx>
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>
#include <Operation/Devices/CardController.hxx>
#include "Gui/Widgets/AbstractFactoryWidget.hxx"
#include <Log/SMTTLogManager.h>
#include <Configuration/label-configuration.h>
#include <Operation/Devices/BCRController.hxx>
#include <Gui/Windows/VoteProcessWindow.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Gtk;
using namespace Smartmatic::Environment;
using namespace Smartmatic::Functionality;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::GUI::Windows;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Windows;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::Printing;
using namespace Smartmatic::SAES::Resources;
using namespace Smartmatic::SAES::Voting;
using namespace Smartmatic::SAES::Voting::Status;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::SAES::Operation::Devices;

ISMTTLog * VoteProcessDemoFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.VoteProcessDemoFunctionality", GETTEXT_PACKAGE );

VoteProcessDemoFunctionality * VoteProcessDemoFunctionality::current_instance = NULL;

VoteProcessDemoFunctionality * VoteProcessDemoFunctionality::getInstance()
{
    if ( !current_instance )
    {
        current_instance = new VoteProcessDemoFunctionality();
    }

    return current_instance;
}

VoteProcessDemoFunctionality::VoteProcessDemoFunctionality()
{
    framePrincipal = NULL;
    frameNormal = NULL;
    frame2 = NULL;
    vbox2 = NULL;
    imageCard = NULL;
    imageVote = NULL;
    labelResult = NULL;
    labelStatus = NULL;
    labelVoteGen = NULL;
    buttonMagnify = NULL;
    scrolledwindowVote = NULL;
    eventboxVoteDemo = NULL;
    eventboxStepBarcode = NULL;
    printWidget = NULL;
    frameMagnify = NULL;
    vboxMagnify = NULL;
    scrolledMagnify = NULL;
    viewMagnify = NULL;
    buttonBackMagnify = NULL;
    checkbuttonIsAudio = NULL;
    viewportVote = NULL;
    doc = NULL;
    docMagnify = NULL;
    printWidgetMagnify = NULL;
    cardActivatorBox = NULL;
    eventbox1 = NULL;
    validVote = false;
    statusActivate = false;
}

VoteProcessDemoFunctionality::~VoteProcessDemoFunctionality()
{
    deleteElements();
}

void VoteProcessDemoFunctionality::deleteElements()
{
    if ( cardActivatorBox )
    {
        delete ( cardActivatorBox );
        cardActivatorBox = NULL;
    }

    if ( framePrincipal )
    {
        delete ( framePrincipal );
        framePrincipal = NULL;
    }

    if ( frameNormal )
    {
        delete ( frameNormal );
        frameNormal = NULL;
    }

    if ( frame2 )
    {
        delete ( frame2 );
        frame2 = NULL;
    }

    if ( vbox2 != NULL )
    {
        delete ( vbox2 );
        vbox2 = NULL;
    }

    if ( imageCard != NULL )
    {
        delete ( imageCard );
        imageCard = NULL;
    }

    if ( imageVote )
    {
        delete imageVote;
        imageVote = NULL;
    }

    if ( labelResult )
    {
        delete labelResult;
        labelResult = NULL;
    }

    if ( labelStatus )
    {
        delete ( labelStatus );
        labelStatus = NULL;
    }

    if ( labelVoteGen )
    {
        delete ( labelVoteGen );
        labelVoteGen = NULL;
    }

    if ( buttonMagnify )
    {
        delete ( buttonMagnify );
        buttonMagnify = NULL;
    }

    if ( eventbox1 )
    {
        delete ( eventbox1 );
        eventbox1 = NULL;
    }

    if ( scrolledwindowVote )
    {
        delete ( scrolledwindowVote );
        scrolledwindowVote = NULL;
    }

    if ( eventboxVoteDemo )
    {
        delete ( eventboxVoteDemo );
        eventboxVoteDemo = NULL;
    }

    if ( eventboxStepBarcode )
    {
        delete ( eventboxStepBarcode );
        eventboxStepBarcode = NULL;
    }

    if ( printWidget )
    {
        delete ( printWidget );
        printWidget = NULL;
    }

    if ( frameMagnify )
    {
        delete ( frameMagnify );
        frameMagnify = NULL;
    }

    if ( vboxMagnify )
    {
        delete ( vboxMagnify );
        vboxMagnify = NULL;
    }

    if ( scrolledMagnify )
    {
        delete ( scrolledMagnify );
        scrolledMagnify = NULL;
    }

    if ( viewMagnify )
    {
        delete ( viewMagnify );
        viewMagnify = NULL;
    }

    if ( buttonBackMagnify )
    {
        delete ( buttonBackMagnify );
        buttonBackMagnify = NULL;
    }

    if ( checkbuttonIsAudio )
    {
        delete ( checkbuttonIsAudio );
        checkbuttonIsAudio = NULL;
    }

    if ( viewportVote )
    {
        delete ( viewportVote );
        viewportVote = NULL;
    }

    if ( doc )
    {
        delete doc;
        doc = NULL;
    }

    if ( docMagnify )
    {
        delete docMagnify;
        docMagnify = NULL;
    }

    if ( printWidgetMagnify )
    {
        delete printWidgetMagnify;
        printWidgetMagnify = NULL;
    }
}

void VoteProcessDemoFunctionality::Initialize()
{
    magnify = false;
    validVote = false;
    docMagnify = NULL;
    reconfigure = false;
    framePrincipal->remove();
    framePrincipal->add ( *frameNormal );
    buttonMagnify->set_sensitive ( false );
    viewportVote->remove();

    labelStatus->set_label ( "" );
    int timerRefresh = SAESGUIConfigurationManager::getInstance()->getPollingCardConfiguration().getVoteProcessDemoFunctionality();
    sigc::slot<bool> my_slot = sigc::bind ( sigc::mem_fun ( *this,
                                            &VoteProcessDemoFunctionality::Refresh ), 0 );
    conn = Glib::signal_timeout().connect ( my_slot, timerRefresh );
    labelResult->set_label ( _ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.PleaseInsertCardToActivate" ) );
    labelVoteGen->set_label ( _ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.WaitingForCard" ) );
    labelStatus->set_label ( "" );
    wasPresent = false;
    signalVote.disconnect();
    signalStatusVote.disconnect();
    //signalVote = BCRController::getInstance()->getSignalVote().connect ( sigc::mem_fun ( *this, &VoteProcessDemoFunctionality::onSignalVote ) );
    //signalStatusVote = BCRController::getInstance()->getSignalStatus().connect ( sigc::mem_fun ( *this, &VoteProcessDemoFunctionality::onSignalState ) );
    VoteProcessWindow::getInstance()->stop();
    //BCRController::getInstance()->enableSaveVote ( false );
    //BCRController::getInstance()->enableSaveDemoVote ( SAESGUIConfigurationManager::getInstance()->getVoteDemoFunctionalityConfiguration().getPersistVote() );
    //BCRController::getInstance()->force ( true );
    //BCRController::getInstance()->resume ();
    enableExitButton();
}

std::string VoteProcessDemoFunctionality::getCodeByName ( std::string optionName )
{
    for ( std::list<VotingDevice::Custom_attribute_definition>::iterator
            l ( listCAD.begin() );
            l != listCAD.end();
            ++l )
    {
        if ( ( *l ).getName_key().compare ( optionName ) == 0 )
        {
            return ( *l ).getCode();
        }
    }

    return "";
}

std::string VoteProcessDemoFunctionality::getNameByCode ( std::string optionCode )
{
    for ( std::list<VotingDevice::Custom_attribute_definition>::iterator
            l ( listCAD.begin() );
            l != listCAD.end();
            ++l )
    {
        if ( ( *l ).getCode().compare ( optionCode ) == 0 )
        {
            return ( *l ).getName_key();
        }
    }

    return "";
}

void VoteProcessDemoFunctionality::BarcodeError ( bool enabledMagnify )
{
    validVote = false;
    labelStatus->set_label ( _ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.BarcodeErrorTryAgain" ) );
    refresh();
    logger->Audit ( N_ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.ScannedVoteWithErrors" ) );

    if ( buttonMagnify )
    {
        buttonMagnify->set_sensitive ( enabledMagnify );
    }
}

void VoteProcessDemoFunctionality::BarcodeRefreshDemo ( bool enabledMagnify )
{
    labelStatus->set_label ( _ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.VoteMarkedAsDemoGenerateCardWhenReady" ) );
    labelVoteGen->set_label ( _ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.WaitingForCard" ) );
    refresh();
}

void VoteProcessDemoFunctionality::BarcodeRefreshNotDemo()
{
    validVote = false;
    refresh();
    labelStatus->set_label ( _ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.VoteNotMarkedAsDemoTryAgain" ) );
    logger->Audit ( N_ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.VoteNotMarkedAsDemoTryAgain" ) );
}

void VoteProcessDemoFunctionality::BarcodeRefresh()
{
    logger->Debug ( "Vote code is:" + vote.getCode() );

    if ( vote.getMode() == Vote::VoteMode::VOTE_D )
    {
        logger->Debug ( "Vote is DEMO!!!!" );
        BarcodeRefreshDemo ( true );
    }
    else
    {
        logger->Debug ( "Vote is NOT DEMO!!!!" );
        buttonMagnify->set_sensitive ( false );
        BarcodeRefreshNotDemo();
    }
}

bool VoteProcessDemoFunctionality::Refresh ( int time_num )
{
    bool present = false;

    try
    {
        present = CardController::getInstance()->isCardPresent();
    }
    catch ( ... )
    {
    }

    if ( present && !wasPresent )
    {
        statusActivate = false;
        wasPresent = true;
        activateCardData();
    }
    else if ( !present && wasPresent )
    {
        labelResult->set_label ( _ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.PleaseInsertCardToActivate" ) );
        imageCard->set ( ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, "ui/smartcard_activation.gif" ) );
        wasPresent = false;

        if ( statusActivate && SAESGUIConfigurationManager::getInstance()->getVoteDemoFunctionalityConfiguration().getResetDefaultCustomAttribute() )
        {
            cardActivatorBox->reset( );
        }
    }

    return true;
}

void VoteProcessDemoFunctionality::activateCardData()
{
    try
    {
        logger->Audit ( N_ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.StartingToActivateVoteDemoCard" ) );
        viewportVote->remove();
        buttonMagnify->set_sensitive ( false );

        CardData::Card_data cardData;
        CardData::CardDataWrapper::GenerateCardData ( MachineOperationManager::getInstance()->getElectoralConfiguration(), MachineOperationManager::getInstance()->getOperationStatus(), attributes, cardData, true, Smartmatic::SAES::Voting::CardData::Card_type::CARD_DATA_DEMOSTRATION_VOTE_CARD, checkbuttonIsAudio->get_active() );

        if ( !CardController::getInstance()->writeCardData ( cardData ) )
        {
            statusActivate = false;
            labelResult->set_label ( _ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.ErrorValidatingDataCheckPositionOfCard" ) );
            logger->Audit ( N_ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.ErrorActivationCard" ) );
            imageCard->set ( ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, "ui/wiz_extract_identity_card_error.gif" ) );
        }
        else
        {
            statusActivate = true;
            labelResult->set_label ( _ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.CardActivatedRemoveCard" ) );
            logger->Audit ( N_ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.CardDemoWasActivatedSuccessfully" ) );
            labelVoteGen->set_label ( _ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.NowScanPrintedVoteToView" ) );
            lastCardGUUID = cardData.getCode();
            Smartmatic::SAES::Operation::MachineOperationManager::getInstance()->getActivatedCardStatistics()->RefreshStats ( cardData );
            imageCard->set ( ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, "ui/wiz_extract_identity_card.gif" ) );
        }
    }
    catch ( const ::xsd::cxx::tree::exception< char > & e )
    {
        labelResult->set_label ( _ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.ErrorValidatingDataCheckPositionOfCard" ) );
        logger->Audit ( N_ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.ErrorActivationCard" ) );
    }
    catch ( Smartmatic::System::Exception::CryptoException & ex )
    {
        labelResult->set_label ( _ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.ErrorValidatingDataCheckPositionOfCard" ) );
        logger->Audit ( N_ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.ErrorActivationCard" ) );
    }
    catch ( Smartmatic::System::Exception::SignedException & ex )
    {
        labelResult->set_label ( _ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.ErrorValidatingDataCheckPositionOfCard" ) );
        logger->Audit ( N_ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.ErrorActivationCard" ) );
    }
    catch ( Smartmatic::System::Exception::XmlException & ex )
    {
        labelResult->set_label ( _ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.ErrorValidatingDataCheckPositionOfCard" ) );
        logger->Audit ( N_ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.ErrorActivationCard" ) );
    }
    catch ( ... )
    {
        labelResult->set_label ( _ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.ErrorValidatingDataCheckPositionOfCard" ) );
        logger->Audit ( N_ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.ErrorActivationCard" ) );
    }
}

void VoteProcessDemoFunctionality::on_buttonBackMagnify_clicked()
{
    magnify = false;
    enableExitButton();
    refresh();
}

void VoteProcessDemoFunctionality::on_buttonMagnify_clicked()
{
    magnify = true;
    disableExitButton();
    refresh();
}

void VoteProcessDemoFunctionality::CreateNormalFrame()
{
    Glib::RefPtr<Gtk::Builder> builder;

    try
    {
        builder = Gtk::Builder::create_from_file ( ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, "ui/vote-process-demo.glade" ) );
    }
    catch ( const Glib::FileError & ex )
    {
        logger->Debug ( "FATAL - VoteProcessDemoFunctionality CreateNormalFrame" );
    }

    builder->get_widget ( "framePrincipal", framePrincipal );
    builder->get_widget ( "frameNormal", frameNormal );
    builder->get_widget ( "frame2", frame2 );
    builder->get_widget ( "eventboxVoteProcessDemo", eventboxVoteDemo );
    builder->get_widget ( "eventboxStepBarcode", eventboxStepBarcode );
    builder->get_widget ( "vbox2", vbox2 );
    builder->get_widget ( "imageCard", imageCard );
    builder->get_widget ( "labelResult", labelResult );
    builder->get_widget ( "labelStatus", labelStatus );
    builder->get_widget ( "checkbuttonIsAudio", checkbuttonIsAudio );
    builder->get_widget_derived ( "buttonMagnify", buttonMagnify );
    builder->get_widget ( "labelVoteGen", labelVoteGen );
    builder->get_widget_derived ( "scrolledwindowVote", scrolledwindowVote );
    builder->get_widget ( "viewportVote", viewportVote );
    //builder->get_widget("imageVote", imageVote);
    builder->get_widget_derived ( "buttonBackMagnify", buttonBackMagnify );
    builder->get_widget ( "frameMagnify", frameMagnify );
    builder->get_widget ( "vboxMagnify", vboxMagnify );
    builder->get_widget_derived ( "scrolledwindowMagnify", scrolledMagnify );
    builder->get_widget ( "viewportMagnify", viewMagnify );
    builder->get_widget ( "eventbox1", eventbox1 );
    eventboxStepBarcode->set_name ( SAESGUIConfigurationManager::getInstance()->GetEventboxStepBarcodeName() );
    labelVoteGen->set_alignment ( 0.5, 0.5 );
    labelStatus->set_alignment ( 0.5, 0.5 );
    labelResult->set_alignment ( 0.5, 0.5 );
    checkbuttonIsAudio->set_label ( _ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.IsAudio" ) );
    checkbuttonIsAudio->set_sensitive ( false );
    buttonMagnify->SetLabel ( _ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.Magnify" ) );
    buttonMagnify->WidgetsPosition ( 5, 0, 0 );
    buttonMagnify->set_size_request ( 100, 50 );
    buttonMagnify->signal_clicked ().connect ( sigc::mem_fun ( *this, &VoteProcessDemoFunctionality::on_buttonMagnify_clicked ) );
    buttonBackMagnify->SetLabel ( _ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.BackMagnify" ) );
    buttonBackMagnify->WidgetsPosition ( 5, 0, 0 );
    buttonBackMagnify->set_size_request ( 200, 50 );
    buttonBackMagnify->signal_clicked ().connect ( sigc::mem_fun ( *this, &VoteProcessDemoFunctionality::on_buttonBackMagnify_clicked ) );
    eventboxVoteDemo->set_name ( SAESGUIConfigurationManager::getInstance()->GetVoteDemoFunctionalityMessageName() );
    //comboSelections = new CustomAttributesComboSelectionsWidget(_("Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.CustomAttributeSelection"),"",true);
    cardActivatorBox = new CardActivatorEventBox ( 300 );
    cardActivatorBox->signal_vectorCustomAttribute_changed().connect ( sigc::mem_fun ( *this, &VoteProcessDemoFunctionality::SetCustomAttributeVector ) );
    static VoteDemoFunctionalityConfiguration config =
        SAESGUIConfigurationManager::getInstance()->getVoteDemoFunctionalityConfiguration();
    static LabelConfiguration selectedLabelConfiguration =
        SAESGUIConfigurationManager::ConvertToLabelConfiguration ( config.getLabelSelectedConfiguration() );
    static LabelConfiguration unselectedLabelConfiguration =
        SAESGUIConfigurationManager::ConvertToLabelConfiguration ( config.getLabelUnselectedConfiguration() );
    static LabelConfiguration titleLabelConfiguration =
        SAESGUIConfigurationManager::ConvertToLabelConfiguration ( config.getTitleFontConfiguration() );
    cardActivatorBox->setFont ( titleLabelConfiguration, selectedLabelConfiguration, unselectedLabelConfiguration );
    LabelConfiguration::SetLabelConfiguration ( labelResult, titleLabelConfiguration );
    LabelConfiguration::SetLabelConfiguration ( labelStatus, titleLabelConfiguration );
    LabelConfiguration::SetLabelConfiguration ( labelVoteGen, titleLabelConfiguration );
    eventbox1->add ( *cardActivatorBox );
    eventbox1->show_all_children();
    imageCard->set ( ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, "ui/smartcard_activation.gif" ) );
    ///Here Comes the initialization of many Widgets, which can be translated to Initialize if needed to "refresh" the status every time the window is opened
    Smartmatic::SAES::Voting::VotingDevice::Voting_device vd = Smartmatic::SAES::Operation::MachineOperationManager::getInstance()->getElectoralConfiguration()->getVotingDevice()->getFirstVotingDevice();
    listCAD = Smartmatic::SAES::Operation::MachineOperationManager::getInstance()->getElectoralConfiguration()->getVotingDevice()->getCustomAttributeDefinitionList ( vd, VotingDevice::Machine_type::VOTING_DEVICES_PM );
    voteStats = MachineOperationManager::getInstance()->getVoteStatistics();
    normalFrameWidget =  framePrincipal;
}

Gtk::Widget * VoteProcessDemoFunctionality::GetFrame()
{
    CreateNormalFrame();
    return normalFrameWidget;
}

void VoteProcessDemoFunctionality::SetCustomAttributeVector ( std::vector< Smartmatic::SAES::Voting::VotingDevice::Custom_attribute > vecCA )
{
    attributes = vecCA;
}

std::string VoteProcessDemoFunctionality::GetWindowTitle()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.WindowTitle" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType VoteProcessDemoFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMVOTEPROCESSDEMOFUNCTIONALITY;
}

void VoteProcessDemoFunctionality::onBeforeExit()
{
    //BCRController::getInstance()->enableSaveVote();
    //BCRController::getInstance()->enableSaveDemoVote ( false );
    //BCRController::getInstance()->force ( false );
    //BCRController::getInstance()->resume();
    VoteProcessWindow::getInstance()->start();

    if ( SAESGUIConfigurationManager::getInstance()->getMinimumDemoCounterToAllowActivation() == 0 ||
            !SAESGUIConfigurationManager::getInstance()->getVoteDemoFunctionalityConfiguration().getPersistVote() ||
            MachineOperationManager::getInstance()->getVoteStatistics()->getDemoVotes() >= SAESGUIConfigurationManager::getInstance()->getMinimumDemoCounterToAllowActivation() )
    {
        exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.ExitFunctionality" ) );
    }
    else
    {
        exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.ElectionStatusNotChanged" ) );
    }

    AdjustElectionStatus();
}

void VoteProcessDemoFunctionality::Dispose()
{
    if ( buttonMagnify )
    {
        buttonMagnify->set_sensitive ( false );
    }

    signalVote.disconnect();
    signalStatusVote.disconnect();

    viewMagnify->remove();
    viewportVote->remove();
    conn.disconnect();
}

void VoteProcessDemoFunctionality::AdjustElectionStatus()
{
    try
    {
        if ( Smartmatic::SAES::Operation::MachineOperationManager::getInstance()->isNotDemostrationVote() )
        {
            Smartmatic::SAES::Operation::MachineOperationManager::getInstance()->demostrationVote();
            exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.ElectionStatusChanged" ) );
        }
    }
    catch ( ... )
    {
        exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.UnexpectedErrorChangingElectionStatus" ) );
    }
}

Smartmatic::Log::ISMTTLog * VoteProcessDemoFunctionality::getLogger()
{
    return logger;
}

Glib::ustring VoteProcessDemoFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.VoteProcessDemoFunctionality.LogStartFunctionality" );
}

Glib::ustring VoteProcessDemoFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.VoteProcessDemoFunctionality.LogCloseFunctionality" );
}

void VoteProcessDemoFunctionality::refresh()
{
    GraphicDisplayFunctionality::refresh();
    Glib::Mutex::Lock lock ( mutex );

    if ( reconfigure )
    {
        return;
    }

    viewMagnify->remove();
    viewportVote->remove();

    if ( printWidget )
    {
        delete ( printWidget );
        printWidget = NULL;
    }

    if ( doc )
    {
        delete doc;
        doc = NULL;
    }

    if ( docMagnify )
    {
        delete docMagnify;
        docMagnify = NULL;
    }

    buttonMagnify->set_sensitive ( !magnify );
    framePrincipal->remove();

    if ( magnify )
    {
        framePrincipal->add ( *frameMagnify );
    }
    else
    {
        framePrincipal->add ( *frameNormal );
    }

    if ( !validVote )
    {
        magnify = false;
        framePrincipal->remove();
        framePrincipal->add ( *frameNormal );
        buttonMagnify->set_sensitive ( false );
        enableExitButton();
        return;
    }

    bool showBarcode = SAESGUIConfigurationManager::getInstance()->getVoteDemoFunctionalityConfiguration().getShowBarcodeInPreview();
    doc = new VotePrintDocument ( Smartmatic::SAES::Operation::MachineOperationManager::getInstance()->getElectoralConfiguration(), vote, true, showBarcode );
    docMagnify = new VotePrintDocument ( Smartmatic::SAES::Operation::MachineOperationManager::getInstance()->getElectoralConfiguration(), vote, true, showBarcode );
    printWidget = new PrintPreviewWidget ( doc );

    if ( magnify )
    {
        viewMagnify->add ( *printWidget );
        viewMagnify->show_all_children();
    }
    else
    {
        viewportVote->add ( *printWidget );
        viewportVote->show_all_children ();
    }
}

void VoteProcessDemoFunctionality::block()
{
    logger->Debug ( "Block functionality" );
}

void VoteProcessDemoFunctionality::partial()
{
    logger->Debug ( "Partial functionality" );
}

void VoteProcessDemoFunctionality::resume()
{
    logger->Debug ( "Resume functionality" );

    //BCRController::getInstance()->resume ( true );
}

void VoteProcessDemoFunctionality::reconfigureBarcode()
{
    reconfigure = true;
    disableExitButton();
}

void VoteProcessDemoFunctionality::endReconfigureBarcode()
{
    reconfigure = false;
    enableExitButton();
}

void VoteProcessDemoFunctionality::onSignalVote ( Smartmatic::SAES::Voting::Vote::Vote * vote )
{
    this->vote = *vote;
    validVote = true;
}

void VoteProcessDemoFunctionality::onSignalState ( Smartmatic::SAES::Operation::Voting::VotePersistence::PersistenceStatusVote status )
{
    switch ( status )
    {
        case Smartmatic::SAES::Operation::Voting::VotePersistence::PERSISTENCE_VOTE_FAIL:
        default:
            BarcodeError ( false );
            break;

        case Smartmatic::SAES::Operation::Voting::VotePersistence::PERSISTENCE_VOTE_DUPLICATE:
            validVote = false;
            refresh();
            logger->Audit ( N_ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.VoteAlreadyProcessed" ) );
            labelStatus->set_label ( _ ( "Smartmatic.SAES.GUI.Functionality.VoteProcessDemoFunctionality.VoteAlreadyProcessed" ) );
            break;

        case Smartmatic::SAES::Operation::Voting::VotePersistence::PERSISTENCE_VOTE_SUCCESS:
            BarcodeRefresh();
            logger->Audit ( N_ ( "Smartmatic.SAES.GUI.Functionality.VoteDemoFunctionality.SuccessfullProcessVote" ) );
            break;
    }
}
