/**
 * @file	vote-demo-functionality.h
 * @brief	Declares the vote demo functionality class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#ifndef _VOTE_DEMO_FUNCTIONALITY_H_
#define _VOTE_DEMO_FUNCTIONALITY_H_

#include <gtkmm.h>
#include <string>
#include "Voting/Vote/vote-schema.hxx"
#include <Functionalities/graphic-display-functionality.h>
#include "Printing/PrintPreviewWidget.h"
#include "Printing/VotePrintDocument.h"
#include <System/SafeBuffer.h>
#include <Log/ISMTTLog.h>
#include <Widgets/smartmatic-button.h>
#include "Gui/Widgets/CardActivatorEventBox.h"
#include <Operation/Voting/VotePersistence.hxx>
#include <Widgets/SmartmaticBasicScrollContainer.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Voting
        {
            namespace PBReports
            {
                class VoteStatisticsWrapper;
            }
        }

        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	VoteProcessDemoFunctionality
                 * @brief	Vote process demo functionality.
                 * @author	Youssef.tourkmani
                 * @date	01/11/2012
                 */
                class VoteProcessDemoFunctionality: public GraphicDisplayFunctionality
                {

                    public:

                        /**
                         * @fn	bool VoteProcessDemoFunctionality::DontAllowHelp();
                         * @brief	Gets the dont allow help.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	true if it succeeds, false if it fails.
                         */

                        bool DontAllowHelp();

                        /**
                         * @fn	std::vector<Smartmatic::GUI::Widgets::KeysActionsCode> VoteProcessDemoFunctionality::getHelpSeqKey();
                         * @brief	Gets the help sequence key.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The help sequence key.
                         */

                        std::vector<Smartmatic::GUI::Widgets::KeysActionsCode> getHelpSeqKey();

                        /**
                         * @fn	bool VoteProcessDemoFunctionality::DontAllowExit();
                         * @brief	Gets the dont allow exit.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	true if it succeeds, false if it fails.
                         */

                        bool DontAllowExit();

                        /**
                         * @fn	std::vector<Smartmatic::GUI::Widgets::KeysActionsCode> VoteProcessDemoFunctionality::getSeqKey();
                         * @brief	Gets the sequence key.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The sequence key.
                         */

                        std::vector<Smartmatic::GUI::Widgets::KeysActionsCode> getSeqKey();

                        /**
                         * @fn	static VoteProcessDemoFunctionality * VoteProcessDemoFunctionality::getInstance();
                         * @brief	Gets the current.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	null if it fails, else.
                         */

                        static VoteProcessDemoFunctionality * getInstance();

                        /**
                         * @fn	virtual void VoteProcessDemoFunctionality::refresh();
                         * @brief	refresh widget method.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         */
                        virtual void refresh();

                    protected:

                        Glib::Mutex mutex;	///< The mutex
                        bool validVote; ///< flag valid vote
                        bool magnify; ///< flag magnify vote


                        /**
                         * @fn	virtual void VoteProcessDemoFunctionality::block();
                         * @brief	method block functionality.
                         * @author	Yadickson Soto
                         * @date	19/04/2012
                         */
                        virtual void block();
                        /**
                         * @fn	virtual void VoteProcessDemoFunctionality::partial();
                         * @brief	method partial functionality.
                         * @author	Yadickson Soto
                         * @date	19/04/2012
                         */
                        virtual void partial();
                        /**
                         * @fn	virtual void VoteProcessDemoFunctionality::resume();
                         * @brief	method resume functionality.
                         * @author	Yadickson Soto
                         * @date	19/04/2012
                         */
                        virtual void resume();

                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * VoteProcessDemoFunctionality::getLogger();
                         * @brief	Gets the logger.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	null if it fails, else the logger.
                         */

                        Smartmatic::Log::ISMTTLog * getLogger();

                        /**
                         * @fn	Glib::ustring VoteProcessDemoFunctionality::getStartLogMessage();
                         * @brief	Gets the start log message.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The start log message.
                         */

                        Glib::ustring getStartLogMessage();

                        /**
                         * @fn	Glib::ustring VoteProcessDemoFunctionality::getFinishLogMessage();
                         * @brief	Gets the finish log message.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The finish log message.
                         */

                        Glib::ustring getFinishLogMessage();

                    private:

                        Smartmatic::SAES::Voting::Vote::Vote vote;	///< The vote
                        sigc::connection signalVote;	///< The signal vote
                        sigc::connection signalStatusVote; ///< the signal status vote

                        Gtk::Widget * normalFrameWidget;	///< The normal frame widget

                        /**
                         * @fn	void VoteProcessDemoFunctionality::CreateNormalFrame();
                         * @brief	Create the normal frame.
                         * @author	Juan.Delgado
                         * @date	23/07/2011
                         */
                        void  CreateNormalFrame();

                        /**
                         * @fn	void VoteProcessDemoFunctionality::reconfigureBarcode();
                         * @brief	Reconfigure barcode.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void reconfigureBarcode();

                        /**
                         * @fn	void VoteProcessDemoFunctionality::endReconfigureBarcode();
                         * @brief	Ends reconfigure barcode.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void endReconfigureBarcode();

                        bool reconfigure; ///< flag reconfigure

                        Smartmatic::SAES::Voting::PBReports::VoteStatisticsWrapper * voteStats; ///< The vote stats

                        bool wasPresent;	///< true to was present
                        std::vector<unsigned char> dataBinarizedToWrite;	///< The data binarized to write
                        sigc::connection conn;  ///< The connection
                        Gtk::Frame * framePrincipal; ///< The frame principal
                        Gtk::Frame * frameNormal;	///< The frame normal
                        Gtk::Frame * frame2; ///< The second frame
                        Gtk::EventBox * eventboxVoteDemo;	///< The eventbox vote demo
                        Gtk::EventBox * eventboxStepBarcode; ///< The eventbox step barcode
                        Gtk::VBox * vbox2;  ///< The second vbox
                        std::string lastCardGUUID;  ///< The last card guuid
                        Smartmatic::SAES::Printing::PrintPreviewWidget * printWidget;	///< The print widget
                        Smartmatic::SAES::Printing::PrintPreviewWidget * printWidgetMagnify; ///< The print widget magnify
                        Smartmatic::SAES::Printing::VotePrintDocument * doc; ///< The document
                        Smartmatic::SAES::Printing::VotePrintDocument * docMagnify; ///< The document magnify
                        Gtk::Image * imageCard; ///< The image card
                        Gtk::Image * imageVote; ///< The image vote
                        Gtk::Label * labelResult;	///< The label result
                        Gtk::Label	* labelStatus;	///< The label status
                        Gtk::Label * labelVoteGen;  ///< The label vote generate
                        Smartmatic::GUI::Widgets::SmartmaticBasicScrollContainer * scrolledwindowVote;	///< The scrolledwindow vote
                        Gtk::Viewport * viewportVote;	///< The viewport vote
                        Gtk::EventBox * eventbox1; ///< The eventbox custom attributes

                        Gtk::CheckButton * checkbuttonIsAudio;  ///< The button to determine if is Audio
                        Gtk::Frame * frameMagnify;  ///< The frame magnify
                        Gtk::VBox * vboxMagnify; ///< The vbox magnify
                        Smartmatic::GUI::Widgets::SmartmaticBasicScrollContainer * scrolledMagnify;  ///< The scrolled magnify
                        Gtk::Viewport  * viewMagnify;   ///< The view magnify
                        Smartmatic::GUI::Widgets::SmartmaticButton * buttonBackMagnify; ///< The button back magnify
                        Smartmatic::GUI::Widgets::SmartmaticButton * buttonMagnify; ///< The button magnify

                        /**
                         * @fn	void VoteProcessDemoFunctionality::activateCardData();
                         * @brief	Method activate card data.
                         * @author	Yadickson Soto
                         * @date	10/05/2012
                         */
                        void activateCardData();

                        /**
                         * @fn	void VoteProcessDemoFunctionality::SetCustomAttributeVector ( std::vector< Smartmatic::SAES::Voting::VotingDevice::Custom_attribute > vecCA );
                         * @brief	Sets custom attribute vector.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @param	vecCA	The vector ca.
                         */
                        void SetCustomAttributeVector ( std::vector< Smartmatic::SAES::Voting::VotingDevice::Custom_attribute > vecCA );

                        /**
                         * @fn	void VoteProcessDemoFunctionality::on_buttonBackMagnify_clicked();
                         * @brief	Handles button back magnify clicked signals.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        void on_buttonBackMagnify_clicked();

                        /**
                         * @fn	void VoteProcessDemoFunctionality::on_buttonMagnify_clicked();
                         * @brief	Handles button magnify clicked signals.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        void on_buttonMagnify_clicked();

                        Smartmatic::SAES::GUI::Widgets::CardActivatorEventBox * cardActivatorBox; ///< The card activator box
                        std::vector<Smartmatic::SAES::Voting::VotingDevice::Custom_attribute > attributes;  ///< The attributes
                        static VoteProcessDemoFunctionality * current_instance; ///< The current instance
                        std::string temporaryValue;  ///< The temporary value

                        /**
                         * @fn	VoteProcessDemoFunctionality::VoteProcessDemoFunctionality();
                         * @brief	Default constructor initialize all variables in NULL.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        VoteProcessDemoFunctionality();

                        /**
                         * @fn	virtual VoteProcessDemoFunctionality::~VoteProcessDemoFunctionality();
                         * @brief	Finaliser.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        virtual ~VoteProcessDemoFunctionality();

                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType VoteProcessDemoFunctionality::GetMenuOptionType();
                         * @brief	Gets the menu option type.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The menu option type.
                         */

                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @property	std::list < Smartmatic::SAES::Voting::VotingDevice::Custom_attribute_definition > listCAD
                         * @brief	Gets the list cad.
                         * @return	The list cad.
                         */
                        std::list < Smartmatic::SAES::Voting::VotingDevice::Custom_attribute_definition > listCAD;  ///< The list cad

                        /**
                         * @fn	std::string VoteProcessDemoFunctionality::getCodeByName ( std::string optionName );
                         * @brief	Gets a code by name.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @param	optionName	Name of the option.
                         * @return	The code by name.
                         */

                        std::string getCodeByName ( std::string optionName );

                        /**
                         * @fn	std::string VoteProcessDemoFunctionality::getNameByCode ( std::string optionCode );
                         * @brief	Gets a name by code.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @param	optionCode	The option code.
                         * @return	The name by code.
                         */

                        std::string getNameByCode ( std::string optionCode );

                        /**
                         * @fn	void VoteProcessDemoFunctionality::Dispose();
                         * @brief	Dispose of this object, cleaning up any resources it uses.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        void Dispose();

                        /**
                         * @fn	virtual void VoteProcessDemoFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	03/04/2012
                         */
                        virtual void deleteElements();

                        /**
                         * @fn	void VoteProcessDemoFunctionality::Initialize();
                         * @brief	Initializes this object.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        void Initialize();

                        /**
                         * @fn	Gtk::Widget * VoteProcessDemoFunctionality::GetFrame();
                         * @brief	Gets the frame.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	null if it fails, else the frame.
                         */

                        Gtk::Widget * GetFrame();

                        /**
                         * @fn	bool VoteProcessDemoFunctionality::Refresh ( int time_num );
                         * @brief	Refreshs.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @param	time_num	The time number.
                         * @return	true if it succeeds, false if it fails.
                         */

                        bool Refresh ( int time_num );

                        /**
                         * @fn	void VoteProcessDemoFunctionality::BarcodeRefresh();
                         * @brief	Barcode refresh.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        void BarcodeRefresh();

                        /**
                         * @fn	void VoteProcessDemoFunctionality::BarcodeRefreshDemo ( bool enabledMagnify );
                         * @brief	Barcode refresh demo.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @param	enabledMagnify	The time number.
                         */

                        void BarcodeRefreshDemo ( bool enabledMagnify );

                        /**
                         * @fn	void VoteProcessDemoFunctionality::BarcodeRefreshNotDemo();
                         * @brief	Barcode refresh not demo.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        void BarcodeRefreshNotDemo();

                        /**
                         * @fn	void VoteProcessDemoFunctionality::BarcodeError ( bool enabledMagnify );
                         * @brief	Barcode error.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @param	enabledMagnify	The time number.
                         */

                        void BarcodeError ( bool enabledMagnify );

                        /**
                         * @fn	void VoteProcessDemoFunctionality::AdjustElectionStatus();
                         * @brief	Adjust election status.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void AdjustElectionStatus();

                        /**
                         * @fn	std::string VoteProcessDemoFunctionality::GetWindowTitle();
                         * @brief	Gets the window title.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The window title.
                         */

                        std::string GetWindowTitle();
                        /**
                         * @fn	void VoteProcessDemoFunctionality::onSignalVote ( Smartmatic::SAES::Voting::Vote::Vote * vote );
                         * @brief	Method getter vote process.
                         * @author	Yadickson Soto
                         * @date	23/10/2012
                         * @param	vote	vote.
                         */
                        void onSignalVote ( Smartmatic::SAES::Voting::Vote::Vote * vote );
                        /**
                         * @fn	void VoteProcessDemoFunctionality::onSignalState ( Smartmatic::SAES::Operation::Voting::VotePersistence::PersistenceStatusVote status );
                         * @brief	Method getter status vote process.
                         * @author	Yadickson Soto
                         * @date	23/10/2012
                         * @param	status	status vote process.
                         * @param	count 	count status.
                         */
                        void onSignalState ( Smartmatic::SAES::Operation::Voting::VotePersistence::PersistenceStatusVote status );
                        /**
                         * @fn	virtual void VoteProcessDemoFunctionality::onBeforeExit();
                         * @brief	virtual method before exit.
                         * @author	Yadickson Soto
                         * @date	23/10/2012
                         */
                        virtual void onBeforeExit();

                        bool statusActivate; ///< flag status activation
                        static Smartmatic::Log::ISMTTLog * logger; /**<logger*/ ///< The logger
                };
            }
        }
    }
}


#endif // _VOTE_DEMO_FUNCTIONALITY_H_
