/**
 * @file AuthenticationWidget.hxx
 * @brief Header class authentication widget
 * @date 31/03/2012
 * @author Yadickson Soto
 */

#ifndef AUTHENTICATIONWIDGET_HXX_
#define AUTHENTICATIONWIDGET_HXX_

#include <Widgets/StepWidget.hxx>
#include "PollingPlaceInfoWidget.hxx"
#include "Widgets/keypad-widget.h"
#include "Widgets/key-pad-widget-interface.h"
#include <Operation/Authenticator/IAuthenticator.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	AuthenticationWidget
                 * @brief	Class authentication widget.
                 * @author	Yadickson Soto
                 * @date	31/03/2012
                 */
                class AuthenticationWidget : public Smartmatic::GUI::Widgets::StepWidget,
                    public Smartmatic::GUI::Widgets::KeypadInterface
                {
                    public:
                        /**
                         * @fn	AuthenticationWidget::AuthenticationWidget ( std::string composedTitleKey,
                         * 			PollingPlaceInfoWidget * info,
                         * 			Smartmatic::SAES::Operation::Authenticator::IAuthenticator * authenticator );
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	31/03/2012
                         * @param	composedTitleKey	composed title key.
                         * @param	info							info.
                         * @param	authenticator			authenticator.
                         */
                        AuthenticationWidget ( std::string composedTitleKey, PollingPlaceInfoWidget * info,
                                               Smartmatic::SAES::Operation::Authenticator::IAuthenticator * authenticator );
                        /**
                         * @fn	virtual AuthenticationWidget::~AuthenticationWidget();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	31/03/2012
                         */
                        virtual ~AuthenticationWidget();
                        /**
                         * @fn	virtual void AuthenticationWidget::dispose();
                         * @brief	virtual method stop.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        virtual void dispose();
                        /**
                         * @fn	virtual void AuthenticationWidget::refresh();
                         * @brief	refresh widget method.
                         * @author	Yadickson Soto
                         * @date	31/03/2012
                         */
                        virtual void refresh();
                        /**
                         * @fn	virtual std::string AuthenticationWidget::getTitleText();
                         * @brief	virtual method getter title.
                         * @author	Yadickson Soto
                         * @date	31/03/2012
                         * @return	title.
                         */
                        virtual std::string getTitleText();
                        /**
                         * @fn	virtual void AuthenticationWidget::clearPassword();
                         * @brief	method clear password.
                         * @author	Yadickson Soto
                         * @date	31/03/2012
                         */
                        virtual void clearPassword();
                        /**
                         * @fn	virtual void AuthenticationWidget::checkPassword();
                         * @brief	method check password.
                         * @author	Yadickson Soto
                         * @date	31/03/2012
                         */
                        virtual void checkPassword();
                        /**
                         * @fn	sigc::signal<void> AuthenticationWidget::getSignalRunMenu();
                         * @brief	method getter signal run menu.
                         * @author	Yadickson Soto
                         * @date	22/04/2012
                         * @return	signal run menu.
                         */
                        sigc::signal<void> getSignalRunMenu();
                        /**
                         * @fn	sigc::signal<void> AuthenticationWidget::getSignalRunMachine();
                         * @brief	method getter signal run machine.
                         * @author	Yadickson Soto
                         * @date	22/04/2012
                         * @return	signal run machine.
                         */
                        sigc::signal<void> getSignalRunMachine();
                        /**
                         * @fn	virtual void AuthenticationWidget::stop() = 0;
                         * @brief	method stop widget.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         */
                        virtual void stop() = 0;

                    protected:

                        sigc::signal<void> signalRunMenu; ///< signal menu
                        sigc::signal<void> signalRunMachine; ///< signal run machine process

                        /**
                         * @fn	void AuthenticationWidget::config();
                         * @brief	method config label.
                         * @author	Yadickson Soto
                         * @date	24/04/2012
                         */
                        void config();
                        /**
                         * @fn	virtual void AuthenticationWidget::SetKey ( Smartmatic::GUI::Widgets::KeysActionsCode value );
                         * @brief	virtual method setter key.
                         * @author	Yadickson Soto
                         * @date	31/03/2012
                         * @param	value	value key.
                         */
                        virtual void SetKey ( Smartmatic::GUI::Widgets::KeysActionsCode value );
                        /**
                         * @fn	virtual void AuthenticationWidget::OnKeyPress ( int data );
                         * @brief	virtual method key press.
                         * @author	Yadickson Soto
                         * @date	31/03/2012
                         * @param	data	key value.
                         */
                        virtual void OnKeyPress ( int data );
                        /**
                         * @fn	virtual void AuthenticationWidget::OnKeyPressT9 ( char data );
                         * @brief	virtual method key press.
                         * @author	Yadickson Soto
                         * @date	31/03/2012
                         * @param	data	key value.
                         */
                        virtual void OnKeyPressT9 ( char data );
                        /**
                         * @fn	virtual void AuthenticationWidget::clearAlarm();
                         * @brief	method clear alarm.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         */
                        virtual void clearAlarm();

                    protected:

                        Gtk::Frame * mainFrame; ///< main frame
                        Gtk::HBox * mainHBox; ///< main hbox
                        Gtk::Frame * infoFrame; ///< information frame
                        Gtk::HBox * keyHBox; ///< key vbox
                        Gtk::Label * topLabel; ///< top label
                        Gtk::Label * leftLabel; ///< left label
                        Gtk::Frame * keyFrame; ///< key frame
                        Gtk::Label * bottomLabel; ///< bottom label
                        Gtk::Label * alarmLabel; ///< alarm label
                        Gtk::VBox * mainVBox; ///< error label
                        std::string composedTitleKey; ///< compose title key
                        std::string composedTitle; ///< composed title
                        std::string textFeedBack;   ///< feed back text
                        Smartmatic::GUI::Widgets::KeypadWidget * keypadTest; ///< keypad test
                        PollingPlaceInfoWidget * info; ///< info authentication
                };
            }
        }
    }
}

#endif /* AUTHENTICATIONWIDGET_HXX_ */
