/**
 * @file	BallotOptionInfoWidget.cxx
 * @brief	Declares the ballot option info widget class.
 * @author	Yadickson Soto
 * @date	26/02/2014
 */

#include "BallotOptionInfoWidget.hxx"
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>
#include <Resources/election-string-resources-manager.h>
#include <System/Utils/StringUtils.hxx>

using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::Voting::Election;
using namespace Smartmatic::System::Utils;
using namespace Smartmatic::SAES::Runtime::Environment;
using namespace Smartmatic::SAES::Resources;

BallotOptionInfoWidget::BallotOptionInfoWidget ( const Eligible_option & elegibleOption, SaesDirectories & saesDir, bool enableClick, bool showBorder )
    : BoxSelectionWidget ( elegibleOption.getBallot_options().getBallot_option().begin()->getCode(), enableClick, showBorder )
{
    static BallotOptionWidgetConfiguration config = SAESGUIConfigurationManager::getInstance()->GetBallotOptionWidgetConfiguration();

    this->ballotOption = * ( ( elegibleOption.getBallot_options().getBallot_option() ).begin() );

    std::string sname = elegibleOption.getBallot_name_key();
    labelFullName = ElectionStringResourcesManager::getInstance()->getResource ( sname );

    std::stringstream ss;
    ss << ballotOption.getTally_position();
    labelNumber = ss.str();

    numberWidth = config.getNumberWidth();
    displayConfig = config.getDisplay();
    paddingConfig = config.getPadding();

    imagePath = ballotOption.getImage_file_name().present() ? saesDir.getImageElectoralResource ( ballotOption.getImage_file_name().get() ) : " ";

    std::string separator = config.getSeparatorCharacter();
    std::vector <std::string> parts;
    StringUtils::splitToVector ( labelFullName, separator, parts );

    if ( parts.size() >= 2 )
    {
        labelFirstName = parts[0];
        labelLastName = parts[1];
    }

    set_name ( SAESGUIConfigurationManager::getInstance()->GetVotingExperienceSelectBallotOptionWidgetName() );

    Gdk::Color selectedColor;
    Gdk::Color unSelectedColor;

    selectedColor.set_rgb ( config.getSelectedColor().getRed(), config.getSelectedColor().getGreen(), config.getSelectedColor().getBlue() );
    unSelectedColor.set_rgb ( config.getUnSelectedColor().getRed(), config.getUnSelectedColor().getGreen(), config.getUnSelectedColor().getBlue() );

    setSelectedColor ( selectedColor );
    setUnselectedColor ( unSelectedColor );
}

BallotOptionInfoWidget::~BallotOptionInfoWidget()
{
}

Category BallotOptionInfoWidget::getCategory()
{
    return ballotOption.getCategory();
}
