/**
 * @file	BarcodeDetectionWidget.cpp
 * @brief	Implements the barcode detection widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#include "BarcodeDetectionWidget.h"
#include <Log/SMTTLogManager.h>
#include <Operation/Devices/BCRController.hxx>
#include <Operation/Devices/Polling/BCRPolling.hxx>
#include <Configuration/s-a-e-s-functionality-conf-manager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Functionality::Configuration;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::Operation::Devices;

ISMTTLog * BarcodeDetectionWidget::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.BarcodeDetectionWidget", GETTEXT_PACKAGE );

BarcodeDetectionWidget::BarcodeDetectionWidget ( ProgressWidget * progress )
    : WizardWidgetBase(), progress ( progress )
{
    showReconfigure();
    setWidget ( progress );
    signalDispatcher.getSyncSignal().connect ( sigc::mem_fun ( *this, &BarcodeDetectionWidget::onRawObject ) );
}

BarcodeDetectionWidget::~BarcodeDetectionWidget()
{
    this->remove();

    if ( progress )
    {
        delete progress;
        progress = NULL;
    }

}

void BarcodeDetectionWidget::showReconfigure()
{
    progress->setInfoTitle ( _ ( "Smartmatic.SAES.GUI.Widgets.BarcodeDetectionWidget.ReconfigureBarcode" ) );
    progress->setInfoText ( _ ( "Smartmatic.SAES.GUI.Widgets.BarcodeDetectionWidget.InfoMessage" ) );
    progress->setImage ( Smartmatic::SAES::GUI::Operation::ImageResourcePath::RECONFIGURE_BARCODE );
}

bool BarcodeDetectionWidget::process()
{
    return controller.process(signalDispatcher);
}

void BarcodeDetectionWidget::onRawObject ( void * object )
{
    bool * status = static_cast < bool * > ( object );

    if ( *status )
    {
        logger->Debug ( "Reconfigure Successfully" );
        progress->setInfoText ( _ ( "Smartmatic.SAES.GUI.Widgets.BarcodeDetectionWidget.BarcodeConnected" ) );
        progress->setImage ( Smartmatic::SAES::GUI::Operation::ImageResourcePath::RECONFIGURE_BARCODE_SUCCESS );
    }
    else
    {
        logger->Debug ( "Reconfigure Fail" );
        progress->setInfoText ( _ ( "Smartmatic.SAES.GUI.Widgets.BarcodeDetectionWidget.BarcodeConfigurationFail" ) );
        progress->setImage ( Smartmatic::SAES::GUI::Operation::ImageResourcePath::RECONFIGURE_BARCODE_FAIL );
    }

    Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &BarcodeDetectionWidget::emit ), 2000 );

    delete status;
}
