/**
 * @file	BarcodeDetectionWidget.h
 * @brief	Declares the barcode detection widget class.
 * @author	Yadickson Soto
 * @date	01/11/2012
 */


#ifndef BARCODEDETECTIONWIDGET_H_
#define BARCODEDETECTIONWIDGET_H_

#include <gtkmm.h>
#include <Widgets/smartmatic-button.h>
#include <Widgets/wizard-widget-base.h>
#include <Log/ISMTTLog.h>
#include <Gui/Widgets/ProgressWidget.hxx>
#include <Gui/Widgets/BarcodeDetectionWidgetController.h>
#include <System/SafeThread.hxx>
#include <System/SafeDispatcher.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	BarcodeDetectionWidget
                 * @brief	Barcode detection widget.
                 * @author	Yadickson Soto
                 * @date	01/11/2012
                 */
                class BarcodeDetectionWidget: public Smartmatic::GUI::Widgets::WizardWidgetBase, public Smartmatic::System::SafeThread
                {
                    public:
                        /**
                         * @fn	BarcodeDetectionWidget::BarcodeDetectionWidget ( ProgressWidget * progress );
                         * @brief	Default constructor.
                         * @author	Juan.Delgado
                         * @date	23/07/2011
                         * @param	progress	progress widget.
                         */
                        explicit BarcodeDetectionWidget ( ProgressWidget * progress );

                        /**
                         * @fn	virtual BarcodeDetectionWidget::~BarcodeDetectionWidget();
                         * @brief	Default finalizer.
                         * @author	Juan.Delgado
                         * @date	23/07/2011
                         */
                        virtual ~BarcodeDetectionWidget();

                        /**
                         * @fn	void showReconfigure();
                         * @brief	show reconfigure.
                         * @author	Yadickson Soto
                         * @date	05/09/2013
                         */
                        void showReconfigure();

                    protected:
                         /**
                          * @fn	    virtual bool process ();
                          * @brief	Callback from thread one time. Send reconfigure parameters.
                          * @author	Yadickson Soto
                          * @date	31/07/2015
                          * @return false, only one time
                          */
                        virtual bool process ();
                        /**
                         * @fn	    void onRawObject ( void * object );
                         * @brief	Callback when emit sync signal.
                         * @author	Yadickson Soto
                         * @date	31/07/2015
                         * @param 	object The object to process
                         */
                        void onRawObject ( void * object );

                        /**
                         * @fn	void endReconfigure ( );
                         * @brief	method end reconfigure report.
                         * @author	Yadickson Soto
                         * @date	24/10/2012
                         */
                        void endReconfigure ( );

                    private:

                        Smartmatic::System::SafeDispatcher signalDispatcher; ///> The signal dispatcher
                        ProgressWidget * progress; ///< principal frame
                        BarcodeDetectionWidgetController  controller;///< controller
                        static Smartmatic::Log::ISMTTLog * logger; ///< logger
                };
            }
        }
    }
}

#endif /* BARCODEDETECTIONWIDGET_H_ */
