/**
 * @file	ClosingElectionStatusWidget.h
 * @brief	Declares the closing election status widget class.
 * @author	eduardo.fernandez
 * @date	10/12/2018
 */

#ifndef CLOSING_ELECTION_STATUS_WIDGET
#define CLOSING_ELECTION_STATUS_WIDGET

#include <Widgets/wizard-widget-base.h>
#include "ProgressWidget.hxx"

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	ClosingElectionStatusWidget
                 * @brief	Close election status widget.
                 * @author  eduardo.fernandez
                 * @date    10/12/2018
                 */

                class ClosingElectionStatusWidget: public Smartmatic::GUI::Widgets::WizardWidgetBase
                {
                    public:

                        /**
                         * @fn	ClosingElectionStatusWidget::ClosingElectionStatusWidget ( ProgressWidget * progress );
                         * @brief	Default constructor.
                         * @author  eduardo.fernandez
                         * @date    10/12/2018
                         * @param	progress	widget with label and image.
                         */

                        explicit ClosingElectionStatusWidget ( ProgressWidget * progress );

                        /**
                         * @fn	ClosingElectionStatusWidget::~ClosingElectionStatusWidget();
                         * @brief	Finaliser.
                         * @author  eduardo.fernandez
                         * @date    10/12/2018
                         */

                        ~ClosingElectionStatusWidget();
                        /**
                         * @fn	virtual void ClosingElectionStatusWidget::initialize();
                         * @brief	Initializer method.
                         * @author  eduardo.fernandez
                         * @date    10/12/2018
                         */
                        virtual void initialize();
                        /**
                         * @fn	virtual void StartClosingElectionStatusWidget::dispose();
                         * @brief	virtual method stop.
                         * @author  eduardo.fernandez
                         * @date    10/12/2018
                         */
                        virtual void dispose();

                        /**
                         * @fn	virtual bool ClosingElectionStatusWidget::isEnabledButtonExitWizard();
                         * @brief	Method getter is enabled button exit wizard.
                         * @author  eduardo.fernandez
                         * @date    10/12/2018
                         * @return	true is enabled button exit wizard.
                         */
                        virtual bool isEnabledButtonExitWizard();

                    private:
                        Glib::Thread * m_thread; ///< The thread pointer

                        ProgressWidget * progress; ///< widget with label and image
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger

                        /**
                         * @fn	void ClosingElectionStatusWidget::start();
                         * @brief	Method start persist codi files.
                         * @author  eduardo.fernandez
                         * @date    10/12/2018
                         */
                        void start();

                        /**
                         * @fn	void ClosingElectionStatusWidget::end();
                         * @brief	Method end persist codi files.
                         * @author  eduardo.fernandez
                         * @date    10/12/2018
                         */
                        void end();

                        /**
                         * @fn	void ClosingElectionStatusWidget::updateLabel ( std::string text );
                         * @brief	Method start persist codi files.
                         * @author  eduardo.fernandez
                         * @date    10/12/2018
                         * @param	text	new text for widget.
                         */
                        void updateLabel ( std::string text );
                };
            }
        }
    }
}

#endif // CLOSING_ELECTION_STATUS_WIDGET
