/**
 * @file DeviceMonitorWidget.hxx
 * @brief Body class device monitor result widget
 * @date 13/12/2012
 * @author Yadickson Soto
 */

#ifndef DEVICEMONITORWIDGET_HXX_
#define DEVICEMONITORWIDGET_HXX_

#include <gtkmm.h>
#include <Operation/Monitor/DeviceTypeMonitor.hxx>
#include <Widgets/StepWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	DeviceMonitorWidget
                 * @brief	Device monitor result widget.
                 * @author	Yadickson Soto
                 * @date	13/12/2012
                 */
                class DeviceMonitorWidget : public Smartmatic::GUI::Widgets::StepWidget
                {
                    public:
                        /**
                         * @fn	DeviceMonitorWidget::DeviceMonitorWidget ( Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor * device, int width, int height );
                         * @brief	Constructor.
                         * @author	Yadickson Soto
                         * @date	13/12/2012
                         * @param 	device 		pointer device monitor
                         * @param	width		Width of the image.
                         * @param	height		Height of the image.
                         */
                        DeviceMonitorWidget ( Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor * device, int width, int height );
                        /**
                         * @fn	virtual DeviceMonitorWidget::~DeviceMonitorWidget();
                         * @brief	Destructor.
                         * @author	Yadickson Soto
                         * @date	13/12/2012
                         */
                        virtual ~DeviceMonitorWidget();
                        /**
                         * @fn	Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor * getDeviceTypeMonitor();
                         * @brief	Gets the device type monitor.
                         * @author	Yadickson Soto
                         * @date	13/12/2012
                         * @return	the device type monitor.
                         */
                        Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor * getDeviceTypeMonitor();
                        /**
                         * @fn	void DeviceMonitorWidget::update();
                         * @brief	Updates this object.
                         * @author	Yadickson Soto
                         * @date	13/12/2012
                         */
                        void update();
                        /**
                         * @fn	void DeviceMonitorWidget::showWidget( bool show = true );
                         * @brief	Show all object.
                         * @author	Yadickson Soto
                         * @date	09/06/2015
                         * @param show show widget
                         */
                        void showWidget ( bool show = true );
                        /**
                         * @fn	void DeviceMonitorWidget::isShowWidget();
                         * @brief	Gets if widget is showing.
                         * @author	Yadickson Soto
                         * @date	09/06/2015
                         */
                        bool isShowWidget();

                    protected:
                        /**
                         * @fn	void DeviceMonitorWidget::initialize();
                         * @brief	Initializes this object.
                         * @author	Yadickson Soto
                         * @date	13/12/2012
                         */
                        void initialize();
                        /**
                         * @fn	void DeviceMonitorWidget::dispose();
                         * @brief	Performs application-defined tasks associated with freeing, releasing, or resetting
                         * 				unmanaged resources.
                         * @author	Yadickson Soto
                         * @date	13/12/2012
                         */
                        void dispose();

                    private:

                        bool showFlag; ///< Flag to say if widget is showing
                        Gtk::Image * image; ///< The image
                        Glib::RefPtr<Gdk::Pixbuf> pixbuf;   ///< The pixbuf
                        int width; ///< Width of the image
                        int height;	///< Height of the image
                        Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor * device; ///< The device
                        static Smartmatic::Log::ISMTTLog * logger;	///< The logger
                };
            }
        }
    }
}

#endif /* DEVICEMONITORWIDGET_HXX_ */
