/**
 * @file AbleButtonWidget.cxx
 * @brief Body class able button widget
 * @date 06/09/2012
 * @author Yadickson Soto
 */

#include "AbleButtonWidget.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Gui/Widgets/FactoryMethodWidget.hxx>
#include <Environment/Configurations/resource-path-provider.h>
#include "Configuration/label-configuration.h"
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"
#include <Operation/Voting/AudioVoting/AudioVotingCheckUtility.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::Log;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::Environment;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::HW::Configuration;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Operation::AudioVoting;

ISMTTLog * AbleButtonWidget::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.AbleButtonWidget", GETTEXT_PACKAGE );

AbleButtonWidget::AbleButtonWidget()
    : BasicDiagnosticWidget ()
{
    mainFrame = NULL;
    mainVbox = NULL;
    mainHbox = NULL;
    infoText = NULL;
    container = NULL;
    ableWidget = NULL;
    initialize();
    setWidget ( mainFrame );
}

AbleButtonWidget::~AbleButtonWidget()
{
    remove();

    if ( mainFrame )
    {
        delete mainFrame;
        mainFrame = NULL;
    }

    if ( mainVbox )
    {
        delete mainVbox;
        mainVbox = NULL;
    }

    if ( mainHbox )
    {
        delete mainHbox;
        mainHbox = NULL;
    }

    if ( infoText )
    {
        delete infoText;
        infoText = NULL;
    }

    if ( container )
    {
        delete container;
        container = NULL;
    }

    if ( ableWidget )
    {
        delete ableWidget;
        ableWidget = NULL;
    }
}

void AbleButtonWidget::initialize()
{
    setAbleWidget();

    Glib::RefPtr<Gtk::Builder> builder;
    std::string gladeFile = ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, "ui/AbleButtonWidget.glade" );

    try
    {
        builder = Gtk::Builder::create_from_file ( gladeFile );
    }
    catch ( const Glib::FileError & ex )
    {
        logger->Debug ( "FATAL - AbleButtonWidget Initialize" );
    }

    builder->get_widget ( "main-frame", mainFrame );
    builder->get_widget ( "main-vbox", mainVbox );
    builder->get_widget ( "main-hbox", mainHbox );
    builder->get_widget ( "label", infoText );
    builder->get_widget ( "container", container );

    LabelConfiguration diagConf = SAESGUIConfigurationManager::getInstance()->GetDiagnosisLabelConfiguration();
    LabelConfiguration::SetLabelConfiguration ( infoText, diagConf );

    viewButton();
    setText ( " " );
    container->add ( *ableWidget );
    show_all_children();
}

void AbleButtonWidget::setAbleWidget()
{
    AudioVotingCheckUtility audioVotingCheckUtility;

    if ((audioVotingCheckUtility.ableIsConnected(true)) &&
        (audioVotingCheckUtility.getAbledConnected() == AudioVotingCheckUtility::ABLED20))
    {
        ableWidget = FactoryMethodWidget::createAble20ButtonWidget();
    }
    else
    {
        ableWidget = FactoryMethodWidget::createAble10ButtonWidget();
    }
}

bool AbleButtonWidget::pressButton ( AbleButtonType button )
{
    logger->Debug ( "Press Button" );
    return ableWidget->pressButton ( button );
}

bool AbleButtonWidget::pressButton ( A4517AbleButtonType button )
{
    logger->Debug ( "Press Button" );
    return ableWidget->pressButton ( button );
}

bool AbleButtonWidget::releaseButton ( AbleButtonType button )
{
    logger->Debug ( "Release Button" );
    return ableWidget->releaseButton ( button );
}

std::list <AbleButtonType> & AbleButtonWidget::getButtons()
{
    return ableWidget->getButtons();
}

void AbleButtonWidget::setText ( const std::string & text )
{
    infoText->set_text ( text );
    infoText->set_visible ( true );
}

sigc::signal<void> AbleButtonWidget::getSignalCancel()
{
    return signalCancelDetected;
}

void AbleButtonWidget::viewButton ( bool view )
{

}
