/*
 * AbleDiagnosticSoundWidget.hxx
 *
 *  Created on: Feb 20, 2018
 *      Author: eduardo.fernandez
 */

#ifndef ABLE_DIAGNOSTIC_SOUND_WIDGET_HXX
#define ABLE_DIAGNOSTIC_SOUND_WIDGET_HXX

#include <Gui/Widgets/Diagnose/BasicDiagnosticWidget.hxx>
#include <Gui/Widgets/Diagnose/EurnEndDiagnoseWidget.hxx>
#include <Gui/Widgets/Diagnose/AlarmBoxDiagnoseStepWidget.hxx>
#include <Operation/Devices/EurnController.hxx>
#include <Widgets/SmartmaticBasicFrame.hxx>
#include <Widgets/SmartmaticBasicEventBox.hxx>
#include <Widgets/SmartmaticBasicLabel.hxx>
#include <Widgets/SmartmaticBasicVBox.hxx>
#include <Widgets/smartmatic-button.h>
#include <set>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace System
    {
        namespace Audio
        {
            class Audio;
        }
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	AbleDiagnosticSoundWidget
                 * @brief	able diagnostic sound diagnosis widget.
                 * @author	eduardo.fernandez
                 * @date	Feb 20, 2018
                 */

                class AbleDiagnosticSoundWidget: public Smartmatic::SAES::GUI::Widgets::BasicDiagnosticWidget
                {
                    public:

                        /**
                         * @fn	AbleDiagnosticSoundWidget::AbleDiagnosticSoundWidget ();
                         * @brief	Constructor.
                         * @author	eduardo.fernandez
                         * @date	Feb 20, 2018
                         */
                        AbleDiagnosticSoundWidget ();

                        /**
                         * @fn	virtual ~AbleDiagnosticSoundWidget();
                         * @brief	Destroy.
                         * @author	eduardo.fernandez
                         * @date	Feb 20, 2018
                         */
                        virtual ~AbleDiagnosticSoundWidget();

                        /**
                         * @fn	void AbleDiagnosticSoundWidget::initialize();
                         * @brief	Initializes this object.
                         * @author	eduardo.fernandez
                         * @date	Feb 20, 2018
                         */
                        void initialize();
                        /**
                         * @fn	virtual void AbleDiagnosticSoundWidget::dispose();
                         * @brief	virtual method stop.
                         * @author	eduardo.fernandez
                         * @date	Feb 20, 2018
                         */
                        virtual void dispose();
                        /**
                         * @fn  virtual bool AbleDiagnosticSoundWidget::getSoundTestIsCorrect();
                         * @brief   Gets whether the able-d sound test was correct.
                         * @author  eduardo.fernandez
                         * @date    Feb 20, 2018
                         */
                        bool getSoundTestIsCorrect();

                        /**
                         * @fn  sigc::signal<void> AbleDiagnosticSoundWidget::getSignalOk();
                         * @brief   method getter signal ok.
                         * @author  eduardo.fernandez
                         * @date    21/02/2018
                         * @return  signal ok.
                         */
                        sigc::signal<void> getSignalOk();

                        /**
                         * @fn  sigc::signal<void> AbleDiagnosticSoundWidget::getSignalCancel();
                         * @brief   method getter signal cancel.
                         * @author  eduardo.fernandez
                         * @date    21/02/2018
                         * @return  signal cancel.
                         */
                        sigc::signal<void> getSignalCancel();

                    private:

                        void onOptionSelected();

                    private:

                        Smartmatic::GUI::Widgets::SmartmaticBasicFrame  frame; ///< The principal frame
                        Gtk::Alignment  alignment; ///< The principal container of labels and buttons
                        ProgressWidget *progressWidget;
                        Smartmatic::GUI::Widgets::SmartmaticBasicVBox  vboxOptions; ///< The vbox container
                        Smartmatic::GUI::Widgets::SmartmaticButton  buttonSoundTest; ///< Button open test
                        Smartmatic::SAES::GUI::Widgets::AlarmBoxDiagnoseStepWidget  soundTestOption; ///< buzzer test
                        static Smartmatic::Log::ISMTTLog * logger; /**<logger*/ ///< The logger

                        Smartmatic::System::Audio::Audio buildSampleAudio();

                        /**
                         * @fn  void AbleDiagnosticSoundWidget::onPlaySoundTest();
                         * @brief   Action Open door.
                         * @author  eduardo.fernandez
                         * @date    Feb 20, 2018
                         */
                        void onPlaySoundTest ();
};
            }
        }
    }
}
#endif /* ABLE_DIAGNOSTIC_SOUND_WIDGET_HXX */
