/**
 * @file AbleDiagnosticWidget.hxx
 * @brief Header class able diagnostic widget
 * @date 05/09/2012
 * @author Yadickson Soto
 */

#ifndef ABLEDIAGNOSTICWIDGET_HXX_
#define ABLEDIAGNOSTICWIDGET_HXX_

#include <Gui/Widgets/Diagnose/BasicDiagnosticWidget.hxx>
#include "AbleButtonDiagnosticWidget.hxx"
#include "AbleDiagnosticSoundWidget.hxx"
#include <Operation/Voting/AudioVoting/AudioVotingCheckUtility.hxx>
#include <Gui/Widgets/ProgressWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Voting
        {
            namespace Status
            {
                class VotingMachineStatusWrapper;
            }
        }

        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	AbleDiagnosticWidget
                 * @brief	Class able diagnostic widget.
                 * @author	Yadickson Soto
                 * @date	05/09/2012
                 */
                class AbleDiagnosticWidget : public BasicDiagnosticWidget
                {
                    public:
                        /**
                         * @fn	AbleDiagnosticWidget::AbleDiagnosticWidget ();
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	05/09/2012
                         */
                        AbleDiagnosticWidget ();
                        /**
                         * @fn	virtual AbleDiagnosticWidget::~AbleDiagnosticWidget();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	05/09/2012
                         */
                        virtual ~AbleDiagnosticWidget();
                        /**
                         * @fn	void AbleDiagnosticWidget::Initialize();
                         * @brief	Initializes this object.
                         * @author	Yadickson Soto
                         * @date	05/09/2012
                         */
                        void initialize();
                        /**
                         * @fn	void AbleDiagnosticWidget::Dispose();
                         * @brief	Dispose of this object, cleaning up any resources it uses.
                         * @author	Yadickson Soto
                         * @date	05/09/2012
                         */
                        void Dispose();

                    protected:

                        /**
                         * @fn	void AbleDiagnosticWidget::endDiagnosis();
                         * @brief	method end diagnosis.
                         * @author	Yadickson Soto
                         * @date	05/09/2012
                         */
                        void endDiagnosis();
                        /**
                         * @fn	void AbleDiagnosticWidget::endError();
                         * @brief	method error diagnostic.
                         * @author	Yadickson Soto
                         * @date	06/09/2012
                         */
                        void endError();
                        /**
                         * @fn  void AbleDiagnosticWidget::enableOkButton();
                         * @brief   method enable ok button.
                         * @author  eduardo.fernandez
                         * @date    22/02/2018
                         */
                        void enableOkButton();

                    private:

                        /**
                         * @fn  void AbleDiagnosticWidget::setDiagnosticResult();
                         * @brief   method set diagnostic result.
                         * @author  eduardo.fernandez
                         * @date    22/02/2018
                         */
                        void setDiagnosticResult();
                        /**
                         * @fn  void AbleDiagnosticWidget::setResultWidget();
                         * @brief   method set result widget.
                         * @author  eduardo.fernandez
                         * @date    17/04/2018
                         */
                        void setResultWidget();
                        /**
                         * @fn  void AbleDiagnosticWidget::setStatusAbledOk();
                         * @brief   method set status abled ok.
                         * @author  eduardo.fernandez
                         * @date    22/02/2018
                         */
                        void setStatusAbledOk();
                        /**
                         * @fn  void AbleDiagnosticWidget::setDiagnosticResult();
                         * @brief   method set status abled error.
                         * @author  eduardo.fernandez
                         * @date    22/02/2018
                         */
                        void setStatusAbledError();
                        /**
                         * @fn  void AbleDiagnosticWidget::setStatusAbledSoundError();
                         * @brief   method set status abled sound error.
                         * @author  eduardo.fernandez
                         * @date    26/02/2018
                         */
                        void setStatusAbledSoundError();

                    private:

                        bool status; ///< end status diagnosis
                        bool soundTestPerformed;
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                        Smartmatic::SAES::GUI::Widgets::AbleButtonDiagnosticWidget * ableButtonWidget;	///< The able button widget
                        Smartmatic::SAES::GUI::Widgets::AbleDiagnosticSoundWidget * ableDiagnosticSoundWidget;
                        Smartmatic::SAES::Operation::AudioVoting::AudioVotingCheckUtility audioVotingCheckUtility;
                        Smartmatic::SAES::Voting::Status::VotingMachineStatusWrapper * votingMachineStatusWrapper;
                        Smartmatic::SAES::GUI::Widgets::ProgressWidget * progressWidget; ///< The visual container
                };
            }
        }
    }
}
#endif /* ABLEDIAGNOSTICWIDGET_HXX_ */
