/**
 * @file AbleP168AButtonWidget.cxx
 * @brief Body class able p168a widget
 * @date 06/09/2012
 * @author Yadickson Soto
 */

#include "AbleP168AButtonWidget.hxx"
#include <Environment/Configurations/resource-path-provider.h>
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::Environment;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::HW::Configuration;

ISMTTLog * AbleP168AButtonWidget::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.AbleP168AButtonWidget", GETTEXT_PACKAGE );

AbleP168AButtonWidget::AbleP168AButtonWidget()
    : IAbleButtonWidget()
{
    initialize();
    add ( *container );
    show_all_children();
}

AbleP168AButtonWidget::~AbleP168AButtonWidget()
{
}

void AbleP168AButtonWidget::initialize()
{
    Glib::RefPtr<Gtk::Builder> builder;
    std::string gladeFile = ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, "ui/AbleWidget.glade" );

    try
    {
        builder = Gtk::Builder::create_from_file ( gladeFile );
    }
    catch ( const Glib::FileError & ex )
    {
        logger->Debug ( "FATAL - AbleP168AButtonWidget Initialize" );
    }

    builder->get_widget ( "mainFrame", container );
    builder->get_widget ( "image-base", imageBase );
    imageBase->set ( ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, "ui/AbleButtons.png" ) );
    Gtk::Image * image = NULL;
    builder->get_widget ( "image-arrow-up", image );
    addButton ( AbleButtonType::P168A_DEVICE_UP, image );
    image = NULL;
    builder->get_widget ( "image-arrow-down", image );
    addButton ( AbleButtonType::P168A_DEVICE_DOWN, image );
    image = NULL;
    builder->get_widget ( "image-arrow-left", image );
    addButton ( AbleButtonType::P168A_DEVICE_LEFT, image );
    image = NULL;
    builder->get_widget ( "image-arrow-right", image );
    addButton ( AbleButtonType::P168A_DEVICE_RIGHT, image );
    image = NULL;
    builder->get_widget ( "image-select", image );
    addButton ( AbleButtonType::P168A_DEVICE_SELECT, image );
    image = NULL;
    builder->get_widget ( "image-help", image );
    addButton ( AbleButtonType::P168A_DEVICE_HELP, image );
    image = NULL;
    builder->get_widget ( "image-volume-down", image );
    addButton ( AbleButtonType::P168A_DEVICE_VOLUME_DOWN, image );
    image = NULL;
    builder->get_widget ( "image-volume-up", image );
    addButton ( AbleButtonType::P168A_DEVICE_VOLUME_UP, image );
    image = NULL;
    builder->get_widget ( "image-speed-down", image );
    addButton ( AbleButtonType::P168A_DEVICE_SPEED_DOWN, image );
    image = NULL;
    builder->get_widget ( "image-speed-up", image );
    addButton ( AbleButtonType::P168A_DEVICE_SPEED_UP, image );
    image = NULL;
    builder->get_widget ( "image-pause", image );
    addButton ( AbleButtonType::P168A_DEVICE_PAUSE, image );
    std::list <AbleButtonType>::iterator it;

    for ( it = getButtons().begin();
            it != getButtons().end();
            ++it )
    {
        Gtk::Image * image = getButton ( *it );

        if ( image == NULL )
        {
            continue;
        }

        std::string file;
        image->set_visible ( false );
        image->set_no_show_all();

        switch ( *it )
        {
            case AbleButtonType::P168A_DEVICE_HELP:
                file = "ui/AbleHelp.png";
                break;

            case AbleButtonType::P168A_DEVICE_PAUSE:
                file = "ui/AblePause.png";
                break;

            case AbleButtonType::P168A_DEVICE_UP:
                file = "ui/AbleArrowUp.png";
                break;

            case AbleButtonType::P168A_DEVICE_DOWN:
                file = "ui/AbleArrowDown.png";
                break;

            case AbleButtonType::P168A_DEVICE_LEFT:
                file = "ui/AbleArrowLeft.png";
                break;

            case AbleButtonType::P168A_DEVICE_RIGHT:
                file = "ui/AbleArrowRight.png";
                break;

            case AbleButtonType::P168A_DEVICE_SELECT:
                file = "ui/AbleSelect.png";
                break;

            case AbleButtonType::P168A_DEVICE_VOLUME_DOWN:
                file = "ui/AbleVolumeDown.png";
                break;

            case AbleButtonType::P168A_DEVICE_VOLUME_UP:
                file = "ui/AbleVolumeUp.png";
                break;

            case AbleButtonType::P168A_DEVICE_SPEED_DOWN:
                file = "ui/AbleSpeedDown.png";
                break;

            case AbleButtonType::P168A_DEVICE_SPEED_UP:
                file = "ui/AbleSpeedUp.png";
                break;

            case AbleButtonType::P168A_DEVICE_UNKNOWN:
            default:
                break;
        }

        file = ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, file );
        image->set ( Gdk::PixbufAnimation::create_from_file ( file ) );
    }
}
