/**
 * @file	AlarmBoxEndDiagnoseWidget.cxx
 * @brief	alarm box detected device widget class.
 * @author	Yadickson Soto
 * @date	06/09/2013
 */


#include "AlarmBoxDetectedWidget.hxx"
#include "Configuration/label-configuration.h"
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Operation/Devices/AlarmController.hxx>
#include <Operation/MachineOperationManager.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Voting;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Operation::Devices;
using namespace Smartmatic::SAES::Operation;

ISMTTLog * AlarmBoxDetectedWidget::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.AlarmBoxDetectedWidget", GETTEXT_PACKAGE );

AlarmBoxDetectedWidget::AlarmBoxDetectedWidget ( Smartmatic::SAES::GUI::Widgets::ProgressWidget * widget )
    : WizardWidgetBase (), widget ( widget )
{
    timeOK = SAESGUIConfigurationManager::getInstance()->getAlarmBoxDiagnosisConfiguration().getDetectedTimeOk();
    timeFail = SAESGUIConfigurationManager::getInstance()->getAlarmBoxDiagnosisConfiguration().getDetectedTimeFail();

    widget->setImage ( "ui/alarmButton.gif" );
    signalEndDetected.getSyncSignal().connect ( sigc::mem_fun ( *this, &AlarmBoxDetectedWidget::onRawObject ) );

    setWidget ( widget );
}

AlarmBoxDetectedWidget::~AlarmBoxDetectedWidget()
{
    remove();

    if ( widget )
    {
        delete widget;
        widget = NULL;
    }
}

void AlarmBoxDetectedWidget::initialize()
{
    widget->setInfoText ( N_ ( "Smartmatic.SAES.GUI.Widgets.AlarmBoxDiagnosisWidget.InitializingDiagnostic" ) );
    start ( 0 );
}

bool AlarmBoxDetectedWidget::process()
{
    bool status = AlarmController::getInstance()->sendPing();
    AlarmController::getInstance()->shutDownAlarm();
    signalEndDetected.emit ( new bool ( status ) );
    return false;
}

void AlarmBoxDetectedWidget::onRawObject ( void * object )
{
    bool * status = static_cast < bool * > ( object );

    if ( *status )
    {
        widget->setInfoText ( N_ ( "AlarmBox Detected" ) );
        Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &AlarmBoxDetectedWidget::emit ), timeOK );
    }
    else
    {
        widget->setInfoText ( N_ ( "AlarmBox Not Detected" ) );
        MachineOperationManager::getInstance()->getOperationStatus()->getVotingMachineStatusWrapper()->setAlarmBoxFullStatus ( false );
        Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &AlarmBoxDetectedWidget::error ), timeFail );
    }

    delete status;
}

void AlarmBoxDetectedWidget::error()
{
    on_stop_signal_emit().emit();
}
