/**
 * @file	AlarmBoxEndDiagnoseWidget.hxx
 * @brief	Declares the alarm box detected widget class.
 * @author	Yadickson Soto
 * @date	09/09/2013
 */

#ifndef _ALARM_BOX_END_DIAGNOSE_WIDGET_H_
#define _ALARM_BOX_END_DIAGNOSE_WIDGET_H_

#include <Widgets/StepWidget.hxx>
#include <Gui/Widgets/ProgressWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	AlarmBoxEndDiagnoseWidget
                 * @brief	Alarm box detected widget.
                 * @author	Yadickson Soto
                 * @date	09/09/2013
                 */

                class AlarmBoxEndDiagnoseWidget: public Smartmatic::GUI::Widgets::StepWidget
                {
                    public:

                        /**
                         * @fn	AlarmBoxEndDiagnoseWidget::AlarmBoxEndDiagnoseWidget ( Smartmatic::SAES::GUI::Widgets::ProgressWidget * widget );
                         * @brief	Constructor.
                         * @author	Yadickson Soto
                         * @date	09/09/2013
                         * @param 	widget the visual container
                         */
                        explicit AlarmBoxEndDiagnoseWidget ( Smartmatic::SAES::GUI::Widgets::ProgressWidget * widget );

                        /**
                         * @fn	AlarmBoxEndDiagnoseWidget::~AlarmBoxEndDiagnoseWidget();
                         * @brief	Destroy.
                         * @author	Yadickson Soto
                         * @date	09/09/2013
                         */
                        virtual ~AlarmBoxEndDiagnoseWidget();

                        /**
                         * @fn	void showSuccess();
                         * @brief	Show success diagnose.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         */
                        void showSuccess();

                        /**
                         * @fn	void showError();
                         * @brief	Show error diagnose.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         */
                        void showError();

                    private:

                        static Smartmatic::Log::ISMTTLog * logger; /**<logger*/ ///< The logger
                        Smartmatic::SAES::GUI::Widgets::ProgressWidget * widget; ///< The visual container
                };
            }
        }
    }
}

#endif // _ALARM_BOX_END_DIAGNOSE_WIDGET_H_
