/*
 * BarcodeReaderPrintingWidget.cxx
 *
 *  Created on: 05/09/2013
 *      Author: soto
 */

#include "BarcodeReaderPrintingWidget.hxx"
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"
#include "Configuration/s-a-e-s-conf-manager.h"
#include <Graphics/Encoding2D/QREncoding.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Printing;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::System;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::Graphics::Encoding2D;

BarcodeReaderPrintingWidget::BarcodeReaderPrintingWidget ( GenericPrintingWidget * printerWidget )
    : WizardWidgetBase(), printerWidget ( printerWidget )
{
    barcodePrinter = new BarcodePrinting ( SAESGUIConfigurationManager::getInstance()->getBarcodeDiagnosisConfiguration().getStringToEncode() );
    timeFail = SAESGUIConfigurationManager::getInstance()->getBarcodeDiagnosisConfiguration().getPrinterTimeFail();

    setWidget ( printerWidget );
}

BarcodeReaderPrintingWidget::~BarcodeReaderPrintingWidget()
{
    remove();

    if ( printerWidget )
    {
        delete printerWidget;
        printerWidget = NULL;
    }

    if ( barcodePrinter )
    {
        delete barcodePrinter;
        barcodePrinter = NULL;
    }
}

void BarcodeReaderPrintingWidget::initialize()
{
    on_disable_close_signal_emit().emit ();

    std::string data = SAESGUIConfigurationManager::getInstance()->getBarcodeDiagnosisConfiguration().getStringToEncode();
    SafeBuffer buffer ( data );
    QRCodeConfig config = SAESConfigurationManager::getInstance()->getQRCodeBarcodeConfig();
    int pixelSize = config.getSizeQRCode();
    int margin = config.getMarginQRCode();
    int version = config.getVersionQRCode();
    QRecLevel correctionLevel = SAESConfigurationManager::getInstance()->GetCorrectionModeQRCode ( config.getCorrectionModeQRCode() );
    Glib::RefPtr<Gdk::Bitmap> bitmap ( QREncoding::GenerateSymbol ( ( guchar * ) buffer.GetData(), buffer.GetSize(), pixelSize, margin, correctionLevel, version ) );
    Glib::RefPtr<Gdk::Drawable> drwptr = bitmap;
    gint width ( 0 );
    gint height ( 0 );
    bitmap->get_size ( width, height );
    pixBuffBarcode = Gdk::Pixbuf::create ( drwptr, 0, 0, width, height );

    printerWidget->getSignalEnd().connect ( sigc::mem_fun ( *this, &BarcodeReaderPrintingWidget::emit ) );
    printerWidget->getSignalError().connect ( sigc::mem_fun ( *this, &BarcodeReaderPrintingWidget::error ) );

    printerWidget->setTextButtons ( _ ( "Retry printing" ), _ ( "Cancel printing" ) );
    printerWidget->setInfoText ( N_ ( "Smartmatic.SAES.GUI.Widgets.BarCodeDiagnosisWidget.WaitForBarcodeToBePrinted" ) );
    printerWidget->start ( barcodePrinter, true, true, pixBuffBarcode );
}

void BarcodeReaderPrintingWidget::dispose()
{

}

void BarcodeReaderPrintingWidget::error ()
{
    printerWidget->setInfoTitle ( " " );
    Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &BarcodeReaderPrintingWidget::emit ), timeFail );
}
