/**
 * @file	BarcodeReaderReconfigureWidget.hxx
 * @brief	Declares the bar code reconfigure widget class.
 * @author	Yadickson Soto
 * @date	05/09/2013
 */


#ifndef _BAR_CODE_READER_RECONFIGURE_WIDGET_H_
#define _BAR_CODE_READER_RECONFIGURE_WIDGET_H_

#include <Widgets/wizard-widget-manager.h>
#include <Gui/Widgets/ProgressWidget.hxx>
#include <System/SafeThread.hxx>
#include <System/SafeDispatcher.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	BarcodeReaderReconfigureWidget
                 * @brief	Bar code diagnosis widget.
                 * @author	Yadickson Soto
                 * @date	05/09/2013
                 */

                class BarcodeReaderReconfigureWidget: public Smartmatic::GUI::Widgets::WizardWidgetBase, private Smartmatic::System::SafeThread
                {
                    public:

                        /**
                         * @fn	BarcodeReaderReconfigureWidget ( ProgressWidget * widget );
                         * @brief	Constructor.
                         * @author	Yadickson Soto
                         * @date	05/09/2013
                         * @param	widget	 	The visual widget
                         */
                        explicit BarcodeReaderReconfigureWidget ( ProgressWidget * widget );

                        /**
                         * @fn	virtual ~BarcodeReaderReconfigureWidget();
                         * @brief	Destroy.
                         * @author	Yadickson Soto
                         * @date	05/09/2013
                         */
                        virtual ~BarcodeReaderReconfigureWidget();
                        /**
                         * @fn	virtual void initialize();
                         * @brief	Initializer method.
                         * @author	Yadickson Soto
                         * @date	05/09/2013
                         */
                        virtual void initialize();
                        /**
                         * @fn	virtual void dispose();
                         * @brief	virtual method stop.
                         * @author	Yadickson Soto
                         * @date	05/09/2013
                         */
                        virtual void dispose();

                    protected:

                        /**
                         * @fn	    virtual bool process ();
                         * @brief	Callback from thread one time, only reconfigure the barcode reader
                         * @author	Yadickson Soto
                         * @date	31/07/2015
                         * @return always false, only one execution
                         */
                        virtual bool process ();

                        /**
                         * @fn	    void onRawObject ( void * object );
                         * @brief	Callback when emit sync signal.
                         * @author	Yadickson Soto
                         * @date	31/07/2015
                         * @param 	object The object to process
                         */
                        void onRawObject ( void * object );

                        /**
                         * @fn	void error();
                         * @brief	Ends this object.
                         * @author	Yadickson Soto
                         * @date	05/09/2013
                         */
                        void error();

                    private:

                        ProgressWidget * widget; ///< the visual widget
                        std::string commandsReconfigure;	///< The commands reconfigure
                        int timeOK; ///< Timeout end reconfigure successfully
                        int timeFail; ///< Timeout end reconfigure fail
                        Smartmatic::System::SafeDispatcher signalDispatcher; ///< signal dispatcher
                        static Smartmatic::Log::ISMTTLog * logger; /**<logger*/ ///< The logger

                };
            }
        }
    }
}

#endif // _BAR_CODE_READER_RECONFIGURE_WIDGET_H_
