/**
 * @file	BarcodeReaderScanWidget.hxx
 * @brief	Declares the bar code reader scan widget class.
 * @author	Yadickson Soto
 * @date	05/09/2013
 */


#ifndef _BAR_CODE_READER_SCAN_WIDGET_H_
#define _BAR_CODE_READER_SCAN_WIDGET_H_

#include <Gui/Widgets/Diagnose/BasicDiagnosticWidget.hxx>
#include <Gui/Widgets/ProgressWidget.hxx>
#include <System/SafeThread.hxx>
#include <System/SafeDispatcher.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	BarcodeReaderScanWidget
                 * @brief	Bar code scan diagnose widget.
                 * @author	Yadickson Soto
                 * @date	05/09/2013
                 */

                class BarcodeReaderScanWidget: public BasicDiagnosticWidget, public Smartmatic::System::SafeThread
                {
                    public:

                        /**
                         * @fn	BarcodeReaderScanWidget ( ProgressWidget * widget );
                         * @brief	Constructor.
                         * @author	Yadickson Soto
                         * @date	05/09/2013
                         * @param	widget	 	The visual widget
                         */
                        explicit BarcodeReaderScanWidget ( ProgressWidget * widget );

                        /**
                         * @fn	virtual ~BarcodeReaderScanWidget();
                         * @brief	Destroy.
                         * @author	Yadickson Soto
                         * @date	05/09/2013
                         */
                        virtual ~BarcodeReaderScanWidget();
                        /**
                         * @fn	virtual void initialize();
                         * @brief	Initializer method.
                         * @author	Yadickson Soto
                         * @date	05/09/2013
                         */
                        virtual void initialize();
                        /**
                         * @fn	virtual void dispose();
                         * @brief	virtual method stop.
                         * @author	Yadickson Soto
                         * @date	05/09/2013
                         */
                        virtual void dispose();

                    protected:

                        /**
                         * @fn	    virtual void preStart ();
                         * @brief	Callback from thread before start thread. Send command in to device
                         * @author	Yadickson Soto
                         * @date	07/06/2015
                         */
                        virtual void preStart ();

                        /**
                         * @fn	    virtual bool process ();
                         * @brief	Callback from thread any time. Read buffer from device
                         * @author	Yadickson Soto
                         * @date	13/07/2015
                         * @return true if not read device
                         */
                        virtual bool process ();

                        /**
                         * @fn	    virtual void postStop ();
                         * @brief	Callback from thread after stop thread. Send command out to device
                         * @author	Yadickson Soto
                         * @date	07/06/2015
                         */
                        virtual void postStop ();

                        /**
                         * @fn	    void onRawObject ( void * object );
                         * @brief	Callback when emit sync signal.
                         * @author	Yadickson Soto
                         * @date	31/07/2015
                         * @param 	object The object to process
                         */
                        void onRawObject ( void * object );

                        /**
                         * @fn	void onCancel();
                         * @brief	Handles button cancel clicked signals.
                         * @author	Yadickson Soto
                         * @date	05/09/2013
                         */
                        void onCancel();

                        /**
                         * @fn	void error();
                         * @brief	Ends this object.
                         * @author	Yadickson Soto
                         * @date	05/09/2013
                         */
                        void error();

                    private:

                        ProgressWidget * widget; ///< the visual widget
                        int timeOK; ///< Timeout end reconfigure successfully
                        int timeFail; ///< Timeout end reconfigure fail

                        sigc::connection connCancel; ///< The connection signal dispatcher cancel

                        std::string commandsIn;	///< The commands in
                        std::string commandsOut;	///< The commands out

                        Smartmatic::System::SafeDispatcher signalDispatcher; ///< signal dispatcher

                        static Smartmatic::Log::ISMTTLog * logger; /**<logger*/ ///< The logger

                };
            }
        }
    }
}

#endif // _BAR_CODE_READER_SCAN_WIDGET_H_
