/**
 * @file	BarcodeReaderSerialNumberWidget.hxx
 * @brief	Declares the barcode reader set serial number widget class.
 * @author	Yadickson Soto
 * @date	28/01/2014
 */

#ifndef _BAR_CODE_READER_SET_SERIAL_NUMBER_WIDGET_H_
#define _BAR_CODE_READER_SET_SERIAL_NUMBER_WIDGET_H_

#include <Gui/Widgets/Diagnose/BasicDiagnosticWidget.hxx>
#include <Gui/Widgets/ProgressWidget.hxx>
#include <System/SafeThread.hxx>
#include <System/SafeDispatcher.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	BarcodeReaderSerialNumberWidget
                 * @brief	The barcode reader set serial number widget class.
                 * @author	Yadickson Soto
                 * @date	28/01/2014
                 */

                class BarcodeReaderSerialNumberWidget: public BasicDiagnosticWidget, private Smartmatic::System::SafeThread
                {
                    public:

                        /**
                         * @fn	BarcodeReaderSerialNumberWidget ( ProgressWidget * widget );
                         * @brief	Constructor.
                         * @author	Yadickson Soto
                         * @date	28/01/2014
                         * @param	widget	 	The visual widget
                         */
                        explicit BarcodeReaderSerialNumberWidget ( ProgressWidget * widget );

                        /**
                         * @fn	virtual ~BarcodeReaderSerialNumberWidget();
                         * @brief	Destroy.
                         * @author	Yadickson Soto
                         * @date	28/01/2014
                         */
                        virtual ~BarcodeReaderSerialNumberWidget();
                        /**
                         * @fn	virtual void initialize();
                         * @brief	Initializer method.
                         * @author	Yadickson Soto
                         * @date	28/01/2014
                         */
                        virtual void initialize();
                        /**
                         * @fn	virtual void dispose();
                         * @brief	virtual method stop.
                         * @author	Yadickson Soto
                         * @date	28/01/2014
                         */
                        virtual void dispose();

                    protected:

                        /**
                         * @fn	    virtual bool process ();
                         * @brief	Callback from thread one time, which sets the serial of the barcode reader
                         * @author	Yadickson Soto
                         * @date	31/07/2015
                         * @return always false, only one execution
                         */
                        virtual bool process ();

                        /**
                         * @fn	    void onRawObject ( void * object );
                         * @brief	Callback when emit sync signal.
                         * @author	Yadickson Soto
                         * @date	31/07/2015
                         * @param 	object The object to process
                         */
                        void onRawObject ( void * object );

                        /**
                         * @fn	void showErrorReconfigureSerial ();
                         * @brief	Callback show error reconfigure serial device.
                         * @author	Yadickson Soto
                         * @date	28/01/2014
                         */
                        void showErrorReconfigureSerial ();

                        /**
                         * @fn	void error();
                         * @brief	Error in diagnose.
                         * @author	Yadickson Soto
                         * @date	28/01/2014
                         */
                        void error();

                    private:

                        ProgressWidget * widget; ///< the visual widget
                        int timeFail; ///< Timeout end reconfigure fail
                        std::string serial; ///< the serial number
                        Smartmatic::System::SafeDispatcher signalDispatcher; ///< signal dispatcher
                        static Smartmatic::Log::ISMTTLog * logger; /**<logger*/ ///< The logger
                };
            }
        }
    }
}

#endif // _BAR_CODE_READER_SET_SERIAL_NUMBER_WIDGET_H_
