/**
 * @file	BasicDiagnosticWidget.cxx
 * @brief	basic diagnostic widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#include "BasicDiagnosticWidget.hxx"
#include "Environment/Configurations/resource-path-provider.h"
#include <Operation/MachineOperationManager.hxx>
#include "System/Sounds/smartmatic-sounds-manager.h"
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::Environment;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::Voting;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Gtk;

BasicDiagnosticWidget::BasicDiagnosticWidget ( bool showOk, bool showCancel, bool hasRetry )
    : WizardWidgetBase()
{
    buttons = new DiagnosticButtonWidget();
    buttons->set_no_show_all();

    buttons->getSignalAcceptButtonClicked().connect ( sigc::mem_fun ( this, &BasicDiagnosticWidget::onButtonOkClicked ) );
    buttons->getSignalClearButtonClicked().connect ( sigc::mem_fun ( this, &BasicDiagnosticWidget::onButtonCancelClicked ) );
    buttons->getSignalBackButtonClicked().connect ( sigc::mem_fun ( this, &BasicDiagnosticWidget::onButtonRetryClicked ) );

    vboxPrincipal.pack_start ( frameDiagnostic, true, true, 0 );

    frameDiagnostic.set_shadow_type ( Gtk::SHADOW_NONE );

    if ( showOk || showCancel )
    {
        vboxPrincipal.pack_end ( *buttons, false, false, 10 );
        buttons->set_visible ( true );
    }

    showButtons ( showOk, showCancel, hasRetry );
    WizardWidgetBase::setWidget ( &vboxPrincipal );

    show_all_children();
}

BasicDiagnosticWidget::~BasicDiagnosticWidget ()
{
    remove();

    if ( buttons )
    {
        delete buttons;
        buttons = NULL;
    }
}

void BasicDiagnosticWidget::showButtons ( bool showOk, bool showCancel, bool showRetry )
{
    buttons->clearSignals();
    buttons->showButton ( showCancel, showOk, showRetry, false );
}

void BasicDiagnosticWidget::setOkButtonSensitive ( bool sensitive )
{
    buttons->setOkButtonSensitive ( sensitive );
}

void BasicDiagnosticWidget::setCancelButtonSensitive ( bool sensitive )
{
    buttons->setCancelButtonSensitive ( sensitive );
}

void BasicDiagnosticWidget::setRetryButtonSensitive ( bool sensitive )
{
    buttons->setRetryButtonSensitive ( sensitive );
}

void BasicDiagnosticWidget::setWidget ( Gtk::Widget * widget )
{
    frameDiagnostic.remove();
    frameDiagnostic.add ( *widget );
    frameDiagnostic.show_all_children();
}

void BasicDiagnosticWidget::onButtonOkClicked()
{
    setCancelButtonSensitive ( false );
    setOkButtonSensitive ( false );
    setRetryButtonSensitive ( false );
    signalOkDetected.emit();
}

void BasicDiagnosticWidget::onButtonCancelClicked()
{
    setCancelButtonSensitive ( false );
    setOkButtonSensitive ( false );
    setRetryButtonSensitive ( false );
    signalCancelDetected.emit();
}

void BasicDiagnosticWidget::onButtonRetryClicked()
{
    setCancelButtonSensitive ( false );
    setOkButtonSensitive ( false );
    setRetryButtonSensitive ( false );
    signalRetryDetected.emit();
}

void BasicDiagnosticWidget::setOkButtonLabel ( std::string label )
{
    buttons->setTextAcceptButton ( label );
}

void BasicDiagnosticWidget::setCancelButtonLabel ( std::string label )
{
    buttons->setTextClearButton ( label );
}

void BasicDiagnosticWidget::setRetryButtonLabel ( std::string label )
{
    buttons->setTextBackButton ( label );
}
