/**
 * @file	CustomRemarkDiagnoseWidget.hxx
 * @brief	Declares the custom remark diagnose widget class.
 * @author	Yadickson Soto
 * @date	12/09/2013
 */


#ifndef _CUSTOM_REMARK_DIAGNOSE_WIDGET_H_
#define _CUSTOM_REMARK_DIAGNOSE_WIDGET_H_

#include <Gui/Widgets/Diagnose/BasicDiagnosticWidget.hxx>
#include <Widgets/SmartmaticBasicLabel.hxx>
#include <Widgets/SmartmaticTextView.h>
#include <Widgets/key-board-widget.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	CustomRemarkDiagnoseWidget
                 * @brief	Bar code diagnosis widget.
                 * @author	Yadickson Soto
                 * @date	12/09/2013
                 */

                class CustomRemarkDiagnoseWidget: public BasicDiagnosticWidget
                {
                    public:

                        /**
                         * @fn	CustomRemarkDiagnoseWidget ( bool showKeyBoard );
                         * @brief	Constructor.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         * @param	showKeyBoard show key board
                         */
                        explicit CustomRemarkDiagnoseWidget ( bool showKeyBoard );

                        /**
                         * @fn	virtual ~CustomRemarkDiagnoseWidget();
                         * @brief	Destroy.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         */
                        virtual ~CustomRemarkDiagnoseWidget();

                        /**
                         * @fn	virtual void initialize();
                         * @brief	Initializer method.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         */
                        virtual void initialize();

                        /**
                         * @fn	virtual void dispose();
                         * @brief	virtual method stop.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         */
                        virtual void dispose();

                    protected:

                        /**
                         * @fn	void onKeyPress ( std::string data );
                         * @brief	Method on key press.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         * @param	data	key data.
                         */
                        void onKeyPress ( std::string data );
                        /**
                         * @fn	void onKeyDeletePress();
                         * @brief	Method on key delete press.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         */
                        void onKeyDeletePress();
                        /**
                         * @fn	void addEndLine();
                         * @brief	Method on key enter press.
                         * @author	Yadickson Soto
                         * @date	18/09/2013
                         */
                        void addEndLine();

                        void moveUp();
                        void moveDown();
                        void moveLeft();
                        void moveRight();

                    private:

                        /**
                         * @fn	void end();
                         * @brief	End diagnostic.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         */
                        void end();

                        bool showKeyBoard; ///< show key board only to vm
                        Gtk::Alignment * alignment; ///< Alignment
                        Smartmatic::GUI::Widgets::SmartmaticBasicVBox * vbox; ///< vbox container
                        Smartmatic::GUI::Widgets::Keyboard * keyboard; ///< Keyboard
                        Smartmatic::GUI::Widgets::SmartmaticBasicLabel * infoMessage; ///< info message
                        Smartmatic::GUI::Widgets::SmartmaticTextView * remark; ///< The remark widget
                        static Smartmatic::Log::ISMTTLog * logger; /**<logger*/ ///< The logger
                };
            }
        }
    }
}

#endif // _BAR_CODE_READER_RECONFIGURE_WIDGET_H_
