/*
 * EurnDetectedWidget.cxx
 *
 *  Created on: Nov 7, 2017
 *      Author: juanvalera
 */


#include "EurnDetectedWidget.hxx"
#include "Configuration/label-configuration.h"
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Operation/Devices/EurnController.hxx>
#include <Operation/MachineOperationManager.hxx>
#include <Operation/Monitor/DeviceTypeMonitorPool.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Voting;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Operation::Devices;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::Operation::Monitor;
using namespace Smartmatic::SAES::Common::Operation::Monitor;
using namespace Smartmatic::SAES::Common::Configuration;

ISMTTLog * EurnDetectedWidget::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.EurnDetectedWidget", GETTEXT_PACKAGE );

EurnDetectedWidget::EurnDetectedWidget ( Smartmatic::SAES::GUI::Widgets::ProgressWidget * widget )
    : WizardWidgetBase (), widget ( widget )
{
    timeOK = SAESGUIConfigurationManager::getInstance()->getEurnDiagnosisConfiguration().getDetectedTimeOk();
    timeFail = SAESGUIConfigurationManager::getInstance()->getEurnDiagnosisConfiguration().getDetectedTimeFail();

    widget->setImage ( "ui/eUrn.gif" );
    signalEndDetected.getSyncSignal().connect ( sigc::mem_fun ( *this, &EurnDetectedWidget::onRawObject ) );

    setWidget ( widget );
}

EurnDetectedWidget::~EurnDetectedWidget()
{
    remove();

    if ( widget )
    {
        delete widget;
        widget = NULL;
    }
}

void EurnDetectedWidget::initialize()
{
    widget->setInfoText ( N_ ( "Initializing Diagnostic" ) );
    start ( 0 );
}

bool EurnDetectedWidget::process()
{
    DeviceTypeMonitor * deviceTypeMonitor = DeviceTypeMonitorPool::getInstance()->getDeviceTypeMonitor ( DeviceType::CONFIGURATION_EURN );
    bool validate = deviceTypeMonitor != NULL && deviceTypeMonitor->getNumberOfDevices() > 0;

    signalEndDetected.emit ( new bool ( validate ) );
    return false;
}

void EurnDetectedWidget::onRawObject ( void * object )
{
    bool * status = static_cast < bool * > ( object );

    if ( *status )
    {
        widget->setInfoText ( N_ ( "eUrn Detected" ) );
        Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &EurnDetectedWidget::emit ), timeOK );
    }
    else
    {
        widget->setInfoText ( N_ ( "eUrn Not Detected" ) );
        MachineOperationManager::getInstance()->getOperationStatus()->getVotingMachineStatusWrapper()->setEurnFullStatus ( false );
        Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &EurnDetectedWidget::error ), timeFail );
    }

    delete status;
}

void EurnDetectedWidget::error()
{
    on_stop_signal_emit().emit();
}
