/*
 * EurnActionsWidget.cxx
 *
 *  Created on: Nov 7, 2017
 *      Author: juanvalera
 */


#include "LedStripActionsWidget.hxx"
#include "Configuration/label-configuration.h"
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"
#include <Environment/Configurations/resource-path-provider.h>
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Operation/Devices/PDBController.hxx>
#include <Gui/Widgets/AbstractFactoryWidget.hxx>
#include <Operation/MachineOperationManager.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::HW::Devices;
using namespace Smartmatic::Log;
using namespace Smartmatic::Environment;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::Operation::Devices;
using namespace Smartmatic::SAES::Voting::Status;
using namespace Smartmatic::SAES::Voting;
using namespace Smartmatic::GUI::Widgets;

ISMTTLog * LedStripActionsWidget::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.LedStripActionsWidget", GETTEXT_PACKAGE );

LedStripActionsWidget::LedStripActionsWidget (Smartmatic::SAES::GUI::Widgets::ProgressWidget * progressWidget)
: BasicDiagnosticWidget ( true, true )
    , alignment(0.5, 0.5, 0.9, 0.9)
    , turnOnOption(&buttonTurnOn)
    , turnOffOption(&buttonTurnOff)
{
    setOkButtonSensitive ( false );

       turnOnState = OFF;
       turnOffState = OFF;

       Smartmatic::SAES::Configuration::LedStripDiagnosisConfiguration & config ( SAESGUIConfigurationManager::getInstance()->getLedStripDiagnosisConfiguration() );

       timeOk = config.getActionsTimeOk();
       timeFail = config.getActionsTimeFail();

       endWidget = new LedStripEndDiagnoseWidget(progressWidget);

       frame.set_shadow_type(Gtk::SHADOW_NONE);
       frame.set_label_align(0.0,0.5);

       vboxOptions.set_spacing(1);
       vboxOptions.set_homogeneous(true);

       alignment.add(vboxOptions);
       frame.add(alignment);

       ButtonConfiguration buttonConf = config.getButtonConfiguration();
       LabelConfiguration labelText = SAESGUIConfigurationManager::ConvertToLabelConfiguration ( SAESGUIConfigurationManager::getInstance()->getGeneralDiagnosisConfiguration().getDiagnosisLabelConfiguration() );

       buttonTurnOn.ModifyFontSize ( buttonConf.getFontSize() );
       buttonTurnOff.ModifyFontSize ( buttonConf.getFontSize() );


       buttonTurnOn.set_size_request ( buttonConf.getButtonWidth(), buttonConf.getButtonHeight() );
       buttonTurnOff.set_size_request ( buttonConf.getButtonWidth(), buttonConf.getButtonHeight() );

       buttonTurnOn.signal_clicked().connect ( sigc::mem_fun ( *this, &LedStripActionsWidget::onTurnOnAction ) );
       buttonTurnOff.signal_clicked().connect ( sigc::mem_fun ( *this, &LedStripActionsWidget::onTurnOffAction ) );

       buttonTurnOn.set_no_show_all();
       buttonTurnOff.set_no_show_all();


       buttonTurnOn.set_visible ( true );
       buttonTurnOff.set_visible ( true );

       turnOnOption.setLabelConfiguration ( labelText );
       turnOffOption.setLabelConfiguration ( labelText );

       vboxOptions.pack_start ( turnOnOption );
       vboxOptions.pack_start ( turnOffOption );


       turnOnOption.getSignalChange().connect ( sigc::mem_fun ( *this, &LedStripActionsWidget::validate ) );
       turnOffOption.getSignalChange().connect ( sigc::mem_fun ( *this, &LedStripActionsWidget::validate ) );

       setWidget ( &frame );
       signalEnableButtons.getSyncSignal().connect ( sigc::mem_fun ( *this, &LedStripActionsWidget::onRawObject ) );
       setAccessibleName ( "LedStripActionsWidget" );
}

LedStripActionsWidget::~LedStripActionsWidget()
{
    remove();

    dispose();

    if ( endWidget )
    {
        delete endWidget;
        endWidget = NULL;
    }
}

void LedStripActionsWidget::initialize()
{
   connOk.disconnect();
   connError.disconnect();

   setOkButtonSensitive ( true );
   setCancelButtonSensitive ( true );

   turnOnState = OFF;
   turnOffState = OFF;

   connOk = signalOkDetected.connect ( sigc::mem_fun ( *this, &LedStripActionsWidget::viewOk ) );
   connError = signalCancelDetected.connect ( sigc::mem_fun ( *this, &LedStripActionsWidget::viewError ) );

   turnOnOption.setTextConteiner ( _ ( "Turn On LEDs test" ) );
   turnOffOption.setTextConteiner ( _ ( "Turn Off LEDs test" ) );

   turnOnOption.setTextOptions ( _ ( "Please press the button on the left to turn ON the Led Strip of the SCR" ), _ ( "yes" ), _ ( "no" ) );
   turnOffOption.setTextOptions ( _ ( "Please press the button on the left to turn OFF the Led Strip of the SCR" ), _ ( "yes" ), _ ( "no" ) );

   turnOffOption.viewOptions(false);
   turnOnOption.viewOptions(false);

   buttonTurnOff.set_sensitive ( false );

   buttonTurnOn.set_label ( _ ( "Turn on LEDs" ) );
   buttonTurnOff.set_label  ( _ ( "Turn off LEDs" ) );

   turnOnOption.clearOption();
   turnOffOption.clearOption();

   showTurnOnButton = true;
   showTurnOffButton = true;

   restoreLedStripState();

   validate();
   start ( 100 );
}

bool LedStripActionsWidget::process()
{
   bool enableButton = !showTurnOnButton|| !showTurnOffButton;

   if ( !showTurnOnButton )
   {
       showTurnOnButton = true;

       if ( turnOnState == OFF )
       {
           turnOnState = ON;
           turnOffState = OFF;
           PDBController::getInstance()->turnAllLedsOn();
       }
   }

   if ( !showTurnOffButton )
   {
       showTurnOffButton = true;

       if ( turnOffState == OFF )
       {
           turnOffState = ON;
           turnOnState = OFF;
           PDBController::getInstance()->turnAllLedsOff();
       }
   }

   if ( enableButton )
   {
       signalEnableButtons.emit ( NULL );
   }

   return true;
}

void LedStripActionsWidget::dispose()
{
   buttonTurnOn.set_sensitive ( false );
   buttonTurnOff.set_sensitive ( false );


   showButtons ( false, false, false );

   connOk.disconnect();
   connError.disconnect();

   stop();
}

void LedStripActionsWidget::onRawObject (  void * object)
{
    buttonTurnOn.set_sensitive ( turnOnState == OFF );
    buttonTurnOff.set_sensitive ( turnOffState == OFF );
}

void LedStripActionsWidget::onTurnOnAction ()
{
    turnOnOption.viewOptions();
    turnOnOption.setTextOptions ( _ ( "Does the LEDs in the SCR slot turn on correctly?" ), _ ( "yes" ), _ ( "no" ) );
    buttonTurnOn.set_sensitive ( false );

    showTurnOnButton = false;
}

void LedStripActionsWidget::onTurnOffAction ()
{
    turnOffOption.viewOptions();
    turnOffOption.setTextOptions ( _ ( "Does the LEDs in the SCR slot turn off correctly?" ), _ ( "yes" ), _ ( "no" ) );
    buttonTurnOff.set_sensitive ( false );

    showTurnOffButton = false;
}

void LedStripActionsWidget::validate()
{
    bool result = turnOnOption.getOption() &&
            turnOffOption.getOption();

    bool check = turnOnOption.isCheck() &&
            turnOffOption.isCheck();

    showButtons ( result, !result, false );

    setCancelButtonSensitive ( check );
}

void LedStripActionsWidget::end ()
{
    emit();
}

void LedStripActionsWidget::restoreLedStripState()
{
    PDBController::getInstance()->turnAllLedsOff();
}

void LedStripActionsWidget::viewOk()
{
    showButtons ( false, false, false );
    restoreLedStripState();
    setWidget ( endWidget );
    endWidget->showSuccess();
    setStatus();

   Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &LedStripActionsWidget::end ), timeOk );

}

void LedStripActionsWidget::viewError()
{
    showButtons ( false, false, false );
    restoreLedStripState();
    setWidget ( endWidget );
    endWidget->showError();
    setStatus();

    Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &LedStripActionsWidget::error ), timeFail );
}

void LedStripActionsWidget::setStatus()
{
    bool openDoor = turnOnOption.getOption();
    bool closeDoor = turnOffOption.getOption();

    if(!openDoor || !closeDoor)
    {
        MachineOperationManager::getInstance()->getOperationStatus()->getVotingMachineStatusWrapper()->setStatusSmartcardReaderLedStripError();
    }
}

void LedStripActionsWidget::error()
{
    on_stop_signal_emit().emit();
}


