/**
 * @file SerialNumberWidget.hxx
 * @brief Header class serial number widget
 * @date 21/09/2012
 * @author Yadickson Soto
 */

#ifndef _SERIAL_NUMBER_WIDGET_HXX_
#define _SERIAL_NUMBER_WIDGET_HXX_

#include <Gui/Widgets/Diagnose/BasicDiagnosticWidget.hxx>
#include <Widgets/smartmatic-entry.h>
#include <Widgets/SmartmaticRadioButtonVerticalGroup.hxx>
#include <Widgets/keypad-widget.h>
#include <Widgets/SmartmaticBasicLabel.hxx>
#include <Widgets/key-pad-widget-interface.h>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	SerialNumberWidget
                 * @brief	Class serial number widget.
                 * @author	Yadickson Soto
                 * @date	21/09/2012
                 */
                class SerialNumberWidget : public Smartmatic::SAES::GUI::Widgets::BasicDiagnosticWidget,
                    public Smartmatic::GUI::Widgets::KeypadInterface
                {
                    public:
                        /**
                         * @fn	SerialNumberWidget::SerialNumberWidget ( bool showKeyBoard );
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	21/09/2012
                         * @param	showKeyBoard	show key board.
                         */
                        explicit SerialNumberWidget ( bool showKeyBoard );
                        /**
                         * @fn	virtual SerialNumberWidget::~SerialNumberWidget();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	21/09/2012
                         */
                        virtual ~SerialNumberWidget();
                        /**
                         * @fn	void SerialNumberWidget::setSerialNumber ( const std::string & serial );
                         * @brief	Method setter serial number.
                         * @author	Yadickson Soto
                         * @date	21/09/2012
                         * @param	serial	serial number.
                         */
                        void setSerialNumber ( const std::string & serial );
                        /**
                         * @fn	std::string SerialNumberWidget::getSerialNumber();
                         * @brief	Method getter serial number.
                         * @author	Yadickson Soto
                         * @date	21/09/2012
                         * @return	serial.
                         */
                        std::string getSerialNumber();

                    protected:

                        /**
                         * @fn	void SerialNumberWidget::initialize();
                         * @brief	Method initialize widget.
                         * @author	Yadickson Soto
                         * @date	21/09/2012
                         */
                        void initialize();
                        /**
                         * @fn	virtual void ZipCodeWidget::SetKey ( Smartmatic::GUI::Widgets::KeysActionsCode value );
                         * @brief	virtual method setter key.
                         * @author	Yadickson Soto
                         * @date	27/09/2012
                         * @param	value	value key.
                         */
                        virtual void SetKey ( Smartmatic::GUI::Widgets::KeysActionsCode value );
                        /**
                         * @fn	virtual void ZipCodeWidget::OnKeyPress ( int data );
                         * @brief	virtual method key press.
                         * @author	Yadickson Soto
                         * @date	27/09/2012
                         * @param	data	key value.
                         */
                        virtual void OnKeyPress ( int data );
                        /**
                         * @fn	virtual void ZipCodeWidget::OnKeyPressT9 ( char data );
                         * @brief	virtual method key press.
                         * @author	Yadickson Soto
                         * @date	27/09/2012
                         * @param	data	key value.
                         */
                        virtual void OnKeyPressT9 ( char data );
                        /**
                         * @fn	void SerialNumberWidget::validate();
                         * @brief	Method validate serial number.
                         * @author	Yadickson Soto
                         * @date	21/09/2012
                         */
                        void validate();
                        /**
                         * @fn	void SerialNumberWidget::cancel();
                         * @brief	Method cancel serial number.
                         * @author	Yadickson Soto
                         * @date	21/09/2012
                         */
                        void cancel();
                        /**
                         * @fn	void SerialNumberWidget::clearMessage();
                         * @brief	Method clear message.
                         * @author	Yadickson Soto
                         * @date	21/09/2012
                         */
                        void clearMessage();
                        /**
                         * @fn	void SerialNumberWidget::changeOption ( Smartmatic::GUI::Widgets::SmartmaticRadioButton * radioButton );
                         * @brief	Method change option.
                         * @author	Yadickson Soto
                         * @date	21/09/2012
                         * @param	radioButton	radio button change active.
                         */
                        void changeOption ( Smartmatic::GUI::Widgets::SmartmaticRadioButton * radioButton );

                    private:

                        Gtk::EventBox * mainFrame; ///< main frame
                        Gtk::Alignment * keyBoardAlignment; ///< key board alignment
                        Gtk::Table * tableText; ///< The table entry text

                        Gtk::VBox * mainVbox; ///< main vbox
                        Smartmatic::GUI::Widgets::SmartmaticBasicLabel * titleText; ///< info text
                        Smartmatic::GUI::Widgets::SmartmaticBasicLabel * typeText; ///< info text
                        Smartmatic::GUI::Widgets::SmartmaticBasicLabel * serialTitle; ///< info serial title
                        Smartmatic::GUI::Widgets::SmartmaticBasicLabel * serialText; ///< info text
                        Gtk::HSeparator * separator; ///< separator

                        Smartmatic::GUI::Widgets::SmartmaticRadioButton * radioButtonSerial; ///< Radio Button serial
                        std::list < Smartmatic::GUI::Widgets::SmartmaticRadioButton * > allRadioButton; ///< radio button list

                        int currentMax; ///< The max entry serial length
                        std::string currentMask; ///< The mask entry serial text
                        std::string currentRegex; ///< The regex validate entry serial
                        std::string currentPrefix; ///< The current prefix serial number

                        std::string serialDetected; ///< serial detected

                        Smartmatic::GUI::Widgets::KeypadWidget * keyboard; ///< Keyboard
                        Smartmatic::GUI::Widgets::SmartmaticEntry * serialEntry; ///< serial entry
                        Smartmatic::GUI::Widgets::SmartmaticRadioButtonVerticalGroup * groupButton; ///< group buttons

                        bool showKeyBoard; ///< show key board
                        static Smartmatic::Log::ISMTTLog * logger;  ///< logger
                };
            }
        }
    }
}
#endif /* _SERIAL_NUMBER_WIDGET_HXX_ */
