/**
 * @file	SmartcardDetectedWidget.hxx
 * @brief	Declares the smartcard reader device detected widget class.
 * @author	Yadickson Soto
 * @date	12/09/2013
 */

#ifndef _SMART_CARD_DETECTED_WIDGET_H_
#define _SMART_CARD_DETECTED_WIDGET_H_

#include <Widgets/wizard-widget-base.h>
#include <Gui/Widgets/ProgressWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	SmartcardDetectedWidget
                 * @brief	Smart card reader device detected widget.
                 * @author	Yadickson Soto
                 * @date	12/09/2013
                 */
                class SmartcardDetectedWidget: public Smartmatic::GUI::Widgets::WizardWidgetBase
                {
                    public:

                        /**
                         * @fn	SmartcardDetectedWidget::SmartcardDetectedWidget ( Smartmatic::SAES::GUI::Widgets::ProgressWidget * progressWidget );
                         * @brief	Constructor.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         * @param 	progressWidget visual container
                         */
                        explicit SmartcardDetectedWidget ( Smartmatic::SAES::GUI::Widgets::ProgressWidget * progressWidget );

                        /**
                         * @fn	SmartcardDetectedWidget::~SmartcardDetectedWidget();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         */
                        virtual ~SmartcardDetectedWidget();

                        /**
                         * @fn	void SmartcardDetectedWidget::dispose();
                         * @brief	Dispose of this object, cleaning up any resources it uses.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         */
                        void dispose();

                        /**
                         * @fn	void SmartcardDetectedWidget::initialize();
                         * @brief	Initializes this object.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         */
                        void initialize();

                    private:

                        int timeStep;   ///< The time diagnose step
                        int timeFail;   ///< The time diagnose fail

                        Smartmatic::SAES::GUI::Widgets::ProgressWidget * progressWidget; ///< The visual container
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger

                    protected:

                        /**
                         * @fn	void error ();
                         * @brief	Error in diagnose.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         */
                        void error ();
                };
            }
        }
    }
}

#endif // _SMART_CARD_DETECTED_WIDGET_H_
