/**
 * @file FactoryMethodWidget.hxx
 * @brief Header class for creating the widget
 * @date 03/11/2011
 * @author Yadickson Soto
 */

#ifndef FACTORYMETHODWIDGET_HXX_
#define FACTORYMETHODWIDGET_HXX_


#include "InstallMachineWidget.hxx"
#include "ProgressWidget.hxx"
#include "PollingPlaceInfoWidget.hxx"
#include "BallotOptionButtonWidget.hxx"
#include "PartyButtonWidget.hxx"
#include <Widgets/TableCenterWidget.hxx>
#include <Widgets/TableBoxSelectionWidget.hxx>
#include "FillTableWidget.hxx"
#include "AuthenticationWidget.hxx"
#include <Gui/Widgets/Menu/MenuWidget.hxx>
#include "HelpWidget.hxx"
#include <Gui/Widgets/Diagnose/IAbleButtonWidget.hxx>
#include <Gui/Widgets/Diagnose/SerialNumberWidget.hxx>
#include <Gui/Widgets/Diagnose/ZipCodeWidget.hxx>
#include <Gui/Widgets/Diagnose/CustomRemarkDiagnoseWidget.hxx>
#include "InitiatorWidget.hxx"
#include "ReferendumButtonWidget.hxx"
#include "GenericButtonWidget.hxx"
#include "RemoveUSBWidget.hxx"
#include <Gui/Widgets/Transmission/ResultsPackageTransmissionWidget.hxx>
#include <Gui/Widgets/Diagnose/MouseWidget.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	FactoryMethodWidget
                 * @brief	Class for creating the widget.
                 * @author	Yadickson Soto
                 * @date	03/11/2011
                 */
                class FactoryMethodWidget
                {
                    public:
                        /**
                         * @fn	static InstallMachineWidget * FactoryMethodWidget::createInstallMachineWidget ( ProgressWidget * progress,
                         * 			PollingPlaceInfoWidget * pollingPlaceInfo );
                         * @brief	Method for creating the install machine widget.
                         * @author	Yadickson Soto
                         * @date	03/11/2011
                         * @param	progress					progress widget.
                         * @param	pollingPlaceInfo	polling place info.
                         * @return	new widget.
                         */
                        static InstallMachineWidget * createInstallMachineWidget ( ProgressWidget * progress, PollingPlaceInfoWidget * pollingPlaceInfo );
                        /**
                         * @fn	static ProgressWidget * FactoryMethodWidget::createProgressWidget();
                         * @brief	Method for creating the progress widget.
                         * @author	Yadickson Soto
                         * @date	03/11/2011
                         * @return	progress widget.
                         */
                        static ProgressWidget * createProgressWidget();
                        /**
                         * @fn	static PollingPlaceInfoWidget * FactoryMethodWidget::createPollingPlaceInfoWidget();
                         * @brief	Method for creating the polling place info widget.
                         * @author	Yadickson Soto
                         * @date	03/11/2011
                         * @return	polling place info widget.
                         */
                        static PollingPlaceInfoWidget * createPollingPlaceInfoWidget();
                        /**
                         * @fn	static PollingPlaceInfoWidget * FactoryMethodWidget::createAuthenticationPollingPlaceInfoWidget();
                         * @brief	Method for creating the authentication polling place info widget.
                         * @author	Yadickson Soto
                         * @date	03/11/2011
                         * @return	authentication polling place info widget.
                         */
                        static PollingPlaceInfoWidget * createAuthenticationPollingPlaceInfoWidget();
                        /**
                         * @fn	static BallotOptionButtonWidget * FactoryMethodWidget::createBallotOptionButtonWidget();
                         * @brief	Method for creating the ballot option button widget.
                         * @author	Yadickson Soto
                         * @date	12/03/2012
                         * @return	ballot option button widget.
                         */
                        static BallotOptionButtonWidget * createBallotOptionButtonWidget();
                        /**
                         * @fn	static PartyButtonWidget * FactoryMethodWidget::createPartyButtonWidget();
                         * @brief	Method for creating the party button widget.
                         * @author	Yadickson Soto
                         * @date	13/03/2012
                         * @return	party button widget.
                         */
                        static PartyButtonWidget * createPartyButtonWidget();
                        /**
                         * @fn	static Smartmatic::GUI::Widgets::TableCenterWidget * FactoryMethodWidget::createTableWidget();
                         * @brief	Method for creating the table widget.
                         * @author	Yadickson Soto
                         * @date	15/03/2012
                         * @return	table widget.
                         */
                        static Smartmatic::GUI::Widgets::TableCenterWidget * createTableWidget();
                        /**
                         * @fn	static Smartmatic::GUI::Widgets::TableBoxSelectionWidget * createBallotOptionTableBoxSelectionWidget();
                         * @brief	Creates the ballot options TableBoxSelectionWidget.
                         * @author	Yadickson Soto
                         * @date	25/02/2014
                         * @return	table widget.
                         */
                        static Smartmatic::GUI::Widgets::TableBoxSelectionWidget * createBallotOptionTableBoxSelectionWidget();
                        /**
                         * @fn	static FillTableWidget * FactoryMethodWidget::createBallotOptionFillTableWidget ( Smartmatic::GUI::Widgets::TableBoxSelectionWidget * tableWidget );
                         * @brief	Creates the ballot options FillTableWidget.
                         * @author	Yadickson Soto
                         * @date	25/02/2014
                         * @param	tableWidget	table widget.
                         * @return	fill table widget.
                         */
                        static FillTableWidget * createBallotOptionFillTableWidget ( Smartmatic::GUI::Widgets::TableBoxSelectionWidget * tableWidget );
                        /**
                         * @fn	static AuthenticationWidget * FactoryMethodWidget::createAuthenticationWidget ( PollingPlaceInfoWidget * info );
                         * @brief	Method for creating the authentication widget.
                         * @author	Yadickson Soto
                         * @date	31/03/2012
                         * @param	info	info widget.
                         * @return	authentication widget.
                         */
                        static AuthenticationWidget * createAuthenticationWidget ( PollingPlaceInfoWidget * info );
                        /**
                         * @fn	static IAbleButtonWidget * FactoryMethodWidget::createAble10ButtonWidget();
                         * @brief	Method for creating the able 1.0 button widget.
                         * @author	Yadickson Soto
                         * @date	06/09/2012
                         * @return	able 1.0 button widget.
                         */
                        static IAbleButtonWidget * createAble10ButtonWidget();
                        /**
                         * @fn  static IAbleButtonWidget * FactoryMethodWidget::createAble20ButtonWidget();
                         * @brief   Method for creating the able 2.0 button widget.
                         * @author  eduardo.fernandez
                         * @date    16/02/2018
                         * @return  able 2.0 button widget.
                         */
                        static IAbleButtonWidget * createAble20ButtonWidget();
                        /**
                         * @fn	static SerialNumberWidget * FactoryMethodWidget::createSerialNumberWidget();
                         * @brief	Method for creating the serial number widget.
                         * @author	Yadickson Soto
                         * @date	24/09/2012
                         * @return	serial number widget.
                         */
                        static SerialNumberWidget * createSerialNumberWidget();
                        /**
                         * @fn	static ZipCodeWidget * FactoryMethodWidget::createZipCodeWidget();
                         * @brief	Method for creating the zip code widget.
                         * @author	Yadickson Soto
                         * @date	27/09/2012
                         * @return	zip code widget.
                         */
                        static ZipCodeWidget * createZipCodeWidget();
                        /**
                         * @fn	static InitiatorWidget * FactoryMethodWidget::createInitiatorWidget ( ProgressWidget * progress );
                         * @brief	Method for creating the initiator widget.
                         * @author	Yadickson Soto
                         * @date	03/10/2012
                         * @param [in,out]	progress	If non-null, the progress.
                         * @return	initiator widget.
                         */
                        static InitiatorWidget * createInitiatorWidget ( ProgressWidget * progress );
                        /**
                         * @fn	static ReferendumButtonWidget * FactoryMethodWidget::createReferendumButtonWidget();
                         * @brief	Method for creating the referendum button widget.
                         * @author	Yadickson Soto
                         * @date	16/10/2012
                         * @return	referendum button widget.
                         */
                        static ReferendumButtonWidget * createReferendumButtonWidget();
                        /**
                         * @fn	static GenericButtonWidget * FactoryMethodWidget::createGenericButtonWidget();
                         * @brief	Method for creating the generic button widget.
                         * @author	Yadickson Soto
                         * @date	29/11/2012
                         * @return	generic button widget.
                         */
                        static GenericButtonWidget * createGenericButtonWidget();
                        /**
                         * @fn	static CustomRemarkDiagnoseWidget * FactoryMethodWidget::createCustomRemarkDiagnoseWidget();
                         * @brief	Method for creating the custom remark diagnose widget.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         * @return	custom remark diagnose widget.
                         */
                        static CustomRemarkDiagnoseWidget * createCustomRemarkDiagnoseWidget();
                        /**
                         * @fn	static CustomRemarkDiagnoseWidget * FactoryMethodWidget::createCustomRemarkDiagnoseWidget();
                         * @brief	Method for creating the results package transmission widget.
                         * @author	Yadickson Soto
                         * @date	08/04/2014
                         * @return	results package transmission widget.
                         */
                        static ResultsPackageTransmissionWidget * createResultsPackageTransmissionWidget();
                        /**
                         * @fn  static MouseWidget * FactoryMethodWidget::createMouseWidget();
                         * @brief   Method for creating the mouse widget.
                         * @author  eduardo.fernandez
                         * @date    22/03/2019
                         * @return  mouse widget.
                         */
                        static MouseWidget * createMouseWidget();
                };
            }
        }
    }
}

#endif /* FACTORYMETHODWIDGET_HXX_ */
