/**
 * @file FillTableWidget.cxx
 * @brief Body class fill table mode widget
 * @date 15/03/2012
 * @author Yadickson Soto
 */

#include "FillTableWidget.hxx"
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>
#include <Operation/MachineOperationManager.hxx>
#include <Configuration/label-configuration.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::Voting::Election;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::GUI::Configuration;

FillTableWidget::FillTableWidget ( TableBoxSelectionWidget * tableWidget )
    : SmartmaticBasicEventBox(), IFillTableWidget ( tableWidget )
{
    standInLabel = new SmartmaticBasicLabel ( _ ( "Smartmatic.SAES.GUI.Widgets.BallotOptionSelectionWidget.Substitute" ) );
    standInLabel->show();
    standInLabel->set_name ( SAESGUIConfigurationManager::getInstance()->GetStandInLabelLabelName() );

    standInEventBox = new BoxSelectionWidget ( "" , false, false, false );
    standInEventBox->show();
    standInEventBox->addWidget ( standInLabel );
    standInEventBox->set_name ( SAESGUIConfigurationManager::getInstance()->GetStandInLabelEventName() );

    this->add ( *tableWidget );
    this->show();

    setAccessibleName ( "FillTableContainer" );

    standInLabel->setAccessibleName ( "TitleSubstitute" );
    standInEventBox->setAccessibleName ( "TitleSubstitute" );

    static LabelConfiguration configuration = SAESGUIConfigurationManager::ConvertToLabelConfiguration ( SAESGUIConfigurationManager::getInstance()->GetVotingExperienceLabelConfiguration().getBallotSubstituteLabelConfiguration() );
    LabelConfiguration::SetLabelConfiguration ( standInLabel, configuration );
}

FillTableWidget::~FillTableWidget()
{
    this->remove();
    clear();

    if ( standInLabel )
    {
        delete standInLabel;
        standInLabel = NULL;
    }

    if ( standInEventBox )
    {
        delete standInEventBox;
        standInEventBox = NULL;
    }
}

void FillTableWidget::update()
{
    standInLabel->set_text ( _ ( "Smartmatic.SAES.GUI.Widgets.BallotOptionSelectionWidget.Substitute" ) );
}

void FillTableWidget::putStandInTitle ()
{
    tableWidget->put ( standInEventBox, currentRow, currentCol );
}

TableBoxSelectionWidget * FillTableWidget::getTableWidget()
{
    return static_cast < TableBoxSelectionWidget * > ( tableWidget );
}
