/**
 * @file HelpWidget.hxx
 * @brief Header help widget
 * @date 29/03/2012
 * @author Yadickson Soto
 */

#ifndef HELPWIDGET_HXX_
#define HELPWIDGET_HXX_

#include <gtkmm.h>
#include <string>
#include <Widgets/StepWidget.hxx>
#include <Widgets/smartmatic-button.h>
#include <Printing/HelpPrinting.hxx>
#include "GenericPrintingWidget.hxx"

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	HelpWidget
                 * @brief	Class help widget.
                 * @author	Yadickson Soto
                 * @date	08/03/2012
                 */
                class HelpWidget : public Smartmatic::GUI::Widgets::StepWidget
                {
                    public:
                        /**
                         * @fn	HelpWidget::HelpWidget();
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        HelpWidget();
                        /**
                         * @fn	HelpWidget::HelpWidget ( const std::string& titleKey, const std::string& image, const std::string& file, bool enableFilePrinting );
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         * @param	titleKey	title key.
                         * @param	image			image.
                         * @param	file			file.
                         * @param 	enableFilePrinting enable file printing button
                         */
                        HelpWidget ( const std::string& titleKey, const std::string& image, const std::string& file, bool enableFilePrinting );
                        /**
                         * @fn	virtual HelpWidget::~HelpWidget();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        virtual ~HelpWidget();
                        /**
                         * @fn	void HelpWidget::setInfo ( const std::string& titleKey, const std::string& image, const std::string& file, bool enableFilePrinting );
                         * @brief	Method set info.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         * @param	titleKey	title key.
                         * @param	image			image.
                         * @param	file			file.
                         * @param 	enableFilePrinting enable file printing button
                         */
                        void setInfo ( const std::string& titleKey, const std::string& image, const std::string& file, bool enableFilePrinting );
                        /**
                         * @fn	virtual bool HelpWidget::isExit();
                         * @brief	virtual method getter is visible help button.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         * @return	true is help button visible.
                         */
                        virtual bool isExit();
                        /**
                         * @fn	virtual void HelpWidget::refresh();
                         * @brief	refresh widget method.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         */
                        virtual void refresh();
                        /**
                         * @fn	sigc::signal<void> HelpWidget::getSignalStartPrint();
                         * @brief	method getter signal run print.
                         * @author	Yadickson Soto
                         * @date	22/04/2012
                         * @return	signal run print.
                         */
                        sigc::signal<void> getSignalStartPrint();
                        /**
                         * @fn	sigc::signal<void> HelpWidget::getSignalEndPrint();
                         * @brief	method getter signal end print.
                         * @author	Yadickson Soto
                         * @date	22/04/2012
                         * @return	signal end print.
                         */
                        sigc::signal<void> getSignalEndPrint();

                        /**
                         * @fn	sigc::signal<void> HelpWidget::getSignalShown();
                         * @brief	method getter signal shown.
                         * @author	Juan Valera
                         * @date	09/02/2017
                         * @return	signal shown.
                         */
                        sigc::signal<void> getSignalShown();

                        /**
                         * @fn	sigc::signal<void> HelpWidget::getSignalClosed();
                         * @brief	method getter signal closed.
                         * @author	Juan Valera
                         * @date	09/02/2017
                         * @return	signal closed.
                         */
                        sigc::signal<void> getSignalClosed();

                    protected:

                        sigc::signal<void> signalStartPrint; ///< signal start print
                        sigc::signal<void> signalEndPrint; ///< signal end print
                        sigc::signal<void> signalShown; ///< signal end print
                        sigc::signal<void> signalClosed; ///< signal end print

                    protected:

                        /**
                         * @fn	virtual void HelpWidget::initialize();
                         * @brief	Initializer method.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        virtual void initialize();
                        /**
                         * @fn	virtual void HelpWidget::dispose();
                         * @brief	virtual method stop.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        virtual void dispose();
                        /**
                         * @fn	void HelpWidget::startPrintProcess();
                         * @brief	method printing.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        void startPrintProcess();
                        /**
                         * @fn	void HelpWidget::endPrinting();
                         * @brief	method end printing, show result.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        void endPrinting();
                        /**
                         * @fn	void HelpWidget::onStart();
                         * @brief	method on start.
                         * @author	Juan Valera
                         * @date	09/02/2017
                         */
                        void onStart();
                        /**
                         * @fn	void HelpWidget::onEnd();
                         * @brief	method on end.
                         * @author	Juan Valera
                         * @date	09/02/2017
                         */
                        void onEnd();

                    private:

                        std::string imageFile; ///< image file
                        std::string file; ///< file to print
                        bool enableFilePrinting; ///< enable file printing button

                        Gtk::EventBox * helpEventBox; ///< help main frame
                        Gtk::VBox * mainVBox; ///< object
                        Gtk::Image * image; ///< The image
                        Gtk::VBox * helpVBox; ///< help container
                        Gtk::HSeparator * separator; ///< horizontal separator
                        Gtk::HButtonBox * printHBox; ///< print hbox

                        GenericPrintingWidget * genericPrinting; ///< generic printing
                        Smartmatic::GUI::Widgets::SmartmaticButton * printButton; ///< print button
                        Smartmatic::SAES::Printing::HelpPrinting * printing; ///< help printing file
                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
                };
            }
        }
    }
}

#endif /* HELPWIDGET_HXX_ */
