/**
 * @file InfoStepWidget.hxx
 * @brief Header message widget
 * @date 29/03/2012
 * @author Yadickson Soto
 */

#ifndef INFOSTEPWIDGET_HXX_
#define INFOSTEPWIDGET_HXX_

#include <gtkmm.h>
#include <Widgets/StepWidget.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	InfoStepWidget
                 * @brief	Information step widget.
                 * @author	Youssef.tourkmani
                 * @date	01/11/2012
                 */
                class InfoStepWidget : public Smartmatic::GUI::Widgets::StepWidget
                {
                    public:
                        /**
                         * @fn	InfoStepWidget::InfoStepWidget();
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        InfoStepWidget();
                        /**
                         * @fn	InfoStepWidget::InfoStepWidget ( const std::string& info, int timeout );
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         * @param	info	 	info.
                         * @param	timeout	exit.
                         */
                        InfoStepWidget ( const std::string& info, int timeout );
                        /**
                         * @fn	virtual InfoStepWidget::~InfoStepWidget();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        virtual ~InfoStepWidget();
                        /**
                         * @fn	void InfoStepWidget::setInfo ( const std::string& info );
                         * @brief	method setter info.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         * @param	info	info.
                         */
                        void setInfo ( const std::string& info );
                        /**
                         * @fn	void InfoStepWidget::setTimeout ( int timeout );
                         * @brief	method setter timeout
                         * 				@param timeout.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         * @param	timeout	The timeout.
                         */
                        void setTimeout ( int timeout );
                        /**
                         * @fn	int InfoStepWidget::getTimeout();
                         * @brief	method getter timeout.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         * @return	timeout.
                         */
                        int getTimeout();
                        /**
                         * @fn	virtual void InfoStepWidget::refresh();
                         * @brief	refresh widget method.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         */
                        virtual void refresh();

                    protected:

                        /**
                         * @fn	virtual void InfoStepWidget::initialize();
                         * @brief	Initializer method.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        virtual void initialize();
                        /**
                         * @fn	virtual void InfoStepWidget::dispose();
                         * @brief	virtual method stop.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        virtual void dispose();

                    private:

                        std::string info; ///< info message
                        int timeout; ///< timeout message
                        Gtk::Label * labelInfo; ///< message language
                };
            }
        }
    }
}

#endif /* INFOSTEPWIDGET_HXX_ */
