/**
 * @file MachineWizardWidget.hxx
 * @brief Header machine wizard widget
 * @date 31/03/2012
 * @author Yadickson Soto
 */

#ifndef MACHINEWIZARDWIDGET_HXX_
#define MACHINEWIZARDWIDGET_HXX_

#include "RunMachineWidget.hxx"
#include <Gui/Widgets/Wizard/WizardWidget.h>
#include <Gui/Widgets/Wizard/WizardConfiguration.h>
#include "HelpWidget.hxx"

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	MachineWizardWidget
                 * @brief	Class machine wizard widget.
                 * @author	Yadickson Soto
                 * @date	31/03/2012
                 */
                class MachineWizardWidget : public RunMachineWidget
                {
                    public:
                        /**
                         * @fn	MachineWizardWidget::MachineWizardWidget();
                         * @brief	Class constructor.
                         * @param 	help help widget
                         * @author	Yadickson Soto
                         * @date	31/03/2012
                         */
                        explicit MachineWizardWidget ( HelpWidget * help );
                        /**
                         * @fn	virtual MachineWizardWidget::~MachineWizardWidget();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	31/03/2012
                         */
                        virtual ~MachineWizardWidget();
                        /**
                         * @fn	virtual std::string MachineWizardWidget::getTitleText();
                         * @brief	virtual method getter title.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         * @return	title.
                         */
                        virtual std::string getTitleText();
                        /**
                         * @fn	virtual void MachineWizardWidget::refresh();
                         * @brief	refresh widget method.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         */
                        virtual void refresh();
                        /**
                         * @fn	virtual void MachineWizardWidget::start();
                         * @brief	virtual method start widget.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        virtual void start();
                        /**
                         * @fn	virtual void MachineWizardWidget::dispose();
                         * @brief	virtual method stop.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        virtual void dispose();
                        /**
                         * @fn	virtual void MachineWizardWidget::SetKey ( Smartmatic::GUI::Widgets::KeysActionsCode value );
                         * @brief	virtual method setter key.
                         * @author	Yadickson Soto
                         * @date	31/03/2012
                         * @param	value	value key.
                         */
                        virtual void SetKey ( Smartmatic::GUI::Widgets::KeysActionsCode value );
                        /**
                         * @fn	virtual bool isHelp();
                         * @brief	virtual method getter is visible help button.
                         * @author	Yadickson Soto
                         * @date	10/04/2014
                         * @return	true is help button visible.
                         */
                        virtual bool isHelp();

                    protected:
                        /**
                         * @fn	virtual void MachineWizardWidget::initialize();
                         * @brief	Initializer method.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        virtual void initialize();

                        std::string currentState; ///< curren state
                        Smartmatic::SAES::GUI::Widgets::WizardWidget * wizard;  ///< The menu
                        HelpWidget * help; ///< help widget
                        Gtk::Notebook * notebook; ///< notebook widget
                        std::map<std::string, int> indexByState; ///< map wizard
                        bool useHelp; ///< Use help
                        std::map<std::string, Smartmatic::SAES::GUI::Widgets::WizardWidget *> wizardWidgetByState; ///< map wizard
                        std::vector<Smartmatic::SAES::GUI::Widgets::WizardConfiguration> wizardConfiguration; ///< wizard configuration
                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
                };
            }
        }
    }
}

#endif /* MACHINEWIZARDWIDGET_HXX_ */
