/**
 * @file PersistAllResultWidget.cxx
 * @brief Body class persist all result files widget
 * @date 17/02/2012
 * @author Yadickson Soto
 */

#include "PersistAllResultWidget.hxx"

#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Operation/MachineOperationManager.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::Log;

ISMTTLog * PersistAllResultWidget::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.PersistAllResultWidget", GETTEXT_PACKAGE );

PersistAllResultWidget::PersistAllResultWidget ( ProgressWidget * progress )
    : WizardWidgetBase(), progress ( progress )
{
    m_thread = NULL;

    this->progress->setImage ( "ui/persist-all-result-files.gif" );
    this->progress->setInfoText ( N_ ( "Smartmatic.SAES.GUI.Widgets.PersistAllResultWidget.PersistAllResult" ) );
    setWidget ( progress );

    signalEndProcess.connect ( sigc::mem_fun ( *this, &PersistAllResultWidget::endProcess ) );
    signalErrorProcess.connect ( sigc::mem_fun ( *this, &PersistAllResultWidget::errorProcess ) );

    setAccessibleName ( "PersistAllResultWidget" );
}

PersistAllResultWidget::~PersistAllResultWidget()
{
    dispose();

    this->remove();

    if ( progress )
    {
        delete progress;
        progress = NULL;
    }
}

void PersistAllResultWidget::initialize()
{
    m_disable_close_signal.emit();

    if ( !Glib::thread_supported() )
    {
        Glib::thread_init();
    }

    if ( m_thread != NULL )
    {
        m_thread->join();
        m_thread = NULL;
    }

    m_thread = Glib::Thread::create ( sigc::mem_fun ( *this, &PersistAllResultWidget::start ), true );
}

void PersistAllResultWidget::dispose()
{
    if ( m_thread != NULL )
    {
        m_thread->join();
        m_thread = NULL;
    }
}

void PersistAllResultWidget::start()
{
    bool validate = MachineOperationManager::getInstance()->persistAllResult();

    if ( validate )
    {
        signalEndProcess.emit();
    }
    else
    {
        signalErrorProcess.emit();
    }
}

void PersistAllResultWidget::end()
{
    emit();
}

bool PersistAllResultWidget::isEnabledButtonExitWizard()
{
    return false;
}

void PersistAllResultWidget::endProcess()
{
    Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &PersistAllResultWidget::end ), 100 );
}

void PersistAllResultWidget::errorProcess ()
{
    Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &PersistAllResultWidget::errorMessage ), 100 );
}

void PersistAllResultWidget::errorMessage()
{
    emitError();
}
