/**
 * @file PersistAllResultWidget.hxx
 * @brief Header class persist all result files widget
 * @date 17/02/2012
 * @author Yadickson Soto
 */

#ifndef PERSISTALLRESULTWIDGET_HXX_
#define PERSISTALLRESULTWIDGET_HXX_

#include <Widgets/wizard-widget-base.h>
#include <Gui/Widgets/ShutdownWidget.hxx>
#include "ProgressWidget.hxx"

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	PersistAllResultWidget
                 * @brief	Class persist all result files widget.
                 * @author	Yadickson Soto
                 * 					@see WizardWidgetBase
                 * @date	17/02/2012
                 */
                class PersistAllResultWidget: public Smartmatic::GUI::Widgets::WizardWidgetBase
                {
                    public:
                        /**
                         * @fn	PersistAllResultWidget::PersistAllResultWidget ( ProgressWidget * progress );
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	17/02/2012
                         * @param	progress	widget with label and image.
                         */
                        explicit PersistAllResultWidget ( ProgressWidget * progress );

                        /**
                         * @fn	virtual PersistAllResultWidget::~PersistAllResultWidget();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	17/02/2012
                         */
                        virtual ~PersistAllResultWidget();

                        /**
                         * @fn	virtual void PersistAllResultWidget::initialize();
                         * @brief	Initializer method.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        virtual void initialize();
                        /**
                         * @fn	virtual void PersistAllResultWidget::dispose();
                         * @brief	virtual method stop.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        virtual void dispose();

                        /**
                         * @fn	virtual bool PersistAllResultWidget::isEnabledButtonExitWizard();
                         * @brief	Method getter is enabled button exit wizard.
                         * @author	Yadickson Soto
                         * @date	22/02/2012
                         * @return	true is enabled button exit wizard.
                         */
                        virtual bool isEnabledButtonExitWizard();

                    private:

                        ProgressWidget * progress; ///< widget with label and image
                        Glib::Dispatcher signalEndProcess; ///< signal end process
                        Glib::Dispatcher signalErrorProcess; ///< signal error process
                        Glib::Thread * m_thread; ///< The thread pointer
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger

                        /**
                         * @fn	void PersistAllResultWidget::start();
                         * @brief	Method start persist codi files.
                         * @author	Yadickson Soto
                         * @date	17/02/2012
                         */
                        void start();

                        /**
                         * @fn	void end();
                         * @brief	End of the widget.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         */
                        void end();

                        /**
                         * @fn	void errorMessage();
                         * @brief	Show error message.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         */
                        void errorMessage();

                        /**
                         * @fn	void endProcess();
                         * @brief	Method end persistence all result files.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         */
                        void endProcess();

                        /**
                         * @fn	void errorProcess ();
                         * @brief	Method update label from error process.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         */
                        void errorProcess ();
                };
            }
        }
    }
}
#endif /* PERSISTALLRESULTWIDGET_HXX_ */
