/**
 * @file	PollingPlaceInfoWidget.hxx
 * @brief	polling place information widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#ifndef POLLINGPLACEINFOWIDGET_HXX_
#define POLLINGPLACEINFOWIDGET_HXX_

#include <gtkmm.h>
#include <Widgets/info-widget.h>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	PollingPlaceInfoWidget
                 * @brief	Polling place information widget.
                 * @author	Youssef.tourkmani
                 * @date	01/11/2012
                 */
                class PollingPlaceInfoWidget : public Gtk::Frame
                {
                    public:
                        /**
                         * @fn	PollingPlaceInfoWidget::PollingPlaceInfoWidget();
                         * @brief	Default constructor.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        PollingPlaceInfoWidget();
                        /**
                         * @fn	virtual PollingPlaceInfoWidget::~PollingPlaceInfoWidget();
                         * @brief	Destructor.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        virtual ~PollingPlaceInfoWidget();
                        /**
                         * @fn	virtual void PollingPlaceInfoWidget::fillKey() = 0;
                         * @brief	Fill key.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        virtual void fillKey() = 0;
                        /**
                         * @fn	void PollingPlaceInfoWidget::fillInfoWidget();
                         * @brief	Fill information widget.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void fillInfoWidget();

                    protected:

                        Glib::ustring messageErrorKey;	///< The message error key

                        Glib::ustring region1Key; ///< The region 1 key
                        Glib::ustring region2Key; ///< The region 2 key
                        Glib::ustring region3Key; ///< The region 3 key
                        Glib::ustring region4Key; ///< The region 4 key
                        Glib::ustring region5Key; ///< The region 5 key
                        Glib::ustring region6Key; ///< The region 6 key
                        Glib::ustring region7Key; ///< The region 7 key
                        Glib::ustring votingCenterKey;	///< The voting center key
                        Glib::ustring versionKey; ///< The version key
                        Glib::ustring votingCenterAddressKey; ///< The voting center address key
                        Glib::ustring electionNameKey;	///< The election name key
                        Glib::ustring registeredElectorsKey;	///< The registered electors key
                        Glib::ustring pollingStationCodeKey;	///< The polling station code key
                        Glib::ustring votingDeviceCustomCodeKey;	///< The voting device custom code key

                        Glib::ustring region1Value; ///< The region 1 value
                        Glib::ustring region2Value; ///< The region 2 value
                        Glib::ustring region3Value; ///< The region 3 value
                        Glib::ustring region4Value; ///< The region 4 value
                        Glib::ustring region5Value; ///< The region 5 value
                        Glib::ustring region6Value; ///< The region 6 value
                        Glib::ustring region7Value; ///< The region 7 value
                        Glib::ustring votingCenterValue;	///< The voting center value
                        Glib::ustring versionValue; ///< The version value
                        Glib::ustring votingCenterAddressValue; ///< The voting center address value
                        Glib::ustring electionNameValue;	///< The election name value
                        Glib::ustring registeredElectorsValue;	///< The registered electors value
                        Glib::ustring pollingStationCodeValue;	///< The polling station code value
                        Glib::ustring votingDeviceCustomCodeValue;	///< The voting device custom code value

                        Glib::ustring officialKey; ///< Official Key
                        Glib::ustring officialValue; ///< Official Value
                        Glib::ustring recountKey; ///< Recount Key
                        Glib::ustring recountValue; ///< Recount Value

                        /**
                         * @fn	void PollingPlaceInfoWidget::addCompositePair ( std::string key, std::string value );
                         * @brief	Adds a composite pair to 'value'.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @param	key	 	The key.
                         * @param	value	The value.
                         */
                        void addCompositePair ( std::string key, std::string value );

                    private:

                        Gtk::Label * messageError;	///< The message error
                        Smartmatic::GUI::Widgets::InfoWidget * infoWidget;	///< The information widget
                        static Smartmatic::Log::ISMTTLog * logger;  ///< logger

                        /**
                         * @property	std::vector< std::vector<std::string> > composePair
                         * @brief	Gets the compose pair.
                         * @return	The compose pair.
                         */
                        std::vector< std::vector<std::string> > composePair;
                        /**
                         * @property	std::vector< std::vector<std::string> > info
                         * @brief	Gets the information.
                         * @return	The information.
                         */
                        std::vector< std::vector<std::string> > info;

                        /**
                         * @fn	std::string PollingPlaceInfoWidget::composeKey ( std::string toCompose );
                         * @brief	Compose key.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @param	toCompose	to compose.
                         * @return	.
                         */
                        std::string composeKey ( std::string toCompose );
                        /**
                         * @fn	std::string PollingPlaceInfoWidget::composeValue ( std::string toCompose );
                         * @brief	Compose value.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @param	toCompose	to compose.
                         * @return	.
                         */
                        std::string composeValue ( std::string toCompose );

                        /**
                         * @fn	void PollingPlaceInfoWidget::compositePair ( std::string key, std::string value );
                         * @brief	Composite pair.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @param	key	 	The key.
                         * @param	value	The value.
                         */
                        void compositePair ( std::string key, std::string value );
                };
            }
        }
    }
}

#endif /* POLLINGPLACEINFOWIDGET_HXX_ */
