/**
 * @file ProcessResultWidget.cxx
 * @brief Body process results widget class
 * @date 07/11/2012
 * @author Yadickson Soto
 */

#include "ProcessResultWidget.hxx"
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"
#include <Voting/Status/VMProcessStatusWrapper.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::Voting::Status;
using namespace Smartmatic::SAES::Configuration;

ProcessResultWidget::ProcessResultWidget ()
{
    buttonWidget = NULL;
    conteinerWidget = new NotebookContainer();
    conteinerWidget->ShowTabs ( false );

    columns = SAESGUIConfigurationManager::getInstance()->getProcessResultWidgetConfiguration().getColumns();
    width = SAESGUIConfigurationManager::getInstance()->getProcessResultWidgetConfiguration().getWidth();
    height = SAESGUIConfigurationManager::getInstance()->getProcessResultWidgetConfiguration().getHeight();
    countByPage = SAESGUIConfigurationManager::getInstance()->getProcessResultWidgetConfiguration().getElementsByPage();

    resultWidget = new ListResultWidget ( 1, columns * width, height );
    buttonWidget = new SmartmaticButton();

    if ( SAESGUIConfigurationManager::getInstance()->getProcessResultWidgetConfiguration().getShowExitButton() )
    {
        conteinerWidget->AddBottomWidget ( buttonWidget );
        buttonWidget->signal_clicked().connect ( sigc::mem_fun ( *this, &ProcessResultWidget::onSignalEnd ) );
    }

    showResult();

    setWidget ( conteinerWidget );
}

ProcessResultWidget::~ProcessResultWidget()
{
    remove();

    if ( conteinerWidget )
    {
        delete conteinerWidget;
        conteinerWidget = NULL;
    }

    if ( resultWidget )
    {
        delete resultWidget;
        resultWidget = NULL;
    }

    if ( buttonWidget )
    {
        delete buttonWidget;
        buttonWidget = NULL;
    }

    std::list < Smartmatic::SAES::GUI::Widgets::ListResultWidget * >::iterator it;

    for ( it = listResultSuccessWidget.begin();
            it != listResultSuccessWidget.end();
            ++it )
    {
        Smartmatic::SAES::GUI::Widgets::ListResultWidget * widget = ( *it );
        delete widget;
        widget = NULL;
    }

    for ( it = listResultFailWidget.begin();
            it != listResultFailWidget.end();
            ++it )
    {
        Smartmatic::SAES::GUI::Widgets::ListResultWidget * widget = ( *it );
        delete widget;
        widget = NULL;
    }

    listResultSuccessWidget.clear();
    listResultFailWidget.clear();

    VMProcessStatusWrapper::getInstance()->dispose();
}

void ProcessResultWidget::fill ( std::list < Smartmatic::SAES::Voting::Status::MachineProcessStatus * > & list,
                                 std::list < Smartmatic::SAES::GUI::Widgets::ListResultWidget * > & widgetList )
{
    std::list < MachineProcessStatus * >::iterator it;
    ListResultWidget * interList = NULL;

    int count = 0;

    for ( it = list.begin();
            it != list.end();
            ++it, count++ )
    {
        ResultWidget * widget = new ResultWidget();

        MachineProcessStatus::InfoStatusSequence & seq ( ( *it )->getInfoStatus() );
        MachineProcessStatus::InfoStatusIterator itis;

        for ( itis = seq.begin();
                itis != seq.end();
                ++itis )
        {
            widget->addResult ( ( *itis ).getText(), ( *itis ).getStatus() );
        }

        widget->setText ( ( *it )->getName() );
        widget->setStatus ( ( *it )->getStatus() );

        if ( count % countByPage == 0 )
        {
            interList = manage(new ListResultWidget ( columns, width, height ));
            widgetList.push_back ( interList );
        }

        interList->addWidget ( widget, !seq.empty() );
    }
}

void ProcessResultWidget::showResult ( bool showResult, bool showSuccess, bool showFail )
{
    std::list < MachineProcessStatus * > successList;
    std::list < MachineProcessStatus * > failList;

    VMProcessStatusWrapper::getInstance()->getAllSuccess ( successList );
    VMProcessStatusWrapper::getInstance()->getAllFail ( failList );

    buttonWidget->SetLabel ( _ ( "Smartmatic.SAES.GUI.Widgets.DataUtilsValidatorWidget.Exit" ) );

    fill ( successList, listResultSuccessWidget );
    fill ( failList, listResultFailWidget );

    int failCount = VMProcessStatusWrapper::getInstance()->getFailCount();
    int successCount = VMProcessStatusWrapper::getInstance()->getSuccessCount();

    if ( showResult )
    {
        {
            ResultWidget * widget = manage ( new ResultWidget() );
            std::stringstream ss;
            ss << _ ( "Smartmatic.SAES.GUI.Widgets.DataUtilsResultWidget.Success" ) << successCount;
            widget->setText ( ss.str() );
            widget->setStatus ( true );
            resultWidget->addWidget ( widget, false );
        }
        {
            ResultWidget * widget = manage ( new ResultWidget() );
            std::stringstream ss;
            ss << _ ( "Smartmatic.SAES.GUI.Widgets.DataUtilsResultWidget.Fail" ) << failCount;
            widget->setText ( ss.str() );
            widget->setStatus ( false );
            resultWidget->addWidget ( widget, false );
        }
        {
            ResultWidget * widget = manage ( new ResultWidget() );
            std::stringstream ss;
            ss << VMProcessStatusWrapper::getInstance()->getTime();
            widget->setText ( ss.str() );
            resultWidget->addWidget ( widget, false );
        }

        conteinerWidget->AppendPage ( resultWidget, _ ( "Smartmatic.SAES.GUI.Widgets.DataUtilsValidatorWidget.Statistics" ) );
    }

    if ( showFail && failCount > 0 )
    {
        fill ( listResultFailWidget );
    }

    if ( showSuccess && successCount > 0 )
    {
        fill ( listResultSuccessWidget );
    }

    setWidget ( conteinerWidget );
}

void ProcessResultWidget::fill ( std::list < Smartmatic::SAES::GUI::Widgets::ListResultWidget * > & widgetList )
{
    std::list < Smartmatic::SAES::GUI::Widgets::ListResultWidget * >::iterator it;

    for ( it = widgetList.begin();
            it != widgetList.end();
            ++it )
    {
        ListResultWidget * interList = ( *it );
        conteinerWidget->AppendPage ( interList, " " );
    }
}

void ProcessResultWidget::onSignalEnd()
{
    emit();
}
