/**
 * @file ProcessResultWidget.hxx
 * @brief Header process results widget class
 * @date 07/11/2012
 * @author Yadickson Soto
 */

#ifndef PROCESSRESULTWIDGET_HXX_
#define PROCESSRESULTWIDGET_HXX_

#include <Widgets/StepWidget.hxx>
#include <Gui/Widgets/ListResultWidget.hxx>
#include <Widgets/notebook-container.h>
#include <Widgets/smartmatic-button.h>
#include <Voting/Status/voting-machine-process-status-schema.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	ProcessResultWidget
                 * @brief	Process results widget.
                 * @author	Yadickson Soto
                 * @date	07/11/2012
                 */
                class ProcessResultWidget : public Smartmatic::GUI::Widgets::StepWidget
                {
                    public:
                        /**
                         * @fn	ProcessResultWidget::ProcessResultWidget ( );
                         * @brief	Constructor.
                         * @author	Yadickson Soto
                         * @date	07/11/2012
                         */
                        ProcessResultWidget ( );
                        /**
                         * @fn	virtual ProcessResultWidget::~ProcessResultWidget();
                         * @brief	Destructor.
                         * @author	Yadickson Soto
                         * @date	07/11/2012
                         */
                        virtual ~ProcessResultWidget();

                        /**
                         * @fn	void ProcessResultWidget::showResult(  bool showResult = true, bool showSuccess = true, bool showFail = true );
                         * @brief	Shows the result.
                         * @author	Yadickson Soto
                         * @param showResult show results
                         * @param showSuccess show success
                         * @param showFail show fail
                         * @date	07/11/2012
                         */
                        void showResult ( bool showResult = true, bool showSuccess = true, bool showFail = true );

                    protected:

                        /**
                          * @fn	void ProcessResultWidget::onSignalEnd();
                          * @brief	Method on signal end
                          * @author	Yadickson Soto
                          * @date	07/11/2012
                          */
                        void onSignalEnd ( );

                        /**
                          * @fn	void ProcessResultWidget::fill ( std::list < Smartmatic::SAES::Voting::Status::MachineProcessStatus * > & list,
                          *	          std::list < Smartmatic::SAES::GUI::Widgets::ListResultWidget * > & widgetList );
                          * @brief	Method fill result
                          * @author	Yadickson Soto
                          * @date	08/11/2012
                          * @param list origen date
                          * @param widgetList result widget list
                          */
                        void fill ( std::list < Smartmatic::SAES::Voting::Status::MachineProcessStatus * > & list,
                                    std::list < Smartmatic::SAES::GUI::Widgets::ListResultWidget * > & widgetList );

                        /**
                          * @fn	void ProcessResultWidget::fill ( std::list < Smartmatic::SAES::GUI::Widgets::ListResultWidget * > & widgetList );
                          * @brief	Method fill result
                          * @author	Yadickson Soto
                          * @date	12/11/2012
                          * @param  widgetList widget list to view
                          */
                        void fill ( std::list < Smartmatic::SAES::GUI::Widgets::ListResultWidget * > & widgetList );

                    private:

                        int columns; ///< columns
                        int width; ///< width
                        int height; ///< height
                        int countByPage; ///< count by page

                        Smartmatic::GUI::Widgets::SmartmaticButton * buttonWidget; ///< button widget
                        Smartmatic::GUI::Widgets::NotebookContainer * conteinerWidget; ///< conteiner widget
                        Smartmatic::SAES::GUI::Widgets::ListResultWidget * resultWidget; ///< result statistics widget
                        std::list < Smartmatic::SAES::GUI::Widgets::ListResultWidget * > listResultSuccessWidget; ///< result success widget
                        std::list < Smartmatic::SAES::GUI::Widgets::ListResultWidget * > listResultFailWidget; ///< result faild widget
                };
            }
        }
    }
}

#endif /* PROCESSRESULTWIDGET_HXX_ */
