/*
 * RecountPersistConfirm.cpp
 *
 *  Created on: Jun 12, 2013
 *      Author: Georgi Demirchev
 */

#include "RecountPersistConfirm.h"
#include "ConfigBridge.h"
#include <Environment/Configurations/resource-path-provider.h>
#include <Configuration/MachineModelEnum.hxx>
#include <Configuration/s-m-t-t-g-u-i-conf-manager.h>
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Widgets/SmartmaticBasicLabel.hxx>
#include <Widgets/SmartmaticBasicEventBox.hxx>
#include <Widgets/smartmatic-entry.h>
#include <Widgets/SmartmaticBasicTable.hxx>


#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

using namespace Smartmatic::Configuration;
using namespace Smartmatic::Environment;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::GUI::Widgets::Recount;

RecountPersistConfirm::RecountPersistConfirm ( int maxMax, int remaining )
{
    frame = NULL;
    logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.RecountFunctionality",	GETTEXT_PACKAGE );
    std::string gladeFile = ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, "ui/RecountPersistConfirm.glade" );
    Glib::RefPtr<Gtk::Builder> builder;

    try
    {
        builder = Gtk::Builder::create_from_file ( gladeFile );
    }
    catch ( const Glib::FileError & ex )
    {
        logger->Debug ( "FATAL - RecountPersistConfirm failed to Initialize" );
    }

    if ( !builder )
    {
        return;
    }

    builder->get_widget ( "main-frame", frame );

    Smartmatic::GUI::Widgets::SmartmaticBasicLabel * labelAll, *labelToDelete, *labelRemaining, *labelMessage, *labelMessageWarning;

    builder->get_widget_derived ( "label-all", labelAll );
    builder->get_widget_derived ( "label-todelete", labelToDelete );
    builder->get_widget_derived ( "label-remaining", labelRemaining );
    builder->get_widget_derived ( "label-message", labelMessage );
    builder->get_widget_derived ( "label-message-warning", labelMessageWarning );

    if ( labelAll )
    {
        LabelConfiguration::SetLabelConfiguration ( labelAll, ConfigBridge::recountConfirmInfoLabel );
        labelAll->set_text ( _ ( "Smartmatic.SAES.GUI.Widgets.RecountWidget.PersistConfirm.LabelAll" ) );
    }

    if ( labelToDelete )
    {
        LabelConfiguration::SetLabelConfiguration ( labelToDelete, ConfigBridge::recountConfirmInfoLabel );
        labelToDelete->set_text ( _ ( "Smartmatic.SAES.GUI.Widgets.RecountWidget.PersistConfirm.LabelToDelete" ) );
    }

    if ( labelRemaining )
    {
        LabelConfiguration::SetLabelConfiguration ( labelRemaining, ConfigBridge::recountConfirmInfoLabel );
        labelRemaining->set_text ( _ ( "Smartmatic.SAES.GUI.Widgets.RecountWidget.PersistConfirm.LabelRemaining" ) );
    }

    if ( labelMessage )
    {
        LabelConfiguration::SetLabelConfiguration ( labelMessage, ConfigBridge::recountConfirmInfoLabel );
        labelMessage->set_text ( _ ( "Smartmatic.SAES.GUI.Widgets.RecountWidget.PersistConfirm.LabelMessage" ) );
    }

    if ( labelMessageWarning )
    {
        LabelConfiguration::SetLabelConfiguration ( labelMessageWarning, ConfigBridge::recountConfirmInfoLabel );
        labelMessageWarning->set_text ( _ ( "Smartmatic.SAES.GUI.Widgets.RecountWidget.PersistConfirm.LabelMessageWarning" ) );
    }

    builder->get_widget_derived ( "button-ok", buttonOK );
    builder->get_widget_derived ( "button-cancel", buttonCancel );

    int buttonWidth  = ConfigBridge::recountConfirmButton.getButtonWidth();
    int buttonHeight = ConfigBridge::recountConfirmButton.getButtonHeight();

    if ( SMTTGUIConfigurationManager::getInstance()->getSmartmaticGUIMachineModelConfiguration().getId() == EnumToString( PM_VIU805 ) )
    {
        double guiReconfigurationFactor = SMTTGUIConfigurationManager::getInstance()->getConfiguration()->getSmartmaticGUIMachineModelConfiguration().getGuiReconfigurationFactor();

        buttonWidth *= guiReconfigurationFactor;
        buttonHeight *= guiReconfigurationFactor;
    }

    if ( buttonOK )
    {
        buttonOK->set_label ( _ ( "Smartmatic.SAES.GUI.Widgets.RecountWidget.PersistConfirm.ButtonOK" ) );
        buttonOK->set_size_request ( buttonWidth, buttonHeight );
        buttonOK->ModifyFontSize ( ConfigBridge::recountConfirmButton.getFontSize() );
    }

    if ( buttonCancel )
    {
        buttonCancel->set_label ( _ ( "Smartmatic.SAES.GUI.Widgets.RecountWidget.PersistConfirm.ButtonCancel" ) );
        buttonCancel->set_size_request ( buttonWidth, buttonHeight );
        buttonCancel->ModifyFontSize ( ConfigBridge::recountConfirmButton.getFontSize() );
    }


    Smartmatic::GUI::Widgets::SmartmaticBasicLabel * entryAll, *entryToDelete, *entryRemaining;
    builder->get_widget_derived ( "entry-all", entryAll );
    builder->get_widget_derived ( "entry-todelete", entryToDelete );
    builder->get_widget_derived ( "entry-remaining", entryRemaining );

    if ( entryAll )
    {
        LabelConfiguration::SetLabelConfiguration ( entryAll, ConfigBridge::recountConfirmInfoEntryLabel );
        std::stringstream ss;
        ss << maxMax;
        entryAll->set_text ( ss.str() );
    }

    if ( entryToDelete )
    {
        LabelConfiguration::SetLabelConfiguration ( entryToDelete, ConfigBridge::recountConfirmInfoEntryLabel );
        int toDelete = maxMax - remaining;
        std::stringstream ss;
        ss << toDelete;
        entryToDelete->set_text ( ss.str() );
    }

    if ( entryRemaining )
    {
        LabelConfiguration::SetLabelConfiguration ( entryRemaining, ConfigBridge::recountConfirmInfoEntryLabel );
        std::stringstream ss;
        ss << remaining;
        entryRemaining->set_text ( ss.str() );
    }

    if ( ConfigBridge::levelOfSelection < 1 || ConfigBridge::levelOfSelection > 3 )
    {
        labelToDelete->set_no_show_all();
        labelToDelete->set_visible ( false );
        entryToDelete->set_no_show_all();
        entryToDelete->set_visible ( false );
        labelRemaining->set_no_show_all();
        labelRemaining->set_visible ( false );
        entryRemaining->set_no_show_all();
        entryRemaining->set_visible ( false );
        labelMessage->set_no_show_all();
        labelMessage->set_visible ( false );
    }

    setWidget ( frame );
}

RecountPersistConfirm::~RecountPersistConfirm()
{
    delete frame; // NULL permitted

    // builder and internal widgets auto-manageable
}

Glib::SignalProxy0< void > RecountPersistConfirm::getSignalCancel()
{
    return buttonCancel->signal_clicked();
}

Glib::SignalProxy0< void > RecountPersistConfirm::getSignalOK()
{
    return buttonOK->signal_clicked();
}
