#include "RecountSession.h"
#include "ConfigBridge.h"
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets::Recount;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Log;
using namespace Smartmatic::GUI::Configuration;

int RecountSession::m_startRow = 0;

RecountSession::RecountSession ( RecountStatPage * t, const char * name, const char * tooltip, int row, bool isTotals )
    : m_fields ( RecountStatPage::numFields ), m_isTotals ( isTotals ), m_thePage ( t ), m_row ( 0 ), m_isVisible ( false )
{
    m_logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.Recount.RecountSession",	GETTEXT_PACKAGE );

    SetRow ( row );

    m_sessionName.set_tooltip_text ( tooltip );
    m_sessionName.set_text ( name );

    LabelConfiguration::SetLabelConfiguration ( &m_sessionName, m_isTotals ?
            ConfigBridge::recountStatSessionTotalsLabel : ConfigBridge::recountStatSessionLabel );
    m_sessionName.set_justify ( Gtk::JUSTIFY_RIGHT );

    for ( size_t i = 0; i < RecountStatPage::numFields; ++i )
    {
        m_fields[i] = Gtk::manage ( new RecountResultFieldButton ( this, isTotals, i, row ) );
    }
}

RecountSession::~RecountSession ( )
{
}

void RecountSession::PopulateTotals ( const std::vector<int> & accumV, std::vector<int> & activeV, std::vector<int> & maxV, std::vector<ClickAbsorber::STATE> & statusV )
{
    // this variable is accessed from another thread read-only
    m_maxMax = maxV[RecountStatPage::totalIndex];

    for ( size_t i = 0; i < RecountStatPage::numFields; ++i )
    {
        m_fields[i]->setData ( accumV[i] );
        std::ostringstream oss;

        if ( statusV[i] == ClickAbsorber::PUSHED )
        {
            oss << ConfigBridge::zerosReplacementInTotals;
        }
        else
        {
            oss << activeV[i];
        }

        m_fields[i]->set_label ( oss.str() );
        m_fields[i]->SetState ( statusV[i] );
    }
}

void RecountSession::Refresh ( std::vector<int> & accumV, std::vector<int> & activeV, std::vector<int> & maxV, std::vector<ClickAbsorber::STATE> & statusV )
{
    int accumFullFound = 0, accumActiveFound = 0;
    int accumFullNotFound = 0, accumActiveNotFound = 0;
    bool hasFoundPushed = false, hasNotFoundPushed = false;
    bool allFoundPushed = true, allNotFoundPushed = true;

    for ( size_t i = RecountStatPage::startOfFoundVotersIndex; i < RecountStatPage::subtotalFoundIndex; ++i )
    {
        if ( m_fields[i]->GetState() == ClickAbsorber::RELEASED )
        {
            accumActiveFound += m_fields[i]->getData();
        }

        accumFullFound += m_fields[i]->getData();

        if ( !hasFoundPushed )
        {
            if ( m_fields[i]->GetState() == ClickAbsorber::PUSHED )
            {
                hasFoundPushed = true;
            }
        }

        if ( allFoundPushed )
        {
            if ( m_fields[i]->GetState() != ClickAbsorber::PUSHED )
            {
                allFoundPushed = false;
            }
        }
    }

    for ( size_t i = RecountStatPage::startOfNotFoundVotersIndex; i < RecountStatPage::subtotalNotFoundIndex; ++i )
    {
        if ( m_fields[i]->GetState() == ClickAbsorber::RELEASED )
        {
            accumActiveNotFound += m_fields[i]->getData();
        }

        accumFullNotFound += m_fields[i]->getData();

        if ( !hasNotFoundPushed )
        {
            if ( m_fields[i]->GetState() == ClickAbsorber::PUSHED )
            {
                hasNotFoundPushed = true;
            }
        }

        if ( allNotFoundPushed )
        {
            if ( m_fields[i]->GetState() != ClickAbsorber::PUSHED )
            {
                allNotFoundPushed = false;
            }
        }
    }

    maxV[RecountStatPage::subtotalFoundIndex] += accumFullFound;
    maxV[RecountStatPage::subtotalNotFoundIndex] += accumFullNotFound;
    maxV[RecountStatPage::totalIndex] = maxV[RecountStatPage::subtotalFoundIndex]
                                        + maxV[RecountStatPage::subtotalNotFoundIndex];
    m_fields[RecountStatPage::subtotalFoundIndex]->setData ( accumActiveFound );
    m_fields[RecountStatPage::subtotalNotFoundIndex]->setData ( accumActiveNotFound );
    m_fields[RecountStatPage::totalIndex]->setData ( accumActiveFound + accumActiveNotFound );

    if ( hasFoundPushed || hasNotFoundPushed )
    {
        if ( hasFoundPushed )
        {
            m_fields[RecountStatPage::subtotalFoundIndex]->SetState (
                allFoundPushed ? ClickAbsorber::PUSHED : ClickAbsorber::TRANSITIONAL );
        }
        else
        {
            m_fields[RecountStatPage::subtotalFoundIndex]->SetState ( ClickAbsorber::RELEASED );
        }

        if ( hasNotFoundPushed )
        {
            m_fields[RecountStatPage::subtotalNotFoundIndex]->SetState (
                allNotFoundPushed ? ClickAbsorber::PUSHED : ClickAbsorber::TRANSITIONAL );
        }
        else
        {
            m_fields[RecountStatPage::subtotalNotFoundIndex]->SetState ( ClickAbsorber::RELEASED );
        }

        if ( hasFoundPushed == hasNotFoundPushed )
        {
            ClickAbsorber::STATE fState = m_fields[RecountStatPage::subtotalFoundIndex]->GetState ( );
            ClickAbsorber::STATE nfState = m_fields[RecountStatPage::subtotalNotFoundIndex]->GetState ( );
            m_fields[RecountStatPage::totalIndex]->
            SetState ( fState == nfState ? fState : ClickAbsorber::TRANSITIONAL );
        }
        else
        {
            m_fields[RecountStatPage::totalIndex]->SetState ( ClickAbsorber::TRANSITIONAL );
        }
    }
    else
    {
        m_fields[RecountStatPage::totalIndex]->SetState ( ClickAbsorber::RELEASED );
        m_fields[RecountStatPage::subtotalFoundIndex]->SetState ( ClickAbsorber::RELEASED );
        m_fields[RecountStatPage::subtotalNotFoundIndex]->SetState ( ClickAbsorber::RELEASED );
    }

    for ( unsigned int i = 0; i < RecountStatPage::numFields; ++i )
    {
        switch ( m_fields[i]->GetState() )
        {
            default:
                break;

            case ClickAbsorber::PUSHED:
                {
                    if ( m_row == 1 )
                    {
                        statusV[i] = ClickAbsorber::PUSHED;
                    }
                    else if ( statusV[i] == ClickAbsorber::RELEASED )
                    {
                        statusV[i] = ClickAbsorber::TRANSITIONAL;
                    }
                }
                break;

            case ClickAbsorber::TRANSITIONAL:
                {
                    statusV[i] = ClickAbsorber::TRANSITIONAL;
                }
                break;

            case ClickAbsorber::RELEASED:
                {
                    if ( m_row == 1 )
                    {
                        statusV[i] = ClickAbsorber::RELEASED;
                    }
                    else if ( statusV[i] == ClickAbsorber::PUSHED )
                    {
                        statusV[i] = ClickAbsorber::TRANSITIONAL;
                    }
                }
                break;
        }

        accumV[i] += m_fields[i]->getData();
        activeV[i] += ( m_fields[i]->GetState() == ClickAbsorber::PUSHED ) ? 0 : m_fields[i]->getData();

        std::ostringstream oss;

        if ( m_fields[i]->GetState() == ClickAbsorber::PUSHED
                && ( i == RecountStatPage::subtotalFoundIndex || i == RecountStatPage::subtotalNotFoundIndex
                     || i == RecountStatPage::totalIndex ) )
        {
            oss << ConfigBridge::zerosReplacementInTotals;
        }
        else
        {
            oss << m_fields[i]->getData();
        }

        m_fields[i]->set_label ( oss.str() );
    }
}

void RecountSession::OnStatusChanged ( int x, int y, ClickAbsorber::STATE state )
{
    if ( m_isTotals )
    {
        m_thePage->OnStatusChanged ( x, y, state );
        return;
    }

    ClickAbsorber::STATE newState = ( state == ClickAbsorber::PUSHED ) ? ClickAbsorber::RELEASED : ClickAbsorber::PUSHED;

#define	SELECT_FIELDS(START, END)               \
    for ( size_t i = START; i < END; ++i )      \
    {                                                                   \
	m_fields[i]->SetState ( (ConfigBridge::zerosFollowSelection || m_fields[i]->getData() > 0 ) ? newState : ClickAbsorber::RELEASED ); \
    }

    if ( ( size_t ) x == RecountStatPage::totalIndex )
    {
        SELECT_FIELDS ( RecountStatPage::startOfFoundVotersIndex, RecountStatPage::subtotalFoundIndex )
            SELECT_FIELDS ( RecountStatPage::startOfNotFoundVotersIndex, RecountStatPage::subtotalNotFoundIndex )
            }
    else if ( ( size_t ) x == RecountStatPage::subtotalFoundIndex )
    {
        SELECT_FIELDS ( RecountStatPage::startOfFoundVotersIndex, RecountStatPage::subtotalFoundIndex )
            }
    else if ( ( size_t ) x == RecountStatPage::subtotalNotFoundIndex )
    {
        SELECT_FIELDS ( RecountStatPage::startOfNotFoundVotersIndex, RecountStatPage::subtotalNotFoundIndex )
            }
    else
    {
        m_fields[x]->SetState ( newState );
    }

#undef	SELECT_FIELDS

    m_thePage->Refresh();
}

void RecountSession::SetTooltip ( const char * tooltip )
{
    m_sessionName.set_tooltip_text ( tooltip );
}

void RecountSession::SetActive ( bool active )
{
    if ( active )
    {
        const Glib::PropertyProxy<guint> & rows = m_thePage->property_n_rows();

        if ( m_startRow + m_row > ( int ) rows.get_value() )
        {
            const Glib::PropertyProxy<guint> & columns = m_thePage->property_n_columns();
            m_thePage->resize ( m_startRow + m_row, columns.get_value() );
        }
    }

    if ( active )
    {
        m_thePage->Attach ( m_sessionName, 0, 1, m_startRow + m_row, m_startRow + 1 + m_row );
    }
    else
    {
        m_thePage->remove ( m_sessionName );
    }

    const std::list<std::string> & labelsList = m_thePage->GetLabelsList();

    std::list<std::string>::const_iterator itLabels = labelsList.begin();

    ++itLabels; //Skip empty label

    int iFields = 0, iPos = 1;

    for ( ; itLabels != labelsList.end(); ++itLabels, ++iFields, ++iPos )
    {
        if ( *itLabels == RecountStatPage::emptyLabel )
        {
            continue;
        }

        if ( active )
        {
            m_thePage->Attach ( *m_fields[iFields], iPos, 1 + iPos, m_startRow + m_row, m_startRow + 1 + m_row );
        }
        else
        {
            m_thePage->remove ( *m_fields[iFields] );
        }
    }

    m_isVisible = active;
}

void RecountSession::SetStartRow ( int row )
{
    m_startRow = row;
}

void RecountSession::SetRow ( int row )
{

    if ( !m_toRedraw )
    {
        m_toRedraw = ( m_row != row );
    }

    m_row = row;
}

void RecountSession::Draw()
{
    if ( m_toRedraw )
    {
        if ( m_isVisible )
        {
            SetActive ( false );
        }

        SetActive ( true );
    }
}


void RecountSession::GetForPersistence ( std::list< std::pair<int, int> > & deleteQueue )
{
    // Go over data-only (not total) fields...
    // "Found" fields
    for ( size_t i = RecountStatPage::startOfFoundVotersIndex; i < RecountStatPage::subtotalFoundIndex; ++i )
    {
        if ( m_fields[i]->GetState() == ClickAbsorber::PUSHED && m_fields[i]->getData() > 0 )
        {
            deleteQueue.push_back ( std::pair<int, int> ( i, m_row - 1 ) ); // convert rows to 0-based
        }
    }

    // "Not Found" fields
    for ( size_t i = RecountStatPage::startOfNotFoundVotersIndex; i < RecountStatPage::subtotalNotFoundIndex; ++i )
    {
        if ( m_fields[i]->GetState() == ClickAbsorber::PUSHED && m_fields[i]->getData() > 0 )
        {
            deleteQueue.push_back ( std::pair<int, int> ( i - 1, m_row - 1 ) );  // convert rows to 0-based
        }
    }
}

int RecountSession::GetTotal()
{
    return m_fields[RecountStatPage::totalIndex]->getData();
}

int RecountSession::GetMaxMax()
{
    // non-synchronized access as read-only
    return m_maxMax;
}

