#include <Configuration/MachineModelEnum.hxx>
#include <Log/SMTTLogManager.h>
#include "RecountStatPage.h"
#include "ConfigBridge.h"
#include <Widgets/SmartmaticBasicLabel.hxx>
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>
#include <Configuration/s-m-t-t-g-u-i-conf-manager.h>
#include <Functionalities/RecountFunctionality.h>
#include <Resources/election-string-resources-manager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate
#define COLS_HEADER_ADJUSTMENT 50

using namespace Smartmatic::Configuration;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::GUI::Widgets::Recount;

const size_t RecountStatPage::numFields = 17;
const size_t RecountStatPage::MaxVoterTypes = 7;
const size_t RecountStatPage::startOfFoundVotersIndex = 0;
const char * RecountStatPage::emptyLabel = " ";

const size_t RecountStatPage::subtotalFoundIndex = RecountStatPage::startOfFoundVotersIndex + RecountStatPage::MaxVoterTypes;
const size_t RecountStatPage::startOfNotFoundVotersIndex = RecountStatPage::subtotalFoundIndex + 1;
const size_t RecountStatPage::subtotalNotFoundIndex = RecountStatPage::startOfNotFoundVotersIndex + RecountStatPage::MaxVoterTypes;
const size_t RecountStatPage::totalIndex = RecountStatPage::subtotalNotFoundIndex + 1;

static std::vector<SmartmaticBasicLabel *> LABELS;

RecountStatPage::RecountStatPage ( const std::list<std::string> & voterTypes )
    : m_recountSessions ( 0 ), m_recountTotals ( NULL )
{
    logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.Recount.RecountStatPage",	GETTEXT_PACKAGE );

    set_col_spacings ( ConfigBridge::recountStatTableColSpacing );
    set_row_spacings ( ConfigBridge::recountStatTableRowSpacing );

    resize ( 2, numFields + 1 );

    // First row
    if ( ConfigBridge::extendedView )
    {
        SmartmaticBasicLabel * l0 = Gtk::manage ( new SmartmaticBasicLabel ( emptyLabel ) );
        Attach ( *l0, 0, 1, 0, 1 );
        SmartmaticBasicLabel * l1 = Gtk::manage ( new SmartmaticBasicLabel() );
        LabelConfiguration::SetLabelConfiguration ( l1, ConfigBridge::recountStatExtendedViewHeader );
        l1->set_text ( _ ( "Smartmatic.SAES.GUI.Widgets.RecountWidget.Stat.Found" ) );
        l1->set_justify ( Gtk::JUSTIFY_CENTER );
        Attach ( *l1, 1 + RecountStatPage::startOfFoundVotersIndex, 1 + startOfNotFoundVotersIndex, 0, 1 );
        SmartmaticBasicLabel * l2 = Gtk::manage ( new SmartmaticBasicLabel() );
        LabelConfiguration::SetLabelConfiguration ( l2, ConfigBridge::recountStatExtendedViewHeader );
        l2->set_text ( _ ( "Smartmatic.SAES.GUI.Widgets.RecountWidget.Stat.NotFound" ) );
        l2->set_justify ( Gtk::JUSTIFY_CENTER );
        Attach ( *l2, 1 + startOfNotFoundVotersIndex, 1 + totalIndex, 0, 1 );
    }

    set_col_spacing ( startOfFoundVotersIndex, ConfigBridge::recountStatSessionNameToFoundDataSpacing );

    if ( ConfigBridge::extendedView )
    {
        set_col_spacing ( startOfNotFoundVotersIndex, ConfigBridge::recountFoundToNotFoundDataSpacing );
        set_col_spacing ( totalIndex, ConfigBridge::recountNotFoundDataToTotalSpacing );
    }

    std::list<std::string> resourceVoterList;
    std::list<std::string>::const_iterator rit;

    for ( rit = voterTypes.begin();
            rit != voterTypes.end();
            ++rit )
    {
        resourceVoterList.push_back ( Smartmatic::SAES::Resources::ElectionStringResourcesManager::getInstance()->getResource ( *rit ) );
    }

    // Second row
    m_labelsList.push_back ( emptyLabel );
    m_labelsList.insert ( m_labelsList.end(), resourceVoterList.begin(), resourceVoterList.end() );

    for ( int i = 0; i < static_cast<int>(RecountStatPage::MaxVoterTypes - resourceVoterList.size()); ++i )
    {
        m_labelsList.push_back ( emptyLabel );
    }

    m_labelsList.push_back ( _ ( "Smartmatic.SAES.GUI.Widgets.RecountWidget.Stat.SubTotal" ) );

    if ( ConfigBridge::extendedView )
    {
        m_labelsList.insert ( m_labelsList.end(), resourceVoterList.begin(), resourceVoterList.end() );

        for ( int i = 0; i < static_cast<int>(RecountStatPage::MaxVoterTypes - resourceVoterList.size()); ++i )
        {
            m_labelsList.push_back ( emptyLabel );
        }

        m_labelsList.push_back ( _ ( "Smartmatic.SAES.GUI.Widgets.RecountWidget.Stat.SubTotal" ) );
        m_labelsList.push_back ( _ ( "Smartmatic.SAES.GUI.Widgets.RecountWidget.Stat.SessionTotal" ) );
    }

    int iPos = startOfFoundVotersIndex;

    for ( std::list<std::string>::iterator itLabels = m_labelsList.begin(); itLabels != m_labelsList.end(); ++itLabels, iPos++ )
    {
        if ( *itLabels == emptyLabel )
        {
            continue;
        }

        std::string str = *itLabels;

        if ( str.size() && str[str.size() - 1] == ' ' )
        {
            str.erase ( str.size() - 1, 1 );
        }

        SmartmaticBasicLabel * l = Gtk::manage ( new SmartmaticBasicLabel() );
        LabelConfiguration::SetLabelConfiguration ( l, ConfigBridge::recountStatColumnHeader );

        l->set_text ( str );
        l->set_alignment ( Gtk::ALIGN_CENTER );
        l->set_justify ( Gtk::JUSTIFY_CENTER );
        l->set_line_wrap(true);

        Attach ( *l, 0 + iPos, 1 + iPos, 1, 2 );

        LABELS.push_back(l);
    }

    RecountSession::SetStartRow ( 2 );

    Glib::signal_timeout().connect_once(sigc::mem_fun(*this, &RecountStatPage::adjustTableColumnSize), 10);
}

void RecountStatPage::adjustTableColumnSize()
{
    bool isViuMachineModel = SMTTGUIConfigurationManager::getInstance()
      ->getSmartmaticGUIMachineModelConfiguration().getId() == EnumToString(PM_VIU805);
    double guiReconfigurationFactor = 1;
    std::vector<SmartmaticBasicLabel *>::iterator it;

    std::cout << std::endl;

    if (isViuMachineModel)
      guiReconfigurationFactor = SMTTGUIConfigurationManager::getInstance()->
        getConfiguration()->getSmartmaticGUIMachineModelConfiguration().getGuiReconfigurationFactor();

    for (it = LABELS.begin(); it != LABELS.end(); ++it)
    {
      double colHeaderSize = ConfigBridge::extendedView ? ConfigBridge::recountStatTableColHeadersExtendedViewSize :
        ConfigBridge::recountStatTableColHeadersSimpleViewSize;
      Glib::RefPtr<Pango::Layout> layout = (*it)->get_layout();

      if ((*it)->get_text() == _("Smartmatic.SAES.GUI.Widgets.RecountWidget.Stat.SubTotal") ||
      (*it)->get_text() == _("Smartmatic.SAES.GUI.Widgets.RecountWidget.Stat.SessionTotal"))
      {
        colHeaderSize += COLS_HEADER_ADJUSTMENT;
      }

      colHeaderSize *= guiReconfigurationFactor;

      layout->set_width((colHeaderSize * Pango::SCALE));
      (*it)->set_size_request(colHeaderSize, -1);
      queue_resize();
    }
}

RecountStatPage::~RecountStatPage()
{
    for ( std::list<RecountSession *>::iterator it = m_recountSessions.begin(); it != m_recountSessions.end(); ++it )
    {
        delete *it;
    }

    delete m_recountTotals;
}

void RecountStatPage::Attach ( Widget & child, guint left_attach, guint right_attach, guint top_attach, guint bottom_attach )
{
    attach ( child, left_attach, right_attach, top_attach, bottom_attach, Gtk::SHRINK | Gtk::FILL, Gtk::SHRINK | Gtk::FILL );
    child.show_all();
    child.show();
}

void RecountStatPage::OnStatusChanged ( int x, int y, ClickAbsorber::STATE state )
{
    int i = 0;

    for ( std::list<RecountSession *>::iterator it = m_recountSessions.begin(); it != m_recountSessions.end(); ++it, ++i )
    {
        ( *it )->OnStatusChanged ( x, 0, state ); // y=0 for total
    }

    Refresh();
}

void RecountStatPage::Refresh()
{
    std::vector<int> accumV ( numFields );	// accumulates all the data vertically
    std::vector<int> activeV ( numFields ); // accumulates only non-erased data
    std::vector<int> maxV ( numFields ); // accumulates only the data for "Totals" fields
    std::vector<ClickAbsorber::STATE> statusV ( numFields ); // intermediate session-fields state predetermine

    for ( std::list<RecountSession *>::iterator it = m_recountSessions.begin(); it != m_recountSessions.end(); ++it )
    {
        ( *it )->Refresh ( accumV, activeV, maxV, statusV );
    }

    m_recountTotals->PopulateTotals ( accumV, activeV, maxV, statusV );
}

void RecountStatPage::Draw()
{
    for ( std::list<RecountSession *>::iterator it = m_recountSessions.begin(); it != m_recountSessions.end(); ++it )
    {
        ( *it )->Draw();
    }

    m_recountTotals->Draw();

    show_all_children ( true );
    show_all();
    show();
}

void RecountStatPage::IncVote ( const int sessNum, const std::string & sessName, bool onThisStick, const int index )
{
    bool newSession = false;

    RecountSession * sess;

    if ( m_recountSessions.size() < ( size_t ) sessNum )
    {
        std::stringstream ss;
        ss << _ ( "Smartmatic.SAES.GUI.Widgets.RecountWidget.Stat.Session" ) << " " << sessNum;
        sess = new RecountSession ( this, ss.str().c_str(), sessName.c_str(), sessNum, false );
        m_recountSessions.push_back ( sess );
        newSession = true;
    }
    else
    {
        std::list<class RecountSession *>::iterator itSessions = m_recountSessions.begin();
        std::advance ( itSessions, sessNum - 1 );
        sess = * ( itSessions );
    }

    if ( index > -1 )
    {
        sess->IncField ( index );
    }

    // Totals
    if ( !m_recountTotals )
    {
        m_recountTotals = new RecountSession ( this, _ ( "Smartmatic.SAES.GUI.Widgets.RecountWidget.Stat.Total" ),
                                               "", m_recountSessions.size() + 2, true );
    }
    else
    {
        if ( newSession )
        {
            m_recountTotals->SetRow ( m_recountSessions.size() + 2 );
        }
    }
}

std::list<std::string> & RecountStatPage::GetLabelsList()
{
    return m_labelsList;
}

void RecountStatPage::Update ( const std::list< std::pair<int, int> > & updates,
                               const std::list<std::string> & updateSessionNames )
{
    std::list< std::pair<int, int> >::const_iterator it = updates.begin();
    std::list<std::string>::const_iterator itNames = updateSessionNames.begin();

    for ( ; it != updates.end(); ++it, ++itNames )
    {
        IncVote ( it->second, *itNames, true, it->first );
    }

    Draw();
    Refresh();
    Glib::signal_timeout().connect_once(sigc::mem_fun(*this, &RecountStatPage::Draw), 100);
}

void RecountStatPage::GetForPersistence ( std::list< std::pair<int, int> > & deleteQueue )
{
    // non-synchronized access to...
    for ( std::list<RecountSession *>::iterator it = m_recountSessions.begin(); it != m_recountSessions.end(); ++it )
    {
        ( *it )->GetForPersistence ( deleteQueue );
    }
}

int RecountStatPage::GetTotal()
{
    // non-synchronized access to...
    return m_recountTotals ? m_recountTotals->GetTotal() : 0;
}

int RecountStatPage::GetMaxMax()
{
    // non-synchronized access to...
    return m_recountTotals ? m_recountTotals->GetMaxMax() : 0;
}
