/**
 * @file	ReportInstallWidget.hxx
 * @brief	report install widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#ifndef REPORTINSTALLWIDGET_HXX_
#define REPORTINSTALLWIDGET_HXX_

#include <gtkmm.h>
#include <Printing/InstallationPrintDocument.h>
#include <Gui/Widgets/GenericPrintingWidget.hxx>
#include <Widgets/StepWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	ReportInstallWidget
                 * @brief	Report install widget.
                 * @author	Youssef.tourkmani
                 * @date	01/11/2012
                 */
                class ReportInstallWidget: public Smartmatic::GUI::Widgets::StepWidget
                {
                    public:
                        /**
                         * @fn	ReportInstallWidget::ReportInstallWidget ( GenericPrintingWidget * genericWidget );
                         * @brief	Constructor.
                         * @author	Yadickson Soto
                         * @date	01/11/2012
                         * @param [in,out]	genericWidget	the generic printing widget
                         */
                        explicit ReportInstallWidget ( GenericPrintingWidget * genericWidget );
                        /**
                         * @fn	virtual ReportInstallWidget::~ReportInstallWidget();
                         * @brief	Destructor.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        virtual ~ReportInstallWidget();
                        /**
                         * @fn	void ReportInstallWidget::start ( bool createBarcode, bool showRetry, bool showCancel );
                         * @brief	Starts the given create barcode.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @param	createBarcode	(optional) the create barcode.
                         * @param 	showRetry show retry
                         * @param 	showCancel show cancel
                         */
                        void start ( bool createBarcode, bool showRetry, bool showCancel );
                        /**
                         * @fn	bool ReportInstallWidget::getStatus();
                         * @brief	Gets the status.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	true if it succeeds, false if it fails.
                         */
                        bool getStatus();
                        /**
                         * @fn	virtual std::string ReportInstallWidget::getTitleText();
                         * @brief	virtual method getter title.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         * @return	title.
                         */
                        virtual std::string getTitleText();

                    private:

                        GenericPrintingWidget * genericWidget;	///< The generic printing widget
                        Smartmatic::SAES::Printing::InstallationPrintDocument * installationPrintDocument;	///< The installation print document
                        static Smartmatic::Log::ISMTTLog * logger; /**<logger*/ ///< The logger

                    protected:
                        /**
                         * @fn	virtual void ReportInstallWidget::initialize();
                         * @brief	Initializer method.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        virtual void initialize();
                        /**
                         * @fn	virtual void ReportInstallWidget::dispose();
                         * @brief	virtual method stop.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        virtual void dispose();
                        /**
                         * @fn	void ReportInstallWidget::end();
                         * @brief	Ends this object.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void end();
                };
            }
        }
    }
}

#endif /* REPORTINSTALLWIDGET_HXX_ */
