/**
 * @file   ReportPrintingVMWidget.hxx
 * @brief  Declaration of ReportPrintingVMWidget class.
 * @author manuel.arguelles
 * @date   Jun 13, 2017
 */

#ifndef _REPORT_PRINTING_VM_WIDGET_H_
#define _REPORT_PRINTING_VM_WIDGET_H_

#include <Operation/Devices/PrinterController.hxx>
#include <Printing/ReportPrintingController.hxx>
#include <Widgets/SmartmaticBasicHBox.hxx>
#include <Widgets/SmartmaticBasicVBox.hxx>
#include <Widgets/StepWidget.hxx>
#include <Widgets/smartmatic-button.h>
#include <sigc++/sigc++.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                class ProgressWidget;

                /**
                 * @class  ReportPrintingVMWidget
                 * @brief  Widget to print the report in the vm.
                 * @author manuel.arguelles
                 * @date   Jun 13, 2017
                 */
                class ReportPrintingVMWidget : public Smartmatic::GUI::Widgets::StepWidget
                {
                    public:
                        /**
                         * @brief  Class constructor.
                         * @author manuel.arguelles
                         * @date   Jun 13, 2017
                         */
                        explicit ReportPrintingVMWidget(ProgressWidget* progress);

                        /**
                         * @brief  Class destructor.
                         * @author manuel.arguelles
                         * @date   Jun 13, 2017
                         */
                        virtual ~ReportPrintingVMWidget();

                    private:
                        /**
                         * @brief  Start printing process.
                         * @author manuel.arguelles
                         * @date   Jun 20, 2017
                         */
                        void onPrintButtonClicked();

                        /**
                         * @brief  Display printing errors.
                         * @author manuel.arguelles
                         * @date   Jun 20, 2017
                         */
                        void onPrintError(const std::string& message);

                        /**
                         * @brief  Display printing complete.
                         * @author manuel.arguelles
                         * @date   Jun 20, 2017
                         */
                        void onPrintDone();

                        /**
                         * @brief  Shutdown the machine.
                         * @author manuel.arguelles
                         * @date   Mar  8, 2018
                         */
                        void onShutdownButtonClicked();

                    private:
                        ProgressWidget*                                         m_progress;
                        Smartmatic::SAES::Printing::ReportPrintingController    m_report;
                        Smartmatic::GUI::Widgets::SmartmaticButton              m_printButton;
                        Smartmatic::GUI::Widgets::SmartmaticButton              m_shutdownButton;
                        Smartmatic::GUI::Widgets::SmartmaticBasicVBox           m_mainVBox;
                        Smartmatic::GUI::Widgets::SmartmaticBasicHBox           m_buttonHBox;
                        Smartmatic::GUI::Widgets::SmartmaticBasicHBox           m_imageHBox;
                        Smartmatic::GUI::Widgets::SmartmaticBasicVBox           m_centralVBox;
                        Smartmatic::SAES::Operation::Devices::PrinterController m_printerController;
                };
            }
        }
    }
}

#endif /* _REPORT_PRINTING_VM_WIDGET_H_ */
