/**
 * @file	ResultWidget.cxx
 * @brief	result widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */

#include "ResultWidget.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Environment/Configurations/resource-path-provider.h>
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Environment;
using namespace Smartmatic::SAES::Voting;
using namespace Smartmatic::Log;
using namespace Smartmatic::GUI::Configuration;

ISMTTLog * ResultWidget::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.ResultWidget", GETTEXT_PACKAGE );

ResultWidget::ResultWidget ( std::string code )
    : EventBox()
{
    this->code = code;
    this->mainFrame = NULL;
    this->labelFrame = NULL;
    this->imageFrame = NULL;
    this->hbox = NULL;
    this->label = NULL;
    this->image = NULL;
    this->status = true;
    this->initialize();
    add ( *mainFrame );
}

ResultWidget::~ResultWidget()
{
    dispose();
}

void ResultWidget::initialize()
{
    dispose();
    Glib::RefPtr<Gtk::Builder> builder;
    std::string gladeFile;
    gladeFile = ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, "ui/ResultWidget.glade" );

    try
    {
        builder = Gtk::Builder::create_from_file ( gladeFile );
    }
    catch ( const Glib::FileError & ex )
    {
        logger->Debug ( "FATAL - ResultWidget Initialize" );
    }

    builder->get_widget ( "main-frame", mainFrame );
    builder->get_widget ( "label-frame", labelFrame );
    builder->get_widget ( "image-frame", imageFrame );
    builder->get_widget ( "hbox", hbox );
    builder->get_widget ( "label", label );
    builder->get_widget ( "image", image );

    imageFrame->set_no_show_all();
    imageFrame->set_visible ( false );

    this->set_events ( Gdk::BUTTON_PRESS_MASK );
    this->signal_button_release_event().connect ( sigc::mem_fun ( *this, &ResultWidget::clicked ) );
}

void ResultWidget::dispose()
{
    this->remove();

    if ( mainFrame )
    {
        delete mainFrame;
        mainFrame = NULL;
    }

    if ( labelFrame )
    {
        delete labelFrame;
        labelFrame = NULL;
    }

    if ( imageFrame )
    {
        delete imageFrame;
        imageFrame = NULL;
    }

    if ( hbox )
    {
        delete hbox;
        hbox = NULL;
    }

    if ( image )
    {
        delete image;
        image = NULL;
    }

    if ( label )
    {
        delete label;
        label = NULL;
    }
}

void ResultWidget::setText ( std::string text, bool center )
{
    if ( center )
    {
        label->set_justify ( Gtk::JUSTIFY_CENTER );
        label->set_alignment ( 0.5, 0.5 );
    }
    else
    {
        label->set_justify ( Gtk::JUSTIFY_RIGHT );
        label->set_alignment ( 0, 0.5 );
    }

    label->set_text ( text );
}

void ResultWidget::setStatus ( bool status )
{
    this->status = status;
    std::string iconFile;
    iconFile = ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, ( status ? "ui/result-ok.png" : "ui/result-error.png" ) );
    image->set ( iconFile );
    imageFrame->set_visible ( true );
}

std::string ResultWidget::getText()
{
    return label->get_text();
}

bool ResultWidget::getStatus()
{
    return status;
}

void ResultWidget::addResult ( const std::string & text, bool status )
{
    Result result;

    result.message = text;
    result.status = status;
    list.push_back ( result );
}

std::list <ResultWidget::Result> & ResultWidget::getResult()
{
    return list;
}

std::string ResultWidget::getCode()
{
    return code;
}

void ResultWidget::setLabelConfig ( Smartmatic::GUI::Configuration::LabelConfiguration & labelConf )
{
    LabelConfiguration::SetLabelConfiguration ( label, labelConf );
}

bool ResultWidget::clicked ( GdkEventButton * event )
{
    signal.emit ( this );
    return true;
}

sigc::signal<void, ResultWidget * > ResultWidget::getSignalClick()
{
    return signal;
}

