/**
 * @file SearchAndMonitorDevicesWidget.hxx
 * @brief Header class search and mount device monitor pool widget
 * @date 27/07/2015
 * @author Yadickson Soto
 */

#ifndef SEARCH_AND_MONITOR_DEVICES_WIDGET_HXX_
#define SEARCH_AND_MONITOR_DEVICES_WIDGET_HXX_

#include <Widgets/StepWidget.hxx>
#include <Gui/Widgets/ProgressWidget.hxx>
#include <System/SafeThread.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	SearchAndMonitorDevicesWidget
                 * @brief	Class able diagnostic widget.
                 * @author	Yadickson Soto
                 * @date	27/07/2015
                 */
                class SearchAndMonitorDevicesWidget : public Smartmatic::GUI::Widgets::StepWidget,
                    private Smartmatic::System::SafeThread
                {
                    public:

                        /**
                         * @fn	SearchAndMonitorDevicesWidget ();
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	27/07/2015
                         */
                        SearchAndMonitorDevicesWidget ();

                        /**
                         * @fn	virtual ~SearchAndMonitorDevicesWidget();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	27/07/2015
                         */
                        virtual ~SearchAndMonitorDevicesWidget();

                        /**
                         * @fn	virtual void initialize();
                         * @brief	Initializes this object.
                         * @author	Yadickson Soto
                         * @date	27/07/2015
                         */
                        virtual void initialize();

                    protected:

                        /**
                         * @fn	    virtual bool process ();
                         * @brief	Callback from thread to search and mount device monitor pool.
                         * @author	Yadickson Soto
                         * @date	27/07/2015
                         * @return false, only call one time
                         */
                        virtual bool process ();

                        /**
                         * @fn	    void endFindDevices();
                         * @brief	Callback from thread to check if mount media devices.
                         * @author	Yadickson Soto
                         * @date	27/07/2015
                         */
                        void endFindDevices();

                    private:

                        Glib::Dispatcher endSignal; ///< The signal to end search devices
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                        Smartmatic::SAES::GUI::Widgets::ProgressWidget * widget;	///< The widget
                };
            }
        }
    }
}
#endif /* SEARCH_AND_MONITOR_DEVICES_WIDGET_HXX_ */
