/**
 * @file CheckNetworkWidget.cxx
 * @brief Body of the widget which checks the network device
 * @date 08/04/2014
 * @author Yadickson Soto
 */

#include <Gui/Widgets/Transmission/CheckNetworkWidget.hxx>
#include <Operation/MachineOperationManager.hxx>
#include <Operation/Monitor/DeviceTypeMonitorPool.hxx>

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::Common::Configuration;
using namespace Smartmatic::SAES::Common::Operation::Monitor;
using namespace Smartmatic::SAES::Operation::Monitor;

CheckNetworkWidget::CheckNetworkWidget ( GenericWidget * widget )
    : BasicTransmissionWidget ( widget, true, true )
{
    setAccessibleName ( "CheckNetworkWidget" );
}

CheckNetworkWidget::~CheckNetworkWidget()
{
    connNetworkInterface.disconnect();
}

void CheckNetworkWidget::initialize()
{
    widget->setImage ( "ui/check-network-device.gif" );
    widget->setInfoText ( N_ ( "Checking network interface, please wait." ) );
    BasicTransmissionWidget::initialize();
}

bool CheckNetworkWidget::runProcess()
{
    return MachineOperationManager::getInstance()->checkNetworkDevice();
}

void CheckNetworkWidget::showSuccessMessage()
{
    connNetworkInterface.disconnect();
    end();
}

void CheckNetworkWidget::showErrorMessage()
{
    showButtons ( true, false );
    widget->setImage ( "ui/check-network-device-error.gif" );
    widget->setInfoText ( N_ ( "Please connect the network cable to the President Machine." ) );

    connNetworkInterface.disconnect();
    connNetworkInterface = DeviceTypeMonitorPool::getInstance()->getDeviceChangedSignal().connect ( sigc::mem_fun ( *this, &CheckNetworkWidget::deviceChange ) );
}

void CheckNetworkWidget::deviceChange ( DeviceTypeMonitor * deviceTypeMonitor )
{
    if ( deviceTypeMonitor != NULL && deviceTypeMonitor->getType() == DeviceType::CONFIGURATION_ETHERNET && deviceTypeMonitor->getNumberOfDevices() != 0 )
    {
        connNetworkInterface.disconnect();
        showButtons ( true, false );
        end();
    }
}
