/**
 * @file SendResultsPackageWidget.cxx
 * @brief Body class of the send results package widget
 * @date 07/04/2014
 * @author Yadickson Soto
 */

#include <Gui/Widgets/Transmission/SendResultsPackageWidget.hxx>
#include <Operation/MachineOperationManager.hxx>

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::Voting::Status;

SendResultsPackageWidget::SendResultsPackageWidget ( GenericWidget * widget )
    : BasicTransmissionWidget ( widget )
{
    setAccessibleName ( "SendResultsPackageWidget" );
}

SendResultsPackageWidget::~SendResultsPackageWidget()
{

}

void SendResultsPackageWidget::initialize()
{
    widget->setImage ( "ui/send-results-package.gif" );
    widget->setInfoText ( N_ ( "Sending Results Package, please wait." ) );

    ResultsPackageTransmissionStateConfiguration state = MachineOperationManager::getInstance()->getOperationStatus()->getElectionStatusWrapper()->getResultsPackageTransmissionState ();

    switch ( state )
    {
        default:
        case ResultsPackageTransmissionStateConfiguration::ELECTION_STATUS_FIRSTTIME:
            widget->setInfoFooter ( " " );
            break;

        case ResultsPackageTransmissionStateConfiguration::ELECTION_STATUS_TRANSMITTED:
            widget->setInfoFooter ( N_ ( "Re-transmitting" ) );
            break;

        case ResultsPackageTransmissionStateConfiguration::ELECTION_STATUS_NOTTRANSMITTED:
            widget->setInfoFooter ( N_ ( "Retrying transmission" ) );
            break;
    }

    BasicTransmissionWidget::initialize();
}

bool SendResultsPackageWidget::runProcess()
{
    return MachineOperationManager::getInstance()->sendResultsPackages ( messageResponse );
}

void SendResultsPackageWidget::showSuccessMessage()
{
    widget->setImage ( "ui/send-results-package-ok.gif" );
    widget->setInfoText ( N_ ( "Results Package Transmission completed successfully." ) );
    widget->setInfoFooter ( " " );
    Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &BasicTransmissionWidget::end ), 1000 );
}

void SendResultsPackageWidget::showErrorMessage()
{
    showButtons ( true, true );
    widget->setImage ( "ui/send-results-package-error.gif" );
    widget->setInfoText ( messageResponse );
    widget->setInfoFooter ( " " );
}
