/**
 * @file VMAuthenticationWidget.hxx
 * @brief Header class vm authentication widget
 * @date 31/03/2012
 * @author Yadickson Soto
 */

#ifndef VMAUTHENTICATIONWIDGET_HXX_
#define VMAUTHENTICATIONWIDGET_HXX_

#include "AuthenticationWidget.hxx"
#include <Operation/Devices/Polling/AlarmPolling.hxx>
#include <sigc++/sigc++.h>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	VMAuthenticationWidget
                 * @brief	Class vm authentication widget.
                 * @author	Yadickson Soto
                 * @date	31/03/2012
                 */
                class VMAuthenticationWidget : public AuthenticationWidget
                {
                    public:
                        /**
                         * @brief  Class constructor.
                         * @author Yadickson Soto
                         * @date   31/03/2012
                         * @param  info The polling place information.
                         * @param  authenticator The Authenticator object.
                         */
                        VMAuthenticationWidget(PollingPlaceInfoWidget* info,
                                               SAES::Operation::Authenticator::IAuthenticator* authenticator);
                        /**
                         * @brief  Class destructor.
                         * @author Yadickson Soto
                         * @date   31/03/2012
                         */
                        virtual ~VMAuthenticationWidget();

                        /**
                         * @brief  Initializer method.
                         * @author Yadickson Soto
                         * @date   04/08/2015
                         */
                        virtual void initialize();

                        /**
                         * @brief  Refresh method.
                         * @author Yadickson Soto
                         * @date   04/08/2015
                         */
                        virtual void refresh();

                    protected:

                        /**
                         * @brief  Clear the alarm.
                         * @author Yadickson Soto
                         * @date   17/10/2012
                         * @param  status The alarm button status
                         */
                        virtual void clearAlarm(SAES::Operation::Devices::AlarmPolling::AlarmButtonStatus status);

                        /**
                         * @brief  Stop the widget.
                         * @author Yadickson Soto
                         * @date   17/10/2012
                         */
                        virtual void stop();

                    private:

                        /**
                         * @brief  Clear the alarm.
                         * @author manuel.arguelles
                         * @date   Jun 29, 2017
                         */
                        void clearAlarm();

                    private:

                        Gtk::Alignment*                   m_alignmentKeypad;
                        sigc::connection                  m_connAlarm;
                        static Smartmatic::Log::ISMTTLog* m_logger;
                };
            }
        }
    }
}

#endif /* VMAUTHENTICATIONWIDGET_HXX_ */
