/**
 * @file	VMInstallationConfirmation.hxx
 * @brief	voting machine installation confirmation class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#ifndef VMINSTALLATIONCONFIRMATION_HXX_
#define VMINSTALLATIONCONFIRMATION_HXX_

#include <gtkmm.h>
#include <Widgets/smartmatic-button.h>
#include <Widgets/SmartmaticBasicFrame.hxx>
#include <Widgets/StepWidget.hxx>
#include <Gui/Widgets/PollingPlaceInfoWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	VMInstallationConfirmation
                 * @brief	Virtual memory installation confirmation.
                 * @author	Youssef.tourkmani
                 * @date	01/11/2012
                 */
                class VMInstallationConfirmation : public Smartmatic::GUI::Widgets::StepWidget
                {
                    public:
                        /**
                         * @fn	VMInstallationConfirmation::VMInstallationConfirmation();
                         * @brief	Default constructor.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        explicit VMInstallationConfirmation ( PollingPlaceInfoWidget * pollingPlaceInfoWidget );
                        /**
                         * @fn	virtual VMInstallationConfirmation::~VMInstallationConfirmation();
                         * @brief	Destructor.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        virtual ~VMInstallationConfirmation();

                        /**
                         * @fn	virtual void refresh();
                         * @brief	refresh widget method.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         */
                        virtual void refresh();

                        /**
                         * @fn	void start();
                         * @brief	method config widget, show button or timemout view information.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         */
                        void start();

                    private:

                        /**
                         * @fn	void VMInstallationConfirmation::initialize();
                         * @brief	Initializes this object.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void initialize();
                        /**
                         * @fn	void VMInstallationConfirmation::dispose();
                         * @brief	Performs application-defined tasks associated with freeing, releasing, or resetting
                         * 				unmanaged resources.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void dispose();
                        /**
                         * @fn	void VMInstallationConfirmation::end();
                         * @brief	Callback end process with click ok or timeout
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         */
                        void end();

                        Smartmatic::GUI::Widgets::SmartmaticBasicFrame * mainFrame; ///< frame configuration
                        Smartmatic::GUI::Widgets::SmartmaticBasicFrame * infoFrame; ///< information frame
                        Smartmatic::GUI::Widgets::SmartmaticButton * buttonOk;   ///< ok button
                        PollingPlaceInfoWidget * pollingPlaceInfoWidget; ///< info frame polling place

                        static Smartmatic::Log::ISMTTLog * logger;  ///< logger
                };
            }
        }
    }
}

#endif /* VMINSTALLATIONCONFIRMATION_HXX_ */
