/**
 * @file ValidateEmlSignatureWidget.cxx
 * @brief Body class validate Eml Files signature
 * @date 03/06/2013
 * @author Yadickson Soto
 */

#include "ValidateEmlSignatureWidget.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Operation/MachineOperationManager.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::System::Exception;
using namespace Smartmatic::Log;

ISMTTLog * ValidateEmlSignatureWidget::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.ValidateEmlSignatureWidget", GETTEXT_PACKAGE );

ValidateEmlSignatureWidget::ValidateEmlSignatureWidget ( ProgressWidget * progress )
    : WizardWidgetBase(), progress ( progress )
{
    m_thread = NULL;

    this->progress->setImage ( "ui/validate-signature.gif" );
    this->progress->setInfoText ( N_ ( "Smartmatic.SAES.GUI.Widgets.ValidateEmlSignatureWidget.ValidateSignature" ) );
    setWidget ( progress );

    signalEndProcess.connect ( sigc::mem_fun ( *this, &ValidateEmlSignatureWidget::endProcess ) );
    signalErrorProcess.connect ( sigc::mem_fun ( *this, &ValidateEmlSignatureWidget::errorProcess ) );

    setAccessibleName ( "ValidateEmlSignatureWidget" );
}

ValidateEmlSignatureWidget::~ValidateEmlSignatureWidget()
{
    dispose();

    this->remove();

    if ( progress )
    {
        delete progress;
        progress = NULL;
    }
}

void ValidateEmlSignatureWidget::initialize()
{
    m_disable_close_signal.emit();

    if ( !Glib::thread_supported() )
    {
        Glib::thread_init();
    }

    if ( m_thread != NULL )
    {
        m_thread->join();
        m_thread = NULL;
    }

    m_thread = Glib::Thread::create ( sigc::mem_fun ( *this, &ValidateEmlSignatureWidget::start ), true );
}

void ValidateEmlSignatureWidget::dispose()
{
    if ( m_thread != NULL )
    {
        m_thread->join();
        m_thread = NULL;
    }
}

void ValidateEmlSignatureWidget::start()
{
    bool validate = MachineOperationManager::getInstance()->validateEmlSignature();

    if ( validate )
    {
        logger->Audit ( N_ ( "Smartmatic.SAES.GUI.Widgets.ValidateEmlSignatureWidget.ValidateSignatureSuccessfully" ) );
        signalEndProcess.emit();
    }
    else
    {
        logger->Audit ( N_ ( "Smartmatic.SAES.GUI.Widgets.ValidateEmlSignatureWidget.ValidateSignatureFail" ) );
        signalErrorProcess.emit();
    }
}

void ValidateEmlSignatureWidget::endProcess()
{
    Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &ValidateEmlSignatureWidget::end ), 100 );
}

void ValidateEmlSignatureWidget::end()
{
    emit();
}

void ValidateEmlSignatureWidget::errorProcess ()
{
    Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &ValidateEmlSignatureWidget::errorMessage ), 2500 );
}

void ValidateEmlSignatureWidget::errorMessage()
{
    emitError();
}

bool ValidateEmlSignatureWidget::isEnabledButtonExitWizard()
{
    return false;
}
