/**
 * @file ValidateEmlSignatureWidget.hxx
 * @brief Header class validate Eml files signature
 * @date 03/06/2013
 * @author Yadickson Soto
 */

#ifndef VALIDATE_EML_SIGNATURE_WIDGET_HXX_
#define VALIDATE_EML_SIGNATURE_WIDGET_HXX_

#include <Widgets/wizard-widget-base.h>
#include <Gui/Widgets/ShutdownWidget.hxx>
#include "ProgressWidget.hxx"

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	ValidateEmlSignatureWidget
                 * @brief	Class validate Eml files signature.
                 * @author	Yadickson Soto
                 * @see WizardWidgetBase
                 * @date	03/06/2013
                 */
                class ValidateEmlSignatureWidget: public Smartmatic::GUI::Widgets::WizardWidgetBase
                {
                    public:

                        /**
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         * @param	progress	widget with label and image.
                         */
                        explicit ValidateEmlSignatureWidget ( ProgressWidget * progress );

                        /**
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         */
                        virtual ~ValidateEmlSignatureWidget();

                        /**
                         * @brief	Initializer method.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         */
                        virtual void initialize();

                        /**
                         * @brief	virtual method stop.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         */
                        virtual void dispose();

                        /**
                         * @brief	Method getter is enabled button exit wizard.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         * @return	true is enabled button exit wizard.
                         */
                        virtual bool isEnabledButtonExitWizard();

                    private:

                        ProgressWidget * progress; ///< widget with label and image
                        ShutdownWidget m_shutdown;
                        Glib::Dispatcher signalEndProcess; ///< signal end process
                        Glib::Dispatcher signalErrorProcess; ///< signal error process
                        Glib::Thread * m_thread; ///< The thread pointer

                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger

                        /**
                         * @brief	Method start validate codi files.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         */
                        void start();

                        /**
                         * @brief	End of the widget.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         */
                        void end();

                        /**
                         * @brief	Show error message.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         */
                        void errorMessage();

                        /**
                         * @brief	Method end validate Eml files.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         */
                        void endProcess();

                        /**
                         * @brief	Method update label from error process.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         */
                        void errorProcess ();
                };
            }
        }
    }
}
#endif /* VALIDATE_EML_SIGNATURE_WIDGET_HXX_ */
