/**
 * @file ValidateVotesWidget.cxx
 * @brief Body class validate CODI Files signature
 * @date 03/06/2013
 * @author Yadickson Soto
 */

#include "ValidateVotesWidget.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Operation/MachineOperationManager.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::System::Exception;
using namespace Smartmatic::Log;

ISMTTLog * ValidateVotesWidget::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.ValidateVotesWidget", GETTEXT_PACKAGE );

ValidateVotesWidget::ValidateVotesWidget ( ProgressWidget * progress )
    : WizardWidgetBase(), progress ( progress )
{
    m_thread = NULL;

    this->progress->setImage ( "ui/validate-votes.gif" );
    this->progress->setInfoText ( N_ ( "Smartmatic.SAES.GUI.Widgets.ValidateVotesWidget.ValidateVotes" ) );
    setWidget ( progress );

    signalEndProcess.connect ( sigc::mem_fun ( *this, &ValidateVotesWidget::endProcess ) );
    signalErrorProcess.connect ( sigc::mem_fun ( *this, &ValidateVotesWidget::errorProcess ) );

    setAccessibleName ( "ValidateVotesWidget" );
}

ValidateVotesWidget::~ValidateVotesWidget()
{
    dispose();

    this->remove();

    if ( progress )
    {
        delete progress;
        progress = NULL;
    }
}

void ValidateVotesWidget::initialize()
{
    m_disable_close_signal.emit();

    if ( !Glib::thread_supported() )
    {
        Glib::thread_init();
    }

    if ( m_thread != NULL )
    {
        m_thread->join();
        m_thread = NULL;
    }

    m_thread = Glib::Thread::create ( sigc::mem_fun ( *this, &ValidateVotesWidget::start ), true );
}

void ValidateVotesWidget::dispose()
{
    if ( m_thread != NULL )
    {
        m_thread->join();
        m_thread = NULL;
    }
}

void ValidateVotesWidget::start()
{
    bool validate = MachineOperationManager::getInstance()->checkVoteFiles() &&
        MachineOperationManager::getInstance()->checkVotes();

    if ( validate )
    {
        logger->Audit ( N_ ( "Smartmatic.SAES.GUI.Widgets.ValidateVotesWidget.ValidateVoteSuccessfully" ) );
        signalEndProcess.emit();
    }
    else
    {
        logger->Audit ( N_ ( "Smartmatic.SAES.GUI.Widgets.ValidateVotesWidget.ValidateVoteFail" ) );
        signalErrorProcess.emit();
    }
}

void ValidateVotesWidget::end()
{
    emit();
}

void ValidateVotesWidget::endProcess()
{
    Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &ValidateVotesWidget::end ), 100 );
}

void ValidateVotesWidget::errorProcess ()
{
    Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &ValidateVotesWidget::errorMessage ), 2500 );
}

void ValidateVotesWidget::errorMessage()
{
    emitError();
}

bool ValidateVotesWidget::isEnabledButtonExitWizard()
{
    return false;
}
