/**
 * @file ValidateVotesWidget.hxx
 * @brief Header class validate CODI files signature
 * @date 03/06/2013
 * @author Yadickson Soto
 */

#ifndef VALIDATE_VOTES_WIDGET_HXX_
#define VALIDATE_VOTES_WIDGET_HXX_

#include <Widgets/wizard-widget-base.h>
#include <Gui/Widgets/ShutdownWidget.hxx>
#include "ProgressWidget.hxx"

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	ValidateVotesWidget
                 * @brief	Class validate CODI files signature.
                 * @author	Yadickson Soto
                 * @see WizardWidgetBase
                 * @date	03/06/2013
                 */
                class ValidateVotesWidget: public Smartmatic::GUI::Widgets::WizardWidgetBase
                {
                    public:
                        /**
                         * @fn	ValidateVotesWidget::ValidateVotesWidget ( ProgressWidget * progress );
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         * @param	progress	widget with label and image.
                         */
                        explicit ValidateVotesWidget ( ProgressWidget * progress );

                        /**
                         * @fn	virtual ValidateVotesWidget::~ValidateVotesWidget();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         */
                        virtual ~ValidateVotesWidget();

                        /**
                         * @fn	virtual void ValidateVotesWidget::initialize();
                         * @brief	Initializer method.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         */
                        virtual void initialize();
                        /**
                         * @fn	virtual void ValidateVotesWidget::dispose();
                         * @brief	virtual method stop.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         */
                        virtual void dispose();

                        /**
                         * @fn	virtual bool ValidateVotesWidget::isEnabledButtonExitWizard();
                         * @brief	Method getter is enabled button exit wizard.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         * @return	true is enabled button exit wizard.
                         */
                        virtual bool isEnabledButtonExitWizard();

                    private:

                        ProgressWidget * progress; ///< widget with label and image

                        Glib::Dispatcher signalEndProcess; ///< signal end process
                        Glib::Dispatcher signalErrorProcess; ///< signal error process
                        Glib::Thread * m_thread; ///< The thread pointer
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger

                        /**
                         * @fn	void ValidateVotesWidget::start();
                         * @brief	Method start validate codi files.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         */
                        void start();

                        /**
                         * @fn	void end();
                         * @brief	End of the widget.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         */
                        void end();

                        /**
                         * @fn	void errorMessage();
                         * @brief	Show error message.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         */
                        void errorMessage();

                        /**
                         * @fn	void endProcess();
                         * @brief	Method end validate vote files.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         */
                        void endProcess();

                        /**
                         * @fn	void errorProcess ();
                         * @brief	Method update label from error process.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         */
                        void errorProcess ();
                };
            }
        }
    }
}
#endif /* VALIDATE_VOTES_WIDGET_HXX_ */
