/**
 * @file ContestLayout.cxx
 * @brief Body Contest Layout Class
 * @date 22/04/2013
 * @author Yadickson Soto
 */

#include "ContestLayout.hxx"

using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Widgets::Voting;
using namespace Smartmatic::SAES::Voting::Election;

ContestLayout::ContestLayout ( Smartmatic::SAES::Voting::Election::Contest * contest )
{
    swing = false;
    partialSwing = false;

    if ( contest )
    {
        columns = contest->getDisplay_info().getNumber_of_columns().present() ?
                  contest->getDisplay_info().getNumber_of_columns().get() : 0;

        pivot = contest->getDisplay_info().getValue_of_pivot().present() ?
                contest->getDisplay_info().getValue_of_pivot().get() : 0;

        if (contest->getDisplay_info().getFirstname_alignment().present())
          firstnameAlignment = SAESGUIConfigurationManager::ConvertToLabelConfiguration(
            contest->getDisplay_info().getFirstname_alignment().get());

        if (contest->getDisplay_info().getLastname_alignment().present())
          lastnameAlignment = SAESGUIConfigurationManager::ConvertToLabelConfiguration(
            contest->getDisplay_info().getLastname_alignment().get());

        if (contest->getDisplay_info().getSwing().present())
        {
            int displayAlgorithm = contest->getDisplay_info().getSwing().get();

            switch (displayAlgorithm)
            {
                default:
                case 0:
                    break;
                case 1:
                    swing = true;
                    break;
                case 2:
                    partialSwing = true;
                    break;
            }
        }
    }
    else
    {
        columns = 0;
        pivot = 0;
        swing = false;
    }

    BallotOptionSelectionConfiguration config = SAESGUIConfigurationManager::getInstance()->GetBallotOptionSelectionConfiguration();

    if ( columns == 0 )
    {
        columns = config.getMaxColumns();
    }

    if ( pivot == 0 )
    {
        pivot = config.getMaxRows();
    }

    spacing = config.getBallotsMargin();
}

ContestLayout::~ContestLayout()
{

}

int ContestLayout::getColumns()
{
    return columns;
}

int ContestLayout::getPivot()
{
    return pivot;
}

bool ContestLayout::isSwing()
{
    return swing;
}

float ContestLayout::getSpacing()
{
    return spacing;
}

bool ContestLayout::isPartialSwing()
{
    return partialSwing;
}

LabelAlignmentEnum ContestLayout::getFirstnameAlignment()
{
    return firstnameAlignment;
}

LabelAlignmentEnum ContestLayout::getLastnameAlignment()
{
    return lastnameAlignment;
}