/**
 * @file   DetailedStatistics.hxx
 * @brief  Declaration of DetailedStatistics class.
 * @author Georgi Demirchev
 * @date   Jul  8, 2013
 * @author manuel.arguelles
 * @date   Oct 19, 2017
 */

#ifndef DETAILED_STATISTICS_HXX
#define DETAILED_STATISTICS_HXX

#include <Widgets/SmartmaticBasicButton.hxx>
#include <Widgets/SmartmaticBasicComboBox.hxx>
#include <Widgets/SmartmaticBasicFrame.hxx>
#include <Widgets/SmartmaticBasicHBox.hxx>
#include <Widgets/SmartmaticBasicLabel.hxx>
#include <Widgets/SmartmaticBasicVBox.hxx>
#include <gtkmm.h>

namespace Smartmatic
{
    namespace GUI
    {
        namespace Configuration
        {
            class LabelConfiguration;
        }
    }

    namespace SAES
    {
        namespace Voting
        {
            namespace PBReports
            {
                class VoteStatisticsWrapper;
            }
        }

        namespace GUI
        {
            namespace Widgets
            {
                namespace Voting
                {

                    /**
                     * @class  ModelColumns
                     * @brief  Class with the contents of the TreeModel.
                     * @author manuel.arguelles
                     * @date   Oct 19, 2017
                     */
                    class ModelColumns : public Gtk::TreeModel::ColumnRecord
                    {
                        public:

                            ModelColumns()
                            {
                                add(m_voterType);
                                add(m_votes);
                            }

                            Gtk::TreeModelColumn<Glib::ustring> m_voterType;
                            Gtk::TreeModelColumn<Glib::ustring> m_votes;
                    };

                    /**
                     * @class  DetailedStatistics.
                     * @brief  Displays the detailed votes statistics.
                     * @author manuel.arguelles
                     * @date   Oct 19, 2017
                     */
                    class DetailedStatistics : public Smartmatic::GUI::Widgets::SmartmaticBasicVBox
                    {
                        public:

                            /**
                             * @brief  Creates an instance of the class
                             * @author manuel.arguelles
                             * @date   Oct 19, 2017
                             */
                            DetailedStatistics();

                            /**
                             * @brief  Destroys an instance of the class.
                             * @author manuel.arguelles
                             * @date   Oct 19, 2017
                             */
                            virtual ~DetailedStatistics();

                            /**
                             * @brief  Updates the statistics.
                             * @author manuel.arguelles
                             * @date   Oct 19, 2017
                             */
                            void Update();

                            /**
                             * @brief  Sets the title.
                             * @author manuel.arguelles
                             * @date   Oct 19, 2017
                             * @param  title The title to set.
                             * @param  conf  The label configuration of the title.
                             * @param  sizeX The width.
                             * @param  sizeY The height.
                             */
                            void SetTitle(const std::string& title,
                                          Smartmatic::GUI::Configuration::LabelConfiguration& conf,
                                          int sizeX,
                                          int sizeY);

                        private:

                            /**
                             * @brief  Updates the text to reflect the current
                             * statistics in the show details button.
                             * @author manuel.arguelles
                             * @date   Oct 19, 2017
                             */
                            void updateShowDetailsButton();

                            /**
                             * @brief  Called when the user changes the selection
                             * in the combo box.
                             * @author manuel.arguelles
                             * @date   Oct 19, 2017
                             */
                            void onSelectionChanged();

                            /**
                             * @brief  Called when the user requires detailed
                             * votes statistics.
                             * @author manuel.arguelles
                             * @date   Oct 19, 2017
                             */
                            void onShowDetails();

                            /**
                             * @brief  Called when the detailed votes statistics
                             * view goes out of focus.
                             * @author manuel.arguelles
                             * @date   Oct 19, 2017
                             * @param  event The event that triggered the action.
                             */
                            void onOutOfFocus(GdkEvent* event);


                        private:

                            ModelColumns m_columns;
                            Glib::RefPtr<Gtk::ListStore> m_storeModel;
                            SAES::Voting::PBReports::VoteStatisticsWrapper* m_voteStatistics;
                            Smartmatic::GUI::Widgets::SmartmaticBasicLabel m_title;
                            Smartmatic::GUI::Widgets::SmartmaticBasicComboBox m_details;
                            Smartmatic::GUI::Widgets::SmartmaticBasicLabel m_buttonVoteType;
                            Smartmatic::GUI::Widgets::SmartmaticBasicLabel m_buttonVoteTotal;
                            Smartmatic::GUI::Widgets::SmartmaticBasicHBox m_buttonHolder;
                            Smartmatic::GUI::Widgets::SmartmaticBasicButton m_buttonExpander;
                            Smartmatic::GUI::Widgets::SmartmaticBasicFrame m_buttonFrame;
                    };

                } /* namespace Voting */
            } /* namespace Widgets */
        } /* namespace GUI */
    } /* namespace SAES */
} /* namespace Smartmatic */

#endif /* DETAILED_STATISTICS_HXX */

