/**
 * @file DualWaitingForCardWidget.cxx
 * @brief Body of the widget class with voting information and waiting for card.
 * The start of the voter experience is divided into two parts,
 * election information and voting instructions.
 * @date 13/03/2014
 * @author Yadickson Soto
 */

#include "DualWaitingForCardWidget.hxx"
#include "FactoryVotingWidget.hxx"
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>
#include <Operation/FormatLabel.hxx>
#include <Operation/MachineOperationManager.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets::Voting;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Operation;
using namespace Smartmatic::SAES::Voting;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::GUI::Operation;

DualWaitingForCardWidget::DualWaitingForCardWidget ( ProgressWidget * votingInfoWidget,
        WaitingForCardWidget * waitingCardWidget )
    : StepWidget (), votingInfoWidget ( votingInfoWidget ), waitingCardWidget ( waitingCardWidget )
{
    vbox = new SmartmaticBasicVBox ( true, 0 );

    if ( SAESGUIConfigurationManager::getInstance()->getWaitingForCardWindowConfiguration().getShowElectoralInformationFrame() )
    {
        vbox->pack_start ( *votingInfoWidget );

        votingInfoWidget->setInfoTitleConfig ( SAESGUIConfigurationManager::getInstance()->GetVotingWindowEndMessagelabelConfig() );
        votingInfoWidget->setInfoTextConfig ( SAESGUIConfigurationManager::getInstance()->GetVotingWindowEndMessagelabelConfig() );

        std::string image;
        image = SAESGUIConfigurationManager::getInstance()->getWaitingForCardWindowConfiguration().getElectoralInformationImage();
        image = MachineOperationManager::getInstance()->getSaesDirectories()->getImageElectoralResource ( image );

        votingInfoWidget->setImage ( image );
        votingInfoWidget->set_no_show_all();
        votingInfoWidget->setAccessibleName ( "VotingInfo" );
    }

    vbox->pack_end ( *waitingCardWidget );

    setAccessibleName ( "DualWaitingForCardWidget" );

    refresh();
    setWidget ( vbox );

    show_all_children();
    show();
}

DualWaitingForCardWidget::~DualWaitingForCardWidget()
{
    this->remove();

    if ( vbox )
    {
        delete vbox;
        vbox = NULL;
    }

    if ( votingInfoWidget )
    {
        delete votingInfoWidget;
        votingInfoWidget = NULL;
    }

    if ( waitingCardWidget )
    {
        delete waitingCardWidget;
        waitingCardWidget = NULL;
    }
}

void DualWaitingForCardWidget::refresh()
{
    votingInfoWidget->setInfoTitle ( FormatLabel::format ( N_ ( "Election Instruction Title" ) ) );
    votingInfoWidget->setInfoText ( FormatLabel::format ( N_ ( "Election Instruction Info" ) ) );
    waitingCardWidget->refresh();
}

void DualWaitingForCardWidget::showInfo ( bool show )
{
    votingInfoWidget->set_visible ( show );
}

WaitingForCardWidget * DualWaitingForCardWidget::getWaitingForCardWidget()
{
    return waitingCardWidget;
}
