/**
 * @file	ElectoralTypeSelectionBoxWidget.hxx
 * @brief	Header electoral type selection widget.
 * @author	Yadickson Soto
 * @date	13/11/2012
 */

#ifndef _ELECTORAL_TYPE_SELECTION_BOX_WIDGET_H_
#define _ELECTORAL_TYPE_SELECTION_BOX_WIDGET_H_

#include "ILanguageSelectionWidget.hxx"
#include "LanguageSelectionButtonWidget.hxx"
#include <Widgets/TableBoxSelectionWidget.hxx>
#include <Widgets/SmartmaticBasicLabel.hxx>
#include <Widgets/SmartmaticBasicVBox.hxx>
#include <Widgets/StepWidget.hxx>
#include <Voting/CardData/card-data-schema.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                namespace Voting
                {
                    /**
                     * @class	ElectoralTypeSelectionBoxWidget
                     * @brief	Electoral type selection widget.
                     * @author	Yadickson Soto
                     * @date	13/11/2012
                     */
                    class ElectoralTypeSelectionBoxWidget: public Smartmatic::GUI::Widgets::StepWidget
                    {
                        public:

                            /**
                             * @fn	ElectoralTypeSelectionBoxWidget::ElectoralTypeSelectionBoxWidget ( );
                             * @brief	Class constructor.
                             * @author	Yadickson Soto
                             * @date	13/11/2012
                             */
                            ElectoralTypeSelectionBoxWidget ();
                            /**
                             * @fn	virtual ElectoralTypeSelectionBoxWidget::~ElectoralTypeSelectionBoxWidget();
                             * @brief	Class destructor.
                             * @author	Yadickson Soto
                             * @date	13/11/2012
                             */
                            virtual ~ElectoralTypeSelectionBoxWidget();
                            /**
                             * @fn	virtual void ElectoralTypeSelectionBoxWidget::refresh();
                             * @brief	refresh widget method.
                             * @author	Yadickson Soto
                             * @date	13/11/2012
                             */
                            virtual void refresh();
                            /**
                             * @fn	void getCardData ( Smartmatic::SAES::Voting::CardData::Card_data & cardData );
                             * @brief	method getter card data.
                             * @author	Yadickson Soto
                             * @date	13/04/2012
                             * @param	cardData	result card data.
                             */
                            void getCardData ( Smartmatic::SAES::Voting::CardData::Card_data & cardData );

                        protected:

                            /**
                             * @fn	virtual void ElectoralTypeSelectionBoxWidget::initialize();
                             * @brief	Initializer method.
                             * @author	Yadickson Soto
                             * @date	13/11/2012
                             */
                            virtual void initialize();
                            /**
                             * @fn	virtual void ElectoralTypeSelectionBoxWidget::dispose();
                             * @brief	virtual method stop.
                             * @author	Yadickson Soto
                             * @date	13/11/2012
                             */
                            virtual void dispose();

                        private:

                            /**
                             * @fn	void ElectoralTypeSelectionBoxWidget::onBoxClicked( std::list < Smartmatic::GUI::Widgets::BoxSelectionWidget * > & list);
                             * @brief	method box click.
                             * @author	Yadickson Soto
                             * @date	14/11/2012
                             * @param list box selected
                             */
                            void onBoxClicked ( std::list < Smartmatic::GUI::Widgets::BoxSelectionWidget * > & list );

                            Smartmatic::GUI::Widgets::SmartmaticBasicVBox * externalBox; ///< external vbox
                            Smartmatic::GUI::Widgets::BoxSelectionWidget * currentBox; ///< current box
                            Smartmatic::GUI::Widgets::TableBoxSelectionWidget * tableWidget; ///< table widgets
                    };
                }
            }
        }
    }
}

#endif // _ELECTORAL_TYPE_SELECTION_BOX_WIDGET_H_
