/**
 * @file FactoryVotingWidget.cxx
 * @brief Body class for create widget
 * @date 29/02/2012
 * @author Yadickson Soto
 */

#include "FactoryVotingWidget.hxx"
#include <Gui/Widgets/FactoryMethodWidget.hxx>
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"
#include "LanguageSelectionBoxWidget.hxx"
#include "CustomAttributeSelectionBoxWidget.hxx"

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Widgets::Voting;
using namespace Smartmatic::SAES::GUI::Widgets::AudioVoting;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::Operation::Voting;
using namespace Smartmatic::SAES::Voting::VotingDevice;
using namespace Smartmatic::SAES::Configuration;

ILanguageSelectionWidget * FactoryVotingWidget::createLanguageSelectionWidgetConfig ( bool showConfirmation )
{
    bool confirmation = !SAESGUIConfigurationManager::getInstance()->getLanguageSelectionWidgetConfiguration().getAutoSelect();
    bool sortAlphabetically = SAESGUIConfigurationManager::getInstance()->getLanguageSelectionWidgetConfiguration().getSortAlphabetical();

    ILanguageSelectionWidget *widget = new LanguageSelectionBoxWidget ( showConfirmation && confirmation, sortAlphabetically );

    return widget;
}

ILanguageSelectionWidget * FactoryVotingWidget::createVotingLanguageSelectionWidget()
{
    ILanguageSelectionWidget * widget = createLanguageSelectionWidgetConfig ( true );
    return widget;
}

ElectoralTypeSelectionBoxWidget * FactoryVotingWidget::createSimulationWidget()
{
    return new ElectoralTypeSelectionBoxWidget();
}

PreviewWidget * FactoryVotingWidget::createPreviewWidget()
{
    return new PreviewWidget();
}

VotePreviewWidget * FactoryVotingWidget::createVotePreviewWidget()
{
    return new VotePreviewWidget();
}

TimeOutPreviewWidget * FactoryVotingWidget::createTimeOutPreviewWidget()
{
    return new TimeOutPreviewWidget();
}

WaitingForCardWidget * FactoryVotingWidget::createWaitingForCardWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    WaitingForCardWidget * widget = new WaitingForCardWidget ( progress );
    return widget;
}

PrintTimeOutWidget * FactoryVotingWidget::createPrintTimeOutWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    PrintTimeOutWidget * widget = new PrintTimeOutWidget ( progress );
    return widget;
}

PrintVoteErrorWidget * FactoryVotingWidget::createPrintVoteErrorWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    PrintVoteErrorWidget * widget = new PrintVoteErrorWidget ( progress );
    return widget;
}

VoteComplianceFailureWidget * FactoryVotingWidget::createVoteComplianceFailureWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    VoteComplianceFailureWidget * widget = new VoteComplianceFailureWidget ( progress );
    return widget;
}

RemoveCardWidget * FactoryVotingWidget::createRemoveCardWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    RemoveCardWidget * widget = new RemoveCardWidget ( progress );
    return widget;
}

FoldPrintVoteWidget * FactoryVotingWidget::createFoldPrintVoteWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    FoldPrintVoteWidget * widget = new FoldPrintVoteWidget ( progress );
    return widget;
}

CardRemovedWidget * FactoryVotingWidget::createCardRemovedWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    CardRemovedWidget * widget = new CardRemovedWidget ( progress );
    return widget;
}

PrintVoteWidget * FactoryVotingWidget::createPrintVoteWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    PrintVoteErrorWidget * printVoteErrorWidget = FactoryVotingWidget::createPrintVoteErrorWidget();
    VoteComplianceFailureWidget * voteComplianceFailureWidget = FactoryVotingWidget::createVoteComplianceFailureWidget();
    PrintVoteWidget * widget = new PrintVoteWidget ( progress, printVoteErrorWidget, voteComplianceFailureWidget );
    return widget;
}

InterruptVotingWidget * FactoryVotingWidget::createInterruptVotingWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    InterruptVotingWidget * widget = new InterruptVotingWidget ( progress );
    return widget;
}

KeypadVotingPasswordWidget * FactoryVotingWidget::createKeypadVotingPasswordWidget()
{
    KeypadVotingPasswordWidget * widget = new KeypadVotingPasswordWidget();
    return widget;
}

NullVotingWidget * FactoryVotingWidget::createNullVotingWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    NullVotingWidget * widget = new NullVotingWidget ( progress );
    return widget;
}

InterruptWidget * FactoryVotingWidget::createInterruptWidget()
{
    return new InterruptWidget();
}

VotingExperienceValidationWidget * FactoryVotingWidget::createVotingExperineceValidationWidget()
{
    return new VotingExperienceValidationWidget();
}

ICustomAttributeSelectionWidget * FactoryVotingWidget::createCustomAttributeWidget ( Custom_attribute_definition & customAttribute )
{
    bool showConfirmation = ! SAESGUIConfigurationManager::getInstance()->getCustomAttributeSelectionWidgetConfiguration().getAutoSelect();
    bool sortOptions = SAESGUIConfigurationManager::getInstance()->getCustomAttributeSelectionWidgetConfiguration().getSortAlphabetical();

    ICustomAttributeSelectionWidget *widget = new CustomAttributeSelectionBoxWidget ( customAttribute, showConfirmation, sortOptions );

    return widget;
}

ScreenVotingWidget * FactoryVotingWidget::createScreenVotingWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    ScreenVotingWidget * widget = new ScreenVotingWidget ( progress );
    return widget;
}

VotingExperienceWidget * FactoryVotingWidget::createVotingExperienceWidget()
{
    return new VotingExperienceWidget();
}

AudioVotingExperienceWidget * FactoryVotingWidget::createAudioVotingExperienceWidget()
{
    return new AudioVotingExperienceWidget();
}

SimulatorVotesWidget * FactoryVotingWidget::createSimulatorVotesWidget()
{
    return new SimulatorVotesWidget();
}

CustomAttributeSelectionButtonWidget * FactoryVotingWidget::createCustomAttributeSelectionButtonWidget()
{
    CustomAttributeSelectionButtonWidget * widget = NULL;

    switch ( SAESGUIConfigurationManager::getInstance()->getCustomAttributeSelectionWidgetConfiguration().getButtonType() )
    {
        case ViewButtonConfiguration::CONFIGURATION_EXPAND_BUTTONS:
            widget = new CustomAttributeSelectionButtonWidget ( true );
            break;

        default:
        case ViewButtonConfiguration::CONFIGURATION_SEPARATE_BUTTONS:
            widget = new CustomAttributeSelectionButtonWidget ( false );
            break;
    }

    return widget;
}

LanguageSelectionButtonWidget * FactoryVotingWidget::createLanguageSelectionButtonWidget()
{
    LanguageSelectionButtonWidget * widget = NULL;

    switch ( SAESGUIConfigurationManager::getInstance()->getLanguageSelectionWidgetConfiguration().getButtonType() )
    {
        case ViewButtonConfiguration::CONFIGURATION_EXPAND_BUTTONS:
            widget = new LanguageSelectionButtonWidget ( true );
            break;

        default:
        case ViewButtonConfiguration::CONFIGURATION_SEPARATE_BUTTONS:
            widget = new LanguageSelectionButtonWidget ( false );
            break;
    }

    return widget;
}

PrintAndFoldVoteWidget * FactoryVotingWidget::createPrintAndFoldVoteWidget()
{
    ProgressWidget * progressPrint = FactoryMethodWidget::createProgressWidget();
    ProgressWidget * progressFold = FactoryMethodWidget::createProgressWidget();
    PrintVoteErrorWidget * printVoteErrorWidget = FactoryVotingWidget::createPrintVoteErrorWidget();
    VoteComplianceFailureWidget * voteComplianceFailureWidget = FactoryVotingWidget::createVoteComplianceFailureWidget();
    return new PrintAndFoldVoteWidget ( progressPrint, progressFold, printVoteErrorWidget, voteComplianceFailureWidget );
}

PrintAudioVoteWidget * FactoryVotingWidget::createPrintAudioVoteWidget()
{
    PrintVoteErrorWidget * printVoteErrorWidget = FactoryVotingWidget::createPrintVoteErrorWidget();
    VoteComplianceFailureWidget * voteComplianceFailureWidget = FactoryVotingWidget::createVoteComplianceFailureWidget();
    return new PrintAudioVoteWidget ( printVoteErrorWidget,voteComplianceFailureWidget );
}

EndVotingSequenceWidget * FactoryVotingWidget::createEndVotingSequenceWidget()
{
    return new EndVotingSequenceWidget();
}

EndAudioVotingSequenceWidget * FactoryVotingWidget::createEndAudioVotingSequenceWidget()
{
    return new EndAudioVotingSequenceWidget();
}

WaitingVotingWidget * FactoryVotingWidget::createWaitingVotingWidget()
{
    return new WaitingVotingWidget();
}

DualWaitingForCardWidget * FactoryVotingWidget::createDualWaitingForCardWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    WaitingForCardWidget * waitingWidget = FactoryVotingWidget::createWaitingForCardWidget();
    return new DualWaitingForCardWidget ( progress, waitingWidget );
}

ScanVoteWidget * FactoryVotingWidget::createScanVoteWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    return new ScanVoteWidget ( progress );
}
