/**
 * @file IContestLayout.hxx
 * @brief Interface Contest Layout
 * @date 22/04/2013
 * @author Yadickson Soto
 */

#ifndef ICONTESTLAYOUT_HXX_
#define ICONTESTLAYOUT_HXX_

#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                namespace Voting
                {
                    /**
                     * @class IContestLayout
                     * @brief Interface Contest Layout
                     * @date 22/04/2013
                     * @author Yadickson Soto
                     */
                    class IContestLayout
                    {
                        public:

                            /**
                             * @fn virtual ~IContestLayout();
                             * @brief Class destructor
                             * @date 22/04/2013
                             * @author Yadickson Soto
                             */
                            virtual ~IContestLayout() {};
                            /**
                             * @fn virtual int getColumns() = 0;
                             * @brief Method getter number of columns by contest
                             * @date 22/04/2013
                             * @author Yadickson Soto
                             * @return number of columns
                             */
                            virtual int getColumns() = 0;

                            /**
                             * @fn virtual int getPivot() = 0;
                             * @brief Method getter value of pivot by contest
                             * @date 22/04/2013
                             * @author Yadickson Soto
                             * @return value of pivot
                             */
                            virtual int getPivot() = 0;

                            /**
                             * @fn virtual bool isSwing() = 0;
                             * @brief Method getter is swing all principal columns
                             * @date 22/04/2013
                             * @author Yadickson Soto
                             * @return true is swing
                             */
                            virtual bool isSwing() = 0;

                            /**
                             * @brief  Get partial swing.
                             * Partial swing is a basic swing when the first
                             * column has one entry more than the rest.
                             * @author manuel.arguelles
                             * @date   Jun 22, 2018
                             */
                            virtual bool isPartialSwing() = 0;


                            /**
                             * @fn virtual float getSpacing() = 0;
                             * @brief Method getter value of spacing box
                             * @date 23/04/2013
                             * @author Yadickson Soto
                             * @return value of spacing box
                             */
                            virtual float getSpacing() = 0;

                            /**
                             * @fn virtual int getFirstnameAlignment() = 0;
                             * @brief Method getter value of firstname alignment
                             * @date 01/07/2022
                             * @author Gabriel Jaimes
                             * @return value of firstname alignment
                             */
                            virtual Smartmatic::GUI::Configuration::LabelAlignmentEnum getFirstnameAlignment() = 0;

                            /**
                             * @fn virtual int getLastnameAlignment() = 0;
                             * @brief Method getter value of lastname alignment
                             * @date 01/07/2022
                             * @author Gabriel Jaimes
                             * @return value of lastname alignment
                             */
                            virtual Smartmatic::GUI::Configuration::LabelAlignmentEnum getLastnameAlignment() = 0;
                    };
                }
            }
        }
    }
}

#endif /* ICONTESTLAYOUT_HXX_ */
