/**
 * @file	ICustomAttributeSelectionWidget.cxx
 * @brief	Body interface the custom attribute selection widget.
 * @author	Yadickson Soto
 * @date	13/11/2012
 */

#include "ICustomAttributeSelectionWidget.hxx"
#include "Resources/election-string-resources-manager.h"
#include <Operation/MachineOperationManager.hxx>
#include <Operation/Voting/VotingOperation.hxx>
#include <Voting/VotingDevice/CustomAttributeDefinitionWrapper.hxx>
#include "Voting/set-language-functionality.h"

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Widgets::Voting;
using namespace Smartmatic::SAES::Resources;
using namespace Smartmatic::SAES::GUI::Operation::Voting;
using namespace Smartmatic::SAES::Operation;

ICustomAttributeSelectionWidget::ICustomAttributeSelectionWidget (
    Smartmatic::SAES::Voting::VotingDevice::Custom_attribute_definition & customAttr,
    bool showConfirmation, bool sortAlphabetically )
    : StepWidget()
{
    this->flagForce = false;
    this->customAttr = customAttr;
    this->showConfirmation = showConfirmation;
    this->sortAlphabetically = sortAlphabetically;

    setTitle ( false );
    setShowBorder ( true );
    setName ( VotingOperation::getWindowName() );
}

ICustomAttributeSelectionWidget::~ICustomAttributeSelectionWidget()
{

}

ICustomAttributeSelectionWidget::string_signal ICustomAttributeSelectionWidget::signal_Answer()
{
    return m_answer_signal;
}

void ICustomAttributeSelectionWidget::sortCustomAttribute()
{
    cadList.clear();

    if ( sortAlphabetically )
    {
        Smartmatic::SAES::Voting::VotingDevice::CustomAttributeDefinitionWrapper::sortAlphabetically ( customAttr );
    }
    else
    {
        std::string currentLanguage;
        std::string currentCountry;

        Smartmatic::SAES::Voting::SetLanguageFunctionality::getCurrentLanguageCountry ( currentLanguage, currentCountry );
        Smartmatic::SAES::Voting::VotingDevice::CustomAttributeDefinitionWrapper::sortByLanguage ( customAttr, currentLanguage );
    }

    Smartmatic::SAES::Voting::VotingDevice::Custom_attribute_definition_values::Custom_attribute_definition_valueSequence attrList = customAttr.getCustom_attribute_definition_values().getCustom_attribute_definition_value();
    Smartmatic::SAES::Voting::VotingDevice::Custom_attribute_definition_values::Custom_attribute_definition_valueIterator it;

    for ( it = attrList.begin(); it != attrList.end(); ++it )
    {
        cadList.push_back ( ( *it ).getValue() );
    }
}
