/**
 * @file InterruptVotingWidget.hxx
 * @brief Header class interrupt voting widget
 * @date 17/04/2012
 * @author Yadickson Soto
 */

#ifndef _INTERRUPT_VOTING_WIDGET_H_
#define _INTERRUPT_VOTING_WIDGET_H_

#include <gtkmm.h>
#include <Widgets/StepWidget.hxx>
#include <Widgets/smartmatic-button.h>
#include <Gui/Widgets/ProgressWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                namespace Voting
                {
                    /**
                     * @class	InterruptVotingWidget
                     * @brief	Interrupt voting widget.
                     * @author	Yadickson Soto
                     * @date	17/04/2012
                     */
                    class InterruptVotingWidget: public Smartmatic::GUI::Widgets::StepWidget
                    {
                        public:

                            /**
                             * @enum	InterrupVotingState
                             * @brief	state widget.
                             */
                            enum InterrupVotingState
                            {
                                INTERRUPTVOTING_CARDCOUNTER ///< step card counter
                                , INTERRUPTVOTING_CANCELPROCESS ///< step cancel process
                            };

                            /**
                             * @fn	InterruptVotingWidget::InterruptVotingWidget ( Smartmatic::SAES::GUI::Widgets::ProgressWidget * progress );
                             * @brief	Class constructor.
                             * @author	Yadickson Soto
                             * @date	17/04/2012
                             * @param	progress	progress widget.
                             */
                            explicit InterruptVotingWidget ( Smartmatic::SAES::GUI::Widgets::ProgressWidget * progress );
                            /**
                             * @fn	virtual InterruptVotingWidget::~InterruptVotingWidget();
                             * @brief	Class destructor.
                             * @author	Yadickson Soto
                             * @date	17/04/2012
                             */
                            virtual ~InterruptVotingWidget();
                            /**
                             * @fn	virtual void InterruptVotingWidget::refresh();
                             * @brief	refresh widget method.
                             * @author	Yadickson Soto
                             * @date	17/04/2012
                             */
                            virtual void refresh();
                            /**
                             * @fn	void InterruptVotingWidget::changeState ( InterrupVotingState state );
                             * @brief	method change step widget.
                             * @author	Yadickson Soto
                             * @date	17/04/2012
                             * @param	state	state widget.
                             */
                            void changeState ( InterrupVotingState state );
                            /**
                             * @fn	Glib::SignalProxy0<void> InterruptVotingWidget::getSignalClick();
                             * @brief	method egtter signal click.
                             * @author	Yadickson Soto
                             * @date	24/04/2012
                             * @return	signal click.
                             */
                            Glib::SignalProxy0<void> getSignalClick();

                        private:

                            InterrupVotingState currentState; ///< current state
                            Smartmatic::SAES::GUI::Widgets::ProgressWidget * progress; ///< progress widget
                            Gtk::EventBox * mainFrame; ///< main frame
                            Gtk::VBox * mainVBox; ///< main vbox
                            Gtk::EventBox * centerFrame; ///< center frame
                            Gtk::HBox * hboxButton; ///< The hbox button
                            Smartmatic::GUI::Widgets::SmartmaticButton * button; ///< button
                            static Smartmatic::Log::ISMTTLog * logger;  ///< logger
                    };
                }
            }
        }
    }
}

#endif // _INTERRUPT_VOTING_WIDGET_H_
