/**
 * @file InterruptWidget.hxx
 * @brief Header class interrupt voting widget
 * @date 24/04/2012
 * @author Yadickson Soto
 */

#ifndef _INTERRUPTWIDGET_H_
#define _INTERRUPTWIDGET_H_

#include <gtkmm.h>
#include <Widgets/StepWidget.hxx>
#include "InterruptVotingWidget.hxx"
#include "KeypadVotingPasswordWidget.hxx"
#include "NullVotingWidget.hxx"

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                namespace Voting
                {
                    /**
                     * @class	InterruptWidget
                     * @brief	Interrupt voting widget.
                     * @author	Yadickson Soto
                     * @date	17/04/2012
                     */
                    class InterruptWidget: public Smartmatic::GUI::Widgets::StepWidget
                    {
                        public:

                            /**
                             * @fn	InterruptWidget::InterruptWidget();
                             * @brief	Class constructor.
                             * @author	Yadickson Soto
                             * @date	17/04/2012
                             */
                            InterruptWidget();
                            /**
                             * @fn	virtual InterruptWidget::~InterruptWidget();
                             * @brief	Class destructor.
                             * @author	Yadickson Soto
                             * @date	17/04/2012
                             */
                            virtual ~InterruptWidget();
                            /**
                             * @fn	virtual void InterruptWidget::refresh();
                             * @brief	refresh widget method.
                             * @author	Yadickson Soto
                             * @date	17/04/2012
                             */
                            virtual void refresh();
                            /**
                             * @fn	void InterruptWidget::showCardCounter();
                             * @brief	method show card counter.
                             * @author	Yadickson Soto
                             * @date	17/04/2012
                             */
                            void showCardCounter();
                            /**
                             * @fn	void InterruptWidget::showCancelProcess();
                             * @brief	method show cancel process.
                             * @author	Yadickson Soto
                             * @date	17/04/2012
                             */
                            void showCancelProcess();
                            /**
                             * @fn	void InterruptWidget::showEndVoting();
                             * @brief	method show end voting.
                             * @author	Yadickson Soto
                             * @date	17/04/2012
                             */
                            void showEndVoting();
                            /**
                             * @fn	void InterruptWidget::showKeypad();
                             * @brief	method show keypad.
                             * @author	Yadickson Soto
                             * @date	21/03/2013
                             */
                            void showKeypad();
                            /**
                             * @fn	void forceNotChange();
                             * @brief	method force not change.
                             * @author	Yadickson Soto
                             * @date	21/03/2013
                             */
                            void forceNotChange();

                        private:

                            /**
                             * @fn	void InterruptWidget::onActionClicked();
                             * @brief	method action click.
                             * @author	Yadikson Soto
                             * @date	17/04/2012
                             */
                            void onActionClicked();
                            /**
                             * @fn	void InterruptWidget::end();
                             * @brief	method end.
                             * @author	Yadikson Soto
                             * @date	24/04/2012
                             */
                            void end();

                            bool flagNotChange; ///< flag not change
                            InterruptVotingWidget * interruptVotingWidget; ///< interrupt voting widget
                            KeypadVotingPasswordWidget * keypassWidget;	///< keypass widget
                            NullVotingWidget * endVotingWidget; ///< end voting widget
                    };
                }
            }
        }
    }
}

#endif // _INTERRUPTWIDGET_H_
