/**
 * @file PrintAndFoldVoteWidget.cxx
 * @brief Body class end print vote widget
 * @date 20/03/2013
 * @author Yadickson Soto
 */

#include "PrintAndFoldVoteWidget.hxx"
#include "FactoryVotingWidget.hxx"
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets::Voting;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Operation;
using namespace Smartmatic::SAES::Operation::Printer;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::Printing;
using namespace Smartmatic::SAES::Voting;
using namespace Smartmatic::SAES::Functionality::Configuration;
using namespace Smartmatic::GUI::Widgets;

PrintAndFoldVoteWidget::PrintAndFoldVoteWidget (
    Smartmatic::SAES::GUI::Widgets::ProgressWidget * progressPrint,
    Smartmatic::SAES::GUI::Widgets::ProgressWidget * progressFold,
    PrintVoteErrorWidget * printVoteErrorWidget,
    VoteComplianceFailureWidget * voteComplianceFailureWidget )
: IPrintVoteWidget ( printVoteErrorWidget, voteComplianceFailureWidget ),
  progressPrint ( progressPrint ),
  progressFold ( progressFold )
{
    vbox = new SmartmaticBasicVBox ( true, 10 );
    vbox->pack_start ( *progressPrint );
    vbox->pack_end ( *progressFold );

    progressPrint->setInfoTitleConfig ( SAESGUIConfigurationManager::getInstance()->GetVotingWindowEndMessagelabelConfig() );
    progressFold->setInfoTitleConfig ( SAESGUIConfigurationManager::getInstance()->GetVotingWindowEndMessagelabelConfig() );

    progressPrint->setInfoTextConfig ( SAESGUIConfigurationManager::getInstance()->GetVotingWindowEndMessagelabelConfig() );
    progressFold->setInfoTextConfig ( SAESGUIConfigurationManager::getInstance()->GetVotingWindowEndMessagelabelConfig() );

    progressPrint->setImage ( "ui/end-voting-experience.img" );
    progressFold->setImage ( "ui/voting-experience-finalization-image.gif" );

    setAccessibleName ( "PrintFoldVote" );
    progressPrint->setAccessibleName ( "PrintVote" );
    progressFold->setAccessibleName ( "FoldVote" );

    refresh();
    setWidget ( vbox );
}

PrintAndFoldVoteWidget::~PrintAndFoldVoteWidget()
{
    this->remove();

    if ( vbox )
    {
        delete vbox;
        vbox = NULL;
    }

    if ( progressPrint )
    {
        delete progressPrint;
        progressPrint = NULL;
    }

    if ( progressFold )
    {
        delete progressFold;
        progressFold = NULL;
    }
}

void PrintAndFoldVoteWidget::refresh()
{
    progressPrint->setInfoTitle ( N_ ( "Smartmatic.SAES.GUI.Widgets.PrintAndFoldVoteWidget.TitlePrinting" ) );
    progressFold->setInfoTitle ( N_ ( "Smartmatic.SAES.GUI.Widgets.PrintAndFoldVoteWidget.TitleFoldVote" ) );
    progressPrint->setInfoText ( N_ ( "Smartmatic.SAES.GUI.Widgets.PrintAndFoldVoteWidget.Printing" ) );
    progressFold->setInfoText ( N_ ( "Smartmatic.SAES.GUI.Widgets.PrintAndFoldVoteWidget.FoldVote" ) );
}
