/**
 * @file PrintVoteWidget.cxx
 * @brief Body class print vote widget
 * @date 29/02/2012
 * @author Yadickson Soto
 */

#include "PrintVoteWidget.hxx"
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>
#include <Operation/MachineOperationManager.hxx>
#include <Operation/AlarmMessage.hxx>
#include <Gui/Widgets/Voting/FactoryVotingWidget.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets::Voting;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Operation;
using namespace Smartmatic::SAES::Operation::Printer;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::Printing;
using namespace Smartmatic::SAES::Voting;
using namespace Smartmatic::SAES::Functionality::Configuration;

PrintVoteWidget::PrintVoteWidget (
    ProgressWidget * progress,
    PrintVoteErrorWidget * printVoteErrorWidget,
    VoteComplianceFailureWidget * voteComplianceFailureWidget )
: IPrintVoteWidget ( printVoteErrorWidget, voteComplianceFailureWidget )
, progress ( progress )
{
    progress->setInfoTextConfig ( SAESGUIConfigurationManager::getInstance()->GetVotingWindowEndMessagelabelConfig() );
    progress->setImage ( "ui/end-voting-experience.img" );
    setAccessibleName ( "PrintVote" );

    refresh();
    setTitle ( false );
    setShowBorder ( true );
    setWidget ( progress );
}

PrintVoteWidget::~PrintVoteWidget()
{
    this->remove();

    if ( progress )
    {
        delete progress;
        progress = NULL;
    }
}

void PrintVoteWidget::refresh()
{
    progress->setInfoText ( N_ ( "Smartmatic.SAES.GUI.Windows.VotingWindow.WaitPrintingTicket" ) );
}

void PrintVoteWidget::setText ( std::string text )
{
    progress->setInfoText ( text );
}
