/**
 * @file PrintVoteWidget.hxx
 * @brief Header class print vote widget
 * @date 29/02/2012
 * @author Yadickson Soto
 */

#ifndef PRINTVOTEWIDGET_HXX_
#define PRINTVOTEWIDGET_HXX_

#include <Gui/Widgets/ProgressWidget.hxx>
#include <Gui/Widgets/Voting/IPrintVoteWidget.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                namespace Voting
                {
                    /**
                     * @class	PrintVoteWidget
                     * @brief	Class print vote widget.
                     * @author	Yadickson Soto
                     * @date	29/02/2012
                     */
                    class PrintVoteWidget : public IPrintVoteWidget
                    {
                        public:

                            /**
                             * @fn	PrintVoteWidget::PrintVoteWidget ( Smartmatic::SAES::GUI::Widgets::ProgressWidget * progress,
                             *     Smartmatic::SAES::GUI::Widgets::Voting::PrintVoteErrorWidget * printVoteErrorWidget );
                             * @brief	Class constructor.
                             * @author	Yadickson Soto
                             * @date	29/02/2012
                             * @param	progress	progress widget.
                             * @param printVoteErrorWidget print vote error widget
                             * @param voteComplianceFailureWidget vote compliance failure widget
                             */
                            PrintVoteWidget ( Smartmatic::SAES::GUI::Widgets::ProgressWidget * progress,
                                              Smartmatic::SAES::GUI::Widgets::Voting::PrintVoteErrorWidget * printVoteErrorWidget,
                                              Smartmatic::SAES::GUI::Widgets::Voting::VoteComplianceFailureWidget * voteComplianceFailureWidget);
                            /**
                             * @fn	virtual PrintVoteWidget::~PrintVoteWidget();
                             * @brief	Class destructor.
                             * @author	Yadickson Soto
                             * @date	29/02/2012
                             */
                            virtual ~PrintVoteWidget();
                            /**
                             * @fn	virtual void PrintVoteWidget::refresh();
                             * @brief	refresh widget method.
                             * @author	Yadickson Soto
                             * @date	30/03/2012
                             */
                            virtual void refresh();
                            /**
                             * @fn	void PrintVoteWidget::setText ( std::string text );
                             * @brief	method setter text.
                             * @author	Yadickson Soto
                             * @date	29/02/2012
                             * @param	text	new text.
                             */
                            void setText ( std::string text );

                        private:

                            Smartmatic::SAES::GUI::Widgets::ProgressWidget * progress; ///< principal frame
                    };
                }
            }
        }
    }
}

#endif /* PRINTVOTEWIDGET_HXX_ */
