/**
 * @file VotePreviewWidget.hxx
 * @brief Body class vote preview widget
 * @date 05/10/2011
 * @author Yadickson Soto
 */

#ifndef VOTEPREVIEWWIDGET_HXX_
#define VOTEPREVIEWWIDGET_HXX_

#include <gtkmm.h>
#include <Widgets/smartmatic-button.h>
#include <Printing/PrintPreviewWidget.h>
#include <Printing/VotePrintDocument.h>
#include <Widgets/StepWidget.hxx>
#include <Widgets/SmartmaticBasicScrollContainer.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                namespace Voting
                {
                    /**
                     * @class	VotePreviewWidget
                     * @brief	Class vote preview widget.
                     * @author	Yadickson Soto
                     * @date	05/10/2011
                     */
                    class VotePreviewWidget: public Smartmatic::GUI::Widgets::StepWidget
                    {
                        public:
                            /**
                             * @fn	VotePreviewWidget::VotePreviewWidget();
                             * @brief	Class constructor.
                             * @author	Yadickson Soto
                             * @date	05/10/2011
                             */
                            VotePreviewWidget();
                            /**
                             * @fn	virtual VotePreviewWidget::~VotePreviewWidget();
                             * @brief	Class destructor.
                             * @author	Yadickson Soto
                             * @date	05/10/2011
                             */
                            virtual ~VotePreviewWidget();
                            /**
                             * @fn	void VotePreviewWidget::preview ( Smartmatic::SAES::Voting::Vote::Vote & vote );
                             * @brief	Method preview.
                             * @author	Yadickson Soto
                             * @date	05/10/2011
                             * @param	vote	to preview.
                             */
                            void preview ( Smartmatic::SAES::Voting::Vote::Vote & vote );
                            /**
                             * @fn	void VotePreviewWidget::error();
                             * @brief	Method preview error.
                             * @author	Yadickson Soto
                             * @date	05/10/2011
                             */
                            void error();
                            /**
                             * @fn	Glib::SignalProxy0< void > VotePreviewWidget::getBackClicked();
                             * @brief	Method getter signal back clicked.
                             * @author	Yadickson Soto
                             * @date	05/10/2011
                             * @return	signal.
                             */
                            Glib::SignalProxy0< void > getBackClicked();
                            /**
                             * @fn	sigc::signal<void> getSignalEvent();
                             * @brief	Getter method: signal event.
                             * @author	Yadickson Soto
                             * @date	03/06/2013
                             * @return	signal.
                             */
                            sigc::signal<void> getSignalEvent();

                        protected:
                            /**
                             * @fn	void VotePreviewWidget::clear();
                             * @brief	Method clear element.
                             * @author	Yadickson Soto
                             * @date	05/10/2011
                             */
                            void clear();
                            /**
                             * @fn	void change();
                             * @brief	Callback method: scrollbar change.
                             * @author	Yadickson Soto
                             * @date	03/06/2013
                             */
                            void change();
                            /**
                             * @fn	bool button_press ( GdkEventButton * event );
                             * @brief	Call back method: button press over scroll bar.
                             * @author	Yadickson Soto
                             * @date	03/06/2013
                             * @param event event
                             * @return	false
                             */
                            bool button_press ( GdkEventButton * event );
                            /**
                             * @fn	bool button_press ( GdkEventButton * event );
                             * @brief	Call back method: button press over scroll bar.
                             * @author	Yadickson Soto
                             * @date	03/06/2013
                             * @param event event
                             * @return	false
                             */
                            bool button_release ( GdkEventButton * event );

                        private:

                            Gtk::Label * labelMessage;   ///< Message describing the label
                            Gtk::VBox * vboxMagnify; ///< The vbox magnify
                            Smartmatic::GUI::Widgets::SmartmaticBasicScrollContainer * scrolledMagnify;  ///< The scrolled magnify
                            Gtk::Viewport * viewMagnify;   ///< The view magnify
                            Smartmatic::GUI::Widgets::SmartmaticButton * buttonBack; ///< button back preview

                            sigc::signal<void> signalEvent; ///< signal event user

                            Smartmatic::SAES::Printing::PrintPreviewWidget * printWidgetMagnify; ///< The print widget magnify
                            Smartmatic::SAES::Printing::VotePrintDocument * docMagnify; ///< The document magnify

                            static Smartmatic::Log::ISMTTLog * logger; /**<logger*/
                    };
                }
            }
        }
    }
}

#endif /* VOTEPREVIEWWIDGET_HXX_ */
