/**
 * @file WaitingForCardWidget.cxx
 * @brief Body class waiting card widget
 * @date 11/04/2012
 * @author Yadickson Soto
 */

#include "WaitingForCardWidget.hxx"
#include <Environment/Configurations/resource-path-provider.h>
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>
#include <Operation/MachineOperationManager.hxx>
#include <Operation/FormatLabel.hxx>
#include <Operation/Monitor/DeviceTypeMonitorPool.hxx>
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <System/OptParser.hxx>
#include <Configuration/MachineModelEnum.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets::Voting;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Operation;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::Common::Operation::Monitor;
using namespace Smartmatic::Configuration;
using namespace Smartmatic::Environment;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Common::Configuration;
using namespace Smartmatic::SAES::Operation::Monitor;
using namespace Smartmatic::System;

ISMTTLog * WaitingForCardWidget::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.Voting.WaitingForCardWidget", GETTEXT_PACKAGE );

WaitingForCardWidget::WaitingForCardWidget ( ProgressWidget * progress )
    : StepWidget()
{
    this->progress = progress;
    this->flagNotChange = false;

    std::string machineModel;
    OptParser::getInstance()->getArg( OptParser::MACHINE_MODEL, machineModel );

    if (machineModel == EnumToString( VM_A4517 ))
    {
        insertCardMessage = N_ ( "Smartmatic.SAES.GUI.Widgets.WaitingCardWidget.A4517.PleaseInsertCard" );
    }
    else
    {
        insertCardMessage = N_ ( "Smartmatic.SAES.GUI.Widgets.WaitingCardWidget.SAES3370.PleaseInsertCard" );
    }

    progress->setInfoTitleConfig ( SAESGUIConfigurationManager::getInstance()->GetVotingWindowEndMessagelabelConfig() );
    progress->setInfoTextConfig ( SAESGUIConfigurationManager::getInstance()->GetVotingWindowEndMessagelabelConfig() );
    progress->setAccessibleName ( "WaitingForCardInfoContainer" );

    viewOnlyCard();

    setTitle ( false );
    setShowBorder ( true );
    setWidget ( progress );
    setName ( SAESGUIConfigurationManager::getInstance()->GetVotingExperienceWindowName() );
    setAccessibleName ( "WaitingForCardWidget" );
}

WaitingForCardWidget::~WaitingForCardWidget()
{
    remove();

    if ( progress )
    {
        delete progress;
        progress = NULL;
    }
}

void WaitingForCardWidget::viewOnlyCard()
{
    state = ONLY_CARD;
    update();
}

void WaitingForCardWidget::viewCardAndBarcode()
{
    state = CARD_AND_BARCODE;
    update();
}

void WaitingForCardWidget::viewCardAndNotBarcode()
{
    state = CARD_AND_NOT_BARCODE;
    update();
}

void WaitingForCardWidget::viewReconfigureBarcode()
{
    state = RECONFIGURE_BARCODE;
    update();
}

void WaitingForCardWidget::viewCardValidate()
{
    state = CARD_VALIDATE;
    update();
}

void WaitingForCardWidget::viewErrorCardValidate()
{
    state = ERROR_CARD;
    update();
}

void WaitingForCardWidget::viewErrorCardAID()
{
    state = ERROR_CARD_AID;
    update();
}

void WaitingForCardWidget::viewErrorCardPIN()
{
    state = ERROR_CARD_PIN;
    update();
}

void WaitingForCardWidget::viewErrorCardGeneric()
{
    state = ERROR_CARD_GENERIC;
    update();
}

void WaitingForCardWidget::viewErrorCardUsed()
{
    state = ERROR_CARD_USED;
    update();
}

void WaitingForCardWidget::update()
{
    switch ( state )
    {
        case ONLY_CARD:
            progress->showInfoTitle();
            progress->setInfoTitle ( FormatLabel::format ( N_ ( "Smartmatic.SAES.GUI.Widgets.WaitingCardWidget.TitleInsertCard" ) ) );
            progress->setImage ( "ui/waitingForVoterCard.gif" );

            {
                std::string text =
                    FormatLabel::format ( insertCardMessage ) +
                    FormatLabel::format ( N_ ( "Smartmatic.SAES.GUI.Widgets.WaitingCardWidget.PleaseInsertCardAux" ) );

                progress->setInfoText ( text );
            }

            progress->hideInfoFooter();
            break;

        case CARD_AND_BARCODE:
            progress->showInfoTitle();
            progress->setInfoTitle ( FormatLabel::format ( N_ ( "Smartmatic.SAES.GUI.Widgets.WaitingCardWidget.TitleInsertCardOrScanVote" ) ) );
            progress->setImage ( "ui/waitingForVoterCardOrVoteScan.gif" );

            {
                std::string text =
                    FormatLabel::format ( insertCardMessage ) +
                    FormatLabel::format ( N_ ( "Smartmatic.SAES.GUI.Widgets.WaitingCardWidget.PleaseInsertCardOrScanVoteAux" ) );

                progress->setInfoText ( text );
            }

            progress->hideInfoFooter();
            break;

        case CARD_AND_NOT_BARCODE:
            progress->showInfoTitle();
            progress->setInfoTitle ( FormatLabel::format ( N_ ( "Smartmatic.SAES.GUI.Widgets.WaitingCardWidget.TitleInsertCardAndBarcodeNotFound" ) ) );
            progress->setImage ( "ui/waitingForVoterCardScannerNotFound.gif" );

            {
                std::string text =
                    FormatLabel::format ( insertCardMessage ) +
                    FormatLabel::format ( N_ ( "Smartmatic.SAES.GUI.Widgets.WaitingCardWidget.PleaseInsertCardAndBarcodeNotFoundAux" ) );

                progress->setInfoText ( text );
            }

            progress->hideInfoFooter();
            break;

        case RECONFIGURE_BARCODE:
            progress->hideInfoTitle();
            progress->setImage ( "ui/waitingForVoterReconfigureBarcode.gif" );
            progress->setInfoText ( FormatLabel::format ( N_ ( "Smartmatic.SAES.GUI.Widgets.WaitingCardWidget.ReconfigureBarcode" ) ) );
            progress->hideInfoFooter();
            break;

        case CARD_VALIDATE:
            progress->showInfoTitle();
            progress->setInfoTitle ( FormatLabel::format ( N_ ( "Smartmatic.SAES.GUI.Widgets.WaitingCardWidget.TitleValidatingCardInserted" ) ) );
            progress->setImage ( Smartmatic::SAES::GUI::Operation::ImageResourcePath::PROGRESS );
            progress->setInfoText ( FormatLabel::format ( N_ ( "Smartmatic.SAES.GUI.Widgets.WaitingCardWidget.ValidatingCardInserted" ) ) );
            progress->hideInfoFooter();
            break;

        case ERROR_CARD_USED:
            progress->showInfoTitle();
            progress->setInfoTitle ( FormatLabel::format ( N_ ( "Smartmatic.SAES.GUI.Widgets.WaitingCardWidget.TitleErrorCardUsed" ) ) );
            progress->setImage ( "ui/CardUsed.gif" );
            progress->setInfoText ( FormatLabel::format ( N_ ( "Smartmatic.SAES.GUI.Widgets.WaitingCardWidget.ErrorCardUsed" ) ) );
            progress->hideInfoFooter();
            break;

        case ERROR_CARD:
            progress->showInfoTitle();
            progress->setInfoTitle ( "  " );
            progress->setImage ( "ui/IncorrectCardInsertion.gif" );
            progress->setInfoText ( FormatLabel::format ( N_ ( "Smartmatic.SAES.GUI.Widgets.WaitingCardWidget.CardCorrectInsertionIndication" ) ) );
            progress->showInfoFooter();
            progress->setInfoFooter ( FormatLabel::format ( N_ ( "Smartmatic.SAES.GUI.Widgets.WaitingCardWidget.CardNotProperlyInserted" ) ) );
            break;

        case ERROR_CARD_AID:
            progress->showInfoTitle();
            progress->setInfoTitle ( "  " );
            progress->setImage ( "ui/ErrorCardAID.gif" );
            progress->setInfoText ( FormatLabel::format ( N_ ( "Smartmatic.SAES.GUI.Widgets.WaitingCardWidget.ErrorCardAID" ) ) );
            progress->hideInfoFooter();
            break;

        case ERROR_CARD_PIN:
            progress->showInfoTitle();
            progress->setInfoTitle ( "  " );
            progress->setImage ( "ui/ErrorCardPIN.gif" );
            progress->setInfoText ( FormatLabel::format ( N_ ( "Smartmatic.SAES.GUI.Widgets.WaitingCardWidget.ErrorCardPIN" ) ) );
            progress->hideInfoFooter();
            break;

        case ERROR_CARD_GENERIC:
            progress->showInfoTitle();
            progress->setInfoTitle ( "  " );
            progress->setImage ( "ui/ErrorCardGeneric.gif" );
            progress->setInfoText ( FormatLabel::format ( N_ ( "Smartmatic.SAES.GUI.Widgets.WaitingCardWidget.ErrorCardGeneric" ) ) );
            progress->hideInfoFooter();
            break;

        default:
            break;
    }
}

void WaitingForCardWidget::forceNotChange ()
{
    flagNotChange = true;
}

void WaitingForCardWidget::refresh()
{
    if ( flagNotChange )
    {
        update();
    }
    else if ( SAESGUIConfigurationManager::getInstance()->getWaitingForCardWindowConfiguration().getAllowVotePreview() )
    {
        unsigned int numberOfDevices = DeviceTypeMonitorPool::getInstance()->getNumberOfDevicesByType ( DeviceType::CONFIGURATION_BARCODE );

        if ( numberOfDevices != 0 )
        {
            viewCardAndBarcode();
        }
        else
        {
            viewCardAndNotBarcode();
        }
    }
    else
    {
        viewOnlyCard();
    }
}
