/**
 * @file WaitingVotingWidget.cxx
 * @brief Body of the container widget class which is at the beginning of the voting experience.
 * Contains simulation buttons which allow for the simulation of the card and returning to the keypad lock.
 * @date 13/03/2014
 * @author Yadickson Soto
 */

#include "WaitingVotingWidget.hxx"
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>
#include <Operation/FormatLabel.hxx>
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets::Voting;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Operation;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::Log;

ISMTTLog * WaitingVotingWidget::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.Voting.WaitingVotingWidget", GETTEXT_PACKAGE );

WaitingVotingWidget::WaitingVotingWidget ()
    : StepWidget()
{
    this->mainFrame = NULL;
    this->mainVBox = NULL;
    this->buttons = NULL;

    setTitle ( false );
    setShowBorder ( true );

    mainFrame = manage ( new SmartmaticBasicEventBox () );
    mainVBox = manage ( new SmartmaticBasicVBox () );
    buttons = manage ( new ButtonsWidget ( false ) );
    buttons->set_no_show_all();

    mainVBox->pack_start ( *mainFrame, true, true );
    mainVBox->pack_end ( *buttons, false, false );

    buttons->setSizeAcceptButton ( 300, 80 );
    buttons->setSizeBackButton ( 300, 80 );

    buttons->getAcceptButton()->SetCustomName ( SAESGUIConfigurationManager::getInstance()->GetVotingWindowButtonName() );
    buttons->getBackButton()->SetCustomName ( SAESGUIConfigurationManager::getInstance()->GetVotingWindowButtonName() );
    buttons->getNullButton()->SetCustomName ( "Audio" );

    setName ( SAESGUIConfigurationManager::getInstance()->GetVotingExperienceWindowName() );

    mainFrame->setAccessibleName ( "WaitingForCardContainer" );
    mainVBox->setAccessibleName ( "WaitingForCardVerticalContainer" );
    buttons->getAcceptButton()->setAccessibleName ( "Simulate" );
    buttons->getBackButton()->setAccessibleName ( "Back" );
    buttons->getNullButton()->setAccessibleName ( "Audio" );
    setAccessibleName ( "WaitingVotingWidget" );

    StepWidget::setWidget ( mainVBox );
    hideButtons();
    show();
}

WaitingVotingWidget::~WaitingVotingWidget()
{
    remove();
}

void WaitingVotingWidget::hideButtons()
{
    buttons->showButton ( false, false, false, false );
    buttons->set_visible ( false );
}

void WaitingVotingWidget::showButtons()
{
    bool showSim = SAESGUIConfigurationManager::getInstance()->getWaitingForCardWindowConfiguration().getShowSimulateButton();
    bool showBack = SAESGUIConfigurationManager::getInstance()->getWaitingForCardWindowConfiguration().getShowSimulateButton();
    bool showAudio = SAESGUIConfigurationManager::getInstance()->getWaitingForCardWindowConfiguration().getShowSimulateButton();

    buttons->showButton ( false, showSim, showBack, showAudio );
    buttons->set_visible ( showSim || showBack );
}

void WaitingVotingWidget::refresh()
{
    buttons->setTextAcceptButton ( FormatLabel::format ( N_ ( "Smartmatic.SAES.GUI.Widgets.WaitingCardWidget.SimulateCard" ) ) );
    buttons->setTextBackButton ( FormatLabel::format ( N_ ( "Smartmatic.SAES.GUI.Widgets.PartySelectionWidget.Back" ) ) );
    buttons->setTextNullButton ( FormatLabel::format ( N_ ( "Audio Voting" ) ) );
    buttons->clearSignals();

    showButtons();
}

sigc::signal<void> WaitingVotingWidget::getSignalSim()
{
    return buttons->getSignalAcceptButtonClicked();
}

sigc::signal<void> WaitingVotingWidget::getSignalBack()
{
    return buttons->getSignalBackButtonClicked();
}

sigc::signal<void> WaitingVotingWidget::getSignalAudioVoting()
{
    return buttons->getSignalNullButtonClicked();
}

void WaitingVotingWidget::setWidget ( Gtk::Widget * widget )
{
    mainFrame->remove();
    mainFrame->add ( *widget );
    mainFrame->show_all_children();
    show();
}
