/**
 * @file WaitingVotingWidget.hxx
 * @brief Header of the container widget class which is at the beginning of the voting experience.
 * Contains simulation buttons which allow for the simulation of the card and returning to the keypad lock.
 * @date 13/03/2014
 * @author Yadickson Soto
 */

#ifndef MAIN_VOTING_WIDGET_HXX_
#define MAIN_VOTING_WIDGET_HXX_

#include <Gui/Widgets/ProgressWidget.hxx>
#include <Widgets/ButtonsWidget.hxx>
#include <Widgets/StepWidget.hxx>
#include <Widgets/SmartmaticBasicEventBox.hxx>
#include <Widgets/SmartmaticBasicVBox.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                namespace Voting
                {
                    /**
                     * @class	WaitingVotingWidget
                     * @brief	Class main container widget for initialize the voting experience.
                     * Contains the simulation buttons and a main frame to place the dual waiting for card widget.
                     * @author	Yadickson Soto
                     * @date	13/03/2014
                     */
                    class WaitingVotingWidget : public Smartmatic::GUI::Widgets::StepWidget
                    {
                        public:

                            /**
                             * @fn	WaitingVotingWidget::WaitingVotingWidget ();
                             * @brief	Class constructor.
                             * @author	Yadickson Soto
                             * @date	13/03/2014
                             */
                            WaitingVotingWidget ();
                            /**
                             * @fn	virtual WaitingVotingWidget::~WaitingVotingWidget();
                             * @brief	Class destructor.
                             * @author	Yadickson Soto
                             * @date	13/03/2014
                             */
                            virtual ~WaitingVotingWidget();
                            /**
                             * @fn	void WaitingVotingWidget::hideButtons();
                             * @brief	hide (card simulation and back) buttons method.
                             * @author	Yadickson Soto
                             * @date	13/03/2014
                             */
                            void hideButtons();
                            /**
                             * @fn	void WaitingVotingWidget::showButtons();
                             * @brief	show (card simulation and back) buttons method.
                             * @author	Yadickson Soto
                             * @date	13/03/2014
                             */
                            void showButtons();
                            /**
                             * @fn	virtual void WaitingVotingWidget::refresh();
                             * @brief	refresh widget method.
                             * @author	Yadickson Soto
                             * @date	13/03/2014
                             */
                            virtual void refresh();
                            /**
                             * @fn	virtual void setWidget(Gtk::Widget * widget);
                             * @brief	widget setter method.
                             * @author	Yadickson Soto
                             * @date	13/03/2014
                             * @param	widget	widget.
                             */
                            virtual void setWidget ( Gtk::Widget * widget );
                            /**
                             * @fn	sigc::signal<void> WaitingVotingWidget::getSignalSim();
                             * @brief	Simulated signal getter method.
                             * @author	Yadickson Soto
                             * @date	13/03/2014
                             * @return	signal simulation.
                             */
                            sigc::signal<void> getSignalSim();
                            /**
                             * @fn	sigc::signal<void> WaitingVotingWidget::getSignalBack();
                             * @brief	Back signal getter method.
                             * @author	Yadickson Soto
                             * @date	13/03/2014
                             * @return	signal back.
                             */
                            sigc::signal<void> getSignalBack();

                            /**
                             * @brief  Signal for simulating audio voting.
                             * @author manuel.arguelles
                             * @date   Oct 10, 2017
                             * @return Signal of audio voting button.
                             */
                            sigc::signal<void> getSignalAudioVoting();

                        private:

                            Smartmatic::GUI::Widgets::SmartmaticBasicEventBox * mainFrame; ///< main frame
                            Smartmatic::GUI::Widgets::SmartmaticBasicVBox * mainVBox; ///< main vbox
                            Smartmatic::GUI::Widgets::ButtonsWidget * buttons; ///< buttons widget

                            static Smartmatic::Log::ISMTTLog * logger;  ///< logger
                    };
                }
            }
        }
    }
}

#endif /* MAIN_VOTING_WIDGET_HXX_ */
