/**
 * @file	WarningVotingInfoWidget.cxx
 * @brief	Declares the ballot option info widget class which appears when too many ballot options are selected.
 * @author	Yadickson Soto
 * @date	11/03/2014
 */

#include "WarningVotingInfoWidget.hxx"
#include <Environment/Configurations/resource-path-provider.h>
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::GUI::Operation;
using namespace Smartmatic::Environment;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Configuration;

WarningVotingInfoWidget::WarningVotingInfoWidget ( unsigned int maximum )
    : SmartmaticBasicEventBox (), maximum ( maximum )
{
    image = manage ( new SmartmaticBasicImage () );
    vbox = manage ( new SmartmaticBasicVBox () );
    hbox = manage ( new SmartmaticBasicHBox () );
    instructionTitle = manage ( new SmartmaticBasicLabel () );
    instructionInfo = manage ( new SmartmaticBasicLabel () );
    frame = manage ( new SmartmaticBasicEventBox () );

    hbox->pack_start ( *image, false, false, 5 );
    hbox->pack_start ( *instructionTitle, true, true, 5 );

    LabelConfiguration titleConfig = SAESGUIConfigurationManager::ConvertToLabelConfiguration ( SAESGUIConfigurationManager::getInstance()->GetBallotOptionSelectionConfiguration().getWarningInstructionTitle() );
    LabelConfiguration infoConfig = SAESGUIConfigurationManager::ConvertToLabelConfiguration ( SAESGUIConfigurationManager::getInstance()->GetBallotOptionSelectionConfiguration().getWarningInstructionInfo() );

    LabelConfiguration::SetLabelConfiguration ( instructionTitle, titleConfig );
    LabelConfiguration::SetLabelConfiguration ( instructionInfo, infoConfig );

    vbox->pack_start ( *hbox, false, false, 5 );
    vbox->pack_start ( *instructionInfo );

    image->setAccessibleName ( "WarningVoting" );
    hbox->setAccessibleName ( "HWarningVoting" );
    vbox->setAccessibleName ( "VWarningVoting" );
    frame->setAccessibleName ( "FrameContainer" );
    instructionTitle->setAccessibleName ( "WarningInstructionTitle" );
    instructionInfo->setAccessibleName ( "WarningInstructionInfo" );
    setAccessibleName ( "WarningVotingInfoWidget" );

    std::string imageFile = "ui/warning.png";
    imageFile = ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, imageFile );
    image->clear();
    image->set ( imageFile );

    frame->add ( *vbox );

    add ( * frame );
    show_all_children();

    set_border_width ( SAESGUIConfigurationManager::getInstance()->GetBallotOptionSelectionConfiguration().getBorderInfo() );
    frame->set_border_width ( SAESGUIConfigurationManager::getInstance()->GetBallotOptionSelectionConfiguration().getBorderWarning() );

    if ( SAESGUIConfigurationManager::getInstance()->GetBallotOptionSelectionConfiguration().getUseWarningColor() )
    {
        frame->modify_bg ( Gtk::STATE_NORMAL, SAESGUIConfigurationManager::ConvertToGdkColor ( SAESGUIConfigurationManager::getInstance()->GetBallotOptionSelectionConfiguration().getWarningFillColor() ) );
        modify_bg ( Gtk::STATE_NORMAL, SAESGUIConfigurationManager::ConvertToGdkColor ( SAESGUIConfigurationManager::getInstance()->GetBallotOptionSelectionConfiguration().getWarningBorderColor() ) );

    }
}

WarningVotingInfoWidget::~WarningVotingInfoWidget()
{

}

void WarningVotingInfoWidget::refresh()
{
    instructionTitle->set_text ( Glib::ustring::compose ( _ ( "Warning Instruction Voting Title" ) , maximum ) );
    instructionInfo->set_text ( Glib::ustring::compose ( _ ( "Warning Instruction Voting Information" ) , maximum ) );
}
