/**
 * @file	WarningVotingInfoWidget.hxx
 * @brief	Declares the ballot option info widget class which appears when too many ballot options are selected.
 * @author	Yadickson Soto
 * @date	11/03/2014
 */

#ifndef _WARNING__INFO_WIDGET_H_
#define _WARNING__INFO_WIDGET_H_

#include <Widgets/SmartmaticBasicEventBox.hxx>
#include <Widgets/SmartmaticBasicVBox.hxx>
#include <Widgets/SmartmaticBasicHBox.hxx>
#include <Widgets/SmartmaticBasicLabel.hxx>
#include <Widgets/SmartmaticBasicImage.hxx>
#include <Widgets/RefreshListener.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	WarningVotingInfoWidget
                 * @brief	Ballot option widget.
                 * @author	Yadickson Soto
                 * @date	11/03/2014
                 */

                class WarningVotingInfoWidget: public Smartmatic::GUI::Widgets::SmartmaticBasicEventBox, Smartmatic::GUI::Widgets::RefreshListener
                {
                    public:
                        /**
                         * @fn	WarningVotingInfoWidget ( unsigned int maximum );
                         * @brief	class constructor.
                         * @author	Yadickson Soto
                         * @date	11/03/2014
                         * @param	maximum The maximum selection
                         */
                        explicit WarningVotingInfoWidget ( unsigned int maximum );

                        /**
                         * @fn	virtual ~WarningVotingInfoWidget();
                         * @brief	class destructor.
                         * @author	Yadickson Soto
                         * @date	11/03/2014
                         */
                        virtual ~WarningVotingInfoWidget();

                        /**
                         * @fn	void refresh();
                         * @brief	Refresh images and labels.
                         * @author	Yadickson Soto
                         * @date	11/03/2014
                         */
                        void refresh();

                    protected:

                        Smartmatic::GUI::Widgets::SmartmaticBasicImage * image; ///< The image
                        Smartmatic::GUI::Widgets::SmartmaticBasicVBox * vbox; ///< Vertical box
                        Smartmatic::GUI::Widgets::SmartmaticBasicHBox * hbox; ///< Horizontal box
                        Smartmatic::GUI::Widgets::SmartmaticBasicEventBox * frame; ///< The frame container
                        Smartmatic::GUI::Widgets::SmartmaticBasicLabel * instructionTitle; ///< The instruction title
                        Smartmatic::GUI::Widgets::SmartmaticBasicLabel * instructionInfo; ///< The instruction information
                        unsigned int maximum; ///< The maximum selection
                };
            }
        }
    }
}

#endif // _WARNING__INFO_WIDGET_H_
