/**
 * @file ToolkitElement.h
 * @brief Header class toolkit element
 * @date 28/05/2011
 * @author Gerardo Hernandez
 */

#ifndef TOOLKITELEMENT_H_
#define TOOLKITELEMENT_H_

#include <gtkmm.h>
#include "WizardConfiguration.h"
#include <Gui/Widgets/Menu/menu-option.h>
#include <Widgets/SmartmaticBasicFrame.hxx>
#include <Widgets/SmartmaticBasicLabel.hxx>
#include <Widgets/SmartmaticBasicEventBox.hxx>
#include <Widgets/SmartmaticBasicVBox.hxx>
#include <Widgets/SmartmaticBasicImage.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {

                /**
                 * @class	ToolkitElement
                 * @brief	Toolkit element.
                 * @author	Youssef.tourkmani
                 * @date	25/10/2012
                 */
                class ToolkitElement : public Smartmatic::GUI::Widgets::SmartmaticBasicFrame
                {
                    public:

                        /**
                         * @fn	ToolkitElement::ToolkitElement(std::string imagepath, std::string messageA,
                         * 			MenuOption optionA, WizardConfiguration currentWizardConfiguration,
                         * 			bool useMessage = false);
                         * @brief	Constructor.
                         * @author	Youssef.tourkmani
                         * @date	25/10/2012
                         * @param	imagepath										The imagepath.
                         * @param	messageA										The message a.
                         * @param	optionA											The option a.
                         * @param	currentWizardConfiguration	The current wizard configuration.
                         * @param	useMessage									(optional) message describing the use.
                         */
                        ToolkitElement ( std::string imagepath, std::string messageA, MenuOption optionA,
                                         WizardConfiguration currentWizardConfiguration,  bool useMessage = false );

                        /**
                         * @fn	virtual ToolkitElement::~ToolkitElement();
                         * @brief	Destructor.
                         * @author	Youssef.tourkmani
                         * @date	25/10/2012
                         */
                        virtual ~ToolkitElement();

                        /**
                         * @typedef	sigc::signal<void, MenuOption> toolkit_element_sigc
                         * @brief	signals definitions.
                         */
                        typedef sigc::signal<void, MenuOption> toolkit_element_sigc;

                        /**
                         * @fn	toolkit_element_sigc ToolkitElement::ToolkitElementClickSigc()
                         * @brief	Gets the toolkit element click sigc.
                         * @author	Youssef.tourkmani
                         * @date	25/10/2012
                         * @return	.
                         */
                        toolkit_element_sigc ToolkitElementClickSigc()
                        {
                            return m_toolkit_element_sigc;
                        };

                    protected:
                        toolkit_element_sigc m_toolkit_element_sigc;	///< The toolkit element sigc

                        /**
                         * @fn	virtual bool ToolkitElement::on_eventbox_clicked(GdkEventButton* event);
                         * @brief	Executes the eventbox clicked action.
                         * @author	Youssef.tourkmani
                         * @date	25/10/2012
                         * @param	event	If non-null, the event.
                         * @return	true if it succeeds, false if it fails.
                         */
                        virtual bool on_eventbox_clicked ( GdkEventButton * event );

                    private:

                        Smartmatic::GUI::Widgets::SmartmaticBasicImage * image;	///< The image
                        std::string message;	///< The message
                        Smartmatic::GUI::Widgets::SmartmaticBasicVBox * vbox;	///< The vbox
                        Smartmatic::GUI::Widgets::SmartmaticBasicEventBox * clickEventBox; ///< The click event box
                        Smartmatic::GUI::Widgets::SmartmaticBasicLabel * title;	///< The title
                        MenuOption option;	///< The option

                };
            }
        }
    }
}

#endif /* TOOLKITELEMENT_H_ */
