/**
 * @file WizardToolkit.h
 * @brief Header wizard toolkit class
 * @date 28/05/2011
 * @author Gerardo Hernandez
 */

#ifndef WIZARDTOOLKIT_H_
#define WIZARDTOOLKIT_H_

#include <gtkmm.h>
#include <Gui/Widgets/Menu/menu-option.h>
#include <Gui/Widgets/Wizard/ToolkitElement.h>
#include <Gui/Widgets/Wizard/WizardConfiguration.h>
#include <Widgets/SmartmaticBasicFrame.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {

                /**
                 * @class	WizardToolkit
                 * @brief	Wizard toolkit.
                 * @author	Youssef.tourkmani
                 * @date	25/10/2012
                 */
                class WizardToolkit : public Smartmatic::GUI::Widgets::SmartmaticBasicFrame
                {
                    public:

                        /**
                         * @fn	WizardToolkit::WizardToolkit( const std::vector<MenuOption>& optionsA, WizardConfiguration currentWizardConfiguration );
                         * @brief	Constructor.
                         * @author	Youssef.tourkmani
                         * @date	25/10/2012
                         * @param	optionsA										The options a.
                         * @param	currentWizardConfiguration	The current wizard configuration.
                         */
                        WizardToolkit ( const std::vector<MenuOption>& optionsA, WizardConfiguration currentWizardConfiguration );

                        /**
                         * @fn	virtual WizardToolkit::~WizardToolkit();
                         * @brief	Destructor.
                         * @author	Youssef.tourkmani
                         * @date	25/10/2012
                         */
                        virtual ~WizardToolkit();

                        /**
                         * @typedef	sigc::signal<void, MenuOption> wizard_toolkit_element_sigc
                         * @brief	signals definitions.
                         */
                        typedef sigc::signal<void, MenuOption> wizard_toolkit_element_sigc;

                        /**
                         * @fn	wizard_toolkit_element_sigc WizardToolkit::WizardToolkitElementClickSigc()
                         * @brief	Gets the wizard toolkit element click sigc.
                         * @author	Youssef.tourkmani
                         * @date	25/10/2012
                         * @return	.
                         */
                        wizard_toolkit_element_sigc WizardToolkitElementClickSigc()
                        {
                            return m_wizard_toolkit_element_sigc;
                        };

                    protected:
                        wizard_toolkit_element_sigc m_wizard_toolkit_element_sigc;	///< The wizard toolkit element sigc

                    private:
                        std::vector<MenuOption> options;	///< Options for controlling the operation
                        Gtk::Table * table;	///< The table

                        /**
                         * @fn	void WizardToolkit::on_element_click(MenuOption option);
                         * @brief	Handles element click signals.
                         * @author	Youssef.tourkmani
                         * @date	25/10/2012
                         * @param	option	The option.
                         */
                        void on_element_click ( MenuOption option );
                };
            }
        }
    }
}

#endif /* WIZARDTOOLKIT_H_ */
