/**
 * @file	ballot-option-selection-widget.h
 * @brief	Declares the ballot option selection widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#ifndef _BALLOT_OPTION_SELECTION_WIDGET_H_
#define _BALLOT_OPTION_SELECTION_WIDGET_H_

#include <gtkmm.h>
#include "Configuration/SaesGUIConfiguration-schema.hxx"
#include <Voting/Election/election-schema.hxx>
#include <Widgets/smartmatic-button.h>
#include "Runtime/Environment/saes-directories.h"
#include "Gui/Widgets/voting-frame-base.h"
#include <Widgets/SmartmaticBasicFrame.hxx>
#include <Widgets/SmartmaticBasicEventBox.hxx>
#include <Widgets/SmartmaticBasicLabel.hxx>
#include <Widgets/SmartmaticBasicVBox.hxx>
#include <Widgets/BoxSelectionWidget.hxx>
#include <Widgets/ISizeWidget.hxx>
#include <Gui/Widgets/VotingInfoWidget.hxx>
#include <Gui/Widgets/WarningVotingInfoWidget.hxx>


namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                class ComplexBallotOptionWidget;
                class BallotOptionTableWidget;
                class BallotOptionButtonWidget;

                /**
                 * @class	BallotOptionSelectionWidget
                 * @brief	Header class BallotOptionSelectionWidget.
                 * @author	Juan delgado &lt;juan.delgado@smartmatic.com&gt;
                 * @date	4/29/2011
                 */

                class BallotOptionSelectionWidget: public VotingFrameBase
                {
                    public:

                        /**
                         * @fn	BallotOptionSelectionWidget::BallotOptionSelectionWidget ( Smartmatic::SAES::Voting::Election::Contest * contest );
                         * @brief	class constructor.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @param	contest	contest that hold ballot options to be displayed.
                         */

                        explicit BallotOptionSelectionWidget ( Smartmatic::SAES::Voting::Election::Contest * contest );

                        /**
                         * @fn	virtual BallotOptionSelectionWidget::~BallotOptionSelectionWidget();
                         * @brief	class destructor.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */

                        virtual ~BallotOptionSelectionWidget();

                        /**
                         * @fn	void BallotOptionSelectionWidget::Initialize ( std::list<Smartmatic::SAES::Voting::Election::Eligible_option * > & ballotList,
                         * 			std::list<Smartmatic::SAES::Voting::Election::Eligible_option * > & principalBallotList,
                         * 			std::list<Smartmatic::SAES::Voting::Election::Eligible_option * > & standInBallotList,
                         * 			Smartmatic::SAES::Runtime::Environment::SaesDirectories & saesDir );
                         * @brief	calculate position and size of ballot option widgets.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @param [in,out]	ballotList	List of ballots.
                         * @param	principalBallotList 	list of all principal ballots to be displayed.
                         * @param	standInBallotList			list of all stand in ballots to be displayed.
                         * @param	saesDir								The saes dir.
                         */

                        void Initialize ( std::list<Smartmatic::SAES::Voting::Election::Eligible_option * > & ballotList,
                                          std::list<Smartmatic::SAES::Voting::Election::Eligible_option * > & principalBallotList,
                                          std::list<Smartmatic::SAES::Voting::Election::Eligible_option * > & standInBallotList,
                                          Smartmatic::SAES::Runtime::Environment::SaesDirectories & saesDir );

                        /**
                         * @fn	Smartmatic::SAES::Voting::Election::Contest * BallotOptionSelectionWidget::getContest();
                         * @brief	get contest.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @return	The contest.
                         */

                        Smartmatic::SAES::Voting::Election::Contest * getContest();

                        /**
                         * @fn	int BallotOptionSelectionWidget::GetTotalBallotsDisplayed();
                         * @brief	Gets the total ballots displayed.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @return	The total ballots displayed.
                         */

                        int GetTotalBallotsDisplayed();

                        /**
                         * @fn	void BallotOptionSelectionWidget::RefreshLabels();
                         * @brief	Refresh labels.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */

                        void RefreshLabels();

                        /**
                         * @typedef	sigc::signal<void> type_accept_clicked
                         * @brief	signals definitions.
                         */

                        typedef sigc::signal<void> type_accept_clicked;

                        /**
                         * @typedef	sigc::signal<void> type_back_clicked
                         * @brief	Defines an alias representing the type back clicked. .
                         */

                        typedef sigc::signal<void> type_back_clicked;

                        /**
                         * @typedef	sigc::signal<void> type_clear_clicked
                         * @brief	signals definitions to clear all ballot.
                         */

                        typedef sigc::signal<void> type_clear_clicked;

                        /**
                         * @typedef	sigc::signal<void, std::string, bool > type_ballotOption_clicked
                         * @brief	Defines an alias representing the type ballot option clicked. .
                         */

                        typedef sigc::signal<void, std::string, bool > type_ballotOption_clicked;

                        /**
                         * @fn	void BallotOptionSelectionWidget::ClearVisualSelection();
                         * @brief	Clears the visual selection.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */

                        void ClearVisualSelection();

                        /**
                         * @fn	type_accept_clicked BallotOptionSelectionWidget::accept_clicked();
                         * @brief	signals connect methods.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @return	.
                         */

                        type_accept_clicked accept_clicked();

                        /**
                         * @fn	type_back_clicked BallotOptionSelectionWidget::back_clicked();
                         * @brief	Gets the back clicked.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @return	.
                         */

                        type_back_clicked back_clicked();

                        /**
                         * @fn	type_accept_clicked BallotOptionSelectionWidget::clear_clicked();
                         * @brief	Gets the clear clicked.
                         * @author	Yadickson Soto
                         * @date	24/04/2014
                         * @return	The signal
                         */

                        type_clear_clicked clear_clicked();

                        /**
                         * @fn	type_ballotOption_clicked BallotOptionSelectionWidget::ballotOption_clicked();
                         * @brief	Gets the ballot option clicked.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @return	.
                         */

                        type_ballotOption_clicked ballotOption_clicked();

                        /**
                         * @fn	unsigned int BallotOptionSelectionWidget::GetTallyPosition()
                         * @brief	Gets tally position.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	The tally position.
                         */
                        unsigned int GetTallyPosition()
                        {
                            return tallyPosition;
                        }

                        /**
                         * @fn	virtual void BallotOptionSelectionWidget::SetWidgetEnabled ( bool enabled = true );
                         * @brief	Sets widget enabled.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @param	enabled	(optional) the enabled.
                         */
                        virtual void SetWidgetEnabled ( bool enabled = true );

                        /**
                         * @fn	virtual void BallotOptionSelectionWidget::refresh();
                         * @brief	refresh widget.
                         * @author	Yadickson Soto
                         * @date	22/04/2012
                         */
                        virtual void refresh();

                        /**
                         * @fn	virtual void BallotOptionSelectionWidget::SetChildCustomAttribute ( bool enabled = false );
                         * @brief	Sets whether the parent object is a custom attribute widget.
                         * @author	gabriel.jaimes
                         * @date	01/06/2022
                         * @param	enabled	(optional) the enabled.
                         */
                        virtual void SetChildCustomAttribute ( bool enabled = false );

                    protected:
                        /**
                         * @brief signals declaration
                         */
                        type_ballotOption_clicked m_ballotOption_clicked;   ///< The ballot option clicked
                        type_accept_clicked m_accept_clicked;   ///< The accept clicked
                        type_back_clicked m_back_clicked;   ///< The back clicked
                        type_clear_clicked m_clear_clicked;   ///< The clear clicked
                        bool m_isChildCustomAttribute; ///< true if the parent object is a custom attribute widget, false otherwise

                        /**
                         * @fn	void BallotOptionSelectionWidget::on_clearButton_clicked();
                         * @brief	signal button clear, clear all ballots selected.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */

                        void on_clearButton_clicked();

                        /**
                         * @fn	void BallotOptionSelectionWidget::on_acceptButton_clicked();
                         * @brief	send the ballots selected.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */

                        void on_acceptButton_clicked();

                        /**
                         * @fn	void BallotOptionSelectionWidget::on_backButton_clicked();
                         * @brief	send back signal.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */

                        void on_backButton_clicked();
                        /**
                         * @fn	virtual Smartmatic::GUI::Configuration::LabelConfiguration BallotOptionSelectionWidget::getTitleLabelConfig();
                         * @brief	virtual method getter label config.
                         * @author	Gabriel Jaimes
                         * @date	27/05/2022
                         * @return	title label config.
                         */
                        virtual Smartmatic::GUI::Configuration::LabelConfiguration getTitleLabelConfig();
                        /**
                         * @fn	virtual Smartmatic::GUI::Configuration::LabelConfiguration BallotOptionSelectionWidget::getSubtitleLabelConfig();
                         * @brief	virtual method getter label config.
                         * @author	Gabriel Jaimes
                         * @date	27/05/2022
                         * @return	subtitle label config.
                         */
                        virtual Smartmatic::GUI::Configuration::LabelConfiguration getSubtitleLabelConfig();
                        /**
                         * @fn	virtual Smartmatic::GUI::Configuration::LabelConfiguration BallotOptionSelectionWidget::getBottomLabelConfig();
                         * @brief	virtual method getter label config.
                         * @author	Yadickson Soto
                         * @date	25/04/2012
                         * @return	bottom label config.
                         */
                        virtual Smartmatic::GUI::Configuration::LabelConfiguration getBottomLabelConfig();
                        /**
                         * @fn	virtual std::string BallotOptionSelectionWidget::getBottomText();
                         * @brief	virtual method getter title.
                         * @author	Yadickson Soto
                         * @date	25/04/2012
                         * @return	bottom.
                         */
                        virtual std::string getBottomText();
                        /**
                         * @fn	virtual std::string getHelp();
                         * @brief	virtual method getter help information.
                         * @author	Gabriel Jaimes
                         * @date	27/05/2022
                         * @return	subtitle label config.
                         */
                        virtual std::string getHelp();
                        /**
                         * @fn	virtual std::string getDistrictDescription();
                         * @brief	virtual method getter district description information.
                         * @author	Gabriel Jaimes
                         * @date	27/05/2022
                         * @return	subtitle label config.
                         */
                        virtual std::string getDistrictDescription();
                        /**
                         * @fn	virtual virtual void buildHeader();
                         * @brief	build header information.
                         * @author	Gabriel Jaimes
                         * @date	27/05/2022
                         * @return	subtitle label config.
                         */
                        virtual void buildHeader();

                    private:

                        /**
                         * @fn	void BallotOptionSelectionWidget::CheckButtonsLogic();
                         * @brief	check the visual logic buttons.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */

                        void CheckButtonsLogic();

                        /**
                         * @fn	void BallotOptionSelectionWidget::ButtonsLogicShowHide ( bool clear, bool accept,
                         * 			bool back );
                         * @brief	hide or show the buttons.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @param	clear 	if true show button clear, else hide button.
                         * @param	accept	if true show button accept, else hide button.
                         * @param	back		if true show button back, else hide button.
                         */

                        void ButtonsLogicShowHide ( bool clear, bool accept, bool back );

                        /**
                         * @fn	void onMinSignal ( unsigned int minValue, unsigned int size );
                         * @brief	Callback minimum ballot signal.
                         * @author	Yadickson Soto
                         * @date	24/02/2014
                         * @param	minValue current minimum value
                         * @param	size current size
                         */
                        void onMinSignal ( unsigned int minValue, unsigned int size );

                        /**
                         * @fn	void onMaxSignal ( unsigned int maxValue );
                         * @brief	Callback maximum ballot signal.
                         * @author	Yadickson Soto
                         * @date	24/02/2014
                         * @param	maxValue current maximum value
                         */
                        void onMaxSignal ( unsigned int maxValue );

                        /**
                         * @fn	void onBoxClicked ( Smartmatic::GUI::Widgets::BoxSelectionWidget * widget );
                         * @brief	method box click.
                         * @author	Yadickson Soto
                         * @date	24/02/2014
                         * @param	widget box selected
                         */
                        void onBoxClicked ( Smartmatic::GUI::Widgets::BoxSelectionWidget * widget );

                        /**
                         * Child Widgets
                         */
                        Smartmatic::GUI::Widgets::SmartmaticBasicVBox * externalBox; ///< The external box
                        Smartmatic::GUI::Widgets::SmartmaticBasicLabel * titleLabel;	///< The title label
                        Smartmatic::GUI::Widgets::SmartmaticBasicLabel * subtitleLabel;	///< The subtitle label
                        Smartmatic::GUI::Widgets::SmartmaticBasicEventBox * listFrame;	///< The header frame
                        Smartmatic::GUI::Widgets::SmartmaticBasicEventBox * clientAreaFrame;	///< The client area frame
                        Smartmatic::GUI::Widgets::SmartmaticBasicEventBox * infoFrame;	///< The info frame
                        Smartmatic::GUI::Widgets::SmartmaticBasicEventBox * bottomFrame;	///< The bottom frame

                        BallotOptionTableWidget * ballotOptionTableWidget;	///< The client area table
                        BallotOptionButtonWidget * ballotOptionButtonWidget; ///< ballot option button widget

                        Smartmatic::SAES::GUI::Widgets::VotingInfoWidget * infoVoting; ///< The voting instructions
                        Smartmatic::SAES::GUI::Widgets::WarningVotingInfoWidget * warningVoting; ///< The too-many-selected warning

                        std::string SoundBallotS;   ///< The sound ballot s
                        unsigned int tallyPosition;	///< The tally position
                        bool showBackButton; ///< flag show back bottom

                        bool showInfoFrame; ///< Whether the voting instructions are being displayed currently
                        bool useInfoVoting; ///< Whether to show the voting instructions
                        bool useWarningVoting; ///< Whether to show a warning when too many candidates selected

                        Smartmatic::SAES::Voting::Election::Contest * contest;	///< The contest
                        ComplexBallotOptionWidget * ballotOptionListWidget; ///< The ballot option list widget

                        int padding; ///< padding between
                        int topHeight;   ///< The top height
                        int listHeight;   ///< The list height
                        int infoHeight;   ///< The info height
                        int bottomHeight;   ///< The bottom height

                        unsigned int listBallotsSelected; ///< The list ballots selected
                        unsigned int principalBallotsSelected;   ///< The principal ballots selected
                        unsigned int standInBallotsSelected; ///< The stand in ballots selected

                        int totalPrincipalBallots;  ///< The total principal ballots
                        int totalStandInBallots;	///< The total stand in ballots
                        bool loopbackSelection; ///< true to loopback selection
                        bool HideStandInLabelIfEmpty; ///< true if hide stand in label if there are no stand in candidate

                        std::list<Smartmatic::GUI::Widgets::ISizeWidget *>::iterator itWidget; ///< The iterator widget

                        bool 			m_widgetEnabled;	///< true to enable, false to disable the widget
                        bool 			m_skipAcceptSignal; ///< true to skip accept signal

                        unsigned int minimumAllowed; ///< the minimum number of selections allowed.
                        unsigned int maximumAllowed; ///< the maximum number of selections allowed.

                    private:

                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                };
            }
        }
    }
}

#endif // _BALLOT_OPTION_SELECTION_WIDGET_H_
