/**
 * @file	change-language-widget.h
 * @brief	Declares the change language widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */

#ifndef _CHANGE_LANGUAGE_WIDGET_H_
#define _CHANGE_LANGUAGE_WIDGET_H_

#include <gtkmm.h>
#include <vector>
#include "Widgets/image-selection-widget.h"
#include "Runtime/Environment/saes-directories.h"
#include <Voting/Election/ElectionInstalationLanguages.h>
#include <Widgets/StepWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	ChangeLanguageWidget
                 * @brief	Change language widget.
                 * @author	Cesar.bonilla
                 * @date	4/29/2011
                 */

                class ChangeLanguageWidget : public Smartmatic::GUI::Widgets::StepWidget
                {
                    public:

                        /**
                         * @fn	ChangeLanguageWidget::ChangeLanguageWidget();
                         * @brief	Constructor.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */

                        ChangeLanguageWidget();

                        /**
                         * @fn	ChangeLanguageWidget::~ChangeLanguageWidget();
                         * @brief	Finaliser.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */

                        ~ChangeLanguageWidget();

                        /**
                         * @fn	void ChangeLanguageWidget::init ( Smartmatic::SAES::Runtime::Environment::SaesDirectories * directories );
                         * @brief	Initialises this object.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @param [in,out]	directories	If non-null, the directories.
                         */
                        void init ( Smartmatic::SAES::Runtime::Environment::SaesDirectories * directories );

                        /**
                         * @fn	void ChangeLanguageWidget::initialize ( std::list<Smartmatic::SAES::Voting::Election::Language>& listLang,
                         * 			bool showOnOneLanguage );
                         * @brief	Initializes this object.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @param [in,out]	listLang	The list language.
                         * @param	showOnOneLanguage 	true to show, false to hide the on one language.
                         */
                        void initialize ( std::list<Smartmatic::SAES::Voting::Election::Language> & listLang, bool showOnOneLanguage );

                        /**
                         * @fn	bool ChangeLanguageWidget::loadDefaultLanguage();
                         * @brief	Loads the default language.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @return	true if it succeeds, false if it fails.
                         */

                        bool loadDefaultLanguage();

                        /**
                         * @typedef	sigc::signal<void> language_changed
                         * @brief	signals definitions.
                         */

                        typedef sigc::signal<void> language_changed;

                        /**
                         * @fn	language_changed ChangeLanguageWidget::LanguageChanged();
                         * @brief	Gets the language changed.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @return	.
                         */

                        language_changed LanguageChanged();

                        /**
                         * @fn	void ChangeLanguageWidget::SetSaveFile ( bool saveFileA );
                         * @brief	Sets a save file.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @param	saveFileA	true to save file a.
                         */

                        void SetSaveFile ( bool saveFileA );

                        /**
                         * @fn	void ChangeLanguageWidget::SetShowMessage ( bool shoMessageA );
                         * @brief	Sets a show message.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @param	shoMessageA	true to sho message a.
                         */

                        void SetShowMessage ( bool shoMessageA );

                    protected:

                        /**
                         * @fn	void ChangeLanguageWidget::on_image_selected ( const std::string& imageCode );
                         * @brief	Handles image selected signals.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @param	imageCode	The image code.
                         */

                        void on_image_selected ( const std::string& imageCode );


                    private:
                        bool saveFile;  ///< true to save file
                        bool showMessage;   ///< true to show, false to hide the message
                        Gtk::Label * labelMessage; ///< message
                        Smartmatic::GUI::Widgets::ImageSelectionWidget * imageWidget;	///< The image widget
                        Gtk::Alignment * clientAreaAlignment;	///< The client area alignment
                        Smartmatic::SAES::Runtime::Environment::SaesDirectories * directories;	///< The directories
                        language_changed m_language_changed;	///< The language changed
                        static Smartmatic::Log::ISMTTLog * logger;	///< The logger
                };
            }
        }
    }
}

#endif // _CHANGE_LANGUAGE_WIDGET_H_
