/**
 * @file	close-election-status-widget.h
 * @brief	Declares the close election status widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */

#ifndef _CLOSE_ELECTION_STATUS_WIDGET_H_
#define _CLOSE_ELECTION_STATUS_WIDGET_H_

#include <Widgets/wizard-widget-base.h>
#include "ProgressWidget.hxx"

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	CloseElectionStatusWidget
                 * @brief	Close election status widget.
                 * @author	Cesar.bonilla
                 * @date	4/29/2011
                 */

                class CloseElectionStatusWidget: public Smartmatic::GUI::Widgets::WizardWidgetBase
                {
                    public:

                        /**
                         * @fn	CloseElectionStatusWidget::CloseElectionStatusWidget ( ProgressWidget * progress );
                         * @brief	Default constructor.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @param	progress	widget with label and image.
                         */

                        explicit CloseElectionStatusWidget ( ProgressWidget * progress );

                        /**
                         * @fn	CloseElectionStatusWidget::~CloseElectionStatusWidget();
                         * @brief	Finaliser.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */

                        ~CloseElectionStatusWidget();
                        /**
                         * @fn	virtual void CloseElectionStatusWidget::initialize();
                         * @brief	Initializer method.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        virtual void initialize();
                        /**
                         * @fn	virtual void CloseElectionStatusWidget::dispose();
                         * @brief	virtual method stop.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        virtual void dispose();

                        /**
                         * @fn	virtual bool CloseElectionStatusWidget::isEnabledButtonExitWizard();
                         * @brief	Method getter is enabled button exit wizard.
                         * @author	Yadickson Soto
                         * @date	22/02/2012
                         * @return	true is enabled button exit wizard.
                         */
                        virtual bool isEnabledButtonExitWizard();

                    private:
                        Glib::Thread * m_thread; ///< The thread pointer

                        ProgressWidget * progress; ///< widget with label and image
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger

                        /**
                         * @fn	void CloseElectionStatusWidget::start();
                         * @brief	Method start persist codi files.
                         * @author	Yadickson Soto
                         * @date	16/02/2012
                         */
                        void start();

                        /**
                         * @fn	void CloseElectionStatusWidget::end();
                         * @brief	Method end persist codi files.
                         * @author	Yadickson Soto
                         * @date	16/02/2012
                         */
                        void end();

                        /**
                         * @fn	void CloseElectionStatusWidget::updateLabel ( std::string text );
                         * @brief	Method start persist codi files.
                         * @author	Yadickson Soto
                         * @date	16/02/2012
                         * @param	text	new text for widget.
                         */
                        void updateLabel ( std::string text );
                };
            }
        }
    }
}

#endif // _CLOSE_ELECTION_STATUS_WIDGET_H_
