/**
 * @file	confirmation-delete-widget.h
 * @brief	Declares the confirmation delete widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#ifndef _CONFIRMATION_DELETE_WIDGET_H_
#define _CONFIRMATION_DELETE_WIDGET_H_

#include <gtkmm.h>
#include <Widgets/smartmatic-button.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	ConfirmationDeleteWidget
                 * @brief	Confirmation delete widget.
                 * @author	Youssef.tourkmani
                 * @date	01/11/2012
                 */
                class ConfirmationDeleteWidget : public Gtk::Frame
                {
                    public:
                        /**
                         * @fn	ConfirmationDeleteWidget::ConfirmationDeleteWidget();
                         * @brief	Default constructor.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        ConfirmationDeleteWidget();

                        /**
                         * @fn	ConfirmationDeleteWidget::~ConfirmationDeleteWidget();
                         * @brief	Destructor.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        ~ConfirmationDeleteWidget();

                        /**
                         * @typedef	sigc::signal<void, bool> type_bool_signal
                         * @brief	Defines an alias representing the type bool signal.
                         */
                        typedef sigc::signal<void, bool> type_bool_signal;

                        /**
                         * @fn	type_bool_signal ConfirmationDeleteWidget::on_answer_emit();
                         * @brief	Executes the answer emit action.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	.
                         */
                        type_bool_signal on_answer_emit();

                    protected:
                        type_bool_signal m_answer_signal; ///< The done signal
                        Gtk::Label * label; ///< label message
                        Gtk::HButtonBox * btnBox; ///< The button box
                        Gtk::VBox * vbox; ///< The vbox
                        Gtk::Alignment * align; ///< The align
                        Smartmatic::GUI::Widgets::SmartmaticButton * deleteButton; ///< delete button
                        Smartmatic::GUI::Widgets::SmartmaticButton * backButton; ///< back button

                        /**
                         * @fn	void ConfirmationDeleteWidget::on_deleteButton_clicked();
                         * @brief	Handles delete button clicked signals.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void on_deleteButton_clicked();

                        /**
                         * @fn	void ConfirmationDeleteWidget::on_backButton_clicked();
                         * @brief	Handles back button clicked signals.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void on_backButton_clicked();

                    private:

                };
            }
        }
    }
}



#endif // _CONFIRMATION_DELETE_WIDGET_H_
