/**
 * @file	print-pv-report-widget.cc
 * @brief	print pv report widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */

#include "print-pv-report-widget.h"
#include "Environment/Configurations/resource-path-provider.h"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::Environment;
using namespace Smartmatic::Log;

Smartmatic::Log::ISMTTLog * PrintPVReportWidget::logger = Smartmatic::Log::SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.PrintPVReportWidget", GETTEXT_PACKAGE );

PrintPVReportWidget::PrintPVReportWidget()
    : m_thread(NULL)
{
    std::string fileImage = ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, "ui/print-pv-report.gif" );

    loadImage = manage ( new Gtk::Image() );

    loadImage->set ( Gdk::PixbufAnimation::create_from_file ( fileImage ) );
    label = manage ( new Gtk::Label ( _ ( "Smartmatic.SAES.GUI.Widgets.PrintPVReportWidget.PrintingPVReportFile" ) ) );
    Pango::FontDescription fontTitle = label->get_style()->get_font();
    fontTitle.set_size ( 14 * Pango::SCALE );
    fontTitle.set_weight ( Pango::WEIGHT_BOLD );
    label->modify_font ( fontTitle );
    Gtk::VBox * vbox = manage ( new Gtk::VBox() );
    vbox->pack_start ( *loadImage );
    vbox->pack_start ( *label );
    add ( *vbox );
}

PrintPVReportWidget::~PrintPVReportWidget()
{
    dispose();
}

void PrintPVReportWidget::initialize()
{
    if ( !Glib::thread_supported() )
    {
        Glib::thread_init();
    }

    if ( m_thread != NULL )
    {
        m_thread->join();
        m_thread = NULL;
    }

    m_thread = Glib::Thread::create ( sigc::mem_fun ( *this, &PrintPVReportWidget::ThreadStart ), true );
    //Glib::signal_timeout().connect_once(sigc::mem_fun(*this, &SignTransmissionPackageWidget::on_done),5000);
}

void PrintPVReportWidget::dispose()
{
    if ( m_thread != NULL )
    {
        m_thread->join();
        m_thread = NULL;
    }
}

void PrintPVReportWidget::ThreadStart()
{
    bool errorHappen = false;

    try
    {
        //TODO call the method to print report
    }
    catch ( ... )
    {
        //TODO catch exceptions
        errorHappen = true;
    }

    sleep ( 3 );

    if ( !errorHappen )
    {
        Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &PrintPVReportWidget::on_done ), 500 );
    }
    else
        Glib::signal_timeout().connect_once ( sigc::bind<Glib::ustring> ( sigc::mem_fun ( *this, &PrintPVReportWidget::UpdateLabel ),
                                              _ ( "Smartmatic.SAES.GUI.Widgets.PrintPVReportWidget.ErrorMessage" ) ), 500 );
}

void PrintPVReportWidget::on_done()
{
    emit();
}

void PrintPVReportWidget::UpdateLabel ( Glib::ustring text )
{
    loadImage->hide();
    label->set_text ( text );
}

