/**
 * @file	referendum-selection-widget.h
 * @brief	Declares the referendum selection widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#ifndef _REFERENDUM_SELECTION_WIDGET_H_
#define _REFERENDUM_SELECTION_WIDGET_H_

#include "Configuration/SaesGUIConfiguration-schema.hxx"
#include <Voting/Election/election-schema.hxx>
#include <Widgets/smartmatic-button.h>
#include <Widgets/SmartmaticBasicLabel.hxx>
#include <Widgets/SmartmaticBasicVBox.hxx>
#include <Widgets/SmartmaticBasicEventBox.hxx>
#include <Widgets/SmartmaticBasicFrame.hxx>
#include "referendum-widget.h"
#include "Operation/Voting/VotingExperienceController.hxx"
#include "Runtime/Environment/saes-directories.h"
#include "Gui/Widgets/voting-frame-base.h"
#include "ReferendumTableWidget.hxx"
#include "ReferendumButtonWidget.hxx"

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	ReferendumSelectionWidget
                 * @brief	Header class ReferendumSelectionWidget.
                 * @author	Juan delgado &lt;juan.delgado@smartmatic.com&gt;
                 * @date	4/29/2011
                 */

                class ReferendumSelectionWidget: public VotingFrameBase
                {
                    public:

                        /**
                         * @fn	ReferendumSelectionWidget::ReferendumSelectionWidget ( Smartmatic::SAES::Voting::Election::Contest * contest );
                         * @brief	class constructor.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @param	contest	contest that hold ballot options to be displayed.
                         */

                        explicit ReferendumSelectionWidget ( Smartmatic::SAES::Voting::Election::Contest * contest );

                        /**
                         * @fn	virtual ReferendumSelectionWidget::~ReferendumSelectionWidget();
                         * @brief	class destructor.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */

                        virtual ~ReferendumSelectionWidget();

                        /**
                         * @fn	void ReferendumSelectionWidget::Initialize ( std::list<Smartmatic::SAES::Voting::Election::Eligible_option> & principalBallotList );
                         * @brief	calculate position and size of ballot option widgets.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @param	principalBallotList	list of all principal ballots to be displayed.
                         */

                        void Initialize ( std::list<Smartmatic::SAES::Voting::Election::Eligible_option * > & principalBallotList );

                        /**
                         * @fn	Smartmatic::SAES::Voting::Election::Contest * ReferendumSelectionWidget::getContest();
                         * @brief	get contest.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @return	The contest.
                         */

                        Smartmatic::SAES::Voting::Election::Contest * getContest();
                        /**
                         * @fn	virtual void ReferendumSelectionWidget::refresh();
                         * @brief	refresh widget method.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         */
                        virtual void refresh();

                        /**
                         * @fn	void ReferendumSelectionWidget::RefreshLabels();
                         * @brief	Refresh labels.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */

                        void RefreshLabels();

                        /**
                         * @fn	void ReferendumSelectionWidget::SetBackButton ( bool show );
                         * @brief	Sets a back button.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @param	show	true to show, false to hide.
                         */

                        void SetBackButton ( bool show );

                        /**
                         * @typedef	sigc::signal<void> type_back_clicked
                         * @brief	Defines an alias representing the type back clicked. .
                         */

                        typedef sigc::signal<void> type_back_clicked;

                        /**
                         * @typedef	sigc::signal<void, std::string, bool> type_ballotOption_clicked
                         * @brief	Defines an alias representing the type ballot option clicked. .
                         */

                        typedef sigc::signal<void, std::string, bool> type_ballotOption_clicked;

                        /**
                         * @fn	type_back_clicked ReferendumSelectionWidget::back_clicked();
                         * @brief	Gets the back clicked.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @return	.
                         */

                        type_back_clicked back_clicked();

                        /**
                         * @fn	type_back_clicked ReferendumSelectionWidget::accept_clicked();
                         * @brief	Gets the accept clicked.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @return	.
                         */

                        type_back_clicked accept_clicked();

                        /**
                         * @fn	type_back_clicked ReferendumSelectionWidget::null_clicked();
                         * @brief	Gets the null clicked.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @return	.
                         */
                        type_back_clicked null_clicked();

                        /**
                         * @fn	type_ballotOption_clicked ReferendumSelectionWidget::ballotOption_clicked();
                         * @brief	Gets the ballot option clicked.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @return	.
                         */

                        type_ballotOption_clicked ballotOption_clicked();

                        /**
                         * @fn	void ReferendumSelectionWidget::SetWidgetEnabled ( bool enabled = true );
                         * @brief	Sets widget enabled.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @param	enabled	(optional) the enabled.
                         */
                        void SetWidgetEnabled ( bool enabled = true );

                    protected:
                        /**
                         * @brief signals declaration
                         */
                        type_ballotOption_clicked m_ballotOption_clicked;   ///< The ballot option clicked
                        type_back_clicked m_back_clicked;   ///< The back clicked
                        type_back_clicked m_accept_clicked;   ///< The back clicked
                        type_back_clicked m_null_clicked;   ///< The back clicked

                        /**
                         * @fn	void ReferendumSelectionWidget::on_backButton_clicked();
                         * @brief	send back signal.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */

                        void on_backButton_clicked();

                        /**
                         * @fn	void ReferendumSelectionWidget::on_acceptButton_clicked();
                         * @brief	handles accept button signal.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */

                        void on_acceptButton_clicked();

                        /**
                         * @fn	void ReferendumSelectionWidget::on_nullOption_clicked();
                         * @brief	handles null option signal.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */

                        void on_nullOption_clicked();

                        /**
                         * @fn	void ReferendumSelectionWidget::on_clearButton_clicked();
                         * @brief	handles clear button signal.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */
                        void on_clearButton_clicked();

                        /**
                         * @fn	void onBallotOptionClicked ( Smartmatic::GUI::Widgets::BoxSelectionWidget * ballot );
                         * @brief	method that receives ballot option clicked.
                         * @author	Yadickson Soto
                         * @date	29/07/2014
                         * @param	ballot	ballot option clicked.
                         */
                        void onBallotOptionClicked ( Smartmatic::GUI::Widgets::BoxSelectionWidget * ballot );

                        /**
                         * @fn	virtual Smartmatic::GUI::Configuration::LabelConfiguration ReferendumSelectionWidget::getTitleLabelConfig();
                         * @brief	virtual method getter label config.
                         * @author	Yadickson Soto
                         * @date	25/04/2012
                         * @return	title label config.
                         */
                        virtual Smartmatic::GUI::Configuration::LabelConfiguration getTitleLabelConfig();
                        /**
                         * @fn	virtual Smartmatic::GUI::Configuration::LabelConfiguration ReferendumSelectionWidget::getBottomLabelConfig();
                         * @brief	virtual method getter label config.
                         * @author	Yadickson Soto
                         * @date	25/04/2012
                         * @return	bottom label config.
                         */
                        virtual Smartmatic::GUI::Configuration::LabelConfiguration getBottomLabelConfig();
                        /**
                         * @fn	virtual std::string ReferendumSelectionWidget::getTitleText();
                         * @brief	virtual method getter title.
                         * @author	Yadickson Soto
                         * @date	25/04/2012
                         * @return	title.
                         */
                        virtual std::string getTitleText();
                        /**
                         * @fn	virtual std::string ReferendumSelectionWidget::getBottomText();
                         * @brief	virtual method getter title.
                         * @author	Yadickson Soto
                         * @date	25/04/2012
                         * @return	bottom.
                         */
                        virtual std::string getBottomText();

                    private:

                        /**
                         * @fn	std::string ReferendumSelectionWidget::ComposeQuestionText();
                         * @brief	Gets the compose question text.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	.
                         */
                        std::string ComposeQuestionText();

                        /**
                         * Child Widgets
                         */
                        Smartmatic::GUI::Widgets::SmartmaticBasicLabel * headerLabel;	///< The header label
                        Smartmatic::GUI::Widgets::SmartmaticBasicEventBox * labelEventBox; ///< The label event box
                        Smartmatic::GUI::Widgets::SmartmaticBasicVBox * externalBox; ///< The external box
                        Smartmatic::GUI::Widgets::SmartmaticBasicVBox * internalBox; ///< The internal box

                        ReferendumButtonWidget * buttonWidget; ///< button widget
                        ReferendumTableWidget * tableWidgets;   ///< The ballots box

                        Smartmatic::GUI::Widgets::BoxSelectionWidget * currentBallot; ///< The current ballot selected

                        Smartmatic::GUI::Widgets::SmartmaticBasicFrame * clientAreaFrame;	///< The client area frame
                        Smartmatic::GUI::Widgets::SmartmaticBasicFrame * bottomFrame;	///< The bottom frame

                        /**
                         * SAES voting objects
                         */
                        Smartmatic::SAES::Voting::Election::Contest * contest;	///< The contest

                        /**
                         * Variables
                         */
                        bool showBackButton;	///< The show back button
                        bool showClearButton;	///< The show clear button
                        int bottomHeigth;   ///< The bottom heigth
                        bool m_widgetEnabled; ///< true to enable, false to disable the widget

                        Smartmatic::SAES::Configuration::ReferendumConfiguration config;///< The configuration

                };
            }
        }
    }
}

#endif // _REFERENDUM_SELECTION_WIDGET_H_
