/**
 * @file	referendum-widget.h
 * @brief	Declares the referendum widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */

#ifndef _REFERENDUM_WIDGET_H_
#define _REFERENDUM_WIDGET_H_

#include <Voting/Election/election-schema.hxx>
#include <Widgets/BoxSelectionWidget.hxx>
#include <Widgets/SmartmaticBasicLabel.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	ReferendumWidget
                 * @brief	Referendum widget.
                 * @author	Cesar.bonilla
                 * @date	4/29/2011
                 */

                class ReferendumWidget: public Smartmatic::GUI::Widgets::BoxSelectionWidget
                {
                    public:

                        /**
                         * @fn	ReferendumWidget ( Smartmatic::SAES::Voting::Election::Eligible_option & elegibleOption, bool enableClick );
                         * @brief	class constructor.
                         * @author	Cesar.bonilla
                         * @date	29/07/2014
                         * @param	elegibleOption	ballot option to be displayed.
                         * @param	enableClick enable click if true
                         */
                        ReferendumWidget ( Smartmatic::SAES::Voting::Election::Eligible_option & elegibleOption, bool enableClick );

                        /**
                         * @fn	ReferendumWidget ( const std::string & text, bool enableClick );
                         * @brief	class constructor.
                         * @author	Yadickson Soto
                         * @date	29/07/2014
                         * @param	Text to show
                         * @param	enableClick enable click if true
                         */
                        ReferendumWidget ( const std::string & text, bool enableClick );

                        /**
                         * @fn	virtual ~ReferendumWidget();
                         * @brief	class destructor.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */
                        virtual ~ReferendumWidget();

                    private:

                        /**
                         * @fn void config( const std::string & labelName );
                         * @brief Config label and select and unselect colors
                         * @author	Yadickson Soto
                         * @date	29/07/2014
                         * @param 	labelName label name to show
                         */
                        void config ( const std::string & labelName );

                    private:

                        Smartmatic::GUI::Widgets::SmartmaticBasicLabel * label; ///< Text label

                };
            }
        }
    }
}

#endif // _REFERENDUM_WIDGET_H_
