/**
 * @file	voting-frame-base.h
 * @brief	Declares the voting frame base class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#ifndef _VOTING_FRAME_BASE_H
#define _VOTING_FRAME_BASE_H

#include <Widgets/StepWidget.hxx>
#include <Configuration/label-configuration.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	VotingFrameBase
                 * @brief	Header class VotingFrameBase.
                 * @author	Juan delgado &lt;juan.delgado@smartmatic.com&gt;
                 * @date	4/29/2011
                 */

                class VotingFrameBase: public Smartmatic::GUI::Widgets::StepWidget
                {
                public:

                    virtual ~VotingFrameBase() {}

                    public:

                        /**
                         * @fn	virtual void VotingFrameBase::RefreshLabels() = 0;
                         * @brief	Refresh labels.
                         * @author	Youssef.tourkmani
                         * @date	05/11/2012
                         */
                        virtual void RefreshLabels() = 0;

                        /**
                         * @fn	virtual void VotingFrameBase::ShowBackButton();
                         * @brief	Shows the back button.
                         * @author	Youssef.tourkmani
                         * @date	05/11/2012
                         */
                        virtual void ShowBackButton();

                        /**
                         * @fn	virtual void VotingFrameBase::SetBackButton ( bool show );
                         * @brief	Sets back button.
                         * @author	Youssef.tourkmani
                         * @date	05/11/2012
                         * @param	show	true to show, false to hide.
                         */
                        virtual void SetBackButton ( bool show );

                        /**
                         * @fn	virtual void VotingFrameBase::SetWidgetEnabled ( bool enabled = true ) = 0;
                         * @brief	Sets widget enabled.
                         * @author	Youssef.tourkmani
                         * @date	05/11/2012
                         * @param	enabled	(optional) the enabled.
                         */
                        virtual void SetWidgetEnabled ( bool enabled = true ) = 0;
                };
            }
        }
    }
}

#endif // _VOTING_FRAME_BASE_H
