/**
 * @file USBMonitorWindow.cxx
 * @brief Body class usb monitor window
 * @date 13/12/2012
 * @author Yadickson Soto
 */

#include "USBMonitorWindow.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>
#include <Configuration/s-m-t-t-g-u-i-conf-manager.h>
#include <Configuration/BasicWindowConfManager.hxx>
#include <Operation/Monitor/DeviceTypeMonitorPool.hxx>
#include <Gui/Widgets/DeviceMonitorWidget.hxx>
#include <Gui/Widgets/FactoryMethodWidget.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Windows;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::GUI::Windows;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Common::Operation::Monitor;
using namespace Smartmatic::SAES::Common::Configuration;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::SAES::Runtime::Environment;
using namespace Smartmatic::SAES::Operation::Monitor;

USBMonitorWindow * USBMonitorWindow::instance = NULL;
ISMTTLog * USBMonitorWindow::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Windows.USBMonitorWindow", GETTEXT_PACKAGE );

USBMonitorWindow::USBMonitorWindow()
    : PopUpMessageWindow()
{
    int xPadding;
    int yPadding;
    SMTTGUIConfigurationManager::getInstance()->getPaddings( xPadding, yPadding );
    int timeOut = SAESGUIConfigurationManager::getInstance()->getUSBMonitorWindowConfiguration().getTimeOut();
    int opacity = SAESGUIConfigurationManager::getInstance()->getUSBMonitorWindowConfiguration().getOpacity();

    LabelConfiguration labelConfig = SAESGUIConfigurationManager::ConvertToLabelConfiguration ( SAESGUIConfigurationManager::getInstance()->getUSBMonitorWindowConfiguration().getLabelConfiguration() );

    widget = FactoryMethodWidget::createProgressWidget();
    widget->set_border_width ( xPadding );

    widget->setImage ( "ui/RemoveUSBMini.img" );
    widget->setInfoText ( _ ( "Smartmatic.SAES.GUI.Windows.USBMonitorWindow.Info" ) );
    widget->setInfoTextConfig ( labelConfig );

    setOpacity ( opacity );
    setTimerToClose ( timeOut );

    Smartmatic::GUI::Configuration::PositionConfiguration & position ( SAESGUIConfigurationManager::getInstance()->getUSBMonitorWindowConfiguration().getPosition() );

    if ( position != Smartmatic::GUI::Configuration::PositionConfiguration::CONFIGURATION_FULL_SCREEN )
    {
        int width = SAESGUIConfigurationManager::getInstance()->getUSBMonitorWindowConfiguration().getWidth();
        int height = SAESGUIConfigurationManager::getInstance()->getUSBMonitorWindowConfiguration().getHeight();
        set_default_size ( width, height );
        set_size_request ( width, height );
    }

    if ( position == Smartmatic::GUI::Configuration::PositionConfiguration::CONFIGURATION_CUSTOM )
    {
        int x = SAESGUIConfigurationManager::getInstance()->getUSBMonitorWindowConfiguration().getX();
        int y = SAESGUIConfigurationManager::getInstance()->getUSBMonitorWindowConfiguration().getY();
        setPosition ( x, y );
    }
    else
    {
        setPosition ( position );
    }

    remove ();
    add ( *widget );
    show_all_children();

    setAccessibleName ( "USBMonitor" );
}

USBMonitorWindow::~USBMonitorWindow()
{
    stop();
}

void USBMonitorWindow::start()
{
    if ( SAESGUIConfigurationManager::getInstance()->getUSBMonitorWindowConfiguration().getVisible() )
    {
        unsigned int numberOfDevices = DeviceTypeMonitorPool::getInstance()->getNumberOfDevicesByType ( DeviceType::CONFIGURATION_FLASH );

        if ( numberOfDevices >= 1 )
        {
            ShowDialog ();
            signalChange.disconnect();
            signalChange = DeviceTypeMonitorPool::getInstance()->getDeviceChangedSignal().connect ( sigc::mem_fun ( *this, &USBMonitorWindow::deviceChange ) );
        }
    }
}

void USBMonitorWindow::stop()
{
    signalChange.disconnect();
    QuitDialog();
}

void USBMonitorWindow::deviceChange ( Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor * deviceTypeMonitor )
{
    if ( deviceTypeMonitor != NULL &&
            deviceTypeMonitor->getType() == DeviceType::CONFIGURATION_FLASH &&
            deviceTypeMonitor->getNumberOfDevices() == 0 )
    {
        stop ();
    }
}

USBMonitorWindow * USBMonitorWindow::getInstance()
{
    if ( !instance )
    {
        instance = new USBMonitorWindow();
    }

    return instance;
}
