/**
 * @file VoteProcessWindow.cxx
 * @brief Body class vote process window
 * @date 19/10/2011
 * @author Yadickson Soto
 */

#include "VoteProcessWindow.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Configuration/MachineModelEnum.hxx>
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>
#include <Configuration/s-m-t-t-g-u-i-conf-manager.h>
#include <Operation/Voting/VotingEnqueuer.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate
#define NORMAL_MODE_MAX_WIDTH 380
#define NORMAL_MODE_MAX_HEIGHT 120
#define REDUCE_MODE_MAX_WIDTH 165
#define REDUCE_MODE_MAX_HEIGHT 110

using namespace Smartmatic::Configuration;
using namespace Smartmatic::GUI::Windows;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::GUI::Windows;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::Operation::Voting;
using namespace Smartmatic::SAES::Operation;

VoteProcessWindow * VoteProcessWindow::instance = NULL;
ISMTTLog * VoteProcessWindow::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Windows.VoteProcessWindow", GETTEXT_PACKAGE );

VoteProcessWindow::VoteProcessWindow()
    : PopUpMessageWindow()
{
    showReduceMode();
    set_name ( "scan_popup_window" );
}

VoteProcessWindow::~VoteProcessWindow()
{
    stop();
}

void VoteProcessWindow::start()
{
    showReduceMode();
    signalStatusVote.disconnect();
    signalStatusVote = VotingEnqueuer::getInstance()->getSignalStatus().connect ( sigc::mem_fun ( *this, &VoteProcessWindow::onSignalState ) );
}

void VoteProcessWindow::stop()
{
    signalStatusVote.disconnect();
}

void VoteProcessWindow::setConfiguration ( ScanConsolidationConfiguration & config )
{
    hide();
    Smartmatic::GUI::Configuration::PositionConfiguration & position ( config.getScanPopUpMessageConfiguration().getPosition() );

    if ( position != Smartmatic::GUI::Configuration::PositionConfiguration::CONFIGURATION_FULL_SCREEN )
    {
        int width = config.getScanPopUpMessageConfiguration().getWidth();
        int height = config.getScanPopUpMessageConfiguration().getHeight();

        set_default_size ( width, height );
        set_size_request ( width, height );
    }

    if ( position == Smartmatic::GUI::Configuration::PositionConfiguration::CONFIGURATION_CUSTOM )
    {
        int x = config.getScanPopUpMessageConfiguration().getX();
        int y = config.getScanPopUpMessageConfiguration().getY();
        setPosition ( x, y );
    }
    else
    {
        setPosition ( position );
    }

    LabelConfiguration labelConf = SAESGUIConfigurationManager::ConvertToLabelConfiguration ( config.getTextConfiguration() );
    int timeout = config.getScanPopUpMessageConfiguration().getTimeOut();
    int opacity = config.getScanPopUpMessageConfiguration().getOpacity();
    ColorConfiguration fontVote = config.getFontColorValid();
    ColorConfiguration fontBadVote = config.getFontColorBad();
    ColorConfiguration fontDuplicateVote = config.getFontColorDuplicate();
    ColorConfiguration boxVote = config.getBoxColorValid();
    ColorConfiguration boxBadVote = config.getBoxColorBad();
    ColorConfiguration boxDuplicateVote = config.getBoxColorDuplicate();
    scanFontVoteColor.set_rgb ( fontVote.getRed(), fontVote.getGreen(), fontVote.getBlue() );
    scanFontBadVoteColor.set_rgb ( fontBadVote.getRed(), fontBadVote.getGreen(), fontBadVote.getBlue() );
    scanFontDuplicateVoteColor.set_rgb ( fontDuplicateVote.getRed(), fontDuplicateVote.getGreen(), fontDuplicateVote.getBlue() );
    scanBoxVoteColor.set_rgb ( boxVote.getRed(), boxVote.getGreen(), boxVote.getBlue() );
    scanBoxBadVoteColor.set_rgb ( boxBadVote.getRed(), boxBadVote.getGreen(), boxBadVote.getBlue() );
    scanBoxDuplicateVoteColor.set_rgb ( boxDuplicateVote.getRed(), boxDuplicateVote.getGreen(), boxDuplicateVote.getBlue() );
    showMessage = config.getScanPopUpMessageConfiguration().getVisible();
    enabledChangeColor = config.getEnabledChangeColor();
    setLabelConfig ( labelConf );
    setTimerToClose ( timeout );
    setOpacity ( opacity );
    setText ( " " );
}

void VoteProcessWindow::showNormalMode()
{
    ScanConsolidationConfiguration & config ( SAESGUIConfigurationManager::getInstance()->getScanVoteProcessConfiguration().getNormalScanConsolidationConfiguration() );

    if ( SMTTGUIConfigurationManager::getInstance()->getSmartmaticGUIMachineModelConfiguration().getId() == EnumToString( PM_VIU805 ) )
    {
        config.getScanPopUpMessageConfiguration().setWidth( NORMAL_MODE_MAX_WIDTH );
        config.getScanPopUpMessageConfiguration().setHeight( NORMAL_MODE_MAX_HEIGHT );
    }

    setConfiguration ( config );
    messageVote = _ ( "Smartmatic.SAES.GUI.Widgets.ConsolidationStatsWidget.InstructionGoodProccesedVote" );
    messageBadVote = _ ( "Smartmatic.SAES.GUI.Widgets.ConsolidationStatsWidget.InstructionBadProccesedVote" );
    messageDuplicateVote = _ ( "Smartmatic.SAES.GUI.Widgets.ConsolidationStatsWidget.InstructionDuplicatedProccesedVote" );
}

void VoteProcessWindow::showReduceMode()
{
    ScanConsolidationConfiguration & config ( SAESGUIConfigurationManager::getInstance()->getScanVoteProcessConfiguration().getReduceScanConsolidationConfiguration() );

    if ( SMTTGUIConfigurationManager::getInstance()->getSmartmaticGUIMachineModelConfiguration().getId() == EnumToString( PM_VIU805 ) )
    {
        config.getScanPopUpMessageConfiguration().setWidth( REDUCE_MODE_MAX_WIDTH );
        config.getScanPopUpMessageConfiguration().setHeight( REDUCE_MODE_MAX_HEIGHT );
    }

    setConfiguration ( config );
    messageVote = _ ( "Smartmatic.SAES.GUI.Windows.VoteProcessWindow.InstructionGoodProccesedVote" );
    messageBadVote = _ ( "Smartmatic.SAES.GUI.Windows.VoteProcessWindow.InstructionBadProccesedVote" );
    messageDuplicateVote = _ ( "Smartmatic.SAES.GUI.Windows.VoteProcessWindow.InstructionDuplicatedProccesedVote" );
}

void VoteProcessWindow::onSignalState ( VotePersistence::PersistenceStatusVote status )
{
    logger->Debug ( "Signal State" );
    Glib::ustring message;
    Glib::ustring composed;

    switch ( status )
    {
        case VotePersistence::PERSISTENCE_VOTE_FAIL:
        default:
            message = messageBadVote;
            composed = Glib::ustring::compose ( message, 0 );
            setFontColorLabel ( scanFontBadVoteColor );
            setBoxColorLabel ( scanBoxBadVoteColor );
            break;

        case VotePersistence::PERSISTENCE_VOTE_DUPLICATE:
            message = messageDuplicateVote;
            composed = Glib::ustring::compose ( message, MachineOperationManager::getInstance()->getVoteStatistics()->getDuplicatedVotes(), 0 );
            setFontColorLabel ( scanFontDuplicateVoteColor );
            setBoxColorLabel ( scanBoxDuplicateVoteColor );
            break;

        case VotePersistence::PERSISTENCE_VOTE_SUCCESS:
            message = messageVote;
            composed = Glib::ustring::compose ( message, MachineOperationManager::getInstance()->getVoteStatistics()->getOfficialVotes(), MachineOperationManager::getInstance()->getVoteStatistics()->getTotalVotes(), 0 );
            setFontColorLabel ( scanFontVoteColor );
            setBoxColorLabel ( scanBoxVoteColor );
            break;
    }

    refreshText ( composed );

    if ( !is_visible() && showMessage )
    {
        logger->Debug ( "Show message" );
        Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &VoteProcessWindow::ShowDialog ), 0 );
    }
}

VoteProcessWindow * VoteProcessWindow::getInstance()
{
    if ( !instance )
    {
        instance = new VoteProcessWindow();
    }

    return instance;
}
