/**
 * @file	empty-window.h
 * @brief	Declares the empty Windows Form.
 * @date 03/04/2012
 * @author Yadickson Soto
 */


#ifndef _EMPTY_WINDOW_H_
#define _EMPTY_WINDOW_H_

#include <gtkmm.h>
#include <Windows/basic-window.h>
#include <Widgets/StepWidget.hxx>
#include <Gui/Widgets/InfoStepWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace SAES
    {
        namespace GUI
        {
            namespace Windows
            {
                /**
                 * @class	EmptyWindow
                 * @brief	Form for empty window.
                 * @author	Yadickson Soto
                 * @date	03/04/2012
                 */
                class EmptyWindow : public Smartmatic::GUI::Windows::BasicWindow
                {

                    public:

                        /**
                         * @fn	EmptyWindow::EmptyWindow ( Smartmatic::GUI::Widgets::StepWidget * stepWidget );
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         * @param [in,out]	stepWidget	If non-null, the step widget.
                         */
                        explicit EmptyWindow ( Smartmatic::GUI::Widgets::StepWidget * stepWidget );

                        /**
                         * @fn	EmptyWindow::EmptyWindow ( Gtk::Widget * widget, std::string title, bool showTitleText,
                         * 			bool showHelpButton, bool showExitButton );
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         * @param	widget					the widget container.
                         * @param	title						The title.
                         * @param	showTitleText 	show title.
                         * @param	showHelpButton	true to show help button.
                         * @param	showExitButton	true to show exit button.
                         */
                        EmptyWindow ( Gtk::Widget * widget, std::string title, bool showTitleText, bool showHelpButton, bool showExitButton );
                        /**
                         * @fn	virtual EmptyWindow::~EmptyWindow();
                         * @brief	Finaliser.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         */
                        virtual ~EmptyWindow();
                        /**
                         * @fn	void EmptyWindow::showInitMessageWidget ( Smartmatic::SAES::GUI::Widgets::InfoStepWidget & widget );
                         * @brief	Show message widget.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         * @param	widget	widget base.
                         */
                        void showInitMessageWidget ( Smartmatic::SAES::GUI::Widgets::InfoStepWidget & widget );
                        /**
                         * @fn	void EmptyWindow::showExitMessageWidget ( Smartmatic::SAES::GUI::Widgets::InfoStepWidget & widget );
                         * @brief	Show message widget.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         * @param	widget	widget base.
                         */
                        void showExitMessageWidget ( Smartmatic::SAES::GUI::Widgets::InfoStepWidget & widget );
                        /**
                         * @fn	void EmptyWindow::showMessageWidget ( Smartmatic::SAES::GUI::Widgets::InfoStepWidget & widget );
                         * @brief	Show message widget.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         * @param	widget	widget base.
                         */
                        void showMessageWidget ( Smartmatic::SAES::GUI::Widgets::InfoStepWidget & widget );

                        /**
                         * @fn	void EmptyWindow::restoreOneMemory();
                         * @brief	Restore one memory.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void restoreOneMemory();

                        /**
                         * @fn	void EmptyWindow::restoreTwoMemory();
                         * @brief	Restore two memory.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void restoreTwoMemory();
                        /**
                         * @fn	virtual void EmptyWindow::refreshTitleText();
                         * @brief	Method refresh title.
                         * @author	Yadickson Soto
                         * @date	28/03/2012
                         */
                        virtual void refreshTitleText();
                        /**
                         * @fn	virtual void EmptyWindow::ShowExit();
                         * @brief	Method show exit.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         */
                        virtual void ShowExit();
                        /**
                         * @fn	virtual void EmptyWindow::enableExitButton();
                         * @brief	Method enable exit button.
                         * @author	Yadickson Soto
                         * @date	28/03/2012
                         */
                        virtual void enableExitButton();
                        /**
                         * @fn	virtual void disableExitButton();
                         * @brief	Method disable exit button.
                         * @author	Yadickson Soto
                         * @date	05/11/2012
                         */
                        virtual void disableExitButton();
                        /**
                         * @fn	virtual void forceDisableExitButton();
                         * @brief	Method force disable exit button.
                         * @author	Yadickson Soto
                         * @date	30/11/2012
                         */
                        virtual void forceDisableExitButton();
                        /**
                         * @fn	sigc::signal<void> EmptyWindow::getSignalShowExitMessage();
                         * @brief	method getter signal show message exit.
                         * @author	Yadickson Soto
                         * @date	14/05/2012
                         * @return	signal show message exit.
                         */
                        sigc::signal<void> getSignalShowExitMessage();
                        /**
                         * @fn	sigc::signal<void> EmptyWindow::getSignalExitButton();
                         * @brief	method getter signal exit button.
                         * @author	Yadickson Soto
                         * @date	22/04/2012
                         * @return	signal exit button.
                         */
                        sigc::signal<void> getSignalExitButton();

                    protected:

                        sigc::signal<void> signalShowExitMessage; ///< signal show message
                        sigc::signal<void> signalExitButton; ///< signal exit button

                    protected:

                        /**
                         * @fn	virtual void EmptyWindow::ShowHelp();
                         * @brief	Method show menu clicked.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         */
                        virtual void ShowHelp();
                        /**
                         * @fn	virtual void EmptyWindow::Exit();
                         * @brief	Method exit window clicked.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         */
                        virtual void Exit();
                        /**
                         * @fn	void EmptyWindow::memoryBlock();
                         * @brief	method receive event memory.
                         * @author	Yadickson Soto
                         * @date	20/04/2012
                         */
                        void memoryBlock();
                        /**
                         * @fn	void EmptyWindow::exitMessage();
                         * @brief	Method exit message.
                         * @author	Yadickson Soto
                         * @date	28/05/2012
                         */
                        void exitMessage();
                        /**
                         * @fn	void EmptyWindow::exitInitMessage();
                         * @brief	Exit initialise message.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void exitInitMessage();

                    protected:

                        Smartmatic::GUI::Widgets::StepWidget stepWidget; ///< step widget

                    private:

                        Glib::Mutex mutex; ///< lock show widget
                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger

                        bool forceHide; ///< force hide widget
                        bool viewInitMessage; ///< flag show current message
                        bool viewExitMessage; ///< flag show current message
                        bool viewHelpWidget; ///< flag show current help widget

                        /**
                         * @fn	void EmptyWindow::initConfig();
                         * @brief	Method initialize config.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         */
                        void initConfig();
                };
            }
        }
    }

}



#endif // _EMPTY_WINDOW_H_
