/**
 * @file FormatLabel.cxx
 * @brief Body class format label text
 * @date 11/04/2012
 * @author Yadickson Soto
 */

#include "FormatLabel.hxx"
#include <Operation/MachineOperationManager.hxx>
#include <Resources/election-string-resources-manager.h>
#include <Voting/set-language-functionality.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Operation;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::Voting::Election;
using namespace Smartmatic::SAES::Resources;
using namespace Smartmatic::SAES::Voting;

FormatLabel::FormatLabel()
{

}

FormatLabel::~FormatLabel()
{
}

std::string FormatLabel::format ( std::string text, std::string sep )
{
    if ( text.empty() || text == " " )
    {
        return " ";
    }

    std::string language;
    std::string country;
    const std::string currentLanguage = SetLanguageFunctionality::getCurrentLanguageCode();
    SetLanguageFunctionality::getCurrentLanguageCountry ( language, country );
    Smartmatic::SAES::Voting::Election::Languages & lang ( MachineOperationManager::getInstance()->getElectoralConfiguration()->getLanguages() );
    Smartmatic::SAES::Voting::Election::Languages::LanguageSequence & sequence ( lang.getLanguage() );
    Smartmatic::SAES::Voting::Election::Languages::LanguageIterator it;
    std::list<Smartmatic::SAES::Voting::Election::Language> languages;

    for ( it = sequence.begin(); it != sequence.end(); it++ )
    {
        if ( languages.empty() )
        {
            languages.push_back ( *it );
        }
        else if ( languages.front().getPrecedence() < it->getPrecedence() )
        {
            languages.push_back ( *it );
        }
        else
        {
            languages.push_front ( *it );
        }
    }

    std::list<Smartmatic::SAES::Voting::Election::Language>::iterator iter;
    std::string formattedString;
    unsigned int count = languages.size();

    for ( iter = languages.begin(); iter != languages.end(); ++iter, count++ )
    {
        std::string currentLanguage ( text );
        currentLanguage.append ( iter->getLanguage() );
        std::string tr = _ ( currentLanguage.c_str() );

        if ( tr != currentLanguage && !tr.empty() )
        {
            formattedString.append ( tr );
            formattedString.append ( ( languages.size() - 1 ) != count ? sep : "" );
        }
        else
        {
            std::string lanCode;
            lanCode = iter->getCustom_code();
            SetLanguageFunctionality::SetNewVotingLanguage ( lanCode );
            tr = _ ( text.c_str() );
            formattedString.append ( tr );
            formattedString.append ( ( languages.size() - 1 ) != count ? sep : "" );
        }
    }

    if ( !formattedString.empty() )
    {
        formattedString.resize ( formattedString.size() - 1 );
    }
    else
    {
        formattedString = _ ( text.c_str() );
    }

    SetLanguageFunctionality::setNewVotingLanguageByLanguageCountry ( language, country );
    SetLanguageFunctionality::SetNewVotingLanguage(currentLanguage);
    return formattedString;
}

void FormatLabel::checkComposeString ( std::string & stringToCheck )
{
    if ( stringToCheck.size() > 2 )
    {
        if ( stringToCheck[stringToCheck.size() - 1] == ' ' &&
                stringToCheck[stringToCheck.size() - 2] == '-' )
        {
            size_t pos = stringToCheck.size();
            stringToCheck.erase ( pos - 3, 3 );
        }
    }
}

Glib::ustring FormatLabel::contestText ( Contest & contest, Glib::ustring & format )
{
    Glib::ustring contestClassName;
    Glib::ustring contestClassDescription;
    Glib::ustring contestTitle;
    Glib::ustring contestAbstract;
    Glib::ustring contestHelp;

    try
    {
        Smartmatic::SAES::Voting::Election::Contest_class * contestClass = MachineOperationManager::getInstance()->getElectoralConfiguration()->getContestClassByCode ( contest.getContest_class_code() );
        contestClassName = ElectionStringResourcesManager::getInstance()->getResource ( contestClass->getName_key() );
        contestClassDescription = ElectionStringResourcesManager::getInstance()->getResource ( contestClass->getDescription_key() );
        contestTitle = ElectionStringResourcesManager::getInstance()->getResource ( contest.getTitle_key() );
        contestAbstract = ElectionStringResourcesManager::getInstance()->getResource ( contest.getAbstract_key() );
        contestHelp = ElectionStringResourcesManager::getInstance()->getResource ( contest.getHelp_key() );
    }
    catch ( ... )
    {
    }

    Glib::ustring newFormat = Glib::ustring::compose ( format,
                              contestClassName,
                              contestClassDescription,
                              contestTitle,
                              contestAbstract,
                              contestHelp );
    return newFormat;
}
