/**
 * @file FunctionalityWindowManager.hxx
 * @brief Header class functionality window signal manager
 * @date 03/10/2012
 * @author Yadickson Soto
 */

#ifndef FUNCTIONALITY_WINDOW_MANAGER_HXX_
#define FUNCTIONALITY_WINDOW_MANAGER_HXX_

#include <glibmm.h>
#include <Windows/ExitWindowListener.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace SAES
    {
        namespace GUI
        {
            namespace Operation
            {
                /**
                 * @class	FunctionalityWindowManager
                 * @brief	functionality window signal manager.
                 * @author	Yadickson Soto
                 * @date	03/10/2012
                 */
                class FunctionalityWindowManager
                {
                    protected:
                        /**
                         * @fn	FunctionalityWindowManager::FunctionalityWindowManager();
                         * @brief	class constructor.
                         * @author	Yadickson Soto
                         * @date	03/10/2012
                         */
                        FunctionalityWindowManager();
                        /**
                         * @fn	void FunctionalityWindowManager::onBeforeExit();
                         * @brief	method on before exit functionality.
                         * @author	Yadickson Soto
                         * @date	03/10/2012
                         */
                        void onBeforeExit();
                        /**
                         * @fn	void FunctionalityWindowManager::onExit();
                         * @brief	method on exit functionality.
                         * @author	Yadickson Soto
                         * @date	03/10/2012
                         */
                        void onExit();
                        /**
                         * @fn	void FunctionalityWindowManager::disconnected();
                         * @brief	method disconnected current signals.
                         * @author	Yadickson Soto
                         * @date	03/10/2012
                         */
                        void disconnected();
                        /**
                         * @fn	void FunctionalityWindowManager::connected();
                         * @brief	method connected current signals.
                         * @author	Yadickson Soto
                         * @date	03/10/2012
                         */
                        void connected();
                        /**
                         * @fn	void FunctionalityWindowManager::pop();
                         * @brief	method pop functionality to signals window.
                         * @author	Yadickson Soto
                         * @date	03/10/2012
                         */
                        void pop();

                        sigc::connection connBeforeExitWindow; ///< the connector before exit message
                        sigc::connection connExitWindow; ///< The connector exit window

                    public:
                        /**
                         * @fn	virtual FunctionalityWindowManager::~FunctionalityWindowManager();
                         * @brief	class destructor.
                         * @author	Yadickson Soto
                         * @date	03/10/2012
                         */
                        virtual ~FunctionalityWindowManager();
                        /**
                         * @fn	void FunctionalityWindowManager::push ( Smartmatic::GUI::Windows::ExitWindowListener * functionality );
                         * @brief	method push functionality to signals window.
                         * @author	Yadickson Soto
                         * @date	03/10/2012
                         * @param	functionality	new functionality.
                         */
                        void push ( Smartmatic::GUI::Windows::ExitWindowListener * functionality );
                        /**
                         * @fn	unsigned int FunctionalityWindowManager::getCount();
                         * @brief	method getter count list functionality.
                         * @author	Yadickson Soto
                         * @date	03/10/2012
                         * @return	count list functionality.
                         */
                        unsigned int getCount();
                        /**
                         * @fn	static FunctionalityWindowManager * FunctionalityWindowManager::getInstance();
                         * @brief	method getter instance.
                         * @author	Yadickson Soto
                         * @date	03/10/2012
                         * @return	instance.
                         */
                        static FunctionalityWindowManager * getInstance();

                    private:

                        static FunctionalityWindowManager * instance; ///< class instance
                        std::list <Smartmatic::GUI::Windows::ExitWindowListener * > functionalityList; ///< functionality list
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                };
            }
        }
    }
}

#endif /* FUNCTIONALITY_WINDOW_MANAGER_HXX_ */
