/**
 * @file ImageResourcePath.hxx
 * @brief Header class image resource path
 * @date 14/12/2012
 * @author Yadickson Soto
 */

#ifndef IMAGERESOURCEPATH_HXX_
#define IMAGERESOURCEPATH_HXX_

#include <string>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Operation
            {

                /**
                 * @class	ImageResourcePath
                 * @brief	Class image resource path
                 * @author	Yadickson Soto
                 * @date	14/12/2012
                 */
                class ImageResourcePath
                {
                    public:

                        /**
                         * @enum	Resource
                         * @brief	Any type image.
                         */
                        enum Resource
                        {
                            NONE ///< none image
                            , NOT_FOUND ///< image not found
                            , PROGRESS ///< progress image
                            , PREPARE_PRINT ///< prepare print
                            , PRINTING ///< printing image
                            , PRINTING_OK ///< printing status ok
                            , PRINTING_ERROR ///< printing status error
                            , PRINTING_TEST ///< printing image test
                            , SMARTCARD ///< smartcard image
                            , SMARTCARD_DETECT ///< smartcard image detect
                            , SMARTCARD_DISABLED ///< smartcard disabled
                            , SMARTCARD_INSERT ///< smartcard image insert card
                            , SMARTCARD_REMOVE ///< smartcard image remove card
                            , SMARTCARD_AUTO_DIAGNOSIS ///< smartcard auto diagnosis
                            , AUTO_DIAGNOSIS_DEVICES ///<  auto diagnosis devices
                            , RECONFIGURE_BARCODE ///<  reconfigure barcode
                            , RECONFIGURE_BARCODE_SUCCESS ///<  reconfigure barcode success
                            , RECONFIGURE_BARCODE_FAIL ///<  reconfigure barcode fail
                            , PRINTER_CONNECTED ///< printer connected
                            , PRINTER_DISCONNECTED ///< printer disconnected
                            , BARCODE_CONNECTED ///<  barcode connected
                            , BARCODE_DISCONNECTED ///<  barcode disconnected
                            , SMARTCARD_CONNECTED ///<  smartcard connected
                            , SMARTCARD_DISCONNECTED ///<  smartcard disconnected
                            , FLASH_CONNECTED ///<  flash connected
                            , FLASH_DISCONNECTED ///<  flash disconnected
                            , ONE_USB_CONNECTED ///<  flash one usb connected
                            , TWO_USB_CONNECTED ///<  flash two usb connected
                            , TWO_USB_DISCONNECTED ///<  flash two usb disconnected
                            , MOUSE_CONNECTED ///<  mouse connected
                            , MOUSE_DISCONNECTED ///<  mouse disconnected
                            , ETHERNET_CONNECTED ///<  ethernet connected
                            , ETHERNET_DISCONNECTED ///<  ethernet disconnected
                            , SCREEN_CALIBRATION_INSTRUCTION ///< the screen calibration image instructions
                        };

                        /**
                         * @fn	virtual ~ImageResourcePath();
                         * @brief Class destructor
                         */
                        virtual ~ImageResourcePath();

                        /**
                         * @fn	static std::string getPath ( Resource image );
                         * @brief Method getter path by image resource
                         * @param image image resource
                         * @return path image resource
                         */
                        static std::string getPath ( Resource image );

                        /**
                         * @fn	static std::string getPath ( std::string image );
                         * @brief Method getter path by image string path
                         * @param image image string path
                         * @return path image resource
                         */
                        static std::string getPath ( std::string image );

                    private:

                        /**
                         * @fn	ImageResourcePath();
                         * @brief Class constructor
                         */
                        ImageResourcePath();

                        /**
                         * @fn	static void getPMPath ( Resource image, std::string & path );
                         * @brief Method getter path by image string path for PM
                         * @param image image string path
                         * @param path image resource
                         */
                        static void getPMPath ( Resource image, std::string & path );

                        /**
                         * @fn	static void getVMPath ( Resource image, std::string & path );
                         * @brief Method getter path by image string path for VM
                         * @param image image string path
                         * @param path image resource
                         */
                        static void getVMPath ( Resource image, std::string & path );
                };
            }
        }
    }
}

#endif /* IMAGERESOURCEPATH_HXX_ */
