#ifndef TEST_BARCODE_DETECTION_WIDGET_CONTROLLER_TEST
#define TEST_BARCODE_DETECTION_WIDGET_CONTROLLER_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <tests/MockSaesFunctionalityConfigurationManager.hxx>
#include <tests/MockBCRController.hxx>
#include <tests/MockSafeDispatcher.hxx>
#include "Operation/Devices/BCRController.hxx"
#include "Gui/Widgets/BarcodeDetectionWidgetController.h"

using namespace std;
using namespace Smartmatic::SAES::GUI::Widgets;

class BarcodeDetectionWidgetControllerTest : public CPPUNIT_NS::TestFixture
{
        private:
        typedef Smartmatic::SAES::Functionality::Configuration::SAESFunctionalityConfigurationManager SAESFunctionalityConfigurationManager;
        typedef Smartmatic::SAES::Operation::Devices::BCRController BCRController;

        BarcodeDetectionWidgetController widgetController;

        public:

        BarcodeDetectionWidgetControllerTest()
        {
        }

        void setUp()
        {
        }

        void tearDown()
        {
        }

        void testProcessReturningSucces()
        {
            MockSaesFunctionalityConfigurationManager saesfunctionalityManager;
            SAESFunctionalityConfigurationManager::getInstance ( &saesfunctionalityManager );
            MockBCRController mockBCR;

            MOCKPP_CHAINER_FOR ( MockBCRController, sendReconfigureCommand ) sendReconfigureCommand_mock ( &mockBCR );
            sendReconfigureCommand_mock
            .expects ( MOCKPP_NS::exactly( 2 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                    new MOCKPP_NS::ReturnStub<bool> ( true ) ,
                    new MOCKPP_NS::ReturnStub<bool> ( true ) ) );

            BCRController::getInstance(&mockBCR);

            MockSafeDispatcher mockSafeD;

            widgetController.process (mockSafeD);
            CPPUNIT_ASSERT(mockSafeD.getResult());
        }

        void testProcessReturningFailed()
        {
            MockSaesFunctionalityConfigurationManager saesfunctionalityManager;
            SAESFunctionalityConfigurationManager::getInstance ( &saesfunctionalityManager );
            MockBCRController mockBCR;

            MOCKPP_CHAINER_FOR ( MockBCRController, sendReconfigureCommand ) sendReconfigureCommand_mock ( &mockBCR );
            sendReconfigureCommand_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<bool> ( false ) );

            BCRController::getInstance(&mockBCR);

            MockSafeDispatcher mockSafeD;
            widgetController.process (mockSafeD);
            CPPUNIT_ASSERT(!mockSafeD.getResult());
        }

        CPPUNIT_TEST_SUITE ( BarcodeDetectionWidgetControllerTest );

        CPPUNIT_TEST ( testProcessReturningSucces );
        CPPUNIT_TEST ( testProcessReturningFailed );

        CPPUNIT_TEST_SUITE_END();
};
#endif /* ECUT_MAIN */

#endif /* TEST_BACODE_DETECTION_WIDGET_CONTROLLER_TEST */
