/**
 * @file BarcodeLengthCommandElement.hxx
 * @brief	Defines the length barcode reader command element. Two bytes for length
 * @author	Yadickson Soto
 * @date	23/06/2015
 */

#ifndef BARCODE_FOOTER_READER_BOX_COMMAND_ELEMENT_HXX_
#define BARCODE_FOOTER_READER_BOX_COMMAND_ELEMENT_HXX_

#include <Commands/CommandElement.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace HW
        {
            namespace Commands
            {
                /**
                 * @class	BarcodeLengthCommandElement
                 * @brief	Class to define the length barcode reader command element.
                 * @author	Yadickson Soto
                 * @date	23/06/2015
                 */
                class BarcodeLengthCommandElement : public CommandElement
                {
                    public:
                        /**
                         * @fn BarcodeLengthCommandElement( const std::vector < unsigned char > & data );
                         * @brief	Constructor default.
                         * @author	Yadickson Soto
                         * @date	23/06/2015
                         * @param	data to load length
                         */
                        explicit BarcodeLengthCommandElement ( const std::vector < unsigned char > & data );

                        /**
                         * @fn virtual ~BarcodeLengthCommandElement();
                         * @brief	Constructor destructorer.
                         * @author	Yadickson Soto
                         * @date	23/06/2015
                         */
                        virtual ~BarcodeLengthCommandElement();

                        /**
                         * @fn virtual void addToCommand( std::vector < unsigned char > & command );
                         * @brief Add this command element to a full command.
                         * @date 23/06/2015
                         * @author Yadickson Soto
                         * @param	command The full command to which to add the command element..
                         */
                        virtual void addToCommand ( std::vector < unsigned char > & command );

                    protected:

                        std::vector < unsigned char > data; ///< The data to load length and crc
                };

            } /* namespace Commands */
        } /* namespace HW */
    } /* namespace SAES */
} /* namespace Smartmatic */
#endif /* BARCODE_FOOTER_READER_BOX_COMMAND_ELEMENT_HXX_ */
