/**
 * @file	BarcodeModelCommand.hxx
 * @brief	Header the barcode model command class.
 * @date	23/06/2015
 * @author	Yadickson Soto
 */

#ifndef _BARCODE_MODEL_COMMAND_H_
#define _BARCODE_MODEL_COMMAND_H_

#include <Commands/CommandBaseBarcode.hxx>
#include <vector>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace HW
        {
            namespace Commands
            {
                /**
                 * @class	BarcodeModelCommand
                 * @brief	Barcode get model device command class.
                 * @author	Yadickson Soto
                 * @date	23/06/2015
                 */
                class BarcodeModelCommand: public CommandBaseBarcode
                {

                    public:

                        /**
                         * @fn	BarcodeModelCommand(Smartmatic::SAES::HW::Connections::IConnection * connection );
                         * @brief	Default constructor.
                         * @author	Yadickson Soto
                         * @date	23/06/2015
                         * @param 	connection The connection provider
                         */
                        explicit BarcodeModelCommand ( Smartmatic::SAES::HW::Connections::IConnection * connection );
                        /**
                         * @fn	virtual BarcodeModelCommand::~BarcodeModelCommand();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	23/06/2015
                         */
                        virtual ~BarcodeModelCommand();

                    protected:

                        /**
                         * @fn	virtual void BarcodeModelCommand::initialize();
                         * @brief	Initializes this object.
                         * @author	Yadickson Soto
                         * @date	23/06/2015
                         */
                        virtual void initialize();

                        /**
                         * @fn	virtual bool processResponse(const std::vector<unsigned char> & response);
                         * @brief	Processes the response and checks for its validity.
                         * @author	Yadickson Soto
                         * @date	23/06/2015
                         * @param	response	The response.
                         * @return	true if it succeeds, false if it fails.
                         */
                        virtual bool processResponse ( const std::vector<unsigned char> & response );

                    private:

                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
                };
            }
        }
    }
}

#endif // _BARCODE_MODEL_COMMAND_H_
