/**
 * @file	BarcodeSetSerialNumberCommand.cxx
 * @brief	Body the barcode set serial number from device command class.
 * @date	23/06/2015
 * @author	Yadickson Soto
 */

#include "BarcodeSetSerialNumberCommand.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <System/Utils/StringUtils.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

using namespace Smartmatic::SAES::HW::Commands;
using namespace Smartmatic::System::Utils;
using namespace Smartmatic::Log;

ISMTTLog * BarcodeSetSerialNumberCommand::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.HW.Commands.BarcodeSetSerialNumberCommand", GETTEXT_PACKAGE );

BarcodeSetSerialNumberCommand::BarcodeSetSerialNumberCommand ( Smartmatic::SAES::HW::Connections::IConnection * connection, const std::string & serial )
    : CommandBaseBarcode ( connection ), serial ( serial )
{
    hasResponse_ = false;
}

BarcodeSetSerialNumberCommand::~BarcodeSetSerialNumberCommand()
{

}

void BarcodeSetSerialNumberCommand::initialize()
{
    data.push_back ( 0x31 );
    data.push_back ( 0x31 );
    data.push_back ( 0x33 );
    data.push_back ( 0x30 );
    data.push_back ( 0x32 );
    data.push_back ( 0x30 );
    data.push_back ( 0x30 + serial.size() );

    for ( unsigned int i = 0; i < serial.size(); i++ )
    {
        data.push_back ( ( unsigned char ) serial[i] );
    }
}
