/**
 * @file	BarcodeSetSerialNumberCommand.hxx
 * @brief	Header the barcode set serial number from device command class.
 * @date	26/06/2015
 * @author	Yadickson Soto
 */

#ifndef _BARCODE_SET_SERIAL_NUMBER_COMMAND_H_
#define _BARCODE_SET_SERIAL_NUMBER_COMMAND_H_

#include <Commands/CommandBaseBarcode.hxx>
#include <vector>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace HW
        {
            namespace Commands
            {
                /**
                 * @class	BarcodeSetSerialNumberCommand
                 * @brief	Barcode set serial number from device command class.
                 * @author	Yadickson Soto
                 * @date	26/06/2015
                 */
                class BarcodeSetSerialNumberCommand: public CommandBaseBarcode
                {

                    public:

                        /**
                         * @fn	BarcodeSetSerialNumberCommand(Smartmatic::SAES::HW::Connections::IConnection * connection,
                         *  const std::string & serial );
                         * @brief	Default constructor.
                         * @author	Yadickson Soto
                         * @date	26/06/2015
                         * @param 	connection The connection provider
                         * @param	serial The new serial number
                         */
                        BarcodeSetSerialNumberCommand ( Smartmatic::SAES::HW::Connections::IConnection * connection, const std::string & serial );
                        /**
                         * @fn	virtual BarcodeSetSerialNumberCommand::~BarcodeSetSerialNumberCommand();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	26/06/2015
                         */
                        virtual ~BarcodeSetSerialNumberCommand();

                    protected:

                        /**
                         * @fn	virtual void BarcodeSetSerialNumberCommand::initialize();
                         * @brief	Initializes this object.
                         * @author	Yadickson Soto
                         * @date	26/06/2015
                         */
                        virtual void initialize();

                    private:

                        std::string serial; ///< The serial number to send
                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
                };
            }
        }
    }
}

#endif // _BARCODE_SET_SERIAL_NUMBER_COMMAND_H_
