/**
 * @file ByteCommandElement.hxx
 * @brief Defines the basic byte command to be sent to a device. This will be limited to one-byte values.
 * @date 17/02/2014
 * @author Yadickson Soto
 */

#ifndef BYTECOMMANDELEMENT_HXX_
#define BYTECOMMANDELEMENT_HXX_

#include <Commands/CommandElement.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace HW
        {
            namespace Commands
            {
                /**
                 * @class ByteCommandElement
                 * @brief The basic byte command to be sent to a device. This will be limited to one-byte values.
                 * @date 17/02/2014
                 * @author Yadickson Soto
                 */
                class ByteCommandElement : public CommandElement
                {
                    public:
                        /**
                         * @fn	ByteCommandElement( unsigned char byte );
                         * @brief	Default constructor.
                         * @author	Yadickson Soto
                         * @date	17/02/2014
                         * @param	byte The input byte value. This will be limited to one-byte values.
                         */
                        explicit ByteCommandElement ( unsigned char byte );

                        /**
                         * @fn	virtual ~ByteCommandElement();
                         * @brief	Default destructor.
                         * @author	Yadickson Soto
                         * @date	17/02/2014
                         */
                        virtual ~ByteCommandElement();

                        /**
                         * @fn	virtual void addToCommand ( std::vector < unsigned char > & command )
                         * @brief	Adds the byte value to the being-constructed command.
                         * @author	Yadickson Soto
                         * @date	17/02/2014
                         * @param	command The being-constructed command, to which we want to add the byte value command element.
                         */
                        virtual void addToCommand ( std::vector < unsigned char > & command );

                    protected:

                        unsigned char byte; /// The byte value

                };

            } /* namespace Commands */
        } /* namespace HW */
    } /* namespace SAES */
} /* namespace Smartmatic */
#endif /* BYTECOMMANDELEMENT_HXX_ */
