/**
 * @file   EurnDoorCommand.hxx
 * @brief  Declaration of E-Urn's door command.
 * @author manuel.arguelles
 * @date   Aug 28, 2017
 */

#ifndef EURN_DOOR_COMMAND_HXX
#define EURN_DOOR_COMMAND_HXX

#include "CommandBaseEurn.hxx"

namespace Smartmatic
{
    namespace SAES
    {
        namespace HW
        {
            namespace Connections
            {
                class IConnection;
            }
            namespace Commands
            {
                /**
                 * @class  EurnDoorCommand
                 * @brief  Set of commands for the e-urn's door.
                 * @author manuel.arguelles
                 * @date   Aug 28, 2017
                 */
                class EurnDoorCommand : public CommandBaseEurn
                {
                    public:

                        /**
                         * @brief  Creates an object of EurnDoorCommand class.
                         * @author manuel.arguelles
                         * @date   Aug 28, 2017
                         * @param  connection The connection provider.
                         * @param  openDoor   Specify to open or close the door.
                         * @param  time       The amount of seconds before auto closing the door.
                         */
                        EurnDoorCommand(HW::Connections::IConnection* connection, bool openDoor, unsigned char time);

                        /**
                         * @brief  Destroys the object.
                         * @author manuel.arguelles
                         * @date   Aug 28, 2017
                         */
                        virtual ~EurnDoorCommand();

                    private:

                        /**
                         * @brief  Initialize the command.
                         * @author manuel.arguelles
                         * @date   Aug 28, 2017
                         */
                        virtual void initialize();


                    private:

                        bool m_openDoor;
                        unsigned char m_time;
                };

            } /* namespace Commands */
        } /* namespace HW */
    } /* namespace SAES */
} /* namespace Smartmatic */

#endif /* EURN_DOOR_COMMAND_HXX */
