/**
 * @file   EurnPingCommand.cxx
 * @brief  Implementation of EurnPingCommand class.
 * @author manuel.arguelles
 * @date   Aug 25, 2017
 */

#include "EurnPingCommand.hxx"
#include "EurnHeaderCommandElement.hxx"
#include "EurnFooterCommandElement.hxx"
#include "DataCommandElement.hxx"

static const unsigned char DOOR_MASK        = 0x40;
static const unsigned char GREEN_BLINK_MASK = 0x10;
static const unsigned char GREEN_LED_MASK   = 0x04;
static const unsigned char PING_COMMAND     = 0x01;
static const unsigned char RED_BLINK_MASK   = 0x08;
static const unsigned char RED_LED_MASK     = 0x02;

using namespace Smartmatic::SAES::HW::Commands;
using namespace Smartmatic::SAES::HW::Connections;

EurnPingCommand::EurnPingCommand(IConnection* connection)
    : CommandBaseEurn(connection)
{
}

EurnPingCommand::~EurnPingCommand()
{
}

CommandStructure::CommandList EurnPingCommand::getCommandList()
{
    CommandList commands;

    commands.push_back(new EurnHeaderCommandElement());
    commands.push_back(new DataCommandElement(commandByte));
    commands.push_back(new DataCommandElement(data));
    commands.push_back(new EurnFooterCommandElement());

    return commands;
}

void EurnPingCommand::initialize()
{
    commandByte.push_back(PING_COMMAND);
    data.push_back(0x00);
}

unsigned char EurnPingCommand::getVersion()
{
    return getVersionByte();
}

bool EurnPingCommand::isDoorOpen()
{
    return (getStatus() & DOOR_MASK);
}

bool EurnPingCommand::isRedLedOn()
{
    return (getStatus() & RED_LED_MASK);
}

bool EurnPingCommand::isGreenLedOn()
{
    return (getStatus() & GREEN_LED_MASK);
}

bool EurnPingCommand::isRedLedBlinking()
{
    return (getStatus() & RED_BLINK_MASK);
}

bool EurnPingCommand::isGreenLedBlinking()
{
    return (getStatus() & GREEN_BLINK_MASK);
}
