/**
 * @file LengthCommandElement.hxx
 * @brief Defines the length representation command element.
 * @author	Yadickson Soto
 * @date	14/02/2014
 */

#ifndef LENGTH_COMMAND_ELEMENT_HXX_
#define LENGTH_COMMAND_ELEMENT_HXX_

#include <Commands/CommandElement.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace HW
        {
            namespace Commands
            {
                /**
                 * @class	LengthCommandElement
                 * @brief	Defines the length representation command element.
                 * @author	Yadickson Soto
                 * @date	14/02/2014
                 */
                class LengthCommandElement : public CommandElement
                {
                    public:
                        /**
                         * @fn	LengthCommandElement( unsigned int length );
                         * @brief	Default constructor.
                         * @author	Yadickson Soto
                         * @date	14/02/2014
                         * @param	length The input data length value. This will be limited to one-byte values.
                         */
                        explicit LengthCommandElement ( unsigned int length );

                        /**
                         * @fn	virtual ~LengthCommandElement();
                         * @brief	Default destructor.
                         * @author	Yadickson Soto
                         * @date	14/02/2014
                         */
                        virtual ~LengthCommandElement();

                        /**
                         * @fn	virtual void addToCommand ( std::vector < unsigned char > & command )
                         * @brief	Adds the length representation value of the data to the being-constructed command.
                         * @author	Yadickson Soto
                         * @date	14/02/2014
                         * @param	command The being-constructed command, to which we want to add the data length command element.
                         */
                        virtual void addToCommand ( std::vector < unsigned char > & command );

                    protected:

                        unsigned int length; ///< The length value
                };

            } /* namespace Commands */
        } /* namespace HW */
    } /* namespace SAES */
} /* namespace Smartmatic */
#endif /* LENGTH_COMMAND_ELEMENT_HXX_ */
