/**
 * @file	P168ABoardModelNameCommand.cxx
 * @brief	Body the P168A board model name command class.
 * @date	12/09/2012
 * @author	Yadickson Soto
 */

#include "P168ABoardModelNameCommand.hxx"
#include "Log/ISMTTLog.h"
#include <Log/SMTTLogManager.h>
#include <System/Utils/StringUtils.hxx>
#include <Commands/P168AHeaderCommandElement.hxx>
#include <Commands/DataCommandElement.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate
#define COMMAND 0x00 ///< command value

using namespace Smartmatic::SAES::HW::Commands;
using namespace Smartmatic::System::Utils;
using namespace Smartmatic::Log;

ISMTTLog * P168ABoardModelNameCommand::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.HW.Commands.P168ABoardModelNameCommand", GETTEXT_PACKAGE );

P168ABoardModelNameCommand::P168ABoardModelNameCommand ( Smartmatic::SAES::HW::Connections::IConnection * connection )
    : CommandBaseP168A ( connection )
{
    hasResponse_ = true;
}

P168ABoardModelNameCommand::~P168ABoardModelNameCommand()
{
}

void P168ABoardModelNameCommand::initialize()
{
    commandByte.push_back ( COMMAND );
}

CommandStructure::CommandList P168ABoardModelNameCommand::getCommandList ()
{
    CommandList commands;

    commands.push_back ( new P168AHeaderCommandElement() );
    commands.push_back ( new DataCommandElement ( commandByte ) );

    return commands;
}

bool P168ABoardModelNameCommand::processResponse ( const std::vector<unsigned char> & response )
{
    std::string model;

    if ( response.size() > 3 && response[0] == 0x1B && response[1] == COMMAND )
    {
        std::vector<unsigned char> rawResponse;
        rawResponse.insert ( rawResponse.end(), &response[3], &response[3] + response[2] );

        this->response = rawResponse;
        model = StringUtils::arrayHexToAsciiString ( rawResponse );
    }

    if ( !model.empty() )
    {
        logger->Debug ( "Found board model name ( " + model + " )." );
    }
    else
    {
        logger->Debug ( "Board model name not found." );
    }

    return !model.empty();
}
