/**
 * @file	P168AReadMemoryCommand.cxx
 * @brief	Body the P168A reset memory command class.
 * @date	12/09/2012
 * @author	Yadickson Soto
 */

#include "P168AReadMemoryCommand.hxx"
#include "Log/ISMTTLog.h"
#include <Log/SMTTLogManager.h>
#include <System/Utils/StringUtils.hxx>
#include <Commands/P168AHeaderCommandElement.hxx>
#include <Commands/DataCommandElement.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate
#define COMMAND 0x1C ///< command value

using namespace Smartmatic::SAES::HW::Commands;
using namespace Smartmatic::System::Utils;
using namespace Smartmatic::Log;

ISMTTLog * P168AReadMemoryCommand::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.HW.Commands.P168AReadMemoryCommand", GETTEXT_PACKAGE );

P168AReadMemoryCommand::P168AReadMemoryCommand ( Smartmatic::SAES::HW::Connections::IConnection * connection, unsigned char address1, unsigned char address2, unsigned int length )
    : CommandBaseP168A ( connection )
{
    hasResponse_ = true;
    this->address1 = address1;
    this->address2 = address2;
    this->length = length;
}

P168AReadMemoryCommand::~P168AReadMemoryCommand()
{
}

void P168AReadMemoryCommand::initialize()
{
    commandByte.push_back ( COMMAND );
    commandByte.push_back ( address1 );
    commandByte.push_back ( address2 );
    commandByte.push_back ( length );
}

CommandStructure::CommandList P168AReadMemoryCommand::getCommandList ()
{
    CommandList commands;

    commands.push_back ( new P168AHeaderCommandElement() );
    commands.push_back ( new DataCommandElement ( commandByte ) );

    return commands;
}

bool P168AReadMemoryCommand::processResponse ( const std::vector<unsigned char> & response )
{
    std::string result = StringUtils::arrayHexToString ( response );

    if ( result.compare ( "00000000ffffffff00000000ffffffff" ) == 0 )
    {
        return false;
    }

    if ( response.size() > 5 && response[0] == 0x1B && response[1] == COMMAND &&
            response[2] == address1 && response[3] == address2 && response[4] == length )
    {
        std::vector<unsigned char> rawResponse;
        rawResponse.insert ( rawResponse.end(), &response[5], &response[5] + length );

        this->response = rawResponse;
        return true;
    }

    return false;
}
