/**
 * @file	P168AReadMemoryCommand.hxx
 * @brief	Header the P168A read memory command class.
 * @date	12/09/2012
 * @author	Yadickson Soto
 */

#ifndef _P168A_READ_MEMORY_COMMAND_H_
#define _P168A_READ_MEMORY_COMMAND_H_

#include "command-base-p168-a.h"

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace HW
        {
            namespace Commands
            {
                /**
                 * @class	P168AReadMemoryCommand
                 * @brief	P168A read memory command class.
                 * @author	Yadickson Soto
                 * @date	12/09/2012
                 */
                class P168AReadMemoryCommand: public CommandBaseP168A
                {

                    public:

                        /**
                         * @fn	P168AReadMemoryCommand::P168AReadMemoryCommand(Smartmatic::SAES::HW::Connections::IConnection * connection,
                         * 			unsigned char address1,
                         * 			unsigned char address2,
                         * 			unsigned int length);
                         * @brief	Default constructor.
                         * @author	Yadickson Soto
                         * @date	18/02/2014
                         * @param 	connection The connection provider
                         * @param	address1	address 1.
                         * @param	address2	address 2.
                         * @param	length		data length to read.
                         */
                        P168AReadMemoryCommand ( Smartmatic::SAES::HW::Connections::IConnection * connection, unsigned char address1, unsigned char address2, unsigned int length );
                        /**
                         * @fn	virtual P168AReadMemoryCommand::~P168AReadMemoryCommand();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	12/09/2012
                         */
                        virtual ~P168AReadMemoryCommand();

                    protected:

                        /**
                         * @fn	virtual void P168AReadMemoryCommand::initialize();
                         * @brief	Initializes this object.
                         * @author	Yadickson Soto
                         * @date	12/09/2012
                         */
                        virtual void initialize();
                        /**
                         * @fn	virtual bool P168AReadMemoryCommand::processResponse(const std::vector<unsigned char> & response);
                         * @brief	Processes the response and checks for its validity.
                         * @author	Yadickson Soto
                         * @date	12/09/2012
                         * @param	response	The response.
                         * @return	true if it succeeds, false if it fails.
                         */
                        virtual bool processResponse ( const std::vector<unsigned char> & response );

                        /**
                         * @fn	virtual CommandList getCommandList ();
                         * @brief	Get the complete command (list of command elements) to read memory.
                         * @author	Yadickson Soto
                         * @date	17/02/2014
                         * @return	The command elements to make full command result.
                         */
                        virtual CommandList getCommandList ();

                    private:

                        unsigned char address1; ///< address 1 (80h ~ EFh)
                        unsigned char address2; ///< address 2 (00h ~ FFh)
                        unsigned int length; ///< data length to read
                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
                };
            }
        }
    }
}

#endif // _P168A_READ_MEMORY_COMMAND_H_
