/**
 * @file   PDBControlLEDSCommand.hxx
 * @brief  Declaration of PDBDisableUsbCommand class.
 * @author manuel.arguelles
 * @date   Nov  1, 2017
 */

#ifndef PDB_CONTROL_LEDS_COMMAND_HXX
#define PDB_CONTROL_LEDS_COMMAND_HXX

#include "CommandBasePDB.hxx"
#include "PDBLEDs.hxx"

namespace Smartmatic
{
    namespace SAES
    {
        namespace HW
        {
            namespace Connections
            {
                class IConnection;
            }

            namespace Commands
            {
                /**
                 * @class  PDBControlLEDSCommand
                 * @brief  Command to control the LEDs.
                 * @author manuel.arguelles
                 * @date   Nov  1, 2017
                 */
                class PDBControlLEDSCommand : public CommandBasePDB
                {
                    public:

                        /**
                         * @brief  Creates an instance of the class.
                         * @author manuel.arguelles
                         * @date   Nov  1, 2017
                         */
                        PDBControlLEDSCommand(HW::Connections::IConnection* connection, PDBLEDs LEDs, bool turnOn);

                        /**
                         * @brief  Destroys an instance of the class.
                         * @author manuel.arguelles
                         * @date   Nov  1, 2017
                         */
                        virtual ~PDBControlLEDSCommand();

                    private:

                        /**
                         * @brief  Initialize the command.
                         * @author manuel.arguelles
                         * @date   Nov  1, 2017
                         */
                        virtual void initialize();

                    private:

                        PDBLEDs m_PDBLEDs;

                        bool m_turnOn;
                };

            } /* namespace Commands */
        } /* namespace HW */
    } /* namespace SAES */
} /* namespace Smartmatic */


#endif /* PDB_CONTROL_LEDS_COMMAND_HXX */
