/**
 * @file   PDBDisableUsbCommand.hxx
 * @brief  Declaration of PDBDisableUsbCommand class.
 * @author manuel.arguelles
 * @date   Nov  1, 2017
 */

#ifndef PDB_DISABLE_USB_COMMAND_HXX
#define PDB_DISABLE_USB_COMMAND_HXX

#include "CommandBasePDB.hxx"
#include "PDBUsbPort.hxx"

namespace Smartmatic
{
    namespace SAES
    {
        namespace HW
        {
            namespace Connections
            {
                class IConnection;
            }

            namespace Commands
            {
                /**
                 * @class  PDBDisableUsbCommand
                 * @brief  Command to disable the USB ports.
                 * @author manuel.arguelles
                 * @date   Nov  1, 2017
                 */
                class PDBDisableUsbCommand : public CommandBasePDB
                {
                    public:

                        /**
                         * @brief  Creates an instance of the class.
                         * @author manuel.arguelles
                         * @date   Nov  1, 2017
                         */
                        PDBDisableUsbCommand(HW::Connections::IConnection* connection, PDBUsbPort usbPort);

                        /**
                         * @brief  Destroys an instance of the class.
                         * @author manuel.arguelles
                         * @date   Nov  1, 2017
                         */
                        virtual ~PDBDisableUsbCommand();

                    private:

                        /**
                         * @brief  Initialize the command.
                         * @author manuel.arguelles
                         * @date   Nov  1, 2017
                         */
                        virtual void initialize();

                    private:

                        PDBUsbPort m_usbPort;
                };

            } /* namespace Commands */
        } /* namespace HW */
    } /* namespace SAES */
} /* namespace Smartmatic */


#endif /* PDB_DISABLE_USB_COMMAND_HXX */
