/**
 * @file	command-base-alarm.cc
 * @brief	command base alarm class.
 * @author	Youssef.tourkmani
 * @date	31/10/2012
 */


#include "command-base-alarm.h"
#include <Commands/ChecksumCommandElement.hxx>
#include <Commands/LengthCommandElement.hxx>
#include <Commands/DataCommandElement.hxx>
#include <Commands/AlarmHeaderCommandElement.hxx>
#include <Commands/AlarmFooterCommandElement.hxx>

using namespace Smartmatic::SAES::HW::Commands;

CommandBaseAlarm::CommandBaseAlarm ( Smartmatic::SAES::HW::Connections::IConnection * connection )
    : CommandStructure ( connection )
{

}

CommandStructure::CommandList CommandBaseAlarm::getCommandList ()
{
    CommandList commands;

    commands.push_back ( new AlarmHeaderCommandElement() );
    commands.push_back ( new DataCommandElement ( commandByte ) );
    commands.push_back ( new LengthCommandElement ( data.size() ) );
    commands.push_back ( new DataCommandElement ( data ) );
    commands.push_back ( new ChecksumCommandElement ( data ) );
    commands.push_back ( new AlarmFooterCommandElement() );

    return commands;
}

bool CommandBaseAlarm::processResponse(const std::vector<unsigned char>& response)
{
    return true;
}
