/**
 * @file	command-base-alarm.h
 * @brief	Declares the command base alarm class.
 * @author	Youssef.tourkmani
 * @date	31/10/2012
 */


#ifndef _COMMAND_BASE_ALARM_H_
#define _COMMAND_BASE_ALARM_H_

#include "Commands/command-structure.h"

namespace Smartmatic
{
    namespace SAES
    {
        namespace HW
        {
            namespace Commands
            {
                /**
                 * @class	CommandBaseAlarm
                 * @brief	Base class for managing the alarm commands and its properties.
                 * @author	Fsilva
                 * @date	28/04/2011
                 */

                class CommandBaseAlarm: public CommandStructure
                {
                    public:

                        /**
                         * @fn	CommandBaseAlarm::CommandBaseAlarm( Smartmatic::SAES::HW::Connections::IConnection * connection );
                         * @brief	Default constructor.
                         * @author	Yadickson Soto
                         * @date	18/02/2014
                         * @param 	connection The connection provider
                         */
                        explicit CommandBaseAlarm ( Smartmatic::SAES::HW::Connections::IConnection * connection );

                    protected:

                        /**
                         * @fn	virtual CommandList getCommandList ();
                         * @brief	Get the complete command (list of command elements) for an alarmbox-related operation.
                         * @author	Yadickson Soto
                         * @date	17/02/2014
                         * @return	The command elements to make full command result.
                         */
                        virtual CommandList getCommandList ();

                        /**
                         * @brief  Process the response
                         * @author manuel.arguelles
                         * @date   Oct 31, 2017
                         * @param  response The vector with the response bytes.
                         * @return True if the response was valid, false if not.
                        */
                        virtual bool processResponse(const std::vector<unsigned char>& response);
                };
            }
        }
    }
}

#endif // _COMMAND_BASE_ALARM_H_

