/**
 * @file	AlarmBoxConfigurationManager.cxx
 * @brief	alarm box configuration manager class.
 * @author	Yadickson Soto
 * @date	03/07/2015
 */

#include "AlarmBoxConfigurationManager.hxx"
#include "s-a-e-s-hardware-conf-manager.h"

using namespace Smartmatic::SAES::HW::Configuration;

AlarmBoxConfigurationManager * AlarmBoxConfigurationManager::instance = NULL; ///< The singleton instance

AlarmBoxConfigurationManager::AlarmBoxConfigurationManager()
{

}

AlarmBoxConfigurationManager::~AlarmBoxConfigurationManager()
{
    instance = NULL;
}

bool AlarmBoxConfigurationManager::simulationEnabled ()
{
    return !getAlarmBoxPingFile().empty() && !getAlarmBoxButtonFile().empty() && !getAlarmBoxBehaviorFile().empty();
}

std::string AlarmBoxConfigurationManager::getAlarmBoxPingFile ()
{
    return getAlarmBoxConfiguration().getAlarmBoxPingFile();
}

std::string AlarmBoxConfigurationManager::getAlarmBoxButtonFile ()
{
    return getAlarmBoxConfiguration().getAlarmBoxButtonFile();
}

std::string AlarmBoxConfigurationManager::getAlarmBoxBehaviorFile ()
{
    return getAlarmBoxConfiguration().getAlarmBoxBehaviorFile();
}

AlarmBoxConfiguration & AlarmBoxConfigurationManager::getAlarmBoxConfiguration()
{
    if ( ! SAESHardwareConfigurationManager::getInstance()->getConfiguration()->getAlarmBoxConfiguration().present() )
    {
        AlarmBoxConfiguration config ( "", "", "" );
        SAESHardwareConfigurationManager::getInstance()->getConfiguration()->setAlarmBoxConfiguration ( config );
    }

    return SAESHardwareConfigurationManager::getInstance()->getConfiguration()->getAlarmBoxConfiguration().get();
}

AlarmBoxConfigurationManager * AlarmBoxConfigurationManager::getInstance ( AlarmBoxConfigurationManager * externManager )
{
    if ( ! instance )
    {
        instance = ( externManager == NULL ? new AlarmBoxConfigurationManager() : externManager );
    }

    return instance;
}
