/*
 * IOBDeviceConfigurationManager.hxx
 *
 *  Created on: Jan 2, 2018
 *      Author: eduardo.fernandez
 */

#ifndef IOB_DEVICE_CONFIGURATION_MANAGER_HXX_
#define IOB_DEVICE_CONFIGURATION_MANAGER_HXX_

#include <string>
#include <Configuration/IOBDeviceSchema.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace HW
        {
            namespace Configuration
            {
                /**
                 * @class	IOBDeviceConfigurationManager
                 * @brief	Manager for IOB configurations class.
                 * @author	eduardo.fernandez
                 * @date	Jan 2, 2018
                 */
                class IOBDeviceConfigurationManager
                {
                    public:

                        /**
                         * @fn	static IOBDeviceConfigurationManager *getInstance(IOBDeviceConfigurationManager * externManager = NULL);
                         * @brief	Gets the current IOB Configuration Manager.
                         * @author	eduardo.fernandez
                         * @date	Jan 2, 2018
                         * @param 	externManager external manager to unit test
                         * @return	instance of the class
                         */
                        static IOBDeviceConfigurationManager * getInstance ( IOBDeviceConfigurationManager * externManager = NULL );

                        /**
                         * @fn	IOBPortType getIOBPortForVIUSCRPowerCycle ();
                         * @brief	Gets USB port to perform power cycle in the SCR.
                         * @author	eduardo.fernandez
                         * @date	Jan 2, 2018
                         * @return 	The iob usb port
                         */
                        IOBPortType getIOBPortForVIUSCRPowerCycle ();

                        /**
                         * @fn	virtual ~IOBDeviceConfigurationManager();
                         * @brief	Class destructor
                         * @author	eduardo.fernandez
                         * @date	Jan 2, 2018
                         */
                        virtual ~IOBDeviceConfigurationManager();

                        /**
                         * @fn	virtual IOBDeviceConfiguration & getConfiguration();
                         * @brief	Gets IOB device configuration.
                         * @author	eduardo.fernandez
                         * @date	Jan 2, 2018
                         * @return	The IOB device configuration.
                         */
                        virtual IOBDeviceConfiguration & getConfiguration();

                    protected:
                        /**
                         * @fn	IOBDeviceConfigurationManager();
                         * @brief	Default constructor.
                         * @author	eduardo.fernandez
                         * @date	Jan 2, 2018
                         */
                        IOBDeviceConfigurationManager();

                        /**
                         * @fn	virtual IOBDeviceConfiguration & getIOBDeviceConfiguration();
                         * @brief	Gets IOB device configuration.
                         * @author	eduardo.fernandez
                         * @date	Jan 2, 2018
                         * @return	The IOB device configuration.
                         */
                        virtual IOBDeviceConfiguration & getIOBDeviceConfiguration();

                        static IOBDeviceConfigurationManager * instance; ///< The singleton instance
                };
            }
        }
    }
}
#endif /* IOB_DEVICE_CONFIGURATION_MANAGER_HXX_ */
