/**
 * @file	FactoryConnection.hxx
 * @brief	Declares the factory connection class.
 * @author	Yadickson Soto
 * @date	20/02/2014
 */

#ifndef _FACTORY_CONNECTION_H_
#define _FACTORY_CONNECTION_H_

#include <Connections/IConnection.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace HW
        {
            namespace Connections
            {
                /**
                 * @class	FactoryConnection
                 * @brief	Factory method for creating IConnection objects by device type.
                 * @author	Yadickson Soto
                 * @date	20/02/2014
                 */
                class FactoryConnection
                {
                    public:

                        /**
                         * @fn	static IConnection * createAlarmBoxDeviceConnection ();
                         * @brief	Creates the alarm box device connection object.
                         * @author	Yadickson Soto
                         * @date	20/02/2014
                         * @return	The alarm box device connection object.
                         */
                        static IConnection * createAlarmBoxDeviceConnection ();

                        /**
                         * @fn	static IConnection * createBarcodeDeviceConnection ();
                         * @brief	Creates the barcode device connection object.
                         * @author	Yadickson Soto
                         * @date	20/02/2014
                         * @return	The barcode device connection object.
                         */
                        static IConnection * createBarcodeDeviceConnection ();

                        /**
                         * @fn	static IConnection * createP168ADeviceConnection ();
                         * @brief	Creates the p168a device connection object.
                         * @author	Yadickson Soto
                         * @date	20/02/2014
                         * @return	The p168a device connection object.
                         */
                        static IConnection * createP168ADeviceConnection ();

                        /**
                         * @fn	static IConnection * createEurnDeviceConnection ();
                         * @brief	Creates the Eurn device connection object.
                         * @author	Juan Valera
                         * @date	26/10/2017
                         * @return	The Eurn device connection object.
                         */
                        static IConnection * createEurnDeviceConnection ();

                        /**
                         * @brief  Creates a connection with the PDB device.
                         * @author manuel.arguelles
                         * @date   Nov  1, 2017
                         * @return The PDB device connection object.
                         */
                        static IConnection * createPDBDeviceConnection ();

                        /**
                         * @brief  Creates a connection with the IOB device.
                         * @author eduardo.fernandez
                         * @date   Jan 2, 2018
                         * @return The IOB device connection object.
                         */
                        static IConnection * createIOBDeviceConnection ();

                        /**
                         * @brief  Creates a connection with the abled device.
                         * @author eduardo.fernandez
                         * @date   Jan 11, 2018
                         * @return The abled device connection object.
                         */
                        static IConnection * createAbledDeviceConnection ();
                };
            }
        }
    }
}

#endif // _FACTORY_CONNECTION_H_
