/**
 * @file	IConnection.hxx
 * @brief	Declares the connection interface.
 * @author	Yadickson Soto
 * @date	20/02/2014
 */

#ifndef _I_CONNECTION_H_
#define _I_CONNECTION_H_

#include <System/SafeVector.hxx>
#include <string>

namespace Smartmatic
{
    namespace SAES
    {
        namespace HW
        {
            namespace Connections
            {
                /**
                 * @class	IConnection
                 * @brief	Interface to define the contract that each connection should accomplish.
                 * @author	Yadickson Soto
                 * @date	20/02/2014
                 */
                class IConnection
                {
                    public:

                        /**
                         * @fn	IConnection();
                         * @brief	Default constructor.
                         * @author	Yadickson Soto
                         * @date	20/02/2014
                         */
                        IConnection();

                        /**
                         * @fn	virtual ~IConnection();
                         * @brief	Destructor.
                         * @author	Yadickson Soto
                         * @date	20/02/2014
                         */
                        virtual ~IConnection();

                        /**
                         * @fn	virtual bool openConnection ( const std::string & device  ) = 0;
                         * @brief	Opens the connections.
                         * @author	Yadickson Soto
                         * @date	20/02/2014
                         * @param 	device device path
                         * @return	true if successful.
                         */

                        virtual bool openConnection ( const std::string & device ) = 0;

                        /**
                         * @fn	virtual bool sendCommand ( const std::vector<unsigned char> & command ) = 0;
                         * @brief	Sends command over the connection.
                         * @author	Yadickson Soto
                         * @date	20/02/2014
                         * @param	command	The command to send.
                         * @return	true if successful.
                         */

                        virtual bool sendCommand ( const std::vector<unsigned char> & command ) = 0;

                        /**
                         * @fn	virtual Smartmatic::System::SafeVector <unsigned char> readBuffer () = 0;
                         * @brief	Reads data from the connection.
                         * @author	Yadickson Soto
                         * @date	20/02/2014
                         * @return	data buffer read from the connection, empty if result is false
                         */

                        virtual Smartmatic::System::SafeVector <unsigned char> readBuffer () = 0;

                        /**
                         * @fn	virtual unsigned int getTimeOut() = 0;
                         * @brief	Get timeout to wait the read buffer.
                         * @author	Yadickson Soto
                         * @date	26/06/2015
                         */

                        virtual unsigned int getTimeOut() = 0;

                        /**
                         * @fn	virtual bool closeConnection () = 0;
                         * @brief	Closes the connection.
                         * @author	Yadickson Soto
                         * @date	20/02/2014
                         * @return	true if successful.
                         */

                        virtual bool closeConnection () = 0;
                };
            }
        }
    }
}

#endif // _I_CONNECTION_H_
