/**
 * @file IPeekListener.hxx
 * @brief	Interface to define the method launched on a received affirmative peeking on input data.
 * @date 	20/02/2014
 * @author	Yadickson Soto
 */

#ifndef IPEEKLISTENER_HXX_
#define IPEEKLISTENER_HXX_

#include <vector>

namespace Smartmatic
{
    namespace SAES
    {
        namespace HW
        {
            namespace Connections
            {
                /**
                 * @class	IPeekListener
                 * @brief	Interface to define the method launched on a received affirmative peeking on input data.
                 * @date 	20/02/2014
                 * @author	Yadickson Soto
                 */
                class IPeekListener
                {
                    public:

                        /**
                         * @fn	virtual ~IPeekListener()
                         * @brief	Default destructor.
                         * @date 	20/02/2014
                         * @author	Yadickson Soto
                         */
                        virtual ~IPeekListener() {}

                        /**
                         * @fn	virtual void peekEvent( const std::vector<unsigned char> & data);
                         * @brief	Peek event.
                         * @date 	20/02/2014
                         * @author	Yadickson Soto
                         * @param	data	The data.
                         */
                        virtual void peekEvent ( const std::vector<unsigned char> & data ) = 0;
                };
            }
        }
    }
}


#endif /* IPEEKLISTENER_HXX_ */
