/*
 * EurnInterface.hxx
 *
 *  Created on: Oct 25, 2017
 *      Author: juanvalera
 */

#ifndef EURNINTERFACE_HXX_
#define EURNINTERFACE_HXX_

#include <string>

namespace Smartmatic
{
    namespace SAES
    {
        namespace HW
        {
            namespace Devices
            {
                /**
                 * @class	EurnInterface
                 * @brief	Manage the connections with the barcode.
                 * @author	Juan Valera
                 * @date	25/10/2017
                 */
                class EurnInterface
                {
                    public:

                        /**
                         * @fn	virtual ~EurnInterface();
                         * @brief	Class destroyer.
                         * @author	Juan Valera
                         * @date	25/10/2017
                         */
                        virtual ~EurnInterface() {};

                        /**
                         * @fn	virtual bool open( const std::string & device ) = 0;
                         * @brief	Opens the connections.
                         * @author	Juan Valera
                         * @date	25/10/2017
                         * @param 	device device path
                         * @return	true if successful.
                         */
                        virtual bool open ( const std::string & device ) = 0;

                        /**
                         * @fn	virtual bool close() = 0;
                         * @brief	Closes the connections.
                         * @author	Juan Valera
                         * @date	25/10/2017
                         * @return	true if successful.
                         */
                        virtual bool close() = 0;

                        /**
                         * @fn  virtual std::string getVersion();
                         * @brief   gets the version of the add on
                         * @author  Juan Valera
                         * @date    27/10/2017
                         * @return  hex number if successful, 0x00 if not
                         */
                        virtual std::string getVersion() = 0;

                        /**
                         * @fn	virtual bool turnGreenLedOn();
                         * @brief	Turn on the green led.
                         * @author	Juan Valera
                         * @date	27/10/2017
                         * @return	true if successful.
                         */
                        virtual bool turnGreenLedOn() = 0;

                        /**
                         * @fn	virtual bool turnGreenLedOff();
                         * @brief	Turn off the green led.
                         * @author	Juan Valera
                         * @date	27/10/2017
                         * @return	true if successful.
                         */
                        virtual bool turnGreenLedOff() = 0;

                        /**
                         * @fn	virtual bool turnRedLedOn();
                         * @brief	Turn on the red led.
                         * @author	Juan Valera
                         * @date	27/10/2017
                         * @return	true if successful.
                         */
                        virtual bool turnRedLedOn() = 0;

                        /**
                         * @fn	virtual bool turnRedLedOff();
                         * @brief	Turn off the red led.
                         * @author	Juan Valera
                         * @date	27/10/2017
                         * @return	true if successful.
                         */
                        virtual bool turnRedLedOff() = 0;

                        /**
                         * @fn  virtual bool turnRedLedOnIndefinitely();
                         * @brief   Turn on the red led indefinitely.
                         * @author  Eduardo Fernández
                         * @date    26/12/2017
                         * @return  true if successful.
                         */
                        virtual bool turnRedLedOnIndefinitely() = 0;

                        /**
                         * @fn	virtual bool blinkGreenLedOn();
                         * @brief	Turn on and blink the green led.
                         * @author	Juan Valera
                         * @date	27/10/2017
                         * @return	true if successful.
                         */
                        virtual bool blinkGreenLedOn() = 0;

                        /**
                         * @fn  virtual bool blinkGreenLedOnWithRedLedTurnOnAfter();
                         * @brief   Turn on and blink the green led, turning the red led after.
                         * @author  Juan Valera
                         * @date    27/10/2017
                         * @return  true if successful.
                         */
                        virtual bool blinkGreenLedOnWithRedLedTurnOnAfter() = 0;
                        /**
                         * @fn	virtual bool blinkGreenLedOff();
                         * @brief	Turn off the green led.
                         * @author	Juan Valera
                         * @date	27/10/2017
                         * @return	true if successful.
                         */
                        virtual bool blinkGreenLedOff() = 0;

                        /**
                         * @fn	virtual bool blinkRedLedOn();
                         * @brief	Turn on and blink the red led.
                         * @author	Juan Valera
                         * @date	27/10/2017
                         * @return	true if successful.
                         */
                        virtual bool blinkRedLedOn() = 0;

                        /**
                         * @fn	virtual bool blinkRedLedOff();
                         * @brief	Turn off the red led.
                         * @author	Juan Valera
                         * @date	27/10/2017
                         * @return	true if successful.
                         */
                        virtual bool blinkRedLedOff() = 0;

                        /**
                         * @fn	virtual bool openDoorForAFiniteTime();
                         * @brief	Open the Eurn door for a finite time.
                         * @author	Juan Valera
                         * @date	27/10/2017
                         * @return	true if successful.
                         */
                        virtual bool openDoorForAFiniteTime() = 0;

                        /**
                        * @fn  virtual bool openDoor();
                        * @brief   Open the Eurn door.
                        * @author  Juan Valera
                        * @date    27/10/2017
                        * @return  true if successful.
                        */
                        virtual bool openDoor() = 0;

                        /**
                         * @fn  virtual bool openDoorForAFiniteTimeWithLedActions();
                         * @brief   Open the Eurn door and execute special led actions, during and after the configured time.
                         * @author  Juan Valera
                         * @date    27/10/2017
                         * @return  true if successful.
                         */
                        virtual bool openDoorForAFiniteTimeWithLedActions() = 0;

                        /**
                         * @fn	virtual bool turnGreenLedOff();
                         * @brief	Close the Eurn door.
                         * @author	Juan Valera
                         * @date	27/10/2017
                         * @return	true if successful.
                         */
                        virtual bool closeDoor() = 0;

                };
            }
        }
    }
}
#endif /* EURNINTERFACE_HXX_ */
