/**
 * @file	P168AInterface.hxx
 * @brief	Declares the p168a interface
 * @author	Yadickson Soto
 * @date	30/06/2015
 */

#ifndef _P168A_INTERFACE_H_
#define _P168A_INTERFACE_H_

#include <Operation/AbleDButtonState.hxx>
#include <string>

namespace Smartmatic
{
    namespace SAES
    {
        namespace HW
        {
            namespace Devices
            {
                /**
                 * @class	P168AInterface
                 * @brief	Manage the configuration of the P168A device.
                 * @author	Yadickson Soto
                 * @date	30/06/2015
                 */
                class P168AInterface
                {
                    public:

                        /**
                         * @fn	virtual ~P168AInterface()
                         * @brief	Class destroyer.
                         * @author	Yadickson Soto
                         * @date	30/06/2015
                         */
                        virtual ~P168AInterface() {}

                        /**
                         * @fn	virtual bool open( const std::string & device ) = 0;
                         * @brief	Opens the connections.
                         * @author	Yadickson Soto
                         * @date	30/06/2015
                         * @param 	device device path
                         * @return	true if successful.
                         */
                        virtual bool open ( const std::string & device ) = 0;

                        /**
                         * @fn	virtual bool close() = 0;
                         * @brief	Closes the connections.
                         * @author	Yadickson Soto
                         * @date	30/06/2015
                         * @return	true if successful.
                         */
                        virtual bool close() = 0;

                        /**
                         * @fn	virtual std::string getSerialMachine() = 0;
                         * @brief	Method getter serial machine.
                         * @author	Yadickson Soto
                         * @date	30/06/2015
                         * @return	serial machine.
                         */
                        virtual std::string getSerialMachine() = 0;

                        /**
                         * @fn	virtual bool setSerialMachine ( const std::string & serial ) = 0;
                         * @brief	Method setter serial machine.
                         * @author	Yadickson Soto
                         * @date	30/06/2015
                         * @param	serial	serial machine.
                         * @return  true if successfull
                         */
                        virtual bool setSerialMachine ( const std::string & serial ) = 0;

                        /**
                         * @brief  Enables able-d volume control.
                         * @author eduardo.fernandez
                         * @date   24/01/2018
                         * @return Whether the volume control was correctly enabled.
                         */
                        virtual bool enableVolumeControl() = 0;

                        /**
                         * @fn	virtual Smartmatic::SAES::HW::Operation::AbleButtonState * getAbleDButtonState() = 0;
                         * @brief	Method getter able-d button status.
                         * @author	Yadickson Soto
                         * @date	30/06/2015
                         * @return AbleD button status
                         */
                        virtual Smartmatic::SAES::HW::Operation::AbleDButtonState * getAbleDButtonState () = 0;
                };
            }
        }
    }
}

#endif // _P168A_INTERFACE_H_
