#ifndef TEST_ALARM_COMMAND_ELEMENT_TEST
#define TEST_ALARM_COMMAND_ELEMENT_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <System/Utils/StringUtils.hxx>
#include <tests/StoreMockConnection.hxx>
#include <Commands/alarm-ping-command.h>
#include <Commands/alarm-buzzer-command.h>
#include <Commands/alarm-green-led-command.h>
#include <Commands/alarm-red-led-command.h>

class AlarmCommandElementTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::System::Utils::StringUtils StringUtils;
        typedef Smartmatic::System::SafeVector<unsigned char> ResponseVector;
        typedef Smartmatic::SAES::HW::Commands::AlarmPingCommand AlarmPingCommand;
        typedef Smartmatic::SAES::HW::Commands::AlarmBuzzerCommand AlarmBuzzerCommand;
        typedef Smartmatic::SAES::HW::Commands::AlarmGreenLedCommand AlarmGreenLedCommand;
        typedef Smartmatic::SAES::HW::Commands::AlarmRedLedCommand AlarmRedLedCommand;

    public:

        AlarmCommandElementTest ()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testAlarmPingCommandOk()
        {
            StoreMockConnection connection;
            AlarmPingCommand alarm ( &connection );
            ResponseVector response;

            response.push_back ( 0x55 );
            response.push_back ( 0x00 );
            response.push_back ( 0x00 );
            response.push_back ( 0x00 );
            response.push_back ( 0xAA );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( true == alarm.execute() );
            CPPUNIT_ASSERT ( "55000000aa" == StringUtils::arrayHexToString ( alarm.getResponse() ) );
            CPPUNIT_ASSERT ( "55000000aa" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testAlarmPingCommandError()
        {
            StoreMockConnection connection;
            AlarmPingCommand alarm ( &connection );
            ResponseVector response;

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( false == alarm.execute() );
            CPPUNIT_ASSERT ( true == alarm.getResponse().empty() );
            CPPUNIT_ASSERT ( "55000000aa" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testAlarmBuzzerCommand_Off()
        {
            StoreMockConnection connection;
            AlarmBuzzerCommand alarm ( &connection, 0x00, 0x00 );
            ResponseVector response;

            response.push_back ( 0x00 );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( true == alarm.execute() );
            CPPUNIT_ASSERT ( "00" == StringUtils::arrayHexToString ( alarm.getResponse() ) );
            CPPUNIT_ASSERT ( "550502000000aa" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testAlarmBuzzerCommand_On()
        {
            StoreMockConnection connection;
            AlarmBuzzerCommand alarm ( &connection, 0x11, 0x22 );
            ResponseVector response;

            response.push_back ( 0x00 );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( true == alarm.execute() );
            CPPUNIT_ASSERT ( "00" == StringUtils::arrayHexToString ( alarm.getResponse() ) );
            CPPUNIT_ASSERT ( "550502112233aa" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testAlarmGreenLedCommand_Off()
        {
            StoreMockConnection connection;
            AlarmGreenLedCommand alarm ( &connection, 0x00, 0x00 );
            ResponseVector response;

            response.push_back ( 0x00 );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( true == alarm.execute() );
            CPPUNIT_ASSERT ( "00" == StringUtils::arrayHexToString ( alarm.getResponse() ) );
            CPPUNIT_ASSERT ( "55040301000001aa" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testAlarmGreenLedCommand_On()
        {
            StoreMockConnection connection;
            AlarmGreenLedCommand alarm ( &connection, 0x11, 0x22 );
            ResponseVector response;

            response.push_back ( 0x00 );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( true == alarm.execute() );
            CPPUNIT_ASSERT ( "00" == StringUtils::arrayHexToString ( alarm.getResponse() ) );
            CPPUNIT_ASSERT ( "55040301112234aa" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testAlarmRedLedCommand_Off()
        {
            StoreMockConnection connection;
            AlarmRedLedCommand alarm ( &connection, 0x00, 0x00 );
            ResponseVector response;

            response.push_back ( 0x00 );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( true == alarm.execute() );
            CPPUNIT_ASSERT ( "00" == StringUtils::arrayHexToString ( alarm.getResponse() ) );
            CPPUNIT_ASSERT ( "55040302000002aa" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testAlarmRedLedCommand_On()
        {
            StoreMockConnection connection;
            AlarmRedLedCommand alarm ( &connection, 0x11, 0x22 );
            ResponseVector response;

            response.push_back ( 0x00 );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( true == alarm.execute() );
            CPPUNIT_ASSERT ( "00" == StringUtils::arrayHexToString ( alarm.getResponse() ) );
            CPPUNIT_ASSERT ( "55040302112235aa" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        CPPUNIT_TEST_SUITE ( AlarmCommandElementTest );

        CPPUNIT_TEST ( testAlarmPingCommandOk );
        CPPUNIT_TEST ( testAlarmPingCommandError );

        CPPUNIT_TEST ( testAlarmBuzzerCommand_Off );
        CPPUNIT_TEST ( testAlarmBuzzerCommand_On );

        CPPUNIT_TEST ( testAlarmGreenLedCommand_Off );
        CPPUNIT_TEST ( testAlarmGreenLedCommand_On );

        CPPUNIT_TEST ( testAlarmRedLedCommand_Off );
        CPPUNIT_TEST ( testAlarmRedLedCommand_On );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_ALARM_COMMAND_ELEMENT_TEST */
