#ifndef TEST_BARCODE_SET_SERIAL_NUMBER_COMMAND_TEST
#define TEST_BARCODE_SET_SERIAL_NUMBER_COMMAND_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Commands/BarcodeSetSerialNumberCommand.hxx>
#include <System/Utils/StringUtils.hxx>
#include <tests/StoreMockConnection.hxx>

class BarcodeSetSerialNumberCommandTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::System::Utils::StringUtils StringUtils;
        typedef Smartmatic::System::SafeVector<unsigned char> ResponseVector;
        typedef Smartmatic::SAES::HW::Commands::BarcodeSetSerialNumberCommand BarcodeSetSerialNumberCommand;

    public:

        BarcodeSetSerialNumberCommandTest ()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testCommandSetSerialEmpty()
        {
            StoreMockConnection connection;
            std::string serial;

            BarcodeSetSerialNumberCommand setSerialNumberCommand ( &connection, serial );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::never() );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( true == setSerialNumberCommand.execute() );
            CPPUNIT_ASSERT ( "7e00000731313330323030c9" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testCommandSetSerialFull()
        {
            StoreMockConnection connection;
            std::string serial = "H30G01719NOM";

            BarcodeSetSerialNumberCommand setSerialNumberCommand ( &connection, serial );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::never() );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( true == setSerialNumberCommand.execute() );
            CPPUNIT_ASSERT ( "7e0000133131333032303c4833304730313731394e4f4daf" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        CPPUNIT_TEST_SUITE ( BarcodeSetSerialNumberCommandTest );

        CPPUNIT_TEST ( testCommandSetSerialEmpty );
        CPPUNIT_TEST ( testCommandSetSerialFull );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_BARCODE_SET_SERIAL_NUMBER_COMMAND_TEST */
