#ifndef TEST_P168A_READ_MEMORY_TEST
#define TEST_P168A_READ_MEMORY_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Commands/P168AReadMemoryCommand.hxx>
#include <System/Utils/StringUtils.hxx>
#include <tests/StoreMockConnection.hxx>
#include <tests/MockConnection.hxx>

class P168AReadMemoryCommandTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::System::Utils::StringUtils StringUtils;
        typedef Smartmatic::System::SafeVector<unsigned char> ResponseVector;
        typedef Smartmatic::SAES::HW::Commands::P168AReadMemoryCommand P168AReadMemoryCommand;

    public:

        P168AReadMemoryCommandTest ()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testReadMemoryFrom_0x80_0x00_0x10_fail()
        {
            StoreMockConnection connection;
            P168AReadMemoryCommand readCommand ( &connection, 0x80, 0x00, 0x10 );
            ResponseVector response;

            response.push_back ( 0x00 );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( false == readCommand.execute() );
            CPPUNIT_ASSERT ( true == readCommand.getResponse().empty() );
            CPPUNIT_ASSERT ( "1b1c800010" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testReadMemoryFrom_0x80_0x00_0x10_long_response_fail()
        {
            StoreMockConnection connection;
            P168AReadMemoryCommand readCommand ( &connection, 0x80, 0x00, 0x10 );
            ResponseVector response;

            response.push_back ( 0x00 ); // 00:00:00:00:ff:ff:ff:ff:00:00:00:00:ff:ff:ff:ff
            response.push_back ( 0x00 );
            response.push_back ( 0x00 );
            response.push_back ( 0x00 );
            response.push_back ( 0xFF );
            response.push_back ( 0xFF );
            response.push_back ( 0xFF );
            response.push_back ( 0xFF );
            response.push_back ( 0x00 );
            response.push_back ( 0x00 );
            response.push_back ( 0x00 );
            response.push_back ( 0x00 );
            response.push_back ( 0xFF );
            response.push_back ( 0xFF );
            response.push_back ( 0xFF );
            response.push_back ( 0xFF );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( false == readCommand.execute() );
            CPPUNIT_ASSERT ( true == readCommand.getResponse().empty() );
            CPPUNIT_ASSERT ( "1b1c800010" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testReadMemoryFrom_0x80_0x00_0x04_short_response_fail()
        {
            StoreMockConnection connection;
            P168AReadMemoryCommand readCommand ( &connection, 0x80, 0x00, 0x04 );
            ResponseVector response;

            response.push_back ( 0x1B );
            response.push_back ( 0x1C );
            response.push_back ( 0x80 );
            response.push_back ( 0x00 );
            response.push_back ( 0x04 );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( false == readCommand.execute() );
            CPPUNIT_ASSERT ( true == readCommand.getResponse().empty() );
            CPPUNIT_ASSERT ( "1b1c800004" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testReadMemoryFrom_0x80_0x00_0x04_response_fail_first_value()
        {
            StoreMockConnection connection;
            P168AReadMemoryCommand readCommand ( &connection, 0x80, 0x00, 0x04 );
            ResponseVector response;

            response.push_back ( 0x1A );
            response.push_back ( 0x1C );
            response.push_back ( 0x80 );
            response.push_back ( 0x00 );
            response.push_back ( 0x04 );
            response.push_back ( 0xA0 );
            response.push_back ( 0xB0 );
            response.push_back ( 0xC0 );
            response.push_back ( 0xD0 );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( false == readCommand.execute() );
            CPPUNIT_ASSERT ( true == readCommand.getResponse().empty() );
            CPPUNIT_ASSERT ( "1b1c800004" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testReadMemoryFrom_0x80_0x00_0x04_response_fail_second_value()
        {
            StoreMockConnection connection;
            P168AReadMemoryCommand readCommand ( &connection, 0x80, 0x00, 0x04 );
            ResponseVector response;

            response.push_back ( 0x1B );
            response.push_back ( 0x1A );
            response.push_back ( 0x80 );
            response.push_back ( 0x00 );
            response.push_back ( 0x04 );
            response.push_back ( 0xA0 );
            response.push_back ( 0xB0 );
            response.push_back ( 0xC0 );
            response.push_back ( 0xD0 );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( false == readCommand.execute() );
            CPPUNIT_ASSERT ( true == readCommand.getResponse().empty() );
            CPPUNIT_ASSERT ( "1b1c800004" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testReadMemoryFrom_0x80_0x00_0x04_response_fail_third_value()
        {
            StoreMockConnection connection;
            P168AReadMemoryCommand readCommand ( &connection, 0x80, 0x00, 0x04 );
            ResponseVector response;

            response.push_back ( 0x1B );
            response.push_back ( 0x1C );
            response.push_back ( 0x81 );
            response.push_back ( 0x00 );
            response.push_back ( 0x04 );
            response.push_back ( 0xA0 );
            response.push_back ( 0xB0 );
            response.push_back ( 0xC0 );
            response.push_back ( 0xD0 );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( false == readCommand.execute() );
            CPPUNIT_ASSERT ( true == readCommand.getResponse().empty() );
            CPPUNIT_ASSERT ( "1b1c800004" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testReadMemoryFrom_0x80_0x00_0x04_response_fail_fourth_value()
        {
            StoreMockConnection connection;
            P168AReadMemoryCommand readCommand ( &connection, 0x80, 0x00, 0x04 );
            ResponseVector response;

            response.push_back ( 0x1B );
            response.push_back ( 0x1C );
            response.push_back ( 0x80 );
            response.push_back ( 0x01 );
            response.push_back ( 0x04 );
            response.push_back ( 0xA0 );
            response.push_back ( 0xB0 );
            response.push_back ( 0xC0 );
            response.push_back ( 0xD0 );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( false == readCommand.execute() );
            CPPUNIT_ASSERT ( true == readCommand.getResponse().empty() );
            CPPUNIT_ASSERT ( "1b1c800004" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testReadMemoryFrom_0x80_0x00_0x04_response_fail_different_length()
        {
            StoreMockConnection connection;
            P168AReadMemoryCommand readCommand ( &connection, 0x80, 0x00, 0x04 );
            ResponseVector response;

            response.push_back ( 0x1B );
            response.push_back ( 0x1C );
            response.push_back ( 0x80 );
            response.push_back ( 0x00 );
            response.push_back ( 0x05 );
            response.push_back ( 0xA0 );
            response.push_back ( 0xB0 );
            response.push_back ( 0xC0 );
            response.push_back ( 0xD0 );
            response.push_back ( 0xE0 );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( false == readCommand.execute() );
            CPPUNIT_ASSERT ( true == readCommand.getResponse().empty() );
            CPPUNIT_ASSERT ( "1b1c800004" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testReadMemoryFrom_0x80_0x00_length_zero_response_false()
        {
            StoreMockConnection connection;
            P168AReadMemoryCommand readCommand ( &connection, 0x80, 0x00, 0x00 );
            ResponseVector response;

            response.push_back ( 0x1B );
            response.push_back ( 0x1C );
            response.push_back ( 0x80 );
            response.push_back ( 0x00 );
            response.push_back ( 0x00 );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( false == readCommand.execute() );
            CPPUNIT_ASSERT ( true == readCommand.getResponse().empty() );
            CPPUNIT_ASSERT ( "1b1c800000" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testReadMemoryFrom_0x80_0x00_0x04_response_success()
        {
            StoreMockConnection connection;
            P168AReadMemoryCommand readCommand ( &connection, 0x80, 0x00, 0x04 );
            ResponseVector response;

            response.push_back ( 0x1B );
            response.push_back ( 0x1C );
            response.push_back ( 0x80 );
            response.push_back ( 0x00 );
            response.push_back ( 0x04 );
            response.push_back ( 0xA0 );
            response.push_back ( 0xB0 );
            response.push_back ( 0xC0 );
            response.push_back ( 0xD0 );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( true == readCommand.execute() );
            CPPUNIT_ASSERT ( "a0b0c0d0" == StringUtils::arrayHexToString ( readCommand.getResponse() ) );
            CPPUNIT_ASSERT ( "1b1c800004" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testReadMemoryFrom_0x80_0x00_0x04_response_success_check_behavior()
        {
            MockConnection connection;
            P168AReadMemoryCommand readCommand ( &connection, 0x80, 0x00, 0x04 );
            ResponseVector response;

            response.push_back ( 0x1B );
            response.push_back ( 0x1C );
            response.push_back ( 0x80 );
            response.push_back ( 0x00 );
            response.push_back ( 0x04 );
            response.push_back ( 0xA0 );
            response.push_back ( 0xB0 );
            response.push_back ( 0xC0 );
            response.push_back ( 0xD0 );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( &connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( true ) );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( true == readCommand.execute() );

            connection.verify();
        }

        CPPUNIT_TEST_SUITE ( P168AReadMemoryCommandTest );

        CPPUNIT_TEST ( testReadMemoryFrom_0x80_0x00_0x10_fail );
        CPPUNIT_TEST ( testReadMemoryFrom_0x80_0x00_0x10_long_response_fail );
        CPPUNIT_TEST ( testReadMemoryFrom_0x80_0x00_0x04_short_response_fail );
        CPPUNIT_TEST ( testReadMemoryFrom_0x80_0x00_0x04_response_fail_first_value );
        CPPUNIT_TEST ( testReadMemoryFrom_0x80_0x00_0x04_response_fail_second_value );
        CPPUNIT_TEST ( testReadMemoryFrom_0x80_0x00_0x04_response_fail_third_value );
        CPPUNIT_TEST ( testReadMemoryFrom_0x80_0x00_0x04_response_fail_fourth_value );
        CPPUNIT_TEST ( testReadMemoryFrom_0x80_0x00_0x04_response_fail_different_length );
        CPPUNIT_TEST ( testReadMemoryFrom_0x80_0x00_length_zero_response_false );

        CPPUNIT_TEST ( testReadMemoryFrom_0x80_0x00_0x04_response_success );
        CPPUNIT_TEST ( testReadMemoryFrom_0x80_0x00_0x04_response_success_check_behavior );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_P168A_READ_MEMORY_TEST */
