#ifndef TEST_P168A_CONF_MANAGER_TEST
#define TEST_P168A_CONF_MANAGER_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Configuration/configuration-persistence-manager.h>
#include <Configuration/P168AConfigurationManager.hxx>
#include <tests/MockSAESHWConfigurationManager.hxx>
#include <tests/MockConfigurationPersistenceManager.hxx>
#include <tests/StoreMockP168AConfManager.hxx>
#include <tests/MockProcessLauncher.hxx>
#include <tests/MockExitProcess.hxx>

class P168AConfManagerTest : public CPPUNIT_NS::TestFixture
{
    public:

        typedef Smartmatic::SAES::HW::Configuration::P168AConfigurationManager P168AConfigurationManager;
        typedef Smartmatic::SAES::HW::Configuration::SAESHardwareConfigurationManager SAESHardwareConfigurationManager;
        typedef Smartmatic::Configuration::ConfigurationPersistenceManager ConfigurationPersistenceManager;
        typedef Smartmatic::System::Runtime::ProcessLauncher ProcessLauncher;
        typedef Smartmatic::System::Runtime::ExitProcess ExitProcess;
        typedef Smartmatic::SAES::HW::Configuration::P168ADeviceConfiguration::ButtonTypeSequence ButtonTypeSequence;
        typedef Smartmatic::SAES::HW::Configuration::AbleButtonType AbleButtonType;

        P168AConfManagerTest()
        {
        }

        void setUp()
        {
        }

        void tearDown()
        {
        }

        void testGetDefaultConfiguration_ConfigurationIsEmpty()
        {
            MockConfigurationPersistenceManager manager;
            MockProcessLauncher launcher;
            MockExitProcess exitProcess;
            MockSAESHWConfigurationManager saeshwManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &manager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() )
            .will ( MOCKPP_NS::returnValue<int> ( 0 ) );

            MOCKPP_CHAINER_FOR ( MockExitProcess, exitProcess ) exitProcess_mock ( &exitProcess );

            exitProcess_mock
            .expects ( MOCKPP_NS::never() );

            ExitProcess::getInstance ( &exitProcess );
            ProcessLauncher::getInstance ( &launcher );
            ConfigurationPersistenceManager::getInstance ( &manager );
            SAESHardwareConfigurationManager::getInstance ( &saeshwManager );

            SAESHardwareConfigurationManager::getInstance()->getConfiguration()->getP168ADeviceConfiguration().reset();

            P168AConfigurationManager * p168AManager = P168AConfigurationManager::getInstance();

            CPPUNIT_ASSERT ( true == p168AManager->getButtons().empty() );

            manager.verify();
            launcher.verify();
            exitProcess.verify();

            delete p168AManager;
        }

        void testGetDefaultConfiguration_MockConfigurationIsEmpty()
        {
            StoreMockP168AConfManager mock;
            P168AConfigurationManager * p168AManager = P168AConfigurationManager::getInstance ( &mock );

            CPPUNIT_ASSERT ( true == p168AManager->getButtons().empty() );
        }

        void testGetConfigurationValues()
        {
            StoreMockP168AConfManager mock;
            P168AConfigurationManager * p168AManager = P168AConfigurationManager::getInstance ( &mock );

            ButtonTypeSequence seq;

            seq.push_back ( AbleButtonType::P168A_DEVICE_DOWN );
            seq.push_back ( AbleButtonType::P168A_DEVICE_UP );

            mock.config.setButtonType ( seq );

            CPPUNIT_ASSERT ( 2 == p168AManager->getButtons().size() );
        }

        void testCheckSerialMachineFile()
        {
            StoreMockP168AConfManager mock;
            P168AConfigurationManager * p168AManager = P168AConfigurationManager::getInstance ( &mock );

            mock.config.setSerialMachineFile ( "SerialFile" );

            CPPUNIT_ASSERT ( "SerialFile" == p168AManager->getSerialMachineFile() );
        }

        void testCheckAbleDButtonsFile()
        {
            StoreMockP168AConfManager mock;
            P168AConfigurationManager * p168AManager = P168AConfigurationManager::getInstance ( &mock );

            mock.config.setAbleDButtonsFile ( "AbleDButtonsFile" );

            CPPUNIT_ASSERT ( "AbleDButtonsFile" == p168AManager->getAbleDButtonsFile() );
        }

        void testSimulationModeEnableFalse_MockDefault()
        {
            StoreMockP168AConfManager mock;
            P168AConfigurationManager * p168AManager = P168AConfigurationManager::getInstance ( &mock );

            CPPUNIT_ASSERT ( false == p168AManager->simulationEnabled() );
        }

        void testSimulationModeEnableFalse_SerialNotEmpty()
        {
            StoreMockP168AConfManager mock;
            P168AConfigurationManager * p168AManager = P168AConfigurationManager::getInstance ( &mock );

            mock.config.setSerialMachineFile ( "SerialFile" );

            CPPUNIT_ASSERT ( false == p168AManager->simulationEnabled() );
        }

        void testSimulationModeEnableTrue_AbleDButtonsNotEmpty()
        {
            StoreMockP168AConfManager mock;
            P168AConfigurationManager * p168AManager = P168AConfigurationManager::getInstance ( &mock );

            mock.config.setSerialMachineFile ( "SerialFile" );
            mock.config.setAbleDButtonsFile ( "AbleDButtonsFile" );

            CPPUNIT_ASSERT ( true == p168AManager->simulationEnabled() );
        }

        CPPUNIT_TEST_SUITE ( P168AConfManagerTest );

        CPPUNIT_TEST ( testGetDefaultConfiguration_ConfigurationIsEmpty );
        CPPUNIT_TEST ( testGetDefaultConfiguration_MockConfigurationIsEmpty );
        CPPUNIT_TEST ( testGetConfigurationValues );

        CPPUNIT_TEST ( testCheckSerialMachineFile );
        CPPUNIT_TEST ( testCheckAbleDButtonsFile );

        CPPUNIT_TEST ( testSimulationModeEnableFalse_MockDefault );
        CPPUNIT_TEST ( testSimulationModeEnableFalse_SerialNotEmpty );
        CPPUNIT_TEST ( testSimulationModeEnableTrue_AbleDButtonsNotEmpty );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_P168A_CONF_MANAGER_TEST */
