#ifndef TEST_SIMULATOR_P168A_DEVICE_TEST
#define TEST_SIMULATOR_P168A_DEVICE_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Devices/SimulatorP168ADevice.hxx>
#include <tests/MockFile.hxx>
#include <tests/StoreMockFile.hxx>

class SimulatorP168ADeviceTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::SAES::HW::Devices::SimulatorP168ADevice SimulatorP168ADevice;
        typedef Smartmatic::SAES::HW::Operation::AbleDButtonState AbleDButtonState;
        typedef Smartmatic::System::IO::File File;
        typedef Smartmatic::System::SafeBuffer SafeBuffer;

    public:

        SimulatorP168ADeviceTest ()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testOpenConnectionFail ()
        {
            MockFile mock;
            File::getInstance ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &mock );

            canOpenFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) );

            SimulatorP168ADevice device ( "serial", "buttons" );

            CPPUNIT_ASSERT ( false == device.open ( "" ) );

            mock.verify();
        }

        void testOpenConnectionSuccess ()
        {
            MockFile mock;
            File::getInstance ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &mock );

            canOpenFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) );

            SimulatorP168ADevice device ( "serial", "buttons" );

            CPPUNIT_ASSERT ( true == device.open ( "" ) );

            mock.verify();
        }

        void testCheckOpenFileConnection ()
        {
            StoreMockFile mock;
            File::getInstance ( &mock );

            mock.canOpenFileReturnValues.push_back ( true );

            SimulatorP168ADevice device ( "serial", "buttons" );

            CPPUNIT_ASSERT ( true == device.open ( "dummy" ) );
            CPPUNIT_ASSERT ( false == mock.canOpenFileList.empty() );
            CPPUNIT_ASSERT ( "dummy" == ( * mock.canOpenFileList.begin() ) );
        }

        void testCloseConnection ()
        {
            MockFile mock;
            File::getInstance ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, openFileToBuffer, ext ) openFileToBuffer_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, addBufferToFile, ext ) saveBufferToFile_mock ( &mock );

            canOpenFile_mock.expects ( MOCKPP_NS::never() );
            openFileToBuffer_mock.expects ( MOCKPP_NS::never() );
            saveBufferToFile_mock.expects ( MOCKPP_NS::never() );

            SimulatorP168ADevice device ( "serial", "buttons" );

            CPPUNIT_ASSERT ( true == device.close () );

            mock.verify();
        }

        void testSetSerialMachineFail()
        {
            MockFile mock;
            File::getInstance ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, saveBufferToFile, ext ) saveBufferToFile_mock ( &mock );

            canOpenFile_mock.expects ( MOCKPP_NS::never() );

            saveBufferToFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) );

            SimulatorP168ADevice device ( "serial", "buttons" );

            CPPUNIT_ASSERT ( false == device.setSerialMachine ( "SERIAL-DEVICE" ) );

            mock.verify();
        }

        void testSetSerialMachineSuccess()
        {
            MockFile mock;
            File::getInstance ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, saveBufferToFile, ext ) saveBufferToFile_mock ( &mock );

            canOpenFile_mock.expects ( MOCKPP_NS::never() );

            saveBufferToFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) );

            SimulatorP168ADevice device ( "serial", "buttons" );

            CPPUNIT_ASSERT ( true == device.setSerialMachine ( "SERIAL-DEVICE" ) );

            mock.verify();
        }

        void testSetSerialMachineCheckSave()
        {
            StoreMockFile mock;
            File::getInstance ( &mock );

            SafeBuffer expected ( "SERIAL-DEVICE" );

            mock.saveReturnValues.push_back ( true );

            SimulatorP168ADevice device ( "serial", "buttons" );

            CPPUNIT_ASSERT ( true == device.setSerialMachine ( "SERIAL-DEVICE" ) );
            CPPUNIT_ASSERT ( false == mock.saveBufferValues.empty() );
            CPPUNIT_ASSERT ( "serial" == ( * mock.saveBufferValues.begin() ).file );
            CPPUNIT_ASSERT ( expected == ( * mock.saveBufferValues.begin() ).buffer );
        }

        void testGetSerialMachineFail()
        {
            StoreMockFile mock;
            File::getInstance ( &mock );

            mock.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer (), false ) );

            SimulatorP168ADevice device ( "serial", "buttons" );

            CPPUNIT_ASSERT ( true == device.getSerialMachine().empty() );
            CPPUNIT_ASSERT ( false == mock.openFileListValues.empty() );
            CPPUNIT_ASSERT ( "serial" == ( * mock.openFileListValues.begin() ) );
        }

        void testGetSerialMachineFailEmptyBuffer()
        {
            StoreMockFile mock;
            File::getInstance ( &mock );

            mock.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer (), true ) );

            SimulatorP168ADevice device ( "serial", "buttons" );

            CPPUNIT_ASSERT ( true == device.getSerialMachine().empty() );
            CPPUNIT_ASSERT ( false == mock.openFileListValues.empty() );
            CPPUNIT_ASSERT ( "serial" == ( * mock.openFileListValues.begin() ) );
        }

        void testGetSerialMachineSucess()
        {
            StoreMockFile mock;
            File::getInstance ( &mock );

            mock.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer ( "PM1234" ), true ) );

            SimulatorP168ADevice device ( "serial", "buttons" );

            CPPUNIT_ASSERT ( "PM1234" == device.getSerialMachine() );
            CPPUNIT_ASSERT ( false == mock.openFileListValues.empty() );
            CPPUNIT_ASSERT ( "serial" == ( * mock.openFileListValues.begin() ) );
        }

        void testGetButtonStatusFail()
        {
            StoreMockFile mock;
            File::getInstance ( &mock );

            mock.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer (), false ) );

            SimulatorP168ADevice device ( "serial", "buttons" );

            AbleDButtonState * status = device.getAbleDButtonState();

            CPPUNIT_ASSERT ( NULL != status );
            CPPUNIT_ASSERT ( false == status->isChanged() );
            CPPUNIT_ASSERT ( false == mock.openFileListValues.empty() );
            CPPUNIT_ASSERT ( "buttons" == ( * mock.openFileListValues.begin() ) );
        }

        void testGetButtonStatusFailEmptyBuffer()
        {
            StoreMockFile mock;
            File::getInstance ( &mock );

            mock.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer (), true ) );

            SimulatorP168ADevice device ( "serial", "buttons" );

            AbleDButtonState * status = device.getAbleDButtonState();

            CPPUNIT_ASSERT ( NULL != status );
            CPPUNIT_ASSERT ( false == status->isChanged() );
            CPPUNIT_ASSERT ( false == mock.openFileListValues.empty() );
            CPPUNIT_ASSERT ( "buttons" == ( * mock.openFileListValues.begin() ) );
        }

        void testGetButtonStatusBufferWrong()
        {
            StoreMockFile mock;
            File::getInstance ( &mock );

            mock.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer ( "HELP,PRESS" ), true ) );

            SimulatorP168ADevice device ( "serial", "buttons" );

            AbleDButtonState * status = device.getAbleDButtonState();

            CPPUNIT_ASSERT ( NULL != status );
            CPPUNIT_ASSERT ( false == status->isChanged() );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == status->getStatus ( AbleDButtonState::HELP ) );
            CPPUNIT_ASSERT ( false == mock.openFileListValues.empty() );
            CPPUNIT_ASSERT ( "buttons" == ( * mock.openFileListValues.begin() ) );
        }

        void testGetButtonStatusBufferUnknow()
        {
            StoreMockFile mock;
            File::getInstance ( &mock );

            mock.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer ( "XX:YY" ), true ) );

            SimulatorP168ADevice device ( "serial", "buttons" );

            AbleDButtonState * status = device.getAbleDButtonState();

            CPPUNIT_ASSERT ( NULL != status );
            CPPUNIT_ASSERT ( false == status->isChanged() );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == status->getStatus ( AbleDButtonState::HELP ) );
            CPPUNIT_ASSERT ( false == mock.openFileListValues.empty() );
            CPPUNIT_ASSERT ( "buttons" == ( * mock.openFileListValues.begin() ) );
        }

        void testGetButtonStatusBufferUnknow2()
        {
            StoreMockFile mock;
            File::getInstance ( &mock );

            mock.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer ( "HELP:YY" ), true ) );

            SimulatorP168ADevice device ( "serial", "buttons" );

            AbleDButtonState * status = device.getAbleDButtonState();

            CPPUNIT_ASSERT ( NULL != status );
            CPPUNIT_ASSERT ( false == status->isChanged() );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == status->getStatus ( AbleDButtonState::HELP ) );
            CPPUNIT_ASSERT ( false == mock.openFileListValues.empty() );
            CPPUNIT_ASSERT ( "buttons" == ( * mock.openFileListValues.begin() ) );
        }

        void testGetButtonStatusBufferCorrect()
        {
            StoreMockFile mock;
            File::getInstance ( &mock );

            mock.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer ( "HELP:PRESS" ), true ) );

            SimulatorP168ADevice device ( "serial", "buttons" );

            AbleDButtonState * status = device.getAbleDButtonState();

            CPPUNIT_ASSERT ( NULL != status );
            CPPUNIT_ASSERT ( true == status->isChanged() );
            CPPUNIT_ASSERT ( AbleDButtonState::PRESS == status->getStatus ( AbleDButtonState::HELP ) );
            CPPUNIT_ASSERT ( false == mock.openFileListValues.empty() );
            CPPUNIT_ASSERT ( "buttons" == ( * mock.openFileListValues.begin() ) );
        }

        void testGetButtonStatusBufferCorrect2()
        {
            StoreMockFile mock;
            File::getInstance ( &mock );

            SafeBuffer buffer;

            buffer.AddData ( "HELP:PRESS" );
            buffer.AddData ( "\n" );
            buffer.AddData ( "ACTIVATE:HOLD" );

            mock.openFileValues.push_back ( StoreMockFile::OpenFileValues ( buffer, true ) );

            SimulatorP168ADevice device ( "serial", "buttons" );

            AbleDButtonState * status = device.getAbleDButtonState();

            CPPUNIT_ASSERT ( NULL != status );
            CPPUNIT_ASSERT ( true == status->isChanged() );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == status->getStatus ( AbleDButtonState::HELP ) );
            CPPUNIT_ASSERT ( AbleDButtonState::HOLD == status->getStatus ( AbleDButtonState::ACTIVATE ) );
            CPPUNIT_ASSERT ( false == mock.openFileListValues.empty() );
            CPPUNIT_ASSERT ( "buttons" == ( * mock.openFileListValues.begin() ) );
        }

        CPPUNIT_TEST_SUITE ( SimulatorP168ADeviceTest );

        CPPUNIT_TEST ( testOpenConnectionFail );
        CPPUNIT_TEST ( testOpenConnectionSuccess );
        CPPUNIT_TEST ( testCheckOpenFileConnection );

        CPPUNIT_TEST ( testCloseConnection );

        CPPUNIT_TEST ( testSetSerialMachineFail );
        CPPUNIT_TEST ( testSetSerialMachineSuccess );
        CPPUNIT_TEST ( testSetSerialMachineCheckSave );

        CPPUNIT_TEST ( testGetSerialMachineFail );
        CPPUNIT_TEST ( testGetSerialMachineFailEmptyBuffer );
        CPPUNIT_TEST ( testGetSerialMachineSucess );

        CPPUNIT_TEST ( testGetButtonStatusFail );
        CPPUNIT_TEST ( testGetButtonStatusFailEmptyBuffer );
        CPPUNIT_TEST ( testGetButtonStatusBufferWrong );
        CPPUNIT_TEST ( testGetButtonStatusBufferUnknow );
        CPPUNIT_TEST ( testGetButtonStatusBufferUnknow2 );
        CPPUNIT_TEST ( testGetButtonStatusBufferCorrect );
        CPPUNIT_TEST ( testGetButtonStatusBufferCorrect2 );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_SIMULATOR_P168A_DEVICE_TEST */
