#ifdef ECUT_MAIN

#include <cppunit/TestResult.h>
#include <cppunit/TestResultCollector.h>
#include <cppunit/ui/text/TestRunner.h>
#include <cppunit/extensions/TestFactoryRegistry.h>
#include <cppunit/BriefTestProgressListener.h>
#include <cppunit/CompilerOutputter.h>
#include <cppunit/XmlOutputter.h>

std::string getFilename ( const std::string & str );

int main ( int argc, char ** argv )
{
    // informs test-listener about testresults
    CPPUNIT_NS::TestResult testresult;

    // register listener for collecting the test-results
    CPPUNIT_NS::TestResultCollector collectedresults;
    testresult.addListener ( &collectedresults );

    // register listener for per-test progress output
    CPPUNIT_NS::BriefTestProgressListener progress;
    testresult.addListener ( &progress );

    // insert test-suite at test-runner by registry
    CPPUNIT_NS::TestRunner testrunner;
    testrunner.addTest ( CPPUNIT_NS::TestFactoryRegistry::getRegistry().makeTest () );
    testrunner.run ( testresult );

    // output results in compiler-format
    CPPUNIT_NS::CompilerOutputter compileroutputter ( &collectedresults, std::cerr );
    compileroutputter.write ();

    // Output XML for Jenkins CPPunit plugin
    std::ofstream xmlFileOut ( getFilename ( argv[0] ).c_str() );
    CPPUNIT_NS::XmlOutputter xmlOut ( &collectedresults, xmlFileOut );
    xmlOut.write();

#ifdef TEST_TRUE
    // return 0 always, only for jenkis
    return 0;
#else
    // return 0 if tests were successful
    return collectedresults.wasSuccessful() ? 0 : 1;
#endif
}

std::string getFilename ( const std::string & str )
{
    std::string file;
    size_t found = str.find_last_of ( "/\\" );
    std::stringstream ss;

    if ( found != std::string::npos )
    {
        file = str.substr ( found + 1 );
    }
    else
    {
        file = str;
    }

    ss << file;
    ss << "-result.xml";

    return ss.str();
}

#endif
