/**
 * @file	SmartmaticSoundConfManager.cc
 *
 * @brief	smartmatic sound conf manager class.
 */

#include "SmartmaticSoundConfManager.hxx"
#include "SmartmaticConfigurationManager.hxx"

using namespace Smartmatic::Configuration;
using namespace Smartmatic::System::Sounds;

SmartmaticSoundConfManager * SmartmaticSoundConfManager::instance = NULL; ///< The smartmatic sound configuration manager singleton instance

SmartmaticSoundConfManager::SmartmaticSoundConfManager()
{

}

SmartmaticSoundConfManager::~SmartmaticSoundConfManager()
{
    instance = NULL;
}

bool SmartmaticSoundConfManager::isUsingBeep()
{
    return getSoundOutputConfiguration().getUseBeep();
}

std::string SmartmaticSoundConfManager::getAppSound()
{
    return getSoundOutputConfiguration().getAppSound();
}

std::string SmartmaticSoundConfManager::getSoundFile ( const std::string & soundConfig )
{
    std::string soundFile;

    SoundOutput::SoundConfigurationsSequence & seq ( getSoundOutputConfiguration().getSoundConfigurations() );
    SoundOutput::SoundConfigurationsIterator it;

    for ( it = seq.begin();
            it != seq.end();
            ++it )
    {
        if ( ( * it ).getName().compare ( soundConfig ) == 0 )
        {
            if ( ( * it ).getSoundFile().present() )
            {
                soundFile = ( * it ).getSoundFile().get();
            }

            break;
        }
    }

    return soundFile;
}

Smartmatic::System::SafeVector<BeepDescriptor> SmartmaticSoundConfManager::getSoundConfiguration ( const std::string & sound )
{
    Smartmatic::System::SafeVector<BeepDescriptor> sounds;

    SoundOutput::SoundConfigurationsSequence & seq ( getSoundOutputConfiguration().getSoundConfigurations() );
    SoundOutput::SoundConfigurationsIterator it;

    for ( it = seq.begin();
            it != seq.end();
            ++it )
    {
        if ( ( *it ).getName().compare ( sound ) == 0 )
        {
            SoundConfigurations::SoundConfigurationSequence & itemSeq ( ( *it ).getSoundConfiguration() );
            SoundConfigurations::SoundConfigurationIterator itemIt;

            for ( itemIt = itemSeq.begin();
                    itemIt != itemSeq.end();
                    ++itemIt )
            {
                int frequency = ( *itemIt ).getFrequency();
                int time = ( *itemIt ).getTime();
                int repetitions = ( *itemIt ).getRepetitions();
                int timeBetweenRepetitions = ( *itemIt ).getTimeBetweenRepetitions();

                BeepDescriptor beepDescriptor ( frequency, time, repetitions, timeBetweenRepetitions );
                sounds.push_back ( beepDescriptor );
            }

            break;
        }
    }

    return sounds;
}

Smartmatic::Configuration::SoundOutput & SmartmaticSoundConfManager::getSoundOutputConfiguration()
{
    if ( ! SmartmaticConfigurationManager::getInstance()->getConfiguration()->getSoundOutput().present() )
    {
        SoundOutput config;

        config.setUseBeep ( false );
        config.setAppSound ( "app" );

        SoundOutput::SoundConfigurationsSequence seq;
        config.setSoundConfigurations ( seq );

        SmartmaticConfigurationManager::getInstance()->getConfiguration()->setSoundOutput ( config );
    }

    return SmartmaticConfigurationManager::getInstance()->getConfiguration()->getSoundOutput().get();
}

SmartmaticSoundConfManager * SmartmaticSoundConfManager::getInstance ( SmartmaticSoundConfManager * externManager )
{
    if ( ! instance )
    {
        instance = ( externManager == NULL ? new SmartmaticSoundConfManager() : externManager );
    }

    return instance;
}
