/**
 * @file	BaseLanguageConfiguration.hxx
 * @brief	Header file to the base language configuration class by project. Call configuration methods to gettext
 * @date	18/11/2013
 * @author	Yadickson Soto
 */

#ifndef _BASE_LANGUAGE_CONFIGURATION_HXX_
#define _BASE_LANGUAGE_CONFIGURATION_HXX_

#include <string>

namespace Smartmatic
{
    namespace Environment
    {
        /**
         * @class	BaseLanguageConfiguration
         * @brief	Base language configuration class.
         * @date	18/11/2013
         * @author	Yadickson Soto
         */
        class BaseLanguageConfiguration
        {
            public:

                /**
                 * @fn	BaseLanguageConfiguration();
                 * @brief	Default constructor.
                 * @date	18/11/2013
                 * @author	Yadickson Soto
                 */
                BaseLanguageConfiguration();

                /**
                 * @fn	virtual ~BaseLanguageConfiguration();
                 * @brief	Destroy.
                 * @date	18/11/2013
                 * @author	Yadickson Soto
                 */
                virtual ~BaseLanguageConfiguration();

                /**
                 * @fn	void virtual InitializeLanguage();
                 * @brief	Initializes the language by project.
                 * @date	18/11/2013
                 * @author	Yadickson Soto
                 */
                virtual void InitializeLanguage();

                /**
                 * @fn	virtual std::string getPackageName() = 0;
                 * @brief	Gets the package name by project.
                 * @date	18/11/2013
                 * @author	Yadickson Soto
                 * @return	The package name.
                 */
                virtual std::string getPackageName() = 0;

                /**
                 * @fn	virtual std::string getLocaleDir() = 0;
                 * @brief	Gets the locale dir.
                 * @date	18/11/2013
                 * @author	Yadickson Soto
                 * @return	The locale dir.
                 */
                virtual std::string getLocaleDir() = 0;
        };
    }
}

#endif // _BASE_LANGUAGE_CONFIGURATION_HXX_
