/**
 * @file	resource-path-provider.h
 *
 * @brief	Header file to the resource path provider class.
 */

#ifndef _RESOURCE_PATH_PROVIDER_H_
#define _RESOURCE_PATH_PROVIDER_H_

#include <string>

namespace Smartmatic
{
    namespace Environment
    {
        /**
         * @class	ResourcePathProvider
         * @brief	Resource path provider.
         * @author	Rafael.gasperi
         * @date	28/04/2011
         */
        class ResourcePathProvider
        {

            protected:

                /**
                 * @fn	ResourcePathProvider();
                 * @brief	Default constructor.
                 * @author	Rafael.gasperi
                 * @date	28/04/2011
                 */
                ResourcePathProvider();

            public:

                /**
                 * @fn	virtual ~ResourcePathProvider();
                 * @brief	Destroy.
                 * @author	Yadickson Soto
                 * @date	29/11/2013
                 */
                virtual ~ResourcePathProvider();

                /**
                 * @fn	virtual std::string ResourcePathProvider::GetResourcePath(const std::string& libPath,
                 * 			const std::string& relativePath);
                 * @brief	Gets a resource path.
                 * @author	Rafael.gasperi
                 * @date	28/04/2011
                 * @param	libPath				Full pathname of the library file.
                 * @param	relativePath	Full pathname of the relative file.
                 * @return	The resource path.
                 */
                virtual std::string GetResourcePath ( const std::string & libPath, const std::string & relativePath );
                /**
                 * @fn	virtual std::string getResourcePath(const std::string & path)
                 * @brief	Gets a resource path.
                 * @param path getter path
                 * @author	Yadickson Soto
                 * @date	01/11/2012
                 * @return	result path
                 */
                virtual std::string getResourcePath ( const std::string & path );
                /**
                 * @fn	virtual std::string getResourcePathByLanguage( const std::string & path, const std::string & lang, const std::string & country )
                 * @brief	Gets a resource path.
                 * @param path getter path
                 * @param	lang language
                 * @param	country	country
                 * @author	Yadickson Soto
                 * @date	05/08/2013
                 *
                 * @return	result path
                 */
                virtual std::string getResourcePathByLanguage ( const std::string & path, const std::string & lang, const std::string & country );

                /**
                 * @fn	static ResourcePathProvider ResourcePathProvider::*getInstance( ResourcePathProvider * externResource = NULL );
                 * @brief	Gets the current.
                 * @author	Rafael.gasperi
                 * @date	28/04/2011
                 * @param 	externResource external Resource Path provider to unit test
                 * @return	null if it fails, else.
                 */
                static ResourcePathProvider * getInstance ( ResourcePathProvider * externResource = NULL );

            private:

                static ResourcePathProvider * singleton_instance; ///< The singleton instance
        };
    }
}

#endif // _RESOURCE_PATH_PROVIDER_H_
