/**
 * @file   NuanceVocalizer.cxx
 * @brief  Implementation of NuanceVocalizer class.
 * @author manuel.arguelles
 * @date   Oct 10, 2017
 */

#include "NuanceVocalizer.hxx"
#include "NuanceVocalizerImpl.hxx"
#include <System/Audio/IAudioPlayer.hxx>

using namespace Smartmatic::System::Audio::TextToSpeech;

static const unsigned long DELAY_INTERVAL = 100000;

NuanceVocalizer::NuanceVocalizer(const std::string& dataPath,
                                 System::Audio::IAudioPlayer* audioPlayer)
    : m_impl(new NuanceVocalizerImpl(dataPath, audioPlayer))
{
}

NuanceVocalizer::~NuanceVocalizer()
{
}

bool NuanceVocalizer::setLanguage(const std::string& language)
{
    return m_impl->setLanguage(language);
}

bool NuanceVocalizer::setSpeechRate(const int rate)
{
    return m_impl->setSpeechRate(rate);
}

void NuanceVocalizer::speak(const std::string& text)
{
    if (!text.empty())
    {
        m_impl->speak(text);
    }
}

void NuanceVocalizer::stop()
{
    m_impl->stop();
}

bool NuanceVocalizer::isSpeaking() const
{
    return m_impl->isSpeaking();
}

void NuanceVocalizer::waitWhileSpeaking() const
{
    while (isSpeaking())
    {
        Glib::usleep(DELAY_INTERVAL);
    }
}
