/**
 * @file BaseException.hxx
 * @brief Class base for exceptions
 * @date 24/02/2011
 * @author Yadickson Soto
 */

#ifndef __BASE_EXCEPTION_H__
#define __BASE_EXCEPTION_H__

#include <string>
#include <exception>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace System
    {
        namespace Exception
        {
            /**
             * @class	BaseException
             * @brief	Header class BaseException.
             * @author	Yadickson Soto &lt;yadickson.soto@smartmatic.com&gt;
             * @date	14-02-2011
             */
            class BaseException : public std::exception
            {
                public:
                    /**
                     * @fn	BaseException::BaseException( const std::string& message, const std::string& code,
                     * 			Smartmatic::Log::ISMTTLog *logger);
                     * @brief	Class constructor.
                     * @author	Youssef.tourkmani
                     * @date	29/10/2012
                     * @param	message	exception message for interface.
                     * @param	code	 	exception message for logger.
                     * @param	logger 	logger.
                     */
                    BaseException ( const std::string& message, const std::string& code,
                                    Smartmatic::Log::ISMTTLog *logger );

                    /**
                    * @fn    virtual BaseException::~BaseException() throw ();
                    * @brief    Class destructor.
                    * @author    Youssef.tourkmani
                    * @date    29/10/2012
                    */
                    virtual ~BaseException() throw ();

                    /**
                    * @fn    std::string BaseException::getMessage() const;
                    * @brief    method to obtain the exception message.
                    * @author    Youssef.tourkmani
                    * @date    29/10/2012
                    * @return    the exception message.
                    */
                    std::string getMessage() const;

                    /**
                     * @fn	std::string BaseException::getCode() const;
                     * @brief	method to obtain the exception code.
                     * @author	Youssef.tourkmani
                     * @date	29/10/2012
                     * @return	the exception code.
                     */
                    std::string getCode() const;

                    /**
                     * @fn	virtual const char* BaseException::what() const throw();
                     * @brief	method to obtain the exception message.
                     * @author	Youssef.tourkmani
                     * @date	29/10/2012
                     * @return	the exception message.
                     */
                    virtual const char * what() const throw();

                private:
                    std::string message; ///< exception message
                    std::string code; ///< exception code
            };
        }
    }
}

#endif /*__BASE_EXCEPTION_H__*/
