/**
 * @file CryptoException.hxx
 * @brief Class custom for exceptions in crypto security
 */

#ifndef __CRYPTO_EXCEPTION_H__
#define __CRYPTO_EXCEPTION_H__

#include "BaseException.hxx"

namespace Smartmatic
{
    namespace System
    {
        namespace Exception
        {
            /**
             * @class	CryptoException
             * @brief	Header class CryptoException.
             * @author	Yadickson Soto &lt;yadickson.soto@smartmatic.com&gt;
             * @date	31-03-2011
             */
            class CryptoException : public BaseException
            {
                public:
                    /**
                     * @fn	CryptoException::CryptoException ( std::string message, std::string code,
                     * 		Smartmatic::Log::ISMTTLog* logger )
                     * @brief	Class constructor.
                     * @author	Youssef.tourkmani
                     * @date	29/10/2012
                     * @param	message	exception message.
                     * @param	code	 	exception code, default empty.
                     * @param	logger 	logger.
                     */
                    CryptoException ( std::string message, std::string code,
                                      Smartmatic::Log::ISMTTLog * logger )
                        : BaseException ( message, code, logger ) {}
            };
        }
    }
}

#endif /* __CRYPTO_EXCEPTION_H__ */
