/**
 * @file   TextToSpeechException.hxx
 * @brief  Declaration of TextToSpeechException class.
 * @author manuel.arguelles
 * @date   Oct  9, 2017
 */

#ifndef TEXT_TO_SPEECH_EXCEPTION_HXX
#define TEXT_TO_SPEECH_EXCEPTION_HXX

#include "BaseException.hxx"

namespace Smartmatic
{
    namespace System
    {
        namespace Exception
        {

            /**
             * @class  TextToSpeechException
             * @brief  Text to speech exception class.
             * @author manuel.arguelles
             * @date   Oct  9, 2017
             */
            class TextToSpeechException : public BaseException
            {
                public:

                    /**
                     * @brief  Creates an instance of the class.
                     * @author manuel.arguelles
                     * @date   Oct  9, 2017
                     * @param  message The exception message.
                     * @param  code    The exception code.
                     * @param  logger  The logger.
                     */
                    TextToSpeechException(const std::string& message,
                                          const std::string& code,
                                          Smartmatic::Log::ISMTTLog* logger = NULL)
                        : BaseException(message, code, logger) {}

                    /**
                     * @brief  Destroys an instance of the class.
                     * @author manuel.arguelles
                     * @date   Oct  9, 2017
                     */
                    virtual ~TextToSpeechException() throw() {}
            };

        } /* namespace Exception */
    } /* namespace System */
} /* namespace Smartmatic */

#endif /* TEXT_TO_SPEECH_EXCEPTION_HXX */
