/**
 * @file	Path.h
 *
 * @brief	Header file to the path class.
 */

#ifndef _PATH_CLASS_H_
#define _PATH_CLASS_H_

#include <string>
#include <list>

namespace Smartmatic
{
    namespace System
    {
        namespace IO
        {
            /**
             * @class	Path
             * @brief	Class utilities for Path manager.
             * @author	Rafael.gasperi
             * @date	28/04/2011
             */
            class Path
            {

                public:

                    /**
                     * @fn	static std::string Path::Combine(const std::string & path1, const std::string & path2);
                     * @brief	Combines the given file.
                     * @author	Rafael.gasperi
                     * @date	28/04/2011
                     * @param	path1	The first path.
                     * @param	path2	The second path.
                     * @return	.
                     */
                    static std::string Combine ( const std::string & path1, const std::string & path2 );

                    /**
                     * @fn	static std::string Path::GetFileName(const std::string& path);
                     * @brief	Gets a file name.
                     * @author	Rafael.gasperi
                     * @date	28/04/2011
                     * @param	path	Full pathname of the file.
                     * @return	The file name in the given path.
                     */
                    static std::string GetFileName ( const std::string & path );

                    /**
                     * @fn	static std::string Path::GetFileNameWithOutExtension(const std::string path);
                     * @brief	Gets a file name with out extension.
                     * @author	Rafael.gasperi
                     * @date	28/04/2011
                     * @param	path	Full pathname of the file.
                     * @return	The file name with out extension.
                     */
                    static std::string GetFileNameWithOutExtension ( const std::string & path );

                    /**
                     * @fn	static std::string Path::GetFullFileNameWithOutExtension(const std::string path);
                     * @brief	Gets a full path file name with out extension.
                     * @author	Rafael.gasperi
                     * @date	28/04/2011
                     * @param	path	Full pathname of the file.
                     * @return	The full path file name with out extension.
                     */
                    static std::string GetFullFileNameWithOutExtension ( const std::string & path );

                    /**
                     * @fn	static std::string Path::GetFileExtension(const std::string path);
                     * @brief	Gets a file extension.
                     * @author	Rafael.gasperi
                     * @date	28/04/2011
                     * @param	path	Full pathname of the file.
                     * @return	The file extension.
                     */
                    static std::string GetFileExtension ( const std::string & path );

                    /**
                     * @fn	static std::string Path::GetDirectory(const std::string& path);
                     * @brief	Gets a directory.
                     * @author	Rafael.gasperi
                     * @date	28/04/2011
                     * @param	path	Full pathname of the file.
                     * @return	The directory.
                     */
                    static std::string GetDirectory ( const std::string & path );

                    /**
                     * @fn	static std::string Path::combineFileName( const std::string & file, const std::string  combine );
                     * @brief	Gets combine name file.
                     * @author	Yadickson Soto yadickson.soto@smartmatic.com
                     * @date	03/08/2011
                     * @param	file The file
                     * @param	combine	The combine.
                     * @return	new file name.
                     */
                    static std::string combineFileName ( const std::string & file, const std::string & combine );

                    /**
                     * @fn	static char getPathSeparator();
                     * @brief	Gets path separator.
                     * @author	Yadickson Soto yadickson.soto@smartmatic.com
                     * @date	08/11/2013
                     * @return	path separator.
                     */
                    static char getPathSeparator();
            };
        }
    }
}

#endif //  _PATH_CLASS_H_
