/**
 * @file PipeFile.cxx
 * @brief Body class to process pipe console process.
 * @date 21/02/2014
 * @author Yadickson Soto
 */

#include "PipeFile.hxx"
#include <System/Utils/StringUtils.hxx>
#include <sys/stat.h>
#include <stdio.h>
#include <limits.h>
#include <sstream>

using namespace Smartmatic::System::IO;
using namespace Smartmatic::System::Utils;

PipeFile::PipeFile ()
{
    handle = NULL;
}

PipeFile::~PipeFile()
{
    close();
}

bool PipeFile::open ( const std::string & commandPipe )
{
    close();

    handle = getFileHandle ( commandPipe );

    return handle != NULL;
}

std::string PipeFile::getLine ( bool & result )
{
    std::string line;
    result = false;

    if ( handle != NULL )
    {
        char buffer [PIPE_BUF];

        if ( fgets ( buffer, sizeof ( buffer ), ( FILE * ) handle ) != NULL )
        {
            line.assign ( buffer );
            std::stringstream ss;
            ss << std::endl;
            line = StringUtils::replaceAll ( line, ss.str(), "" );

            result = true;
        }
    }

    return line;
}

void PipeFile::close()
{
    if ( handle != NULL )
    {
        fclose ( ( FILE * ) handle );
        handle = NULL;
    }
}

void * PipeFile::getFileHandle ( const std::string & command )
{
    mkfifo ( command.c_str(), 0666 );
    return fopen ( command.c_str(), "r" );
}
