/**
 * @file PipeFile.hxx
 * @brief Class definition to process pipe console process.
 * @date 21/02/2014
 * @author Yadickson Soto
 */

#ifndef _PIPE_FILE_HXX
#define _PIPE_FILE_HXX

#include <string>

namespace Smartmatic
{
    namespace System
    {
        namespace IO
        {
            /**
             * @class	PipeFile
             * @brief	Class definition to process pipe console process.
             * @author	Yadickson Soto
             * @date	21/02/2014
             */
            class PipeFile
            {
                public:
                    /**
                     * @fn PipeFile();
                     * @brief	Class constructor
                     * @author	Yadickson Soto
                     * @date	21/02/2014
                     */
                    PipeFile ();

                    /**
                     * @fn virtual ~PipeFile();
                     * @brief	Destroy
                     * @author	Yadickson Soto
                     * @date	21/02/2014
                     */
                    virtual ~PipeFile();

                    /**
                     * @fn virtual bool open ( const std::string & commandPipe );
                     * @brief	Call open pipe file handle
                     * @author	Yadickson Soto
                     * @date	21/02/2014
                     * @param	commandPipe command line to execute or pipe to read
                     * @return	true if successfully
                     */
                    virtual bool open ( const std::string & commandPipe );

                    /**
                     * @fn virtual std::string getLine ( bool & result );
                     * @brief	Call get line from file handle
                     * @author	Yadickson Soto
                     * @date	21/02/2014
                     * @param	result True if successful.
                     * @return	The line read
                     */
                    virtual std::string getLine ( bool & result );

                    /**
                     * @fn virtual void close ();
                     * @brief	Call close file handle
                     * @author	Yadickson Soto
                     * @date	21/02/2014
                     */
                    virtual void close ();

                protected:

                    /**
                     * @fn virtual void * getFileHandle( const std::string & commandPipe );
                     * @brief	Call from open method for get pipe file handle
                     * @author	Yadickson Soto
                     * @date	21/02/2014
                     * @param	commandLine command line to execute
                     * @return	pipe file handle
                     */
                    virtual void * getFileHandle ( const std::string & commandPipe );

                private:

                    void * handle; ///< handle of pipe file
            };
        }
    }
}

#endif /* _PIPE_FILE_HXX */
