/**
 * @file SystemPipeProcess.hxx
 * @brief Class definition to process pipe console process.
 * @date 06/02/2014
 * @author Yadickson Soto
 */

#ifndef _SYSTEM_PIPE_PROCESS_HXX_
#define _SYSTEM_PIPE_PROCESS_HXX_

#include <System/IO/PipeFile.hxx>

namespace Smartmatic
{
    namespace System
    {
        namespace Runtime
        {
            /**
             * @class	SystemPipeProcess
             * @brief	Class definition to process pipe console process.
             * @author	Yadickson Soto
             * @date	06/02/2014
             */
            class SystemPipeProcess : public Smartmatic::System::IO::PipeFile
            {
                public:
                    /**
                     * @fn SystemPipeProcess();
                     * @brief	Class constructor
                     * @author	Yadickson Soto
                     * @date	06/02/2014
                     */
                    SystemPipeProcess ();

                    /**
                     * @fn virtual ~SystemPipeProcess();
                     * @brief	Destroy
                     * @author	Yadickson Soto
                     * @date	06/02/2014
                     */
                    virtual ~SystemPipeProcess();

                protected:

                    /**
                     * @fn virtual void * getFileHandle( const std::string & commandPipe );
                     * @brief	Call from open method for get pipe file handle
                     * @author	Yadickson Soto
                     * @date	21/02/2014
                     * @param	commandLine command line to execute
                     * @return	pipe file handle
                     */
                    virtual void * getFileHandle ( const std::string & commandPipe );
            };
        }
    }
}

#endif /* _SYSTEM_PIPE_PROCESS_HXX_ */
