/**
 * @file SafeDispatcher.cxx
 * @brief Body class SafeDispatcher
 * @date 22/07/2015
 * @author Yadickson Soto
 */

#include "SafeDispatcher.hxx"
#include <unistd.h>

using namespace Smartmatic::System;

SafeDispatcher::SafeDispatcher()
{
    popPrivDispatcher.connect ( sigc::mem_fun ( *this, &SafeDispatcher::handleDispatch ) );
}

SafeDispatcher::~SafeDispatcher()
{

}

void SafeDispatcher::emit ( void * object )
{
    Glib::Mutex::Lock lock ( syncProcessing_mutex );

    currentList.push_back ( object );
    popPrivDispatcher();
}

void SafeDispatcher::handleDispatch()
{
    Glib::Mutex::Lock lock ( syncProcessing_mutex );

    while ( !currentList.empty() )
    {
        void * currentObject = currentList.front();
        currentList.pop_front();
        popDispatcher.emit ( currentObject );
    }
}

SafeDispatcher::SyncSignal SafeDispatcher::getSyncSignal()
{
    return popDispatcher;
}

unsigned int SafeDispatcher::getQueueSize()
{
    Glib::Mutex::Lock lock ( syncProcessing_mutex );

    return currentList.size();
}
