/**
 * @file ComposeKey.cxx
 * @brief Body class utility for compose key
 * @date 06/02/2013
 * @author Yadickson Soto
 */

#include "ComposeKey.hxx"
#include <System/Security/Cryptography/MsgDigestUtil.h>

using namespace Smartmatic::System::Security;
using namespace Smartmatic::System::Security::Cryptography;

ComposeKey::ComposeKey ( )
{

}

ComposeKey::ComposeKey ( const Smartmatic::System::SafeBuffer & key )
{
    setKey ( key );
}

ComposeKey::~ComposeKey()
{

}
void ComposeKey::setKey ( const unsigned char key [], unsigned int length )
{
    this->key.Clear();
    this->key.AddData ( key, length );
}

void ComposeKey::setKey ( const Smartmatic::System::SafeBuffer & key )
{
    this->key.Clear();
    this->key.AddData ( key );
}

void ComposeKey::getCompose ( unsigned int length, Smartmatic::System::SafeBuffer & result )
{
    result.Clear();

    if ( key.GetData() != NULL )
    {
        unsigned int size = key.GetSize();
        unsigned char * info = new unsigned char[size];
        const unsigned char * array = key.GetData();

        for ( unsigned int i = 0; i < size; i++ )
        {
            bool high = ( array[i] % 2 ) == 0;
            info[i] = ( unsigned char ) ( high ? ( array[i] & 0xF0 ) : ( array[i] & 0x0F ) );
        }

        Smartmatic::System::SafeBuffer infoBuffer ( info, size );
        Smartmatic::System::SafeBuffer hash;
        delete []info;

        MsgDigestUtil digest ( infoBuffer );
        digest.getDigest ( hash, MsgDigestUtil::getDefaultComposeKeyDigest() );

        if ( hash.GetSize() < length )
        {
            unsigned int pasted = 0;

            while ( pasted < length )
            {
                int lengthToCopy = ( hash.GetSize() < ( length - pasted ) ? hash.GetSize() : ( length - pasted ) );
                result.AddData ( hash.GetData(), lengthToCopy );
                pasted += lengthToCopy;
            }
        }
        else
        {
            result.AddData ( hash.GetData(), length );
        }
    }
}
