/**
 * @file CertificateExtensionDER.h
 * @brief Header class certificate DER extension.
 * @date 18/12/2013
 * @author Beatriz Avila
 */

#ifndef CERTIFICATEEXTENSIONDER_HXX_
#define CERTIFICATEEXTENSIONDER_HXX_

#include <System/Security/Cryptography/CertificateExtensionBase.hxx>

namespace Smartmatic
{
    namespace System
    {
        namespace Security
        {
            namespace Cryptography
            {
                /**
                 * @class	CertificateExtensionDER
                 * @brief	Class for CertificateExtensionDER.
                 * @author	Beatriz Avila
                 * @date	18/12/2013
                 */
                class CertificateExtensionDER : public CertificateExtensionBase
                {
                    public:

                        /**
                         * @fn	CertificateExtensionDER::CertificateExtensionDER( const Smartmatic::System::SafeBuffer & certificateBuffer );
                         * @brief	Class constructor.
                         * @author	Beatriz Avila
                         * @date	18/12/2013
                         * @param	certificateBuffer	SafeBuffer with certificate.
                         */
                        explicit CertificateExtensionDER ( const Smartmatic::System::SafeBuffer & certificateBuffer );

                        /**
                         * @fn	virtual CertificateExtensionDER::~CertificateExtensionDER();
                         * @brief	Class destructor.
                         * @author	Beatriz Avila
                         * @date	18/12/2013
                         */
                        virtual ~CertificateExtensionDER ( );

                    public:

                        /**
                         * @fn     CertificateExtensionDER* clone() const;
                         * @brief  Duplicates the instance of the CertificateExtensionDER class.
                         * @return The new instance.
                         * @author manuel.arguelles
                         * @date   08/08/2022
                         */
                        CertificateExtensionDER* clone() const;

                    protected:
                        /**
                         * @fn virtual	X509 * CertificateExtensionDER::LoadCertifiedX509FromBIO();
                         * @brief	Method load certified file from BIO.
                         * @author	Beatriz Avila
                         * @date	18/12/2013
                         * @return	certificate.
                         */
                        virtual X509 * LoadCertifiedX509FromBIO ( );

                        /**
                         * @fn virtual	EVP_PKEY * CertificateExtensionDER::LoadCertifiedPrivateKeyFromBIO();
                         * @brief	Method load private key from BIO.
                         * @author	Beatriz Avila
                         * @date	18/12/2013
                         * @return	private key.
                         */
                        virtual EVP_PKEY * LoadCertifiedPrivateKeyFromBIO ( );

                        /**
                         * @fn virtual	stack_st_X509 * CertificateExtensionDER::getCertificateAuthoritiesFromBIO();
                         * @brief	Method get certificate authorities from BIO
                         * @author	Beatriz Avila
                         * @date	18/12/2013
                         * @return	certificate authorities.
                         */
                        virtual stack_st_X509 * getCertificateAuthoritiesFromBIO ( );

                    private:
                        static Smartmatic::Log::ISMTTLog * logger; ///<logger
                };
            }
        }
    }
}

#endif /* CERTIFICATEEXTENSIONDER_HXX_ */
