/**
 * @file CertificateExtensionPKCS12.h
 * @brief Header class certificate PKCS12 extension.
 * @date 18/12/2013
 * @author Beatriz Avila
 */

#ifndef CERTIFICATEEXTENSIONPKCS12_HXX_
#define CERTIFICATEEXTENSIONPKCS12_HXX_

#include <System/Security/Cryptography/CertificateExtensionBase.hxx>

namespace Smartmatic
{
    namespace System
    {
        namespace Security
        {
            namespace Cryptography
            {
                /**
                 * @class	CertificateExtensionPKCS12
                 * @brief	Class for CertificateExtensionPKCS12.
                 * @author	Beatriz Avila
                 * @date	18/12/2013
                 */
                class CertificateExtensionPKCS12 : public CertificateExtensionBase
                {
                    public:

                        /**
                         * @fn	CertificateExtensionPKCS12::CertificateExtensionPKCS12( const Smartmatic::System::SafeBuffer & certificateBuffer,
                         * 		std::string certPassword = "");
                         * @brief	Class constructor.
                         * @author	Beatriz Avila
                         * @date	18/12/2013
                         * @param	certificateBuffer	SafeBuffer with certificate.
                         * @param	certPassword		password.
                         */
                        CertificateExtensionPKCS12 ( const Smartmatic::System::SafeBuffer & certificateBuffer, std::string certPassword = "" );

                        /**
                         * @fn	virtual CertificateExtensionPKCS12::~CertificateExtensionPKCS12();
                         * @brief	Class destructor.
                         * @author	Beatriz Avila
                         * @date	18/12/2013
                         */
                        virtual ~CertificateExtensionPKCS12 ( );

                    public:

                        /**
                         * @fn     CertificateExtensionPKCS12* clone() const;
                         * @brief  Duplicates the instance of the CertificateExtensionPKCS12 class.
                         * @return The new instance.
                         * @author manuel.arguelles
                         * @date   08/08/2022
                         */
                        CertificateExtensionPKCS12* clone() const;

                    protected:
                        /**
                         * @fn virtual	X509 * CertificateExtensionPKCS12::LoadCertifiedX509FromBIO();
                         * @brief	Method load certified file from BIO.
                         * @author	Beatriz Avila
                         * @date	18/12/2013
                         * @return	certificate.
                         */
                        virtual X509 * LoadCertifiedX509FromBIO ( );

                        /**
                         * @fn virtual	EVP_PKEY * CertificateExtensionPKCS12::LoadCertifiedPrivateKeyFromBIO();
                         * @brief	Method load private key from BIO.
                         * @author	Beatriz Avila
                         * @date	18/12/2013
                         * @return	private key.
                         */
                        virtual EVP_PKEY * LoadCertifiedPrivateKeyFromBIO ( );

                        /**
                         * @fn virtual	stack_st_X509 * CertificateExtensionPKCS12::getCertificateAuthoritiesFromBIO();
                         * @brief	Method get certificate authorities from BIO
                         * @author	Beatriz Avila
                         * @date	18/12/2013
                         * @return	certificate authorities.
                         */
                        virtual stack_st_X509 * getCertificateAuthoritiesFromBIO ( );

                    private:

                        static Smartmatic::Log::ISMTTLog * logger; ///<logger

                        /**
                         *@fn void loadP12 ()
                         *@brief Method load PKCS12
                         *@date 07/01/2014
                         *@author Beatriz Avila
                         */
                        void LoadP12 ();
                };
            }
        }
    }
}

#endif /* CERTIFICATEEXTENSIONPKCS12_HXX_ */
