/**
 * @file PKCS7Signer.cxx
 * @brief Body class PKCS7Signer
 * @date 02/03/2012
 * @author Yadickson Soto <yadickson.soto@smartmatic.com>
 */

#include "PKCS7Signer.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <openssl/evp.h>
#include <openssl/x509.h>
#include <openssl/safestack.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///< macro for gettext
#else
#define _(String) (String) ///< macro without gettext
#endif

#define N_(String) (String) ///< macro not translate

using namespace Smartmatic::System::Security::Cryptography;
using namespace Smartmatic::System::Exception;
using namespace Smartmatic::Log;
using namespace Smartmatic::System;

ISMTTLog * PKCS7Signer::logger = SMTTLogManager::GetLogger ( "Smartmatic.System.Security.Cryptography.PKCS7Signer", GETTEXT_PACKAGE );

PKCS7Signer::PKCS7Signer ()
    : PKCS7Base ( PKCS7_BINARY )
{

}

PKCS7Signer::~PKCS7Signer()
{

}

void PKCS7Signer::signBuffer ( const SafeBuffer & bufferIn, SafeBuffer & bufferOut, PKCS7Signer::PKCS7BaseType type ) throw ( SignedException )
{
    if ( ! processBuffer ( bufferIn, bufferOut, type ) )
    {
        throw SignedException (
            _ ( "Smartmatic.System.Security.Cryptography.PKCS7Signer.ErrorSignedData" ),
            N_ ( "Smartmatic.System.Security.Cryptography.PKCS7Signer.ErrorSignedData" ), logger );
    }
}

void PKCS7Signer::verifyBuffer ( const SafeBuffer & bufferIn, Smartmatic::System::SafeBuffer & signedBuffer, PKCS7Signer::PKCS7BaseType type ) throw ( SignedException )
{
    if ( ! reprocessBuffer ( bufferIn, signedBuffer, type ) )
    {
        throw SignedException ( _ ( "Smartmatic.System.Security.Cryptography.PKCS7Signer.ErrorValidateData" ),
                                N_ ( "Smartmatic.System.Security.Cryptography.PKCS7Signer.ErrorValidateData" ), logger );
    }
}

void * PKCS7Signer::PKCS7Process()
{
    void * p7 = ( void * ) PKCS7_sign ( certificate->LoadCertifiedX509(),
                                        certificate->LoadCertifiedPrivateKey(),
                                        certificate->getCertificateAuthorities(),
                                        memoryBIO,
                                        flags );

    return p7;
}

int PKCS7Signer::PKCS7Process ( void * p7, BIO * result )
{
    X509 * cert = certificate->LoadCertifiedX509();

    if ( cert == NULL )
    {
        return -1;
    }

    return PKCS7_verify ( ( PKCS7 * ) p7, certificate->getCertificateAuthorities(), NULL, memoryBIO, result, flags | PKCS7_NOVERIFY | PKCS7_NOCHAIN | PKCS7_NOSIGS );
}

