/**
 * @file	beep-descriptor.h
 * @brief	Declares the beep descriptor class.
 */

#ifndef _BEEP_DESCRIPTOR2_H_
#define _BEEP_DESCRIPTOR2_H_

#include <string>

namespace Smartmatic
{
    namespace System
    {
        namespace Sounds
        {
            /**
             * @class	BeepDescriptor
             * @brief	Beep descriptor class.
             * @author	Rafael.gasperi
             * @date	28/04/2011
             */
            class BeepDescriptor
            {
                public:

                    /**
                     * @fn	BeepDescriptor::BeepDescriptor();
                     * @brief	Default constructor.
                     * @author	Rafael.gasperi
                     * @date	28/04/2011
                     */
                    BeepDescriptor();

                    /**
                     * @fn	BeepDescriptor::BeepDescriptor(int frequency, int time, int repetitions,
                     * 			int timeBetweenRepetitions);
                     * @brief	Constructor.
                     * @author	Rafael.gasperi
                     * @date	28/04/2011
                     * @param	frequency								The frequency of beep sound.
                     * @param	time										The time of beep sound.
                     * @param	repetitions							The repetitions.
                     * @param	timeBetweenRepetitions	The time between beep sound repetitions.
                     */
                    BeepDescriptor ( int frequency, int time, int repetitions, int timeBetweenRepetitions );

                    /**
                     * @fn	std::string BeepDescriptor::GetBeepLine();
                     * @brief	Gets the beep line.
                     * @author	Rafael.gasperi
                     * @date	28/04/2011
                     * @return	The beep line.
                     */
                    std::string GetBeepLine();

                private:

                    int frequency; ///< The frequency

                    int time; ///< The time

                    int repetitions; ///< The repetitions

                    int timeBetweenRepetitions;	///< The time between repetitions
            };
        }
    }
}


#endif // _BEEP_DESCRIPTOR2_H_
