/**
 * @file	smartmatic-sounds-manager.cc
 *
 * @brief	Body file to the  sounds manager class.
 */

#include "System/Sounds/smartmatic-sounds-manager.h"
#include <Configuration/SmartmaticSoundConfManager.hxx>
#include <Environment/Configurations/resource-path-provider.h>
#include "System/Runtime/ProcessLauncher.h"
#include <System/Runtime/ProcessMonitor.h>
#include "System/IO/File.h"
#include "System/IO/Path.h"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <System/Utils/StringUtils.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

using namespace Smartmatic::System::Sounds;
using namespace Smartmatic::Configuration;
using namespace Smartmatic::System::IO;
using namespace Smartmatic::System::Sounds;
using namespace Smartmatic::Environment;
using namespace Smartmatic::System::Runtime;
using namespace Smartmatic::System::Utils;
using namespace Smartmatic::Log;

SMTTSoundsManager * SMTTSoundsManager::singleton_instance = NULL;
ISMTTLog * SMTTSoundsManager::logger = SMTTLogManager::GetLogger ( "Smartmatic.System.Sounds.SMTTSoundsManager", GETTEXT_PACKAGE );

SMTTSoundsManager * SMTTSoundsManager::getInstance (SMTTSoundsManager * externManager)
{
    if ( ! singleton_instance )
    {
    	singleton_instance = ( externManager == NULL ? new SMTTSoundsManager() : externManager );
    }

    return singleton_instance;
}

SMTTSoundsManager::SMTTSoundsManager()
{

}

SMTTSoundsManager::~SMTTSoundsManager()
{
    singleton_instance = NULL;
}

void SMTTSoundsManager::Sound ( const std::string & sound )
{
    logger->Debug ( "Used configuration sound (" + sound + ")." );

    if ( !SmartmaticSoundConfManager::getInstance()->isUsingBeep() )
    {
        std::string soundFile = SmartmaticSoundConfManager::getInstance()->getSoundFile ( sound );
        std::string path = Path::Combine ( SOUNDDIR, soundFile );
        std::string file = ResourcePathProvider::getInstance()->GetResourcePath ( GETTEXT_PACKAGE, path );

        if ( File::getInstance()->canOpenFile ( file ) )
        {
            std::string command = SmartmaticSoundConfManager::getInstance()->getAppSound() + " " + file;
            ( void ) ProcessLauncher::getInstance()->RunProcessThroughSystem ( command, true );
        }
    }
    else
    {
        beepManager.Clear();
        std::vector<BeepDescriptor> beepDescriptors = SmartmaticSoundConfManager::getInstance()->getSoundConfiguration ( sound );

        for ( unsigned int i = 0; i < beepDescriptors.size(); i++ )
        {
            beepManager.AddBeep ( beepDescriptors[i] );
        }

        beepManager.Beep();
    }
}

void SMTTSoundsManager::Stop ()
{
    beepManager.Stop();
    std::string appsound = SmartmaticSoundConfManager::getInstance()->getAppSound();
    std::vector < std::string > vector;

    StringUtils::splitToVector ( appsound, " ", vector );

    if ( !vector.empty() && !StringUtils::trim ( vector[0] ).empty() )
    {
        ( void ) ProcessMonitor::KillProcess ( vector[0], false );
    }
}
