/**
 * @file ExtractCertificate.hxx
 * @brief Header class utils for extract certificate from xml buffer
 * @date 09/02/2013
 * @author Yadickson Soto
 */

#ifndef EXTRACTCERTIFICATE_HXX_
#define EXTRACTCERTIFICATE_HXX_

#include <System/SafeBuffer.h>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace System
    {
        namespace XML
        {
            /**
             * @class	ExtractCertificate
             * @brief	Class utils for extract certificate from xml buffer.
             * @author	Yadickson Soto
             * @date	09/02/2013
             */
            class ExtractCertificate
            {
                public:
                    /**
                     * @fn	ExtractCertificate ( const Smartmatic::System::SafeBuffer & buffer );
                     * @brief	Class constructor.
                     * @author	Yadickson Soto
                     * @date	09/02/2013
                     * @param buffer const buffer input to extract certificate
                     */
                    explicit ExtractCertificate ( const Smartmatic::System::SafeBuffer & buffer );

                    /**
                     * @fn	virtual ~ExtractCertificate();
                     * @brief	Class destructor.
                     * @author	Yadickson Soto
                     * @date	09/02/2013
                     */
                    virtual ~ExtractCertificate();

                    /**
                     * @fn	bool getBase64Certificate ( Smartmatic::System::SafeBuffer & certificate );
                     * @brief	Method getter certificate from input buffer.
                     * @author	Yadickson Soto
                     * @date	09/02/2013
                     * @param certificate buffer output result
                     * @return true if successfully getter certificate
                     */
                    bool getBase64Certificate ( Smartmatic::System::SafeBuffer & certificate );

                private:

                    const Smartmatic::System::SafeBuffer & buffer; ///< buffer data
                    static Smartmatic::Log::ISMTTLog * logger; ///<logger
            };
        }
    }
}

#endif /* EXTRACTCERTIFICATE_HXX_ */
