/**
 * @file FOPTransformer.cxx
 * @brief Body class FOPTransformer, xml to pdf runtime
 * @date 27/10/2011
 * @author Yadickson Soto
 */

#include "FOPTransformer.hxx"
#include <System/Runtime/ProcessLauncher.h>
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <System/IO/Directory.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::System::XSLFO;
using namespace Smartmatic::Log;
using namespace Smartmatic::System::IO;
using namespace Smartmatic::System::Runtime;

ISMTTLog * FOPTransformer::logger = SMTTLogManager::GetLogger ( "Smartmatic.System.XSLFO.FOPTransformer", GETTEXT_PACKAGE );
std::string FOPTransformer::configFile = "fop.xconf";

FOPTransformer::FOPTransformer()
{

}

FOPTransformer::~FOPTransformer()
{

}

void FOPTransformer::setConfigFile ( const std::string & configFile )
{
    FOPTransformer::configFile = configFile;
}

std::string FOPTransformer::getConfigFile ()
{
    return FOPTransformer::configFile;
}

bool FOPTransformer::transformFile ( std::string outputFile, std::string inputFile, std::string templateFile )
{
    return transformToFile ( outputFile, inputFile, templateFile, "pdf" );
}

bool FOPTransformer::transformToFile ( const std::string& outputFile, const std::string& inputFile, const std::string& templateFile, const std::string& outputFormat )
{
    logger->Debug ( "Execute transformation to " + outputFormat );

    std::string command;
    command.append ( "fop" );
    command.append ( " -xml " );
    command.append ( inputFile );
    command.append ( " -xsl " );
    command.append ( templateFile );
    command.append ( " -" + outputFormat + " " );
    command.append ( outputFile );

    if ( Directory::getInstance()->FileExists ( configFile ) )
    {
        command.append ( " -c " );
        command.append ( configFile );
    }

    return ProcessLauncher::getInstance()->RunProcessThroughSystem ( command ) == 0;
}
