/**
 * @file ZenityWrapper.hxx
 * @brief Header class zenity wrapper
 * @date 23/02/2012
 * @author Yadickson Soto
 */

#ifndef ZENITYWRAPPER_HXX_
#define ZENITYWRAPPER_HXX_

#include <string>

namespace Smartmatic
{
    namespace System
    {
        /**
         * @class	ZenityWrapper
         * @brief	Class zenity wrapper.
         * @author	Yadickson Soto
         * @date	23/02/2012
         */
        class ZenityWrapper
        {
            public:

                /**
                 * @fn	static void ZenityWrapper::showError( const std::string& message, const std::string& title );
                 * @brief	Method show error.
                 * @author	Yadickson Soto
                 * @date	23/02/2012
                 * @param	message	message info.
                 * @param	title	 	title window (optional)
                 */
                static void showError ( const std::string& message, const std::string& title );

                /**
                 * @fn	static void ZenityWrapper::showWarning(std::string message, std::string title,
                 * 			int timeout = 0);
                 * @brief	Method show warning.
                 * @author	Yadickson Soto
                 * @date	23/02/2012
                 * @param	message	message info.
                 * @param	title	 	title window (optional)
                 * @param	timeout	timeout in seconds (default infinite)
                 */
                static void showWarning ( std::string message, std::string title, int timeout = 0 );

                /**
                 * @fn	static void ZenityWrapper::showInfo(std::string message, std::string title,
                 * 			int timeout = 0);
                 * @brief	Method show info.
                 * @author	Yadickson Soto
                 * @date	23/02/2012
                 * @param	message	message info.
                 * @param	title	 	title window (optional)
                 * @param	timeout	timeout in seconds (default infinite)
                 */
                static void showInfo ( std::string message, std::string title, int timeout = 0 );
        };
    }
}

#endif /* ZENITYWRAPPER_HXX_ */
