#ifndef TEST_SOUND_CONF_MANAGER_TEST
#define TEST_SOUND_CONF_MANAGER_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Configuration/SmartmaticSoundConfManager.hxx>
#include <tests/MockSmttConfigurationManager.hxx>
#include <tests/MockConfigurationPersistenceManager.hxx>

class SmttSoundConfManagerTest : public CPPUNIT_NS::TestFixture
{
    public:

        typedef Smartmatic::Configuration::SmartmaticSoundConfManager SmartmaticSoundConfManager;
        typedef Smartmatic::Configuration::SmartmaticConfigurationManager SmartmaticConfigurationManager;
        typedef Smartmatic::Configuration::SoundOutput SoundOutput;
        typedef Smartmatic::Configuration::SoundConfigurations SoundConfigurations;
        typedef Smartmatic::Configuration::SoundDescriptorConfiguration SoundDescriptorConfiguration;
        typedef Smartmatic::System::Sounds::BeepDescriptor BeepDescriptor;
        typedef Smartmatic::Configuration::ConfigurationPersistenceManager ConfigurationPersistenceManager;

        SmttSoundConfManagerTest()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testGetSmartmaticSoundConfigurationPresent()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSmttConfigurationManager confManager;
            SmartmaticConfigurationManager::getInstance ( &confManager );

            CPPUNIT_ASSERT ( true == SmartmaticConfigurationManager::getInstance()->getConfiguration()->getSoundOutput().present() );

            persistenceManager.verify();
        }

        void testGetSmartmaticSoundConfigurationDefault()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSmttConfigurationManager confManager;
            SmartmaticConfigurationManager::getInstance ( &confManager );

            SmartmaticConfigurationManager::getInstance()->getConfiguration()->getSoundOutput().reset();

            CPPUNIT_ASSERT ( false == SmartmaticSoundConfManager::getInstance()->isUsingBeep() );
            CPPUNIT_ASSERT ( "app" == SmartmaticSoundConfManager::getInstance()->getAppSound() );
            CPPUNIT_ASSERT ( true == SmartmaticSoundConfManager::getInstance()->getSoundFile ( "" ).empty() );
            CPPUNIT_ASSERT ( true == SmartmaticSoundConfManager::getInstance()->getSoundConfiguration ( "" ).empty() );

            persistenceManager.verify();
        }

        void testGetSoundFile_SoundOutputConfigEmpty()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSmttConfigurationManager confManager;
            SmartmaticConfigurationManager::getInstance ( &confManager );

            SoundOutput & sound ( SmartmaticConfigurationManager::getInstance()->getConfiguration()->getSoundOutput().get() );
            sound.getSoundConfigurations().clear();

            std::string result;
            result = SmartmaticSoundConfManager::getInstance()->getSoundFile ( "any" );

            CPPUNIT_ASSERT ( true == result.empty() );

            persistenceManager.verify();
        }

        void testGetAppSound_IfEmpty()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSmttConfigurationManager confManager;
            SmartmaticConfigurationManager::getInstance ( &confManager );

            SoundOutput & sound ( SmartmaticConfigurationManager::getInstance()->getConfiguration()->getSoundOutput().get() );
            sound.setAppSound ( "" );

            std::string result;
            result = SmartmaticSoundConfManager::getInstance()->getAppSound();

            CPPUNIT_ASSERT ( true == result.empty() );

            persistenceManager.verify();
        }

        void testGetAppSound()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSmttConfigurationManager confManager;
            SmartmaticConfigurationManager::getInstance ( &confManager );

            SoundOutput & sound ( SmartmaticConfigurationManager::getInstance()->getConfiguration()->getSoundOutput().get() );
            sound.setAppSound ( "aplay" );

            std::string result;
            result = SmartmaticSoundConfManager::getInstance()->getAppSound();

            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( "aplay" == result );

            persistenceManager.verify();
        }

        void testGetUsingBeepTrue()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSmttConfigurationManager confManager;
            SmartmaticConfigurationManager::getInstance ( &confManager );

            SoundOutput & sound ( SmartmaticConfigurationManager::getInstance()->getConfiguration()->getSoundOutput().get() );
            sound.getSoundConfigurations().clear();
            sound.setUseBeep ( true );

            CPPUNIT_ASSERT ( true == SmartmaticSoundConfManager::getInstance()->isUsingBeep() );

            persistenceManager.verify();
        }

        void testGetUsingBeepFalse()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSmttConfigurationManager confManager;
            SmartmaticConfigurationManager::getInstance ( &confManager );

            SoundOutput & sound ( SmartmaticConfigurationManager::getInstance()->getConfiguration()->getSoundOutput().get() );
            sound.getSoundConfigurations().clear();
            sound.setUseBeep ( false );

            CPPUNIT_ASSERT ( false == SmartmaticSoundConfManager::getInstance()->isUsingBeep() );

            persistenceManager.verify();
        }

        void testGetSoundFile_SoundOutputConfigExist_SoundFileNotFound()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSmttConfigurationManager confManager;
            SmartmaticConfigurationManager::getInstance ( &confManager );

            SoundOutput & sound ( SmartmaticConfigurationManager::getInstance()->getConfiguration()->getSoundOutput().get() );
            sound.getSoundConfigurations().clear();

            SoundConfigurations confSeq ( "ConfigName" );

            sound.getSoundConfigurations().push_back ( confSeq );

            std::string result;
            result = SmartmaticSoundConfManager::getInstance()->getSoundFile ( "ConfigName" );

            CPPUNIT_ASSERT ( true == result.empty() );

            persistenceManager.verify();
        }

        void testGetSoundFile_SoundOutputConfigExist_SoundFileFound()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSmttConfigurationManager confManager;
            SmartmaticConfigurationManager::getInstance ( &confManager );

            SoundOutput & sound ( SmartmaticConfigurationManager::getInstance()->getConfiguration()->getSoundOutput().get() );
            sound.getSoundConfigurations().clear();

            SoundConfigurations confSeq ( "ConfigName" );
            confSeq.setSoundFile ( "file.wav" );

            sound.getSoundConfigurations().push_back ( confSeq );

            std::string result;
            result = SmartmaticSoundConfManager::getInstance()->getSoundFile ( "ConfigName" );

            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( "file.wav" == result );

            persistenceManager.verify();
        }

        void testGetSoundFile_SoundOutputConfigExist_SoundNameNotFound()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSmttConfigurationManager confManager;
            SmartmaticConfigurationManager::getInstance ( &confManager );

            SoundOutput & sound ( SmartmaticConfigurationManager::getInstance()->getConfiguration()->getSoundOutput().get() );
            sound.getSoundConfigurations().clear();

            SoundConfigurations confSeq ( "ConfigName" );
            confSeq.setSoundFile ( "file.wav" );

            sound.getSoundConfigurations().push_back ( confSeq );

            std::string result;
            result = SmartmaticSoundConfManager::getInstance()->getSoundFile ( "OtherName" );

            CPPUNIT_ASSERT ( true == result.empty() );

            persistenceManager.verify();
        }

        void testGetSoundConfiguration_SoundOutputConfigNotExist()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSmttConfigurationManager confManager;
            SmartmaticConfigurationManager::getInstance ( &confManager );

            SoundOutput & sound ( SmartmaticConfigurationManager::getInstance()->getConfiguration()->getSoundOutput().get() );
            sound.getSoundConfigurations().clear();

            std::vector<BeepDescriptor> result = SmartmaticSoundConfManager::getInstance()->getSoundConfiguration ( "ConfigName" );

            CPPUNIT_ASSERT ( true == result.empty() );

            persistenceManager.verify();
        }

        void testGetSoundConfiguration_SoundOutputConfigExist()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSmttConfigurationManager confManager;
            SmartmaticConfigurationManager::getInstance ( &confManager );

            SoundOutput & sound ( SmartmaticConfigurationManager::getInstance()->getConfiguration()->getSoundOutput().get() );
            sound.getSoundConfigurations().clear();


            SoundConfigurations confSeq ( "ConfigName" );
            confSeq.setSoundFile ( "file.wav" );

            SoundConfigurations::SoundConfigurationSequence soundSeq;
            soundSeq.push_back ( SoundDescriptorConfiguration ( 10, 20, 30, 40 ) );

            confSeq.setSoundConfiguration ( soundSeq );
            sound.getSoundConfigurations().push_back ( confSeq );

            std::vector<BeepDescriptor> result = SmartmaticSoundConfManager::getInstance()->getSoundConfiguration ( "ConfigName" );

            CPPUNIT_ASSERT ( 1 == result.size() );
            CPPUNIT_ASSERT ( " -f 10 -l 20 -r 30 -d 40" == ( * ( result.begin() ) ).GetBeepLine() );

            persistenceManager.verify();
        }

        void testGetSoundConfiguration_SoundOutputConfigExist_OtherSoundName()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSmttConfigurationManager confManager;
            SmartmaticConfigurationManager::getInstance ( &confManager );

            SoundOutput & sound ( SmartmaticConfigurationManager::getInstance()->getConfiguration()->getSoundOutput().get() );
            sound.getSoundConfigurations().clear();


            SoundConfigurations confSeq ( "ConfigName" );
            confSeq.setSoundFile ( "file.wav" );

            SoundConfigurations::SoundConfigurationSequence soundSeq;
            soundSeq.push_back ( SoundDescriptorConfiguration ( 10, 20, 30, 40 ) );

            confSeq.setSoundConfiguration ( soundSeq );
            sound.getSoundConfigurations().push_back ( confSeq );

            std::vector<BeepDescriptor> result = SmartmaticSoundConfManager::getInstance()->getSoundConfiguration ( "OtherName" );

            CPPUNIT_ASSERT ( true == result.empty() );

            persistenceManager.verify();
        }

        void testGetSoundConfiguration_TwoBeep_SoundOutputConfigExist()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSmttConfigurationManager confManager;
            SmartmaticConfigurationManager::getInstance ( &confManager );

            SoundOutput & sound ( SmartmaticConfigurationManager::getInstance()->getConfiguration()->getSoundOutput().get() );
            sound.getSoundConfigurations().clear();


            SoundConfigurations confSeq ( "ConfigName" );
            confSeq.setSoundFile ( "file.wav" );

            SoundConfigurations::SoundConfigurationSequence soundSeq;
            soundSeq.push_back ( SoundDescriptorConfiguration ( 10, 20, 30, 40 ) );
            soundSeq.push_back ( SoundDescriptorConfiguration ( 1, 2, 3, 4 ) );

            confSeq.setSoundConfiguration ( soundSeq );
            sound.getSoundConfigurations().push_back ( confSeq );

            std::vector<BeepDescriptor> result = SmartmaticSoundConfManager::getInstance()->getSoundConfiguration ( "ConfigName" );

            CPPUNIT_ASSERT ( 2 == result.size() );

            std::vector<BeepDescriptor>::iterator it = result.begin();

            CPPUNIT_ASSERT ( " -f 10 -l 20 -r 30 -d 40" == ( *it ).GetBeepLine() );

            ++it;

            CPPUNIT_ASSERT ( " -f 1 -l 2 -r 3 -d 4" == ( *it ).GetBeepLine() );

            persistenceManager.verify();
        }

        CPPUNIT_TEST_SUITE ( SmttSoundConfManagerTest );

        CPPUNIT_TEST ( testGetSmartmaticSoundConfigurationPresent );
        CPPUNIT_TEST ( testGetSmartmaticSoundConfigurationDefault );

        CPPUNIT_TEST ( testGetSoundFile_SoundOutputConfigEmpty );
        CPPUNIT_TEST ( testGetAppSound_IfEmpty );
        CPPUNIT_TEST ( testGetAppSound );
        CPPUNIT_TEST ( testGetUsingBeepTrue );
        CPPUNIT_TEST ( testGetUsingBeepFalse );
        CPPUNIT_TEST ( testGetSoundFile_SoundOutputConfigExist_SoundFileNotFound );
        CPPUNIT_TEST ( testGetSoundFile_SoundOutputConfigExist_SoundFileFound );
        CPPUNIT_TEST ( testGetSoundFile_SoundOutputConfigExist_SoundNameNotFound );
        CPPUNIT_TEST ( testGetSoundConfiguration_SoundOutputConfigNotExist );
        CPPUNIT_TEST ( testGetSoundConfiguration_SoundOutputConfigExist );
        CPPUNIT_TEST ( testGetSoundConfiguration_SoundOutputConfigExist_OtherSoundName );
        CPPUNIT_TEST ( testGetSoundConfiguration_TwoBeep_SoundOutputConfigExist );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_SOUND_CONF_MANAGER_TEST */
