#ifndef TEST_LANGUAGE_CONTROLLER_TEST
#define TEST_LANGUAGE_CONTROLLER_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <System/Runtime/ProcessLauncher.h>
#include <tests/MockProcessLauncher.hxx>
#include <tests/StoreMockProcessLauncher.hxx>
#include "MockBasicLanguageController.hxx"
#include "MockExitProcess.hxx"
#include "StoreMockProcessLauncher.hxx"

class LanguageControllerTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::System::Runtime::ProcessLauncher ProcessLauncher;
        typedef Smartmatic::Environment::LanguageController LanguageController;
        typedef Smartmatic::System::Runtime::ExitProcess ExitProcess;

    public:

        LanguageControllerTest ()
        {

        }

        void setUp()
        {
        }

        void tearDown()
        {

        }

        void testEmptyLanguage()
        {
            MockBasicLanguageController controller;
            LanguageController::getInstance ( &controller );

            MOCKPP_CHAINER_FOR ( MockBasicLanguageController, getLangSystem ) getLangSystem_mock ( &controller );
            MOCKPP_CHAINER_FOR_EXT ( MockBasicLanguageController, setLangSystem, ext ) setLangSystem_mock ( &controller );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            MockExitProcess exitProcess;
            ExitProcess::getInstance ( &exitProcess );

            MOCKPP_CHAINER_FOR ( MockExitProcess, exitProcess ) exitProcess_mock ( &exitProcess );

            getLangSystem_mock
            .expects ( MOCKPP_NS::never() );

            setLangSystem_mock
            .expects ( MOCKPP_NS::never() );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() );

            exitProcess_mock
            .expects ( MOCKPP_NS::never() );

            LanguageController::getInstance()->setLanguage ( "", "" );

            CPPUNIT_ASSERT ( false == LanguageController::getInstance()->isSetLang() );

            controller.verify();
            launcher.verify();
            exitProcess.verify();
        }

        void testLanguageNotFound()
        {
            MockBasicLanguageController controller;
            LanguageController::getInstance ( &controller );

            MOCKPP_CHAINER_FOR ( MockBasicLanguageController, getLangSystem ) getLangSystem_mock ( &controller );
            MOCKPP_CHAINER_FOR_EXT ( MockBasicLanguageController, setLangSystem, ext ) setLangSystem_mock ( &controller );

            StoreMockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MockExitProcess exitProcess;
            ExitProcess::getInstance ( &exitProcess );

            MOCKPP_CHAINER_FOR ( MockExitProcess, exitProcess ) exitProcess_mock ( &exitProcess );

            getLangSystem_mock
            .expects ( MOCKPP_NS::never() );

            setLangSystem_mock
            .expects ( MOCKPP_NS::never() );

            exitProcess_mock
            .expects ( MOCKPP_NS::once() );

            LanguageController::getInstance()->setLanguage ( "xx", "yy" );

            CPPUNIT_ASSERT ( false == LanguageController::getInstance()->isSetLang() );

            controller.verify();
            exitProcess.verify();
        }

        void testLoadLanguageNotUtf8()
        {
            MockBasicLanguageController controller;
            LanguageController::getInstance ( &controller );

            MOCKPP_CHAINER_FOR ( MockBasicLanguageController, getLangSystem ) getLangSystem_mock ( &controller );
            MOCKPP_CHAINER_FOR_EXT ( MockBasicLanguageController, setLangSystem, ext ) setLangSystem_mock ( &controller );

            StoreMockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            launcher.listReturn.push_back ( "fr_BE" );
            launcher.listReturn.push_back ( "fr_FR" );

            MockExitProcess exitProcess;
            ExitProcess::getInstance ( &exitProcess );

            MOCKPP_CHAINER_FOR ( MockExitProcess, exitProcess ) exitProcess_mock ( &exitProcess );

            getLangSystem_mock
            .expects ( MOCKPP_NS::once() );

            setLangSystem_mock
            .expects ( MOCKPP_NS::once() );

            exitProcess_mock
            .expects ( MOCKPP_NS::never() );

            LanguageController::getInstance()->setLanguage ( "fr", "fr" );

            std::string langExpected = "fr";
            std::string countryExpected = "FR";
            std::string fullExpected = "fr_FR";
            std::string commandExpected = "locale -a";

            CPPUNIT_ASSERT ( commandExpected == launcher.commandLineWithArgumentsCommandLine );
            CPPUNIT_ASSERT ( true == LanguageController::getInstance()->isSetLang() );
            CPPUNIT_ASSERT ( langExpected == LanguageController::getInstance()->getCurrentLanguage() );
            CPPUNIT_ASSERT ( countryExpected == LanguageController::getInstance()->getCurrentCountry() );
            CPPUNIT_ASSERT ( fullExpected == LanguageController::getInstance()->getCurrentFullLanguage() );

            controller.verify();
            exitProcess.verify();
        }

        void testLoadLanguageUtf8()
        {
            MockBasicLanguageController controller;
            LanguageController::getInstance ( &controller );

            MOCKPP_CHAINER_FOR ( MockBasicLanguageController, getLangSystem ) getLangSystem_mock ( &controller );
            MOCKPP_CHAINER_FOR_EXT ( MockBasicLanguageController, setLangSystem, ext ) setLangSystem_mock ( &controller );

            StoreMockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            launcher.listReturn.push_back ( "fr_BE.utf8" );
            launcher.listReturn.push_back ( "fr_FR.utf8" );

            MockExitProcess exitProcess;
            ExitProcess::getInstance ( &exitProcess );

            MOCKPP_CHAINER_FOR ( MockExitProcess, exitProcess ) exitProcess_mock ( &exitProcess );

            getLangSystem_mock
            .expects ( MOCKPP_NS::once() );

            setLangSystem_mock
            .expects ( MOCKPP_NS::once() );

            exitProcess_mock
            .expects ( MOCKPP_NS::never() );

            LanguageController::getInstance()->setLanguage ( "fr", "fr" );

            std::string langExpected = "fr";
            std::string countryExpected = "FR";
            std::string fullExpected = "fr_FR";

            CPPUNIT_ASSERT ( true == LanguageController::getInstance()->isSetLang() );
            CPPUNIT_ASSERT ( langExpected == LanguageController::getInstance()->getCurrentLanguage() );
            CPPUNIT_ASSERT ( countryExpected == LanguageController::getInstance()->getCurrentCountry() );
            CPPUNIT_ASSERT ( fullExpected == LanguageController::getInstance()->getCurrentFullLanguage() );

            controller.verify();
            exitProcess.verify();
        }

        void testReloadLanguage()
        {
            MockBasicLanguageController controller;
            LanguageController::getInstance ( &controller );

            MOCKPP_CHAINER_FOR ( MockBasicLanguageController, getLangSystem ) getLangSystem_mock ( &controller );
            MOCKPP_CHAINER_FOR_EXT ( MockBasicLanguageController, setLangSystem, ext ) setLangSystem_mock ( &controller );

            StoreMockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            launcher.listReturn.push_back ( "fr_BE.utf8" );
            launcher.listReturn.push_back ( "fr_FR.utf8" );

            getLangSystem_mock
            .expects ( MOCKPP_NS::exactly ( 2 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        new MOCKPP_NS::ReturnStub<std::string> ( "" ),
                        new MOCKPP_NS::ReturnStub<std::string> ( "fr_FR.utf8" ) ) );

            setLangSystem_mock
            .expects ( MOCKPP_NS::once() );

            LanguageController::getInstance()->setLanguage ( "fr", "fr" );
            LanguageController::getInstance()->setLanguage ( "fr", "fr" );

            std::string langExpected = "fr";
            std::string countryExpected = "FR";
            std::string fullExpected = "fr_FR";

            CPPUNIT_ASSERT ( true == LanguageController::getInstance()->isSetLang() );
            CPPUNIT_ASSERT ( langExpected == LanguageController::getInstance()->getCurrentLanguage() );
            CPPUNIT_ASSERT ( countryExpected == LanguageController::getInstance()->getCurrentCountry() );
            CPPUNIT_ASSERT ( fullExpected == LanguageController::getInstance()->getCurrentFullLanguage() );

            controller.verify();
        }

        void testSetTwoLanguage()
        {
            MockBasicLanguageController controller;
            LanguageController::getInstance ( &controller );

            MOCKPP_CHAINER_FOR ( MockBasicLanguageController, getLangSystem ) getLangSystem_mock ( &controller );
            MOCKPP_CHAINER_FOR_EXT ( MockBasicLanguageController, setLangSystem, ext ) setLangSystem_mock ( &controller );

            StoreMockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            launcher.listReturn.push_back ( "fr_BE.utf8" );
            launcher.listReturn.push_back ( "fr_FR.utf8" );

            getLangSystem_mock
            .expects ( MOCKPP_NS::exactly ( 3 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        new MOCKPP_NS::ReturnStub<std::string> ( "" ),
                        new MOCKPP_NS::ReturnStub<std::string> ( "fr_BE.utf8" ),
                        new MOCKPP_NS::ReturnStub<std::string> ( "fr_FR.utf8" ) ) );

            setLangSystem_mock
            .expects ( MOCKPP_NS::exactly ( 2 ) );

            LanguageController::getInstance()->setLanguage ( "fr", "be" );
            LanguageController::getInstance()->setLanguage ( "fr", "fr" );
            LanguageController::getInstance()->setLanguage ( "fr", "fr" );

            std::string langExpected = "fr";
            std::string countryExpected = "FR";
            std::string fullExpected = "fr_FR";

            CPPUNIT_ASSERT ( true == LanguageController::getInstance()->isSetLang() );
            CPPUNIT_ASSERT ( langExpected == LanguageController::getInstance()->getCurrentLanguage() );
            CPPUNIT_ASSERT ( countryExpected == LanguageController::getInstance()->getCurrentCountry() );
            CPPUNIT_ASSERT ( fullExpected == LanguageController::getInstance()->getCurrentFullLanguage() );

            controller.verify();
        }

        CPPUNIT_TEST_SUITE ( LanguageControllerTest );

        CPPUNIT_TEST ( testEmptyLanguage );
        CPPUNIT_TEST ( testLanguageNotFound );
        CPPUNIT_TEST ( testLoadLanguageNotUtf8 );
        CPPUNIT_TEST ( testLoadLanguageUtf8 );
        CPPUNIT_TEST ( testReloadLanguage );
        CPPUNIT_TEST ( testSetTwoLanguage );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_LANGUAGE_CONTROLLER_TEST */
