/**
 * @file   StorageDeviceTest.hxx
 * @brief  Implementation of the unit tests for the StorageDevice.
 * @author manuel.arguelles
 * @date   Sep  6, 2017
 */

#ifndef STORAGE_DEVICE_TEST_HXX
#define STORAGE_DEVICE_TEST_HXX

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <System/Runtime/StorageDevice.hxx>

class StorageDeviceTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::System::Runtime::StorageDevice StorageDevice;

    public:

        StorageDeviceTest() {}

        void setUp() {}

        void tearDown() {}

        void testNotMounted()
        {
            const std::string INVALID_DEVICE = "/dev/sdg15";
            StorageDevice device(INVALID_DEVICE);

            CPPUNIT_ASSERT(device.getDevicePath() == INVALID_DEVICE);
            CPPUNIT_ASSERT(device.isMounted() == false);
        }

        void testSameDevices()
        {
            StorageDevice device1("/dev/sdd1");
            StorageDevice device2("/dev/sdd2");

            CPPUNIT_ASSERT(device1.isSameDevice(device2) == true);
        }

        void testDifferentDevices()
        {
            StorageDevice device1("/dev/sdd1");
            StorageDevice device2("/dev/sde2");

            CPPUNIT_ASSERT(device1.isSameDevice(device2) == false);
        }

        CPPUNIT_TEST_SUITE(StorageDeviceTest);

        CPPUNIT_TEST(testNotMounted);
        CPPUNIT_TEST(testSameDevices);
        CPPUNIT_TEST(testDifferentDevices);

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* STORAGE_DEVICE_TEST_HXX */
