/*
 * CRC32CalculatorTest.h
 *
 *  Created on: Nov 26, 2013
 *      Author: beatriz
 */

#ifndef TEST_CRC32CALCULATORTEST
#define TEST_CRC32CALCULATORTEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <System/Security/CRC32Calculator.hxx>
#include <System/Utils/StringUtils.hxx>

class CRC32CalculatorTest : public CPPUNIT_NS::TestFixture
{
    public:

        CRC32CalculatorTest()
        {

        }

        void setUp()
        {
        }

        void tearDown()
        {
        }

        void testCRC32NullSafeBuffer()
        {
            Smartmatic::System::SafeBuffer buffer;
            Smartmatic::System::SafeBuffer result;

            std::string expected = "00000000";
            std::string resultHex;

            Smartmatic::System::Security::CRC32Calculator::getCRC32 ( buffer, result );
            resultHex = Smartmatic::System::Utils::StringUtils::bufferHexToString ( result );

            CPPUNIT_ASSERT ( NULL != result.GetData() );
            CPPUNIT_ASSERT ( 4 == result.GetSize() );
            CPPUNIT_ASSERT ( expected == resultHex );
        }

        void testCRC32SafeBuffer()
        {
            Smartmatic::System::SafeBuffer buffer ( "abcdefghijklmnop" );
            Smartmatic::System::SafeBuffer result;

            std::string expected = "93c03a94";
            std::string resultHex;

            Smartmatic::System::Security::CRC32Calculator::getCRC32 ( buffer, result );
            resultHex = Smartmatic::System::Utils::StringUtils::bufferHexToString ( result );

            CPPUNIT_ASSERT ( NULL != result.GetData() );
            CPPUNIT_ASSERT ( 4 == result.GetSize() );
            CPPUNIT_ASSERT ( expected == resultHex );
        }

        void testCRC32SafeBuffer32Chars()
        {
            Smartmatic::System::SafeBuffer buffer ( "12345678901234567890123456789012" );
            Smartmatic::System::SafeBuffer result;

            std::string expected = "1e9c7cd0";
            std::string resultHex;

            Smartmatic::System::Security::CRC32Calculator::getCRC32 ( buffer, result );
            resultHex = Smartmatic::System::Utils::StringUtils::bufferHexToString ( result );

            CPPUNIT_ASSERT ( NULL != result.GetData() );
            CPPUNIT_ASSERT ( 4 == result.GetSize() );
            CPPUNIT_ASSERT ( expected == resultHex );
        }

        void testCRC32SafeBuffer64Chars()
        {
            Smartmatic::System::SafeBuffer buffer ( "1234567890123456789012345678901234567890123456789012345678901234" );
            Smartmatic::System::SafeBuffer result;

            std::string expected = "5b68e321";
            std::string resultHex;

            Smartmatic::System::Security::CRC32Calculator::getCRC32 ( buffer, result );
            resultHex = Smartmatic::System::Utils::StringUtils::bufferHexToString ( result );

            CPPUNIT_ASSERT ( NULL != result.GetData() );
            CPPUNIT_ASSERT ( 4 == result.GetSize() );
            CPPUNIT_ASSERT ( expected == resultHex );
        }

        CPPUNIT_TEST_SUITE ( CRC32CalculatorTest );
        CPPUNIT_TEST ( testCRC32NullSafeBuffer );
        CPPUNIT_TEST ( testCRC32SafeBuffer );
        CPPUNIT_TEST ( testCRC32SafeBuffer32Chars );
        CPPUNIT_TEST ( testCRC32SafeBuffer64Chars );
        CPPUNIT_TEST_SUITE_END();
};
#endif /* ECUT_MAIN */

#endif /* TEST_CRC32CALCULATORTEST */
