#ifndef TEST_CERTVALIDATIONRESULT
#define TEST_CERTVALIDATIONRESULT

#ifdef ECUT_MAIN

#include <System/Security/Cryptography/CertValidationResult.h>
#include <System/Security/OpenSSLSecurity.hxx>
#include <cppunit/extensions/HelperMacros.h>

using namespace Smartmatic::System::Security::Cryptography;

class CertValidationResultTest : public CPPUNIT_NS::TestFixture
{
    private:

    public:

        CertValidationResultTest()
        {
        }

        void setUp()
        {
            Smartmatic::System::Security::OpenSSLSecurity::init();
        }

        void tearDown()
        {
            Smartmatic::System::Security::OpenSSLSecurity::clear();
        }

        void testCertValidationResult_DefaultConstructor ()
        {
            CertValidationResult result;

            int depthExpected = 0;
            TrustResultEnum detailExpected = TRUST_OK;

            int depthActual = result.GetDepth();
            TrustResultEnum detailActual = result.GetDetail();

            CPPUNIT_ASSERT ( depthExpected == depthActual );
            CPPUNIT_ASSERT ( detailExpected == detailActual );
        }

        void testCertValidationResult_ConstructorOneParameter ()
        {
            CertValidationResult parameter;

            parameter.SetDepth ( 1 );
            parameter.SetDetail ( TRUST_CANNOT_READ_TARGET );

            CertValidationResult result ( parameter );

            int depthExpected = 1;
            TrustResultEnum detailExpected = TRUST_CANNOT_READ_TARGET;

            int depthActual = result.GetDepth();
            TrustResultEnum detailActual = result.GetDetail();

            CPPUNIT_ASSERT ( depthExpected == depthActual );
            CPPUNIT_ASSERT ( detailExpected == detailActual );
        }

        void testCertValidationResult_ConstructorTwoParameters ()
        {
            int depth = 2;
            TrustResultEnum detail = TRUST_INVALID_DATE;

            CertValidationResult result ( depth, detail );

            int depthExpected = 2;
            TrustResultEnum detailExpected = TRUST_INVALID_DATE;

            int depthActual = result.GetDepth();
            TrustResultEnum detailActual = result.GetDetail();

            CPPUNIT_ASSERT ( depthExpected == depthActual );
            CPPUNIT_ASSERT ( detailExpected == detailActual );
        }

        void testCertValidationResult_GetSuccessTrue ()
        {
            CertValidationResult result;

            bool successExpected = true;
            bool successActual = result.GetSucces();

            CPPUNIT_ASSERT ( successExpected == successActual );
        }

        void testCertValidationResult_GetSuccessFalse ()
        {
            int depth = 2;
            TrustResultEnum detail = TRUST_INVALID_DATE;

            CertValidationResult result ( depth, detail );

            bool successExpected = false;
            bool successActual = result.GetSucces();

            CPPUNIT_ASSERT ( successExpected == successActual );
        }

        CPPUNIT_TEST_SUITE ( CertValidationResultTest );

        CPPUNIT_TEST ( testCertValidationResult_DefaultConstructor );
        CPPUNIT_TEST ( testCertValidationResult_ConstructorOneParameter );
        CPPUNIT_TEST ( testCertValidationResult_ConstructorTwoParameters );
        CPPUNIT_TEST ( testCertValidationResult_GetSuccessTrue );
        CPPUNIT_TEST ( testCertValidationResult_GetSuccessFalse );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_TEST_CERTVALIDATIONRESULTTEST */
