#ifndef TEST_ECDSASIGNERTEST
#define TEST_ECDSASIGNERTEST

#ifdef ECUT_MAIN

#include <System/Security/Cryptography/ECDSASigner.hxx>
#include <cppunit/extensions/HelperMacros.h>
#include <System/Security/OpenSSLSecurity.hxx>
#include <System/Encoding/Base64Encoder.h>
#include <System/IO/File.h>
#include <tests/StoreMockFile.hxx>

static std::string validCertificate_PKCS12_RSA = "MIIJ4QIBAzCCCacGCSqGSIb3DQEHAaCCCZgEggmUMIIJkDCCBo8GCSqGSIb3DQEH"
        "BqCCBoAwggZ8AgEAMIIGdQYJKoZIhvcNAQcBMBwGCiqGSIb3DQEMAQYwDgQIsyAM"
        "Tby61EMCAggAgIIGSNA54zRywSYK7JFdm8Gzfmib0u4oCdZf05yZp/guiXXou7N4"
        "GslmIdVhxtzIiv3XniG3kxWZccv6fs9S77VjyhS+HYi1OsR6TrGWc/sQ+vX+Xa2m"
        "LW2WuZLfjPonKLlY4pmT1saXv46xxgg9PFHiKZ54ao6F0g+24BGP/hXTGYLo9rDy"
        "3/Z6W8E1FX2BuEk1M79zTMMwDkbg5ivO8P9W6tOoMwgOqTnVKuZPmdqjF/BN58By"
        "PiFkBjMuDkRi5RlwhzbQqmd1Fgfq59JTcGrY8uDCcYCzAO7lBZS/bcZy1k9eY1eU"
        "XwUqmlzyszuly2x/0TP+Ycrws/p4hUHKbHeqN+3orxlcJsr/EMwnyipV/VASPjEM"
        "aZ+BKV8Pfr7PlZGyahhfSyHvx3EBFx4ONHTLsg5lzXYCquP41CZRhopgU41Nbu1K"
        "9dz4zC9uUkmA7zloJIbClWigRETS3cqbVUzgbr4wiIfbwdW2XnycAvh8v0GBMcu1"
        "GmWu0hXEEYGXnm30Wr8vxoXoZvfx/Euu0erU+Eo2QH7UL6FfMOYGbKSMzeaRcvnx"
        "gIg1dQkIUThyOYiJ34WELh9QQikJ7iY1uu0nxvWN/X+tH3ufVOIMZ7FFcXH2yLKZ"
        "/f4qFj5JOzKRfbxjB660ccUVXCHJYWeS3eWuRFYEUry6mfmcmXtT2ly2dMBjop2j"
        "t7GFlZBbKelazk9Zn/urrcusZZgaWDZns85ojMqBP9kbnZwBj+LvN3BLSbVhjU5N"
        "Tb2biKaAKhkf2gMO/F/REEs+uzB3vZOg1un0tBcC0enfqynq3wpQV6QDw4n7QIU+"
        "yz9zyif2PQ1IVexau4Me7N9Ot958OSlkVnSwx6rUz5NmAT4wzO7y4HQaJwmp/JDw"
        "EJHMXi5cvekN2ek75a4imk057pNQo4+HuMH1BUZxAIBZ+ylbe8+NjBNzbWDMu6gg"
        "UXTz0B4454ZzJnGO1Qr6neBGGpFQ5DKmmzSZUDCC9TzZG4JuxRzkKPgae66Uugin"
        "xi7F3MnWSI+YAjCow6UGZv/PmCCBVFVxM6ASvS+Y6rPNYOWkn0NfZH+Xb+t/aSAj"
        "3SVs9lPSFZ7q3ng5H0SsXe6cSmAu3UXOt2htM+lypmNduRD18HBaINz6DApu9kQ9"
        "5Q+Q6b27X178VP2ymnStfw0VLAQGFD/LaSpeLU3tW0p+se1jgkL3GEyJ7OhvyeWy"
        "JWTbm3WwtpmUaBTJRyC4AZu/76Uyk72EXYdVSpQXrKFWd3k2ykxyOKFnUOWxtlyX"
        "0AwdUIVooRwTewXzs5+RRtrPd41aTjPhMv7HDIjSHpdhDy5DGj67gWYdKSzJ6Zig"
        "SDCxqqUod5h7paXUFMbPGCPakmIBPdgfraLkK20NXBIzCOrZmBw2EE2oIqQtJ/f6"
        "l1jUUe85iWEVStxlQhgxF1Z9HOjgaWKm8LNjBaq0pPEWHFngIANefHkiibRTA882"
        "MKHuco1bQXYpKat4bKTT6hid1IDojLRo+6FWQptE7qX0WfriUA4Qsr7hmMT10/Kf"
        "bziAHlMIMhCUZvRt7JqR4wyhUq0AWkFA8/aH0FQNs0n6gWO4bUG7KT831XZvr21C"
        "cknButntjTOg0GV8K0EicT90jgY1OawsR4/lRFrMcT+1R9YecCdzpIzqbmLodZG+"
        "ZDrs9XHRNfXpcnz1X6P/8U3aa/x26/ER6bmezznWF60NVrA3u8ACUcymjh2mC+6/"
        "4uQeca8K7v+jvlrjK9jpXEsNPaWfDsTm5Nf39BnmE8WrJTc5BU8GlvarZdWzblSY"
        "JXzi6BlAc/e7u3+NCIlXXlow86upuKxAnGBu142lRe1s2ZnCT/cL2ubab9nHJUUe"
        "CpsW6egPL+rXSVagOHD9d55X8r2USzhTGyVTq6G/wkY1VPAjMfH0+SZ7rbgkCg6z"
        "7wrRuQYWqG5QgtqJ4vXhIZffpyd3TWZhF+iFaXkCZNM48K4CmkpzecmgfgYkIvya"
        "Zqcw8aA0aQARVREnP58xrb2SrdLygpx12jMu6mZiTwxy3BfHmUJUeC15X7Nn7gxH"
        "jXPFsJmuHGKZIa1Wrq3GeImQgFGts/DuynFmV+H/5U6UD9hS4tHvbIbO6cmnyMZ7"
        "x4OkKFvp13nusDiyuzCdQllYx0G06kFzxFuchui23ms0zAp0LjCCAvkGCSqGSIb3"
        "DQEHAaCCAuoEggLmMIIC4jCCAt4GCyqGSIb3DQEMCgECoIICpjCCAqIwHAYKKoZI"
        "hvcNAQwBAzAOBAiwRsjl2i/JBgICCAAEggKAo67L/gzuTYIVlwuVsUF63kISwQ2d"
        "MRwlFQQc5VD9O+lnIksCyZfpcHcSYJGl4AeOy9glAeOn0o13ynkA5oCe1DlemadM"
        "njui44MSLivmNTJleGNqCtoUT88/ADGcGoeOneMCl4yTP42klGZaF2hXoT7tAZkE"
        "vurLAw7VBK7JWT/8tXXFBN2CvNGkyhSQWasfzQUyc44nABsOAprbwGzj7LpOJ4jb"
        "J7FvPcn3lJXR3xPdDNWTg8nLxiALpJMoB0vPFanyxDmhG8LdhxA8E0kOBacF9c9v"
        "165RxCIA/9M1ri1/H7iDpeCwjSPb+yyZTPGEsyuQQdjBiph6YXPQcBs17TkGgjIm"
        "TjKJnnubyKSf2CryfOHlvBTHN84XUzasqkRNMPyk4mhboJCBZ0sduxYnLmbcwBAW"
        "aXdxiGGnhenfnHYZ9NWDeiYXofHn+UZrqjfE3xWxg70h//Nj6ISu9s6u6YR343vB"
        "ivi8UFJu3kpwXkm1yZLtgZb64QH4VvGXE5H/vLVtedRThqq6kSGwKcKJCl31VrF9"
        "Xy+7u4t9amQVpVDIq9IEpwGzqpGxNSpVavUSmzfTbiAwZtkdCgPd2W0lrXSbznxo"
        "RqpQmnejBwy5jUkM6IPn3DovMUWpoxZt2klj286ZqJM7iF11y9H9S0aOt3W88Ulp"
        "sqvA9C0Jp6N3+OftZg4+pJX/MZrfBt0Yk27tA5AzT4AbxmOtKdLtnjMiK0UteTsu"
        "SeriPybTxXJyExR5WAhHU5K5MuURZGpn+dN2viwEwSdMbPGxJijCpnCqdf0iaJWI"
        "DbP8L+x7QUH81sIBZpDXC13hQMjnBOyru71H5tYzPhrvisuxLudqqwi8wzElMCMG"
        "CSqGSIb3DQEJFTEWBBS2X3q5lo9YxXfYjtyJLisz+f5mKTAxMCEwCQYFKw4DAhoF"
        "AAQUd9qIdcVDXDs3XI/8DniFdZhZKpYECGXJksfazXjZAgIIAA==";

static std::string validCertificate_PKCS12_DSA = "MIIJ0QIBAzCCCZcGCSqGSIb3DQEHAaCCCYgEggmEMIIJgDCCB6cGCSqGSIb3DQEH"
        "BqCCB5gwggeUAgEAMIIHjQYJKoZIhvcNAQcBMBwGCiqGSIb3DQEMAQYwDgQIdl1c"
        "XmrEimoCAggAgIIHYH+2XThKpzciDq5mFip3JBWerNIiBjl1mx4UHCqnvSoNo8Yk"
        "yk+TlNwVa1zjycMXDDiXvHF7IJ6l6kvSAlEpobx9q2BE1NU73e/7/7UESqDK/yA9"
        "Xz/huh5XU3FbaYuVB+XPrA86xWDRmbo9HWj4oC2KfygTAIAeAVQ3gB7dvw4OFG0P"
        "yubeoaoG0uVNrElrbrdywkzmfdvZUiCCEBDB2G2Rkgbiq0OiODkW8uKftGuj+ke7"
        "4Mw3iiInE8p5HsIVh5MB7ZlzByz6Dt7qcioM0FiHPn+MUhaxgb9X/2H38GSLYd99"
        "b904fhnK8m4yNT6qUCB7cU/IGZ4R/Q7pWvHwQALqWwh3pub2j1r9tsGUoieZpMmC"
        "VIoWUX4g3jaoKSshD4mxC2l32PceV8YDDJtCZx/0t1+h6ZAtX5vRyuRtkrk9kby6"
        "HFHTDMXq6cAcUSYfc7ebxIA6xR4U7Z/YV530GlQfM+8yw3y4C/0mKmPkIR8jlx06"
        "qyuJlBY3RuOdIEf14rq3zqKccbQpivv9JqlnRjjLJyR1cz6Fz9HOd5ltF6qAEkW1"
        "E+BT6V9os2RGSKdybZ3XTb6fc9xSO8zqO0Y3K1CWio9ulHlRb3Tk1U4vd+LPxnTz"
        "A5zZucTPNSz2FYdTDw/kjRG0KZtwr/JHsHLjTSZLYqF+FmSYxKW8oVpGAvH1paGg"
        "WGzDyLOeESRVsCojq97X1XmBO8jykovnAY9wqBeVOc4q+XZhv1AXqwvbyEOEnJbJ"
        "LKGh9UHng7Exw0eOQmiHplde5tDzsa7JisvR4HMnke3+E8ZPYJyPjTd+fXJQWl4j"
        "l071QntY681BKYDPR7/OKq5WKWrBPOWU5f9Y3n3OTVwbahAopWc3BAGPzuellC2J"
        "vuKs5EhLgShukZayWBsOZA7NIF+kcFJj/TCuVkzC2CBdWktdVJOwed3uoe/tE8bW"
        "a15/0QE+4Qk7KQqjIth9xRflTe/m9t9xHPq2m4DxBHQ0TW7rtIKwnHQ/BBcw108U"
        "wyE5gSU848zSsZ45XTTq8r4/EdzlXIVeiEIm/V4wFbFAbSdgjB043Z+QIh/7CTgn"
        "Luq7xxxHnKE/kYZCHNTgYIToAv58wiZPNnnwPEnFFdf3v5Nf2faDurCnbnhCsv0h"
        "kZ8xtRDP8LaSevw0CWgRcZLBmu54AgowmSKwBtw+eoxG7Aq6LcQG7VvvzHQtJxU2"
        "MhyJ8DPh6+659fnZeOBZ4hAQndudHGTEv0zAlKmyeCBZxULZfuF7rRPTTWL2D8oL"
        "xAWhzRN+YXgVWb8c7S9yY6hTShBe5PgL7DkeuDy9qoCWQXvOieRdp6wJs2J8BNd5"
        "1VwDg7zAk4dPfd4U7WTB284QKHbgCZKvDhx1SumZyyPgQGkpF3p1KY3t6+Fyb2vz"
        "iAL8s63LqUsYBMjnwqR0bjwVZQmW/IgslwY82SavjDmXT4+OSN7JpLRewEyJnP6I"
        "/lnA5fRIXe3yYSdf4y99Vz7ulnkQMClaaSGCgsplrz/KmDVEOqk9uq6i8RrtN2Xu"
        "harEDhxlWHu17aI6tRdQ1jCe81vt8ms6EuJ0yjrc4SXk/z5oKAIWWiofFMYs9pE8"
        "yAC19gIMVP2jmHMBrUc4AQxo9iL9VUCyA8iVZEdO7NjBYopa8aYEXKqL0/X9kt66"
        "/A2Pw2iZ/LEI9LX//kO/h9RsX/KFr+H0L3ofaSB2INzZDsbFpjaJVP+fh5gpB/ny"
        "LVmcWHkq2C0byxIYfQxzKKoBfMfRGtvUkd59DuZpPS/Iw04Ul7+/mQCqrJri8OKI"
        "j+eIRCfJxnPwjSbG1XH4v3YHZQSNRdDVXGL1AViRBaNhWv60XRcoCJCh6/DYrHq8"
        "whfqM5iTEU9LR6GDqNLkO5+PSBG3kyiEUJZgTLGF57/zaoIcgevuN8FxLsQL4fOP"
        "29IIyMTLQq+RhLABvjmHLlimF5ZkNukXVQpv5o+vpm9k7NhRViRid8ViuJoI1Z1+"
        "5vXNKQf1NLVAnVrfrWXwx5nshusQlpBnL1nGqWtOLnB5r7LoA2qPXq8p2iMXrSEF"
        "CiVdbm//fhICHCtEop7fc6GPG7mfVMq4dkIqvEpb5AzAMTQYtv3uwCrucZeVBqBk"
        "zzhwhmR7ujvCcONj2FxH1ldVmKucV9anXWethbNnWEi4JkprRoAyFYgvc4OnUI2U"
        "A8qPIMQ6vdJmCHNxoGOtTZDhmAfDjZLoynLiTOExMu58xEI9WBxvpyZbY6DPt9Eh"
        "qMR/d+UKS9Hy4tfNTgIkWrF8rrtfm+GfmOqqDCg89ksV2zayv0UISbz7I5gt3pfQ"
        "0Bwd15BX6VQ4aC6IDcci6TqtkxW3MX4wjRGE2IpDcGmUBpPns5LUC2n0NMr6PbTE"
        "gCx7ih5eau+N8aYt52CzUoTyOXTs9L+S6TsqFXS9Bw/5pXt94lq3RIfrg8ZH0q+g"
        "VUA36HWAbmQE/YqkBvMEHHwyGZOQrkxZnD6Zsob+WHRtDRYJTESlNBONoO6OutAZ"
        "foSOr7H23pTHMkMnGTEnNPbqY3QCURcGxbimXb4wggHRBgkqhkiG9w0BBwGgggHC"
        "BIIBvjCCAbowggG2BgsqhkiG9w0BDAoBAqCCAX4wggF6MBwGCiqGSIb3DQEMAQMw"
        "DgQIcNKYXn7uCHoCAggABIIBWK8TureSPocvkWHpjMBJhEfEYDz6Wr956KDaDopL"
        "bHxBlPozJqMkjafUVJOxZGnhTBrXvqPa1QO7qf7VS9lsOlRwfkx5wxKEaK+KlJiC"
        "hfa0XSqNsCSNBr6wk5yF+6CUn01OWhnfdAZs9LXDMbWW79k5dpBr0LN3WQoEDy3x"
        "YfGHldhUcl7dQp/LJFoVKa3+0YXpnLeSKYHU8ccxg/arST8+4kIgEKjJUxYb7LaB"
        "iR/H2uYQycYEYNvh+2+dnucs+RYTYRLmDHrkskDNUIncMuZzwN32gaPwdhkOLjla"
        "toiV/gamjNgx5rM3D5U+MWS/EgSWKOeImZb0qk0qVpPzQabzxxOBYeNhUoQgVhsf"
        "FmDnwUNI660cath8pxtQXUDyAcM4MewzdCJDJPHzpOoR22XjsUs2JHGju6X4ULli"
        "PzVYiDQ7JKacasqj2Hl/T7v/6cv66d1Qv0fgMSUwIwYJKoZIhvcNAQkVMRYEFDPC"
        "2Rtdaup+6GFpGFow7pi6QWezMDEwITAJBgUrDgMCGgUABBREjG9Eqljsn8Hx83tS"
        "sVIOOlDX0AQIToyo72q8yC4CAggA";

static std::string validCertificate_PKCS12_ECDSA = "MIIHuQIBAzCCB38GCSqGSIb3DQEHAaCCB3AEggdsMIIHaDCCBmcGCSqGSIb3DQEH"
        "BqCCBlgwggZUAgEAMIIGTQYJKoZIhvcNAQcBMBwGCiqGSIb3DQEMAQYwDgQIYhAP"
        "kpYTnNICAggAgIIGIIz1W7Bul+oUKmk5PBY7HzbeVuU8BOvjMp9G+trPHjX9Cruk"
        "7JJyNrLVmFbqPpY799k1+36zIPq7oFxMWsW0F+/DqIpsj45/ZC1UMC58RThUFMt4"
        "MPkOJ6NpmT3fhit1zuVfhWy+nTEExmcpARvx7Kke/bVnDhc96vWUQGuLisOZMZA6"
        "mZa4gWbIF1VCv3iQ3oWtMgH8uYKDNRVasHWk43Cq9XlrrNWPzKL/w1zrDEXgVu3V"
        "qAYWUNqii+tpgG1QK61GtzBvcxmabKjn9uL7KbNU2y0lWzaTXBZAd80rYp1DclAr"
        "paHIj7tv2l6McTOvAjLv7sO4FtWJSKwHLegRY/I8xqQSaCniv7ztROLlOCeciYcY"
        "cwFabM/hckaQWpGQl1z60vxiMJbQCoPPeIV+DlTf66fBWlDmab99vCRX27lvmf9n"
        "yfItjrWvyySIulyv9oJ2Ng/Pogc5KUwoAOzfC57qmmPm/zBQ82qCI36K2mlgx1PB"
        "xtPgLfrROlasx8uKA9QoZChJBXGXOOpmaN8m+Y++hFEBznT01Rilz36cVTPp2FvI"
        "V6OHMwfIqfzjQY/THnSFh65LVt+EA6H5WgBfIodM/f4aZQkJXa5usUDGw4cczzxE"
        "agLUDNErxkG8NWGo7F0juFvkZ1iQP76P2FUT+zV6HonFjTwG+T/mWQ0CZvUEXrRU"
        "jBSqeVhsmkVbb+YWpmtWgMB91yqrGY9Jycfc/6AOTFUMmY5gQwg0Nlem8NhBA9h7"
        "wpQASdtP8WSC+f448pEVg9/DZ/lPW7cAHtpoSimHz6mW/oDIvEoqfFkerx+akP2D"
        "Uueja5+TBjya5afETUyMq9PvXz/F/J/PhJ5Xt0ZEeJ1C6tBR9Xrfx1Qz6P0fssCW"
        "FVPtMMOUbQF/lU0mGVLETPMtCbytz/xIKZ+24J6226P8Np/0ubqgo0UFdEt2HDSO"
        "mfAHK8W3XbIAOlIXHJdXoIbRkY4279etLxXJf74NKDg7jjlFLHNJxDcF94fnNhyv"
        "chr9lnqAxtMMVZch2UgNCY8cxV6Ep8Ong/DFsORuRQjfJm0lI3kCCTe1bM/VfYZs"
        "RB43fOploShPPDaHH+r2cIInIFrBQWTWsw2bVROMcTpG61n2SJwtTS06n6SXlCFz"
        "KAGJgu+CXtL6Sg+9UCvc3KW54q8ualso45vvaEDEqtWNhYyQ9DQUudw2UlQsxfad"
        "PARBd0rnEpwx5JR2ulCsAM0UvOlhh6IdZQvJ1fQrY7wOhcvcgYf2X4RqbbDIeOMJ"
        "LLFArcqSvdXlO1o2eqBYrjEre0iQCKN5T5J2euY26V8UZ8m30MLPPuCNoFlQS529"
        "A8bHB0OZUFGrWYMppm5+UaonSOkrzoq5TfOhpuIGT45Ig7eddzuSJtDmpMjquDJG"
        "zyONxfebhu69k/QO5kK3tZ2pMiIAMJ58PRVXrKdKufuECNLWSNxdhBY6XhkydlgB"
        "7ALpYzHe3r7isWy9zQ2K4xDka4U9brDlmR78Y9KWEF0Cj9HlfH4krML2sG0nNyZO"
        "ugtQszrD5yhxz12249yFs5ysgeILckFuULjAlVkhbHJZTW5kLyEp6ULreY4RaY5U"
        "lcbcEnMg/xR2XgwlEofKUeUfB1T4kTSehaGxF5hQ32JXpnBkwtHVglIhljJM602I"
        "sE5xGPqOzKpG1C1Mu2hS2xcYBlDOFPDeCCgzucAIsx7nV5fXisjJrvGz0lods/il"
        "TASx1hRhivdRq7ghuUQI+lnLfl61jJ9MBkn4yzXogP04YLKPfUuLGoYHFfMiMzBz"
        "AEov+Cx6n8TQ3I3aDrIoRJ3ZEcPFwxUeCCLGeHdwIBUgCz/Ng4zhNeo/Nt1rKWUi"
        "AwHYraeFvdgrMTL8QA+LXmVAaUN4LhlaMV9KPHXxRFC5W2efOAZjRFJQC9fFSiIu"
        "DXVbDlPhkPnGOnYYQv5OUypNEjiaPQeH05Zr3AxFP4kdNJtkwc8gNAfyfBYQvfse"
        "tZA/Jh2CHXBm7YUJrIYMqHhO3UoCGmCuUnT84HJ7v8gnKeoXZ+AI4nr8JaUsebVE"
        "KfCEZo5rayqMibdSFNXmCVj1bTICwkYKIIecYK+K2WUYEq2kGipp/IyNLiFXMIH6"
        "BgkqhkiG9w0BBwGggewEgekwgeYwgeMGCyqGSIb3DQEMCgECoIGsMIGpMBwGCiqG"
        "SIb3DQEMAQMwDgQID4BJRkx9axMCAggABIGIlH1bwUIEFkYdbZ8Yo9TUsjz9kYKm"
        "XUCCaOlF5PbVm0lY4WLnlOoZm56wKcX9S5DHfmJYhP/CHmn/RanZcIFcBnPGVeET"
        "eN/3TLkuHFh3hq8dKa9MeeD7hGLZEUIhz95VwjD9CCLMB9yW0q5qxQ7dg8k5MMsK"
        "xdoAMg1bcIyBi9hCEtKi6hd0jTElMCMGCSqGSIb3DQEJFTEWBBQ7/S4jA1/ZL82M"
        "loYcuZUFk1imOzAxMCEwCQYFKw4DAhoFAAQUiaevcD0CpJWLOEQYnDq2xOmxzI8E"
        "COv0N34207SUAgIIAA==";

static std::string correctPasswordPKCS12 = "passwordpkcs12";
static std::string filePath = "filePath";
static std::string originalMsg = "Hello World!";

using namespace Smartmatic::System::Security::Cryptography;
using namespace Smartmatic::System::Exception;
using namespace Smartmatic::System::Encoding;
using namespace Smartmatic::System::Security;
using namespace Smartmatic::System::IO;
using namespace Smartmatic::System;

class ECDSASignerTest : public CPPUNIT_NS::TestFixture
{
    private:
        ECDSASigner * ecdsaSigner;

    public:

        ECDSASignerTest()
        {
            ecdsaSigner = NULL;
        }

        void setUp()
        {
            Smartmatic::System::Security::OpenSSLSecurity::init();
            ecdsaSigner = NULL;
        }

        void tearDown()
        {
            Smartmatic::System::Security::OpenSSLSecurity::clear();

            if ( ecdsaSigner )
            {
                delete ecdsaSigner;
                ecdsaSigner = NULL;
            }
        }

        void test_SignData_WithoutCertificate ()
        {
            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer(), true ) );

            SafeBuffer dataIn ( originalMsg );
            SafeBuffer signature;

            ecdsaSigner = new ECDSASigner ();
            ecdsaSigner->SetCertificate ( filePath, CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            CPPUNIT_ASSERT_THROW ( ecdsaSigner->SignData ( dataIn, signature, MsgDigestUtil::DGSTUTIL_SHA256 ), SignedException );
            CPPUNIT_ASSERT ( 0 == signature.GetSize() );
        }

        void test_VerifyData_WithoutCertificate ()
        {
            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer(), true ) );

            SafeBuffer dataIn ( originalMsg );
            SafeBuffer signature;

            ecdsaSigner = new ECDSASigner ();
            ecdsaSigner->SetCertificate ( filePath, CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            CPPUNIT_ASSERT_THROW ( ecdsaSigner->VerifySignature ( dataIn, signature, MsgDigestUtil::DGSTUTIL_SHA256 ), SignedException );
        }

        void test_SignData_PKCS12_RSA ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12_RSA, certificateBuffer );

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );

            SafeBuffer dataIn ( originalMsg );
            SafeBuffer signature;

            ecdsaSigner = new ECDSASigner ();
            ecdsaSigner->SetCertificate ( filePath, CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            CPPUNIT_ASSERT_THROW ( ecdsaSigner->SignData ( dataIn, signature, MsgDigestUtil::DGSTUTIL_SHA256 ), SignedException );
            CPPUNIT_ASSERT ( 0 == signature.GetSize() );
        }

        void test_SignData_PKCS12_DSA ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12_DSA, certificateBuffer );

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );

            SafeBuffer dataIn ( originalMsg );
            SafeBuffer signature;

            ecdsaSigner = new ECDSASigner ();
            ecdsaSigner->SetCertificate ( filePath, CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            CPPUNIT_ASSERT_THROW ( ecdsaSigner->SignData ( dataIn, signature, MsgDigestUtil::DGSTUTIL_SHA256 ), SignedException );
            CPPUNIT_ASSERT ( 0 == signature.GetSize() );
        }

        void test_SignData_PKCS12_ECDSA ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12_ECDSA, certificateBuffer );

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );

            SafeBuffer dataIn ( originalMsg );
            SafeBuffer signature;

            ecdsaSigner = new ECDSASigner ();
            ecdsaSigner->SetCertificate ( filePath, CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            ecdsaSigner->SignData ( dataIn, signature, MsgDigestUtil::DGSTUTIL_SHA256 );

            CPPUNIT_ASSERT ( 0 != signature.GetSize() );
            CPPUNIT_ASSERT ( dataIn != signature );
        }

        void test_SignData_VerifyData ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12_ECDSA, certificateBuffer );

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );

            SafeBuffer dataIn ( originalMsg );
            SafeBuffer signature;

            ecdsaSigner = new ECDSASigner ();
            ecdsaSigner->SetCertificate ( filePath, CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            ecdsaSigner->SignData ( dataIn, signature, MsgDigestUtil::DGSTUTIL_SHA256 );

            CPPUNIT_ASSERT ( 0 != signature.GetSize() );
            CPPUNIT_ASSERT ( dataIn != signature );

            bool retVal = ecdsaSigner->VerifySignature ( dataIn, signature, MsgDigestUtil::DGSTUTIL_SHA256 );

            CPPUNIT_ASSERT ( true == retVal );
        }

        void test_SignData_VerifyData_WithRSA ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12_RSA, certificateBuffer );

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );

            SafeBuffer dataIn ( originalMsg );
            SafeBuffer signature;

            ecdsaSigner = new ECDSASigner ();
            ecdsaSigner->SetCertificate ( filePath, CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            CPPUNIT_ASSERT_THROW ( ecdsaSigner->SignData ( dataIn, signature, MsgDigestUtil::DGSTUTIL_SHA256 ), SignedException );
            CPPUNIT_ASSERT ( 0 == signature.GetSize() );
            CPPUNIT_ASSERT_THROW ( ecdsaSigner->VerifySignature ( dataIn, signature, MsgDigestUtil::DGSTUTIL_SHA256 ), SignedException );
        }

        void test_SignData_VerifyData_SignatureFail ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12_ECDSA, certificateBuffer );

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );

            SafeBuffer dataIn ( originalMsg );
            SafeBuffer signature;

            ecdsaSigner = new ECDSASigner ();
            ecdsaSigner->SetCertificate ( filePath, CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            ecdsaSigner->SignData ( dataIn, signature, MsgDigestUtil::DGSTUTIL_SHA256 );

            CPPUNIT_ASSERT ( 0 != signature.GetSize() );
            CPPUNIT_ASSERT ( dataIn != signature );

            signature.removeData ( 0, 1 );

            bool retVal = ecdsaSigner->VerifySignature ( dataIn, signature, MsgDigestUtil::DGSTUTIL_SHA256 );

            CPPUNIT_ASSERT ( false == retVal );
        }

        void test_SignData_VerifyData_SignatureEmpty ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12_ECDSA, certificateBuffer );

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer(), true ) );

            SafeBuffer dataIn ( originalMsg );
            SafeBuffer signature;

            ecdsaSigner = new ECDSASigner ();
            ecdsaSigner->SetCertificate ( filePath, CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            ecdsaSigner->SignData ( dataIn, signature, MsgDigestUtil::DGSTUTIL_SHA256 );

            CPPUNIT_ASSERT ( 0 != signature.GetSize() );
            CPPUNIT_ASSERT ( dataIn != signature );

            ecdsaSigner->SetCertificate ( filePath, CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            CPPUNIT_ASSERT_THROW ( ecdsaSigner->VerifySignature ( dataIn, signature, MsgDigestUtil::DGSTUTIL_SHA256
 ), SignedException );
        }

        CPPUNIT_TEST_SUITE ( ECDSASignerTest );

        CPPUNIT_TEST ( test_SignData_WithoutCertificate );
        CPPUNIT_TEST ( test_VerifyData_WithoutCertificate );
        CPPUNIT_TEST ( test_SignData_PKCS12_RSA );
        CPPUNIT_TEST ( test_SignData_PKCS12_DSA );
        CPPUNIT_TEST ( test_SignData_PKCS12_ECDSA );
        CPPUNIT_TEST ( test_SignData_VerifyData );
        CPPUNIT_TEST ( test_SignData_VerifyData_WithRSA );
        CPPUNIT_TEST ( test_SignData_VerifyData_SignatureFail );
        CPPUNIT_TEST ( test_SignData_VerifyData_SignatureEmpty );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_TEST_ECDSASIGNERTEST */
