#ifndef TEST_PKCS7SIGNERTEST
#define TEST_PKCS7SIGNERTEST

#ifdef ECUT_MAIN

#include "System/Security/Cryptography/PKCS7Signer.hxx"
#include <cppunit/extensions/HelperMacros.h>
#include <System/Security/OpenSSLSecurity.hxx>
#include <System/Encoding/Base64Encoder.h>
#include <System/SafeBuffer.h>
#include <System/IO/File.h>
#include <tests/StoreMockFile.hxx>

using namespace Smartmatic::System;
using namespace Smartmatic::System::IO;
using namespace Smartmatic::System::Security;
using namespace Smartmatic::System::Encoding;
using namespace Smartmatic::System::Exception;
using namespace Smartmatic::System::Security::Cryptography;

static std::string validCertificate_PKCS12 = "MIIJ4QIBAzCCCacGCSqGSIb3DQEHAaCCCZgEggmUMIIJkDCCBo8GCSqGSIb3DQEH"
        "BqCCBoAwggZ8AgEAMIIGdQYJKoZIhvcNAQcBMBwGCiqGSIb3DQEMAQYwDgQIsyAM"
        "Tby61EMCAggAgIIGSNA54zRywSYK7JFdm8Gzfmib0u4oCdZf05yZp/guiXXou7N4"
        "GslmIdVhxtzIiv3XniG3kxWZccv6fs9S77VjyhS+HYi1OsR6TrGWc/sQ+vX+Xa2m"
        "LW2WuZLfjPonKLlY4pmT1saXv46xxgg9PFHiKZ54ao6F0g+24BGP/hXTGYLo9rDy"
        "3/Z6W8E1FX2BuEk1M79zTMMwDkbg5ivO8P9W6tOoMwgOqTnVKuZPmdqjF/BN58By"
        "PiFkBjMuDkRi5RlwhzbQqmd1Fgfq59JTcGrY8uDCcYCzAO7lBZS/bcZy1k9eY1eU"
        "XwUqmlzyszuly2x/0TP+Ycrws/p4hUHKbHeqN+3orxlcJsr/EMwnyipV/VASPjEM"
        "aZ+BKV8Pfr7PlZGyahhfSyHvx3EBFx4ONHTLsg5lzXYCquP41CZRhopgU41Nbu1K"
        "9dz4zC9uUkmA7zloJIbClWigRETS3cqbVUzgbr4wiIfbwdW2XnycAvh8v0GBMcu1"
        "GmWu0hXEEYGXnm30Wr8vxoXoZvfx/Euu0erU+Eo2QH7UL6FfMOYGbKSMzeaRcvnx"
        "gIg1dQkIUThyOYiJ34WELh9QQikJ7iY1uu0nxvWN/X+tH3ufVOIMZ7FFcXH2yLKZ"
        "/f4qFj5JOzKRfbxjB660ccUVXCHJYWeS3eWuRFYEUry6mfmcmXtT2ly2dMBjop2j"
        "t7GFlZBbKelazk9Zn/urrcusZZgaWDZns85ojMqBP9kbnZwBj+LvN3BLSbVhjU5N"
        "Tb2biKaAKhkf2gMO/F/REEs+uzB3vZOg1un0tBcC0enfqynq3wpQV6QDw4n7QIU+"
        "yz9zyif2PQ1IVexau4Me7N9Ot958OSlkVnSwx6rUz5NmAT4wzO7y4HQaJwmp/JDw"
        "EJHMXi5cvekN2ek75a4imk057pNQo4+HuMH1BUZxAIBZ+ylbe8+NjBNzbWDMu6gg"
        "UXTz0B4454ZzJnGO1Qr6neBGGpFQ5DKmmzSZUDCC9TzZG4JuxRzkKPgae66Uugin"
        "xi7F3MnWSI+YAjCow6UGZv/PmCCBVFVxM6ASvS+Y6rPNYOWkn0NfZH+Xb+t/aSAj"
        "3SVs9lPSFZ7q3ng5H0SsXe6cSmAu3UXOt2htM+lypmNduRD18HBaINz6DApu9kQ9"
        "5Q+Q6b27X178VP2ymnStfw0VLAQGFD/LaSpeLU3tW0p+se1jgkL3GEyJ7OhvyeWy"
        "JWTbm3WwtpmUaBTJRyC4AZu/76Uyk72EXYdVSpQXrKFWd3k2ykxyOKFnUOWxtlyX"
        "0AwdUIVooRwTewXzs5+RRtrPd41aTjPhMv7HDIjSHpdhDy5DGj67gWYdKSzJ6Zig"
        "SDCxqqUod5h7paXUFMbPGCPakmIBPdgfraLkK20NXBIzCOrZmBw2EE2oIqQtJ/f6"
        "l1jUUe85iWEVStxlQhgxF1Z9HOjgaWKm8LNjBaq0pPEWHFngIANefHkiibRTA882"
        "MKHuco1bQXYpKat4bKTT6hid1IDojLRo+6FWQptE7qX0WfriUA4Qsr7hmMT10/Kf"
        "bziAHlMIMhCUZvRt7JqR4wyhUq0AWkFA8/aH0FQNs0n6gWO4bUG7KT831XZvr21C"
        "cknButntjTOg0GV8K0EicT90jgY1OawsR4/lRFrMcT+1R9YecCdzpIzqbmLodZG+"
        "ZDrs9XHRNfXpcnz1X6P/8U3aa/x26/ER6bmezznWF60NVrA3u8ACUcymjh2mC+6/"
        "4uQeca8K7v+jvlrjK9jpXEsNPaWfDsTm5Nf39BnmE8WrJTc5BU8GlvarZdWzblSY"
        "JXzi6BlAc/e7u3+NCIlXXlow86upuKxAnGBu142lRe1s2ZnCT/cL2ubab9nHJUUe"
        "CpsW6egPL+rXSVagOHD9d55X8r2USzhTGyVTq6G/wkY1VPAjMfH0+SZ7rbgkCg6z"
        "7wrRuQYWqG5QgtqJ4vXhIZffpyd3TWZhF+iFaXkCZNM48K4CmkpzecmgfgYkIvya"
        "Zqcw8aA0aQARVREnP58xrb2SrdLygpx12jMu6mZiTwxy3BfHmUJUeC15X7Nn7gxH"
        "jXPFsJmuHGKZIa1Wrq3GeImQgFGts/DuynFmV+H/5U6UD9hS4tHvbIbO6cmnyMZ7"
        "x4OkKFvp13nusDiyuzCdQllYx0G06kFzxFuchui23ms0zAp0LjCCAvkGCSqGSIb3"
        "DQEHAaCCAuoEggLmMIIC4jCCAt4GCyqGSIb3DQEMCgECoIICpjCCAqIwHAYKKoZI"
        "hvcNAQwBAzAOBAiwRsjl2i/JBgICCAAEggKAo67L/gzuTYIVlwuVsUF63kISwQ2d"
        "MRwlFQQc5VD9O+lnIksCyZfpcHcSYJGl4AeOy9glAeOn0o13ynkA5oCe1DlemadM"
        "njui44MSLivmNTJleGNqCtoUT88/ADGcGoeOneMCl4yTP42klGZaF2hXoT7tAZkE"
        "vurLAw7VBK7JWT/8tXXFBN2CvNGkyhSQWasfzQUyc44nABsOAprbwGzj7LpOJ4jb"
        "J7FvPcn3lJXR3xPdDNWTg8nLxiALpJMoB0vPFanyxDmhG8LdhxA8E0kOBacF9c9v"
        "165RxCIA/9M1ri1/H7iDpeCwjSPb+yyZTPGEsyuQQdjBiph6YXPQcBs17TkGgjIm"
        "TjKJnnubyKSf2CryfOHlvBTHN84XUzasqkRNMPyk4mhboJCBZ0sduxYnLmbcwBAW"
        "aXdxiGGnhenfnHYZ9NWDeiYXofHn+UZrqjfE3xWxg70h//Nj6ISu9s6u6YR343vB"
        "ivi8UFJu3kpwXkm1yZLtgZb64QH4VvGXE5H/vLVtedRThqq6kSGwKcKJCl31VrF9"
        "Xy+7u4t9amQVpVDIq9IEpwGzqpGxNSpVavUSmzfTbiAwZtkdCgPd2W0lrXSbznxo"
        "RqpQmnejBwy5jUkM6IPn3DovMUWpoxZt2klj286ZqJM7iF11y9H9S0aOt3W88Ulp"
        "sqvA9C0Jp6N3+OftZg4+pJX/MZrfBt0Yk27tA5AzT4AbxmOtKdLtnjMiK0UteTsu"
        "SeriPybTxXJyExR5WAhHU5K5MuURZGpn+dN2viwEwSdMbPGxJijCpnCqdf0iaJWI"
        "DbP8L+x7QUH81sIBZpDXC13hQMjnBOyru71H5tYzPhrvisuxLudqqwi8wzElMCMG"
        "CSqGSIb3DQEJFTEWBBS2X3q5lo9YxXfYjtyJLisz+f5mKTAxMCEwCQYFKw4DAhoF"
        "AAQUd9qIdcVDXDs3XI/8DniFdZhZKpYECGXJksfazXjZAgIIAA==";

static std::string validPrivateKey_PEM = "-----BEGIN ENCRYPTED PRIVATE KEY-----\n"
        "MIICxjBABgkqhkiG9w0BBQ0wMzAbBgkqhkiG9w0BBQwwDgQIiV8C9Nv/IOcCAggA\n"
        "MBQGCCqGSIb3DQMHBAggVWwspYiQfgSCAoCnX7fmbIA4YMDX+2F26injvxB8Vwz5\n"
        "en5MomnpXGiPFKcVaZgj/vaHo7qPHh3/Xvpj9SboRwrNkO0iY+KCJjaE5GezbJ6z\n"
        "nvElXO3Gs6/mzqFnIc2ApK6ShxZ1mVJEGtUP/D5996kiQZ3/+ks/Ne94B0AxQ6Jt\n"
        "Koi28hdW9YH7lp0iwFfIBrV+0Y7+I/IXYV0fNPWCrI6gaval89XZPfoF8wvK4sO0\n"
        "KDbMMv59X+L07KD5RLBIxLbcq0GVzYsC53MU6aU2UkrSCPEPi39tdzkvF0tPEBbY\n"
        "vME6TrJONkSxaV8nzID/BO+ZNvl0RVUhePbpf/CQhxZZUTWY5mgdZ7Ru0hdl9jJ+\n"
        "zyddWAg24Te56rpsyjhfAJhRYZK1UwQUOLhRaaUvZpBM2QYHA9NSHOGv9IU6krP+\n"
        "iTFOKw2XbGMZkuCJz1Jn8h4jfGHfw2SMZvRcmqNW2OuQQn40kMlOoKp1xcZ2pTR4\n"
        "B0dl1Y4tLe7s4zC9JdyGsYiwlAwHwDSgATg+G6c1cUbxHwlPBAl8fNpmNdp7OGZk\n"
        "DhHoC2rldV3D04HwukarR82OP8VUj7H3ykSEKTEnUX8vGpkruPPXpe3lF9pZrqX5\n"
        "QAvdZuz+jDWy+OOt3NNLR7pEUK96geuDNJegWracsUB2/DwRKhWOWjxG3nko0H+n\n"
        "y1P4TG0xeT/59oJOLvscHpO+IW3p3rjiTvN8hgFt1bLSi+ZKJOxtJNNsQCMokgV9\n"
        "UiB3/sJnLM0f+yRODsR0iscy51rssuSs8P8XjsyEiG+qep8VfGrCAwIw4dMxyZ/P\n"
        "jtuZe1bhjON3Zva27eF47FKRpwiU5KBFBwbSx92lGZ6Gin5dYP045LOf\n"
        "-----END ENCRYPTED PRIVATE KEY-----\n";

static std::string validCertificate_PEM = "-----BEGIN CERTIFICATE-----\n"
        "MIIC9DCCAl2gAwIBAgICEAAwDQYJKoZIhvcNAQEFBQAweTELMAkGA1UEBhMCQkUx\n"
        "ETAPBgNVBAgMCEJydXNzZWxzMRIwEAYDVQQHDAlFdHRlcmJlZWsxEzARBgNVBAoM\n"
        "ClNtYXJ0bWF0aWMxHDAaBgNVBAsME0VsZWN0b3JhbCBTb2x1dGlvbnMxEDAOBgNV\n"
        "BAMMB1JPT1QgQ0EwHhcNMTMxMjI2MTAzNjM0WhcNMTQxMjI2MTAzNjM0WjCBiDEL\n"
        "MAkGA1UEBhMCQkUxETAPBgNVBAgMCEJydXNzZWxzMRMwEQYDVQQKDApTbWFydG1h\n"
        "dGljMRwwGgYDVQQLDBNFbGVjdG9yYWwgU29sdXRpb25zMQ4wDAYDVQQDDAVVc2Vy\n"
        "MTEjMCEGCSqGSIb3DQEJARYUdXNlcjFAc21hcnRtYXRpYy5jb20wgZ8wDQYJKoZI\n"
        "hvcNAQEBBQADgY0AMIGJAoGBALkfis573u0A27LW+n1q9URLy6fFoJ8XIAn1bYrw\n"
        "YQgZPfuLGk0fSFzPf3skMKhvueWgNg9IbOi29Ta8/y4T55SYdTCjumezcjo5kXfP\n"
        "J5dUFNMSnACwP+xH8MGrCaUBn9WEGO4IE0dbiTK4koH0kCrnbOqR+IaNW/TDFJvH\n"
        "mWQ5AgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8WHU9wZW5TU0wg\n"
        "R2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBQb0Vt+kvOcMX8GKNS2Nrp6\n"
        "fJ8RWTAfBgNVHSMEGDAWgBR7ieRpADfz3zAXXjayYT4sn4hRCjANBgkqhkiG9w0B\n"
        "AQUFAAOBgQARS2/N2ySflGKV4bbNgcu9RJspQ7P6wTFgLivsjcLKgJvLgJQUNdsr\n"
        "eoY4T0Jjm3yg+tN6y8831u4JUgZOuvjWmHmIkYFPqqkzEHkPyslBZFHBhE/60xNn\n"
        "p+xjtpQJ/RB9eC4OeaXpgaCLYP5jQPxN00A8HEdLNjqz6sIvWyCzjg==\n"
        "-----END CERTIFICATE-----\n";

static std::string correctPasswordPKCS12 = "passwordpkcs12";
static std::string correctPrivateKeyPassword = "passworduser1";
static std::string filePath = "filePath";
static std::string message = "Hello world!";

class PKCS7SignerTest : public CPPUNIT_NS::TestFixture
{
    public:

        PKCS7SignerTest()
        {
        }

        void setUp()
        {
            Smartmatic::System::Security::OpenSSLSecurity::init();
        }

        void tearDown()
        {
            Smartmatic::System::Security::OpenSSLSecurity::clear();
        }

        void testSignWithoutCertificate ()
        {
            SafeBuffer originalData ( message );
            SafeBuffer signedBuffer ( "exit" );

            PKCS7Signer pkcs7Signer;

            CPPUNIT_ASSERT_THROW ( pkcs7Signer.signBuffer ( originalData, signedBuffer, Cryptography::PKCS7Base::SMIME ), SignedException );
            CPPUNIT_ASSERT ( 0 == signedBuffer.GetSize() );
        }

        void testSignAndVerifyWithPEM ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12, certificateBuffer );

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );

            PKCS7Signer pkcs7Signer;
            pkcs7Signer.SetCertificate ( filePath, CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            SafeBuffer originalData ( message );
            SafeBuffer signedData;
            SafeBuffer output ( "empty" );

            pkcs7Signer.signBuffer ( originalData, signedData, Cryptography::PKCS7Base::PEM );

            CPPUNIT_ASSERT ( 0 != signedData.GetSize() );
            CPPUNIT_ASSERT ( originalData != signedData );

            pkcs7Signer.verifyBuffer ( signedData, output,  Cryptography::PKCS7Base::PEM );
            CPPUNIT_ASSERT ( 0 == output.GetSize() );
        }

        void testSignAndVerifyWithSMIME ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12, certificateBuffer );

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );

            PKCS7Signer pkcs7Signer;
            pkcs7Signer.SetCertificate ( filePath, CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            SafeBuffer originalData ( message );
            SafeBuffer signedData;
            SafeBuffer output;

            pkcs7Signer.signBuffer ( originalData, signedData, Cryptography::PKCS7Base::SMIME );

            CPPUNIT_ASSERT ( 0 != signedData.GetSize() );
            CPPUNIT_ASSERT ( originalData != signedData );

            pkcs7Signer.verifyBuffer ( signedData, output,  Cryptography::PKCS7Base::SMIME );
            CPPUNIT_ASSERT ( originalData == output );
        }

        void testSignAndVerifyWithDER ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12, certificateBuffer );

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );

            PKCS7Signer pkcs7Signer;
            pkcs7Signer.SetCertificate ( filePath, CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            SafeBuffer originalData ( message );
            SafeBuffer signedData;
            SafeBuffer output;

            pkcs7Signer.signBuffer ( originalData, signedData, Cryptography::PKCS7Base::DER );

            CPPUNIT_ASSERT ( 0 != signedData.GetSize() );
            CPPUNIT_ASSERT ( originalData != signedData );

            pkcs7Signer.verifyBuffer ( signedData, output,  Cryptography::PKCS7Base::DER );
            CPPUNIT_ASSERT ( 0 == output.GetSize() );
        }

        void testSignAndVerifyFailPEM ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12, certificateBuffer );

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );

            PKCS7Signer pkcs7Signer;
            pkcs7Signer.SetCertificate ( filePath, Cryptography::CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            SafeBuffer originalData ( message );
            SafeBuffer signedData;
            SafeBuffer output ( "Empty" );

            pkcs7Signer.signBuffer ( originalData, signedData, Cryptography::PKCS7Base::PEM );

            CPPUNIT_ASSERT ( 0 != signedData.GetSize() );
            CPPUNIT_ASSERT ( originalData != signedData );

            signedData.removeData ( 0, 1 );

            CPPUNIT_ASSERT_THROW ( pkcs7Signer.verifyBuffer ( signedData, output,  Cryptography::PKCS7Base::PEM ), SignedException );
            CPPUNIT_ASSERT ( 0 == output.GetSize() );
        }

        void testSignAndVerifyFailSMIME ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12, certificateBuffer );

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );

            PKCS7Signer pkcs7Signer;
            pkcs7Signer.SetCertificate ( filePath, Cryptography::CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            SafeBuffer originalData ( message );
            SafeBuffer signedData;
            SafeBuffer output ( "Empty" );

            pkcs7Signer.signBuffer ( originalData, signedData, Cryptography::PKCS7Base::SMIME );

            CPPUNIT_ASSERT ( 0 != signedData.GetSize() );
            CPPUNIT_ASSERT ( originalData != signedData );

            signedData.removeData ( 193, 1 );

            CPPUNIT_ASSERT_THROW ( pkcs7Signer.verifyBuffer ( signedData, output,  Cryptography::PKCS7Base::SMIME ), SignedException );
            CPPUNIT_ASSERT ( 0 == output.GetSize() );
        }

        void testSignAndVerifyFailDER ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12, certificateBuffer );

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );

            PKCS7Signer pkcs7Signer;
            pkcs7Signer.SetCertificate ( filePath, Cryptography::CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            SafeBuffer originalData ( message );
            SafeBuffer signedData;
            SafeBuffer output ( "Empty" );

            pkcs7Signer.signBuffer ( originalData, signedData, Cryptography::PKCS7Base::DER );

            CPPUNIT_ASSERT ( 0 != signedData.GetSize() );
            CPPUNIT_ASSERT ( originalData != signedData );

            signedData.removeData ( 0, 1 );

            CPPUNIT_ASSERT_THROW ( pkcs7Signer.verifyBuffer ( signedData, output,  Cryptography::PKCS7Base::DER ), SignedException );
            CPPUNIT_ASSERT ( 0 == output.GetSize() );
        }

        void testSignWithX509Null ()
        {
            SafeBuffer certificateBuffer ( validPrivateKey_PEM );

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );

            PKCS7Signer pkcs7Signer;
            pkcs7Signer.SetCertificate ( filePath, Cryptography::CertUtil::CertFormat_PEM, correctPrivateKeyPassword );

            SafeBuffer originalData ( message );
            SafeBuffer buffer ( "empty" );

            CPPUNIT_ASSERT_THROW ( pkcs7Signer.signBuffer ( originalData, buffer, Cryptography::PKCS7Base::PEM ), SignedException );
            CPPUNIT_ASSERT ( 0 == buffer.GetSize() );
        }

        void testSignAndVerifyLoadTwoPKEYCertificatesFail ()
        {
            SafeBuffer certificateBufferPrivatePEM ( validPrivateKey_PEM );

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBufferPrivatePEM, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBufferPrivatePEM, true ) );

            SafeBuffer originalData ( message );
            SafeBuffer signedBuffer, outputData;

            PKCS7Signer pkcs7Signer;
            pkcs7Signer.SetCertificate ( filePath, Cryptography::CertUtil::CertFormat_PEM );

            pkcs7Signer.signBuffer ( originalData, signedBuffer, Cryptography::PKCS7Base::SMIME );

            CPPUNIT_ASSERT ( 0 != signedBuffer.GetSize() );
            CPPUNIT_ASSERT ( originalData != signedBuffer );

            pkcs7Signer.SetCertificate ( filePath, Cryptography::CertUtil::CertFormat_PEM, correctPrivateKeyPassword );

            CPPUNIT_ASSERT_THROW ( pkcs7Signer.verifyBuffer ( signedBuffer, outputData, Cryptography::PKCS7Base::SMIME ), SignedException );
            CPPUNIT_ASSERT ( 0 == outputData.GetSize() );
        }

        void testSignAndVerifyLoadTwoCertificatesFail ()
        {
            SafeBuffer certificateBufferPEM ( validCertificate_PEM );

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBufferPEM, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBufferPEM, true ) );

            SafeBuffer originalData ( message );
            SafeBuffer signedBuffer, outputData;

            PKCS7Signer pkcs7Signer;
            pkcs7Signer.SetCertificate ( filePath, Cryptography::CertUtil::CertFormat_PEM );

            pkcs7Signer.signBuffer ( originalData, signedBuffer, Cryptography::PKCS7Base::SMIME );

            CPPUNIT_ASSERT ( 0 != signedBuffer.GetSize() );
            CPPUNIT_ASSERT ( originalData != signedBuffer );

            pkcs7Signer.SetCertificate ( filePath, Cryptography::CertUtil::CertFormat_PEM );

            CPPUNIT_ASSERT_THROW ( pkcs7Signer.verifyBuffer ( signedBuffer, outputData, Cryptography::PKCS7Base::SMIME ), SignedException );
            CPPUNIT_ASSERT ( 0 == outputData.GetSize() );
        }

        void testSign_NullOriginalData ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12, certificateBuffer );

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );

            PKCS7Signer pkcs7Signer;
            pkcs7Signer.SetCertificate ( filePath, Cryptography::CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            SafeBuffer originalData;
            SafeBuffer signedData;
            SafeBuffer output;

            pkcs7Signer.signBuffer ( originalData, signedData, Cryptography::PKCS7Base::SMIME );

            CPPUNIT_ASSERT ( 0 != signedData.GetSize() );
            CPPUNIT_ASSERT ( originalData != signedData );

            pkcs7Signer.verifyBuffer ( signedData, output,  Cryptography::PKCS7Base::SMIME );
            CPPUNIT_ASSERT ( originalData == output );
        }

        CPPUNIT_TEST_SUITE ( PKCS7SignerTest );

        CPPUNIT_TEST ( testSignWithoutCertificate );

        CPPUNIT_TEST ( testSignAndVerifyWithPEM );
        CPPUNIT_TEST ( testSignAndVerifyWithSMIME );
        CPPUNIT_TEST ( testSignAndVerifyWithDER );

        CPPUNIT_TEST ( testSignAndVerifyFailPEM );
        CPPUNIT_TEST ( testSignAndVerifyFailSMIME );
        CPPUNIT_TEST ( testSignAndVerifyFailDER );

        CPPUNIT_TEST ( testSignWithX509Null );

        CPPUNIT_TEST ( testSignAndVerifyLoadTwoPKEYCertificatesFail );
        CPPUNIT_TEST ( testSignAndVerifyLoadTwoCertificatesFail );

        CPPUNIT_TEST ( testSign_NullOriginalData );
        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_TEST_PKCS7SIGNERTEST */
