#ifndef TEST_SIGNED_CLASS_TEST
#define TEST_SIGNED_CLASS_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <System/Security/OpenSSLSecurity.hxx>
#include <System/Security/XmlSecurityC.hxx>
#include <System/Encoding/Base64Encoder.h>
#include <System/Security/Signed.hxx>
#include <System/SafeBuffer.h>
#include <tests/StoreMockFile.hxx>
#include <System/IO/File.h>

using namespace Smartmatic::System;
using namespace Smartmatic::System::IO;
using namespace Smartmatic::System::Exception;
using namespace Smartmatic::System::Encoding;
using namespace Smartmatic::System::Security;
using namespace Smartmatic::System::Security::Cryptography;

static std::string validCertificate_PKCS12_RSA = "MIIJ4QIBAzCCCacGCSqGSIb3DQEHAaCCCZgEggmUMIIJkDCCBo8GCSqGSIb3DQEH"
        "BqCCBoAwggZ8AgEAMIIGdQYJKoZIhvcNAQcBMBwGCiqGSIb3DQEMAQYwDgQIsyAM"
        "Tby61EMCAggAgIIGSNA54zRywSYK7JFdm8Gzfmib0u4oCdZf05yZp/guiXXou7N4"
        "GslmIdVhxtzIiv3XniG3kxWZccv6fs9S77VjyhS+HYi1OsR6TrGWc/sQ+vX+Xa2m"
        "LW2WuZLfjPonKLlY4pmT1saXv46xxgg9PFHiKZ54ao6F0g+24BGP/hXTGYLo9rDy"
        "3/Z6W8E1FX2BuEk1M79zTMMwDkbg5ivO8P9W6tOoMwgOqTnVKuZPmdqjF/BN58By"
        "PiFkBjMuDkRi5RlwhzbQqmd1Fgfq59JTcGrY8uDCcYCzAO7lBZS/bcZy1k9eY1eU"
        "XwUqmlzyszuly2x/0TP+Ycrws/p4hUHKbHeqN+3orxlcJsr/EMwnyipV/VASPjEM"
        "aZ+BKV8Pfr7PlZGyahhfSyHvx3EBFx4ONHTLsg5lzXYCquP41CZRhopgU41Nbu1K"
        "9dz4zC9uUkmA7zloJIbClWigRETS3cqbVUzgbr4wiIfbwdW2XnycAvh8v0GBMcu1"
        "GmWu0hXEEYGXnm30Wr8vxoXoZvfx/Euu0erU+Eo2QH7UL6FfMOYGbKSMzeaRcvnx"
        "gIg1dQkIUThyOYiJ34WELh9QQikJ7iY1uu0nxvWN/X+tH3ufVOIMZ7FFcXH2yLKZ"
        "/f4qFj5JOzKRfbxjB660ccUVXCHJYWeS3eWuRFYEUry6mfmcmXtT2ly2dMBjop2j"
        "t7GFlZBbKelazk9Zn/urrcusZZgaWDZns85ojMqBP9kbnZwBj+LvN3BLSbVhjU5N"
        "Tb2biKaAKhkf2gMO/F/REEs+uzB3vZOg1un0tBcC0enfqynq3wpQV6QDw4n7QIU+"
        "yz9zyif2PQ1IVexau4Me7N9Ot958OSlkVnSwx6rUz5NmAT4wzO7y4HQaJwmp/JDw"
        "EJHMXi5cvekN2ek75a4imk057pNQo4+HuMH1BUZxAIBZ+ylbe8+NjBNzbWDMu6gg"
        "UXTz0B4454ZzJnGO1Qr6neBGGpFQ5DKmmzSZUDCC9TzZG4JuxRzkKPgae66Uugin"
        "xi7F3MnWSI+YAjCow6UGZv/PmCCBVFVxM6ASvS+Y6rPNYOWkn0NfZH+Xb+t/aSAj"
        "3SVs9lPSFZ7q3ng5H0SsXe6cSmAu3UXOt2htM+lypmNduRD18HBaINz6DApu9kQ9"
        "5Q+Q6b27X178VP2ymnStfw0VLAQGFD/LaSpeLU3tW0p+se1jgkL3GEyJ7OhvyeWy"
        "JWTbm3WwtpmUaBTJRyC4AZu/76Uyk72EXYdVSpQXrKFWd3k2ykxyOKFnUOWxtlyX"
        "0AwdUIVooRwTewXzs5+RRtrPd41aTjPhMv7HDIjSHpdhDy5DGj67gWYdKSzJ6Zig"
        "SDCxqqUod5h7paXUFMbPGCPakmIBPdgfraLkK20NXBIzCOrZmBw2EE2oIqQtJ/f6"
        "l1jUUe85iWEVStxlQhgxF1Z9HOjgaWKm8LNjBaq0pPEWHFngIANefHkiibRTA882"
        "MKHuco1bQXYpKat4bKTT6hid1IDojLRo+6FWQptE7qX0WfriUA4Qsr7hmMT10/Kf"
        "bziAHlMIMhCUZvRt7JqR4wyhUq0AWkFA8/aH0FQNs0n6gWO4bUG7KT831XZvr21C"
        "cknButntjTOg0GV8K0EicT90jgY1OawsR4/lRFrMcT+1R9YecCdzpIzqbmLodZG+"
        "ZDrs9XHRNfXpcnz1X6P/8U3aa/x26/ER6bmezznWF60NVrA3u8ACUcymjh2mC+6/"
        "4uQeca8K7v+jvlrjK9jpXEsNPaWfDsTm5Nf39BnmE8WrJTc5BU8GlvarZdWzblSY"
        "JXzi6BlAc/e7u3+NCIlXXlow86upuKxAnGBu142lRe1s2ZnCT/cL2ubab9nHJUUe"
        "CpsW6egPL+rXSVagOHD9d55X8r2USzhTGyVTq6G/wkY1VPAjMfH0+SZ7rbgkCg6z"
        "7wrRuQYWqG5QgtqJ4vXhIZffpyd3TWZhF+iFaXkCZNM48K4CmkpzecmgfgYkIvya"
        "Zqcw8aA0aQARVREnP58xrb2SrdLygpx12jMu6mZiTwxy3BfHmUJUeC15X7Nn7gxH"
        "jXPFsJmuHGKZIa1Wrq3GeImQgFGts/DuynFmV+H/5U6UD9hS4tHvbIbO6cmnyMZ7"
        "x4OkKFvp13nusDiyuzCdQllYx0G06kFzxFuchui23ms0zAp0LjCCAvkGCSqGSIb3"
        "DQEHAaCCAuoEggLmMIIC4jCCAt4GCyqGSIb3DQEMCgECoIICpjCCAqIwHAYKKoZI"
        "hvcNAQwBAzAOBAiwRsjl2i/JBgICCAAEggKAo67L/gzuTYIVlwuVsUF63kISwQ2d"
        "MRwlFQQc5VD9O+lnIksCyZfpcHcSYJGl4AeOy9glAeOn0o13ynkA5oCe1DlemadM"
        "njui44MSLivmNTJleGNqCtoUT88/ADGcGoeOneMCl4yTP42klGZaF2hXoT7tAZkE"
        "vurLAw7VBK7JWT/8tXXFBN2CvNGkyhSQWasfzQUyc44nABsOAprbwGzj7LpOJ4jb"
        "J7FvPcn3lJXR3xPdDNWTg8nLxiALpJMoB0vPFanyxDmhG8LdhxA8E0kOBacF9c9v"
        "165RxCIA/9M1ri1/H7iDpeCwjSPb+yyZTPGEsyuQQdjBiph6YXPQcBs17TkGgjIm"
        "TjKJnnubyKSf2CryfOHlvBTHN84XUzasqkRNMPyk4mhboJCBZ0sduxYnLmbcwBAW"
        "aXdxiGGnhenfnHYZ9NWDeiYXofHn+UZrqjfE3xWxg70h//Nj6ISu9s6u6YR343vB"
        "ivi8UFJu3kpwXkm1yZLtgZb64QH4VvGXE5H/vLVtedRThqq6kSGwKcKJCl31VrF9"
        "Xy+7u4t9amQVpVDIq9IEpwGzqpGxNSpVavUSmzfTbiAwZtkdCgPd2W0lrXSbznxo"
        "RqpQmnejBwy5jUkM6IPn3DovMUWpoxZt2klj286ZqJM7iF11y9H9S0aOt3W88Ulp"
        "sqvA9C0Jp6N3+OftZg4+pJX/MZrfBt0Yk27tA5AzT4AbxmOtKdLtnjMiK0UteTsu"
        "SeriPybTxXJyExR5WAhHU5K5MuURZGpn+dN2viwEwSdMbPGxJijCpnCqdf0iaJWI"
        "DbP8L+x7QUH81sIBZpDXC13hQMjnBOyru71H5tYzPhrvisuxLudqqwi8wzElMCMG"
        "CSqGSIb3DQEJFTEWBBS2X3q5lo9YxXfYjtyJLisz+f5mKTAxMCEwCQYFKw4DAhoF"
        "AAQUd9qIdcVDXDs3XI/8DniFdZhZKpYECGXJksfazXjZAgIIAA==";

static std::string validCertificate_PKCS12_ECDSA = "MIIHuQIBAzCCB38GCSqGSIb3DQEHAaCCB3AEggdsMIIHaDCCBmcGCSqGSIb3DQEH"
        "BqCCBlgwggZUAgEAMIIGTQYJKoZIhvcNAQcBMBwGCiqGSIb3DQEMAQYwDgQIYhAP"
        "kpYTnNICAggAgIIGIIz1W7Bul+oUKmk5PBY7HzbeVuU8BOvjMp9G+trPHjX9Cruk"
        "7JJyNrLVmFbqPpY799k1+36zIPq7oFxMWsW0F+/DqIpsj45/ZC1UMC58RThUFMt4"
        "MPkOJ6NpmT3fhit1zuVfhWy+nTEExmcpARvx7Kke/bVnDhc96vWUQGuLisOZMZA6"
        "mZa4gWbIF1VCv3iQ3oWtMgH8uYKDNRVasHWk43Cq9XlrrNWPzKL/w1zrDEXgVu3V"
        "qAYWUNqii+tpgG1QK61GtzBvcxmabKjn9uL7KbNU2y0lWzaTXBZAd80rYp1DclAr"
        "paHIj7tv2l6McTOvAjLv7sO4FtWJSKwHLegRY/I8xqQSaCniv7ztROLlOCeciYcY"
        "cwFabM/hckaQWpGQl1z60vxiMJbQCoPPeIV+DlTf66fBWlDmab99vCRX27lvmf9n"
        "yfItjrWvyySIulyv9oJ2Ng/Pogc5KUwoAOzfC57qmmPm/zBQ82qCI36K2mlgx1PB"
        "xtPgLfrROlasx8uKA9QoZChJBXGXOOpmaN8m+Y++hFEBznT01Rilz36cVTPp2FvI"
        "V6OHMwfIqfzjQY/THnSFh65LVt+EA6H5WgBfIodM/f4aZQkJXa5usUDGw4cczzxE"
        "agLUDNErxkG8NWGo7F0juFvkZ1iQP76P2FUT+zV6HonFjTwG+T/mWQ0CZvUEXrRU"
        "jBSqeVhsmkVbb+YWpmtWgMB91yqrGY9Jycfc/6AOTFUMmY5gQwg0Nlem8NhBA9h7"
        "wpQASdtP8WSC+f448pEVg9/DZ/lPW7cAHtpoSimHz6mW/oDIvEoqfFkerx+akP2D"
        "Uueja5+TBjya5afETUyMq9PvXz/F/J/PhJ5Xt0ZEeJ1C6tBR9Xrfx1Qz6P0fssCW"
        "FVPtMMOUbQF/lU0mGVLETPMtCbytz/xIKZ+24J6226P8Np/0ubqgo0UFdEt2HDSO"
        "mfAHK8W3XbIAOlIXHJdXoIbRkY4279etLxXJf74NKDg7jjlFLHNJxDcF94fnNhyv"
        "chr9lnqAxtMMVZch2UgNCY8cxV6Ep8Ong/DFsORuRQjfJm0lI3kCCTe1bM/VfYZs"
        "RB43fOploShPPDaHH+r2cIInIFrBQWTWsw2bVROMcTpG61n2SJwtTS06n6SXlCFz"
        "KAGJgu+CXtL6Sg+9UCvc3KW54q8ualso45vvaEDEqtWNhYyQ9DQUudw2UlQsxfad"
        "PARBd0rnEpwx5JR2ulCsAM0UvOlhh6IdZQvJ1fQrY7wOhcvcgYf2X4RqbbDIeOMJ"
        "LLFArcqSvdXlO1o2eqBYrjEre0iQCKN5T5J2euY26V8UZ8m30MLPPuCNoFlQS529"
        "A8bHB0OZUFGrWYMppm5+UaonSOkrzoq5TfOhpuIGT45Ig7eddzuSJtDmpMjquDJG"
        "zyONxfebhu69k/QO5kK3tZ2pMiIAMJ58PRVXrKdKufuECNLWSNxdhBY6XhkydlgB"
        "7ALpYzHe3r7isWy9zQ2K4xDka4U9brDlmR78Y9KWEF0Cj9HlfH4krML2sG0nNyZO"
        "ugtQszrD5yhxz12249yFs5ysgeILckFuULjAlVkhbHJZTW5kLyEp6ULreY4RaY5U"
        "lcbcEnMg/xR2XgwlEofKUeUfB1T4kTSehaGxF5hQ32JXpnBkwtHVglIhljJM602I"
        "sE5xGPqOzKpG1C1Mu2hS2xcYBlDOFPDeCCgzucAIsx7nV5fXisjJrvGz0lods/il"
        "TASx1hRhivdRq7ghuUQI+lnLfl61jJ9MBkn4yzXogP04YLKPfUuLGoYHFfMiMzBz"
        "AEov+Cx6n8TQ3I3aDrIoRJ3ZEcPFwxUeCCLGeHdwIBUgCz/Ng4zhNeo/Nt1rKWUi"
        "AwHYraeFvdgrMTL8QA+LXmVAaUN4LhlaMV9KPHXxRFC5W2efOAZjRFJQC9fFSiIu"
        "DXVbDlPhkPnGOnYYQv5OUypNEjiaPQeH05Zr3AxFP4kdNJtkwc8gNAfyfBYQvfse"
        "tZA/Jh2CHXBm7YUJrIYMqHhO3UoCGmCuUnT84HJ7v8gnKeoXZ+AI4nr8JaUsebVE"
        "KfCEZo5rayqMibdSFNXmCVj1bTICwkYKIIecYK+K2WUYEq2kGipp/IyNLiFXMIH6"
        "BgkqhkiG9w0BBwGggewEgekwgeYwgeMGCyqGSIb3DQEMCgECoIGsMIGpMBwGCiqG"
        "SIb3DQEMAQMwDgQID4BJRkx9axMCAggABIGIlH1bwUIEFkYdbZ8Yo9TUsjz9kYKm"
        "XUCCaOlF5PbVm0lY4WLnlOoZm56wKcX9S5DHfmJYhP/CHmn/RanZcIFcBnPGVeET"
        "eN/3TLkuHFh3hq8dKa9MeeD7hGLZEUIhz95VwjD9CCLMB9yW0q5qxQ7dg8k5MMsK"
        "xdoAMg1bcIyBi9hCEtKi6hd0jTElMCMGCSqGSIb3DQEJFTEWBBQ7/S4jA1/ZL82M"
        "loYcuZUFk1imOzAxMCEwCQYFKw4DAhoFAAQUiaevcD0CpJWLOEQYnDq2xOmxzI8E"
        "COv0N34207SUAgIIAA==";

static std::string validCertified_DER = "MIIC9zCCAmCgAwIBAgICEAMwDQYJKoZIhvcNAQEEBQAweTELMAkGA1UEBhMCQkUx"
                                        "ETAPBgNVBAgTCEJydXNzZWxzMRIwEAYDVQQHEwlFdHRlcmJlZWsxEzARBgNVBAoT"
                                        "ClNtYXJ0bWF0aWMxHDAaBgNVBAsTE0VsZWN0b3JhbCBTb2x1dGlvbnMxEDAOBgNV"
                                        "BAMTB1JPT1QgQ0EwIBcNMTMxMjMwMTUxMjUzWhgPMjExMjA3MjQxNTEyNTNaMIGJ"
                                        "MQswCQYDVQQGEwJCRTERMA8GA1UECBMIQnJ1c3NlbHMxEzARBgNVBAoTClNtYXJ0"
                                        "bWF0aWMxHDAaBgNVBAsTE0VsZWN0b3JhbCBTb2x1dGlvbnMxDzANBgNVBAMTBlVz"
                                        "ZXIgMjEjMCEGCSqGSIb3DQEJARYUdXNlcjJAc21hcnRtYXRpYy5jb20wgZ8wDQYJ"
                                        "KoZIhvcNAQEBBQADgY0AMIGJAoGBAM2ew78JzhX3GocanVAxqiv0pPcKjUPhtFpD"
                                        "S2uI12SNIyNQqszPXF51euV5g8If308PVhM59Vpk+APR1vqfjrYvVuMJCBFI5IFu"
                                        "HFh0uhqArqL6LoKc2zs5xTbrl+ueyzZkCOLdmoolgaSzas+qbLGeO86ub5qXROTw"
                                        "xj6ijfmNAgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8WHU9wZW5T"
                                        "U0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBTSCgQsgLAejEx7mR5g"
                                        "IRy6irmcBDAfBgNVHSMEGDAWgBSkK16P6n6Mm/Bx4DBAW81buzO8pzANBgkqhkiG"
                                        "9w0BAQQFAAOBgQCG6JPAyVrFc5/mTYIlY9/aIitOET7N14WoArAApwql7rwzPwgw"
                                        "slWSXI+SnVtiKPOSW75H01o0a1FjmA6jnc0fnoS/miCNPwPZCUw01VJK5+UTCz4+"
                                        "xjiljHFMKWIshq9FCYPoYzhAhW+dX9zsW+hUppJ8LLHIlTgXOPgP3NCFGA==";

static std::string correctPasswordPKCS12 = "passwordpkcs12";
static std::string validDomXml = "<node>Hello</node>";

class SignedClassTest : public CPPUNIT_NS::TestFixture
{
    public:

        Signed * manager;

        SignedClassTest()
        {
            manager = NULL;
        }

        void setUp()
        {
            Smartmatic::System::Security::OpenSSLSecurity::init();
            Smartmatic::System::Security::XmlSecurityC::init();
            manager = new Signed();
        }

        void tearDown()
        {
            Smartmatic::System::Security::OpenSSLSecurity::clear();
            Smartmatic::System::Security::XmlSecurityC::clear();
            delete manager;
        }

        void testSignWithoutCertificate ()
        {
            SafeBuffer bufferIn ( validDomXml );
            SafeBuffer bufferOut;

            CPPUNIT_ASSERT_THROW (
                manager->signBuffer ( bufferIn, bufferOut, Signed::FULL_SIGNED ),
                SignedException );
        }

        void testSignNotValidPrivateKey ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertified_DER, certificateBuffer );

            SafeBuffer bufferIn ( validDomXml );
            SafeBuffer bufferOut;

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );

            manager->SetCertificate ( "file", CertUtil::CertFormat_DER );

            CPPUNIT_ASSERT_THROW (
                manager->signBuffer ( bufferIn, bufferOut, Signed::FULL_SIGNED ),
                SignedException );
        }

        void testSignAndValidateBufferWithRSA ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12_RSA, certificateBuffer );

            SafeBuffer bufferIn ( validDomXml );
            SafeBuffer bufferOut;

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );

            manager->SetCertificate ( "file", CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );
            manager->signBuffer ( bufferIn, bufferOut, Signed::FULL_SIGNED );

            CPPUNIT_ASSERT ( 0 != bufferOut.GetSize() );

            bool result = manager->verifyBuffer ( bufferOut );
            CPPUNIT_ASSERT ( true == result );
        }

        void testSignAndValidateBufferWithECDSA ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12_ECDSA, certificateBuffer );

            SafeBuffer bufferIn ( validDomXml );
            SafeBuffer bufferOut;

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );

            manager->SetCertificate ( "file", CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );
            manager->signBuffer ( bufferIn, bufferOut, Signed::FULL_SIGNED );

            CPPUNIT_ASSERT ( 0 != bufferOut.GetSize() );

            bool result = manager->verifyBuffer ( bufferOut );
            CPPUNIT_ASSERT ( true == result );
        }

        void testSignAndValidateWrongBuffer ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12_RSA, certificateBuffer );

            SafeBuffer bufferIn ( validDomXml );
            SafeBuffer bufferOut;

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );

            manager->SetCertificate ( "file", CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );
            manager->signBuffer ( bufferIn, bufferOut, Signed::FULL_SIGNED );

            CPPUNIT_ASSERT ( 0 != bufferOut.GetSize() );

            CPPUNIT_ASSERT_THROW (
                manager->verifyBuffer ( SafeBuffer ( "><wrong" ) ),
                SignedException );
        }

        void testSignAndValidateEmptyBuffer ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12_RSA, certificateBuffer );

            SafeBuffer bufferIn ( validDomXml );
            SafeBuffer bufferOut;

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );

            manager->SetCertificate ( "file", CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );
            manager->signBuffer ( bufferIn, bufferOut, Signed::FULL_SIGNED );

            CPPUNIT_ASSERT ( 0 != bufferOut.GetSize() );

            CPPUNIT_ASSERT_THROW (
                manager->verifyBuffer ( SafeBuffer() ),
                SignedException );
        }

        void testFullSignedAndValidateWithoutCertificate ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12_RSA, certificateBuffer );

            SafeBuffer bufferIn ( validDomXml );
            SafeBuffer bufferOut;

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer(), true ) );

            manager->SetCertificate ( "file", CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );
            manager->signBuffer ( bufferIn, bufferOut, Signed::FULL_SIGNED );

            CPPUNIT_ASSERT ( 0 != bufferOut.GetSize() );

            manager->SetCertificate ( "file", CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            bool result = manager->verifyBuffer ( bufferOut );
            CPPUNIT_ASSERT ( true == result );
        }

        void testSimpleSignedAndValidateWithoutCertificate ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12_RSA, certificateBuffer );

            SafeBuffer bufferIn ( validDomXml );
            SafeBuffer bufferOut;

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer(), true ) );

            manager->SetCertificate ( "file", CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );
            manager->signBuffer ( bufferIn, bufferOut, Signed::SIMPLE_SIGNED );

            CPPUNIT_ASSERT ( 0 != bufferOut.GetSize() );

            manager->SetCertificate ( "file", CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            CPPUNIT_ASSERT_THROW (
                manager->verifyBuffer ( bufferOut ),
                SignedException );
        }

        void testNotSignedAndValidateWithoutCertificate ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12_RSA, certificateBuffer );

            SafeBuffer bufferIn ( validDomXml );
            SafeBuffer bufferOut;

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer(), true ) );

            manager->SetCertificate ( "file", CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );
            manager->signBuffer ( bufferIn, bufferOut, Signed::NOT_SIGNED );

            CPPUNIT_ASSERT ( 0 != bufferOut.GetSize() );

            manager->SetCertificate ( "file", CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            CPPUNIT_ASSERT_THROW (
                manager->verifyBuffer ( bufferOut ),
                SignedException );
        }

        CPPUNIT_TEST_SUITE ( SignedClassTest );

        CPPUNIT_TEST ( testSignWithoutCertificate );
        CPPUNIT_TEST ( testSignNotValidPrivateKey );
        CPPUNIT_TEST ( testSignAndValidateBufferWithRSA );
        CPPUNIT_TEST ( testSignAndValidateBufferWithECDSA );
        CPPUNIT_TEST ( testSignAndValidateWrongBuffer );
        CPPUNIT_TEST ( testSignAndValidateEmptyBuffer );
        CPPUNIT_TEST ( testFullSignedAndValidateWithoutCertificate );
        CPPUNIT_TEST ( testSimpleSignedAndValidateWithoutCertificate );
        CPPUNIT_TEST ( testNotSignedAndValidateWithoutCertificate );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_SIGNED_CLASS_TEST */
