#ifndef TEST_BEEP_MANAGER_TEST
#define TEST_BEEP_MANAGER_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <System/Sounds/beep-manager.h>
#include <tests/MockProcessLauncher.hxx>
#include <tests/StoreMockProcessLauncher.hxx>

class BeepManagerTest : public CPPUNIT_NS::TestFixture
{
    public:

        typedef Smartmatic::System::Sounds::BeepManager BeepManager;
        typedef Smartmatic::System::Sounds::BeepDescriptor BeepDescriptor;
        typedef Smartmatic::System::Runtime::ProcessLauncher ProcessLauncher;

        BeepManagerTest()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testEmptyBeepManager()
        {
            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() );

            BeepManager beep;
            beep.Beep();

            launcher.verify();
        }

        void testBeepManagerProcessOneBeep()
        {
            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<int> ( 0 ) );

            BeepManager beep;

            beep.AddBeep ( BeepDescriptor () );

            beep.Beep();

            launcher.verify();
        }

        void testBeepManagerProcessTwoBeep()
        {
            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<int> ( 0 ) );

            BeepManager beep;

            beep.AddBeep ( BeepDescriptor () );
            beep.AddBeep ( BeepDescriptor () );

            beep.Beep();

            launcher.verify();
        }

        void testBeepManagerProcessClear()
        {
            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() );

            BeepManager beep;
            beep.Clear();
            beep.Beep();

            launcher.verify();
        }

        void testBeepManagerProcessAddAndClearTwoBeep()
        {
            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() );

            BeepManager beep;

            beep.AddBeep ( BeepDescriptor () );
            beep.AddBeep ( BeepDescriptor () );

            beep.Clear();
            beep.Beep();

            launcher.verify();
        }

        void testBeepManagerProcessStop()
        {
            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<int> ( 0 ) );

            BeepManager beep;
            beep.Stop();

            launcher.verify();
        }

        void testBeepManagerOneBeep()
        {
            StoreMockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );
            std::string expected = "beep -f 0 -l 0 -r 0 -d 0";

            BeepManager beep;
            beep.AddBeep ( BeepDescriptor () );
            beep.Beep();

            CPPUNIT_ASSERT ( 0 == expected.compare ( launcher.RunProcessThroughSystemCommandLine ) );
            CPPUNIT_ASSERT ( true == launcher.RunProcessThroughSystemBackground );
        }

        void testBeepManagerTwoBeep()
        {
            StoreMockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );
            std::string expected = "beep -f 0 -l 0 -r 0 -d 0 -n -f 1 -l 2 -r 3 -d 4 -n -f 10 -l 20 -r 30 -d 40";

            BeepManager beep;
            beep.AddBeep ( BeepDescriptor () );
            beep.AddBeep ( BeepDescriptor ( 1, 2, 3, 4 ) );
            beep.AddBeep ( BeepDescriptor ( 10, 20, 30, 40 ) );
            beep.Beep();

            CPPUNIT_ASSERT ( 0 == expected.compare ( launcher.RunProcessThroughSystemCommandLine ) );
            CPPUNIT_ASSERT ( true == launcher.RunProcessThroughSystemBackground );
        }

        void testBeepManagerProcessStopCommand()
        {
            StoreMockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );
            std::string expected = "pkill -9 beep";

            BeepManager beep;
            beep.Stop();

            CPPUNIT_ASSERT ( 0 == expected.compare ( launcher.RunProcessThroughSystemCommandLine ) );
            CPPUNIT_ASSERT ( true == launcher.RunProcessThroughSystemBackground );
        }

        CPPUNIT_TEST_SUITE ( BeepManagerTest );

        CPPUNIT_TEST ( testEmptyBeepManager );
        CPPUNIT_TEST ( testBeepManagerProcessOneBeep );
        CPPUNIT_TEST ( testBeepManagerProcessTwoBeep );
        CPPUNIT_TEST ( testBeepManagerProcessClear );
        CPPUNIT_TEST ( testBeepManagerProcessAddAndClearTwoBeep );
        CPPUNIT_TEST ( testBeepManagerProcessStop );

        CPPUNIT_TEST ( testBeepManagerOneBeep );
        CPPUNIT_TEST ( testBeepManagerTwoBeep );
        CPPUNIT_TEST ( testBeepManagerProcessStopCommand );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_BEEP_MANAGER_TEST */
