#ifndef TEST_SOUND_MANAGER_TEST
#define TEST_SOUND_MANAGER_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <System/Sounds/smartmatic-sounds-manager.h>
#include <tests/MockSmttSoundConfigurationManager.hxx>
#include <tests/MockProcessLauncher.hxx>
#include <tests/MockFile.hxx>
#include <tests/MockResourcePathProvider.hxx>
#include <tests/StoreMockProcessLauncher.hxx>

class SmttSoundManagerTest : public CPPUNIT_NS::TestFixture
{
    public:

        typedef Smartmatic::Configuration::SmartmaticSoundConfManager SmartmaticSoundConfManager;
        typedef Smartmatic::System::Sounds::SMTTSoundsManager SMTTSoundsManager;
        typedef Smartmatic::System::Runtime::ProcessLauncher ProcessLauncher;
        typedef Smartmatic::System::Sounds::BeepDescriptor BeepDescriptor;
        typedef Smartmatic::System::IO::File File;
        typedef Smartmatic::Environment::ResourcePathProvider ResourcePathProvider;
        typedef Smartmatic::System::SafeVector<BeepDescriptor> BeepDescriptorVector;

        SMTTSoundsManager * soundManager;

        SmttSoundManagerTest()
        {
            soundManager = NULL;
        }

        void setUp()
        {
            soundManager = SMTTSoundsManager::getInstance();
        }

        void tearDown()
        {
            delete soundManager;
            soundManager = NULL;
        }

        void testOverwriteUseBeepTrue()
        {
            MockSmttSoundConfigurationManager confManager;
            SmartmaticSoundConfManager::getInstance ( &confManager );

            MOCKPP_CHAINER_FOR ( MockSmttSoundConfigurationManager, isUsingBeep ) isUsingBeep_mock ( &confManager );

            isUsingBeep_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) );

            CPPUNIT_ASSERT ( true == SmartmaticSoundConfManager::getInstance()->isUsingBeep() );

            confManager.verify();
        }

        void testOverwriteUseBeepFalse()
        {
            MockSmttSoundConfigurationManager confManager;
            SmartmaticSoundConfManager::getInstance ( &confManager );

            MOCKPP_CHAINER_FOR ( MockSmttSoundConfigurationManager, isUsingBeep ) isUsingBeep_mock ( &confManager );

            isUsingBeep_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) );

            CPPUNIT_ASSERT ( false == SmartmaticSoundConfManager::getInstance()->isUsingBeep() );

            confManager.verify();
        }

        void testOverwriteGetAppSound()
        {
            MockSmttSoundConfigurationManager confManager;
            SmartmaticSoundConfManager::getInstance ( &confManager );

            MOCKPP_CHAINER_FOR ( MockSmttSoundConfigurationManager, getAppSound ) getAppSound_mock ( &confManager );

            getAppSound_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "mplayer" ) );

            CPPUNIT_ASSERT ( "mplayer" == SmartmaticSoundConfManager::getInstance()->getAppSound() );

            confManager.verify();
        }

        void testOverwriteGetSoundFile()
        {
            MockSmttSoundConfigurationManager confManager;
            SmartmaticSoundConfManager::getInstance ( &confManager );

            MOCKPP_CHAINER_FOR_EXT ( MockSmttSoundConfigurationManager, getSoundFile, ext ) getSoundFile_mock ( &confManager );

            getSoundFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "file.wav" ) );

            CPPUNIT_ASSERT ( "file.wav" == SmartmaticSoundConfManager::getInstance()->getSoundFile ( "SoundConfig" ) );

            confManager.verify();
        }

        void testSmttSoundManagerUseBeepAndNotSound()
        {
            BeepDescriptorVector vector;

            MockSmttSoundConfigurationManager confManager;
            SmartmaticSoundConfManager::getInstance ( &confManager );

            MOCKPP_CHAINER_FOR ( MockSmttSoundConfigurationManager, isUsingBeep ) isUsingBeep_mock ( &confManager );
            MOCKPP_CHAINER_FOR_EXT ( MockSmttSoundConfigurationManager, getSoundConfiguration, ext ) getSoundConfiguration_mock ( &confManager );

            isUsingBeep_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) );

            getSoundConfiguration_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub< BeepDescriptorVector > ( vector ) );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() )
            .will ( MOCKPP_NS::returnValue<int> ( 0 ) );

            soundManager->Sound ( "SoundConf" );

            confManager.verify();
            launcher.verify();
        }

        void testSmttSoundManagerUseBeepAndSound()
        {
            BeepDescriptorVector vector;
            vector.push_back ( BeepDescriptor ( 1, 2, 3, 4 ) );

            MockSmttSoundConfigurationManager confManager;
            SmartmaticSoundConfManager::getInstance ( &confManager );

            MOCKPP_CHAINER_FOR ( MockSmttSoundConfigurationManager, isUsingBeep ) isUsingBeep_mock ( &confManager );
            MOCKPP_CHAINER_FOR_EXT ( MockSmttSoundConfigurationManager, getSoundConfiguration, ext ) getSoundConfiguration_mock ( &confManager );

            isUsingBeep_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) );

            getSoundConfiguration_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub< BeepDescriptorVector > ( vector ) );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<int> ( 0 ) );

            soundManager->Sound ( "SoundConf" );

            confManager.verify();
            launcher.verify();
        }

        void testSmttSoundManagerUseBeep_And_OneSound_CommanLine()
        {
            BeepDescriptorVector vector;
            vector.push_back ( BeepDescriptor ( 1, 2, 3, 4 ) );

            MockSmttSoundConfigurationManager confManager;
            SmartmaticSoundConfManager::getInstance ( &confManager );

            MOCKPP_CHAINER_FOR ( MockSmttSoundConfigurationManager, isUsingBeep ) isUsingBeep_mock ( &confManager );
            MOCKPP_CHAINER_FOR_EXT ( MockSmttSoundConfigurationManager, getSoundConfiguration, ext ) getSoundConfiguration_mock ( &confManager );

            isUsingBeep_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) );

            getSoundConfiguration_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub< BeepDescriptorVector > ( vector ) );

            StoreMockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            soundManager->Sound ( "SoundConf" );

            CPPUNIT_ASSERT ( "beep -f 1 -l 2 -r 3 -d 4" == launcher.RunProcessThroughSystemCommandLine );

            confManager.verify();
        }

        void testSmttSoundManagerUseBeep_And_TwoSound_CommanLine()
        {
            BeepDescriptorVector vector;
            vector.push_back ( BeepDescriptor ( 1, 2, 3, 4 ) );
            vector.push_back ( BeepDescriptor ( 10, 20, 30, 40 ) );

            MockSmttSoundConfigurationManager confManager;
            SmartmaticSoundConfManager::getInstance ( &confManager );

            MOCKPP_CHAINER_FOR ( MockSmttSoundConfigurationManager, isUsingBeep ) isUsingBeep_mock ( &confManager );
            MOCKPP_CHAINER_FOR_EXT ( MockSmttSoundConfigurationManager, getSoundConfiguration, ext ) getSoundConfiguration_mock ( &confManager );

            isUsingBeep_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) );

            getSoundConfiguration_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub< BeepDescriptorVector > ( vector ) );

            StoreMockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            soundManager->Sound ( "SoundConf" );

            CPPUNIT_ASSERT ( "beep -f 1 -l 2 -r 3 -d 4 -n -f 10 -l 20 -r 30 -d 40" == launcher.RunProcessThroughSystemCommandLine );
            CPPUNIT_ASSERT ( true == launcher.RunProcessThroughSystemBackground );

            confManager.verify();
        }

        void testSmttSoundManagerNotUseBeepAndFileSoundNotFound()
        {
            MockSmttSoundConfigurationManager confManager;
            SmartmaticSoundConfManager::getInstance ( &confManager );

            MOCKPP_CHAINER_FOR ( MockSmttSoundConfigurationManager, isUsingBeep ) isUsingBeep_mock ( &confManager );
            MOCKPP_CHAINER_FOR_EXT ( MockSmttSoundConfigurationManager, getSoundFile, ext ) getSoundFile_mock ( &confManager );
            MOCKPP_CHAINER_FOR ( MockSmttSoundConfigurationManager, getAppSound ) getAppSound_mock ( &confManager );

            isUsingBeep_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) );

            getSoundFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "file.wav" ) );

            getAppSound_mock
            .expects ( MOCKPP_NS::never() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "mplayer" ) );

            MockResourcePathProvider resource;
            ResourcePathProvider::getInstance ( &resource );

            MOCKPP_CHAINER_FOR_EXT ( MockResourcePathProvider, GetResourcePath, ext ) GetResourcePath_mock ( &resource );

            GetResourcePath_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "path" ) );

            MockFile file;
            File::getInstance ( &file );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &file );

            canOpenFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() )
            .will ( MOCKPP_NS::returnValue<int> ( 0 ) );

            soundManager->Sound ( "SoundConf" );

            confManager.verify();
            launcher.verify();
            resource.verify();
            file.verify();
        }

        void testSmttSoundManagerNotUseBeepAndFileSoundFound()
        {
            MockSmttSoundConfigurationManager confManager;
            SmartmaticSoundConfManager::getInstance ( &confManager );

            MOCKPP_CHAINER_FOR ( MockSmttSoundConfigurationManager, isUsingBeep ) isUsingBeep_mock ( &confManager );
            MOCKPP_CHAINER_FOR_EXT ( MockSmttSoundConfigurationManager, getSoundFile, ext ) getSoundFile_mock ( &confManager );
            MOCKPP_CHAINER_FOR ( MockSmttSoundConfigurationManager, getAppSound ) getAppSound_mock ( &confManager );

            isUsingBeep_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) );

            getSoundFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "file.wav" ) );

            getAppSound_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "mplayer" ) );

            MockResourcePathProvider resource;
            ResourcePathProvider::getInstance ( &resource );

            MOCKPP_CHAINER_FOR_EXT ( MockResourcePathProvider, GetResourcePath, ext ) GetResourcePath_mock ( &resource );

            GetResourcePath_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "path" ) );

            MockFile file;
            File::getInstance ( &file );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &file );

            canOpenFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<int> ( 0 ) );

            soundManager->Sound ( "SoundConf" );

            confManager.verify();
            launcher.verify();
            resource.verify();
            file.verify();
        }

        void testSmttSoundManagerNotUseBeepCommandLine()
        {
            MockSmttSoundConfigurationManager confManager;
            SmartmaticSoundConfManager::getInstance ( &confManager );

            MOCKPP_CHAINER_FOR ( MockSmttSoundConfigurationManager, isUsingBeep ) isUsingBeep_mock ( &confManager );
            MOCKPP_CHAINER_FOR_EXT ( MockSmttSoundConfigurationManager, getSoundFile, ext ) getSoundFile_mock ( &confManager );
            MOCKPP_CHAINER_FOR ( MockSmttSoundConfigurationManager, getAppSound ) getAppSound_mock ( &confManager );

            isUsingBeep_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) );

            getSoundFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "file.wav" ) );

            getAppSound_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "mplayer" ) );

            MockResourcePathProvider resource;
            ResourcePathProvider::getInstance ( &resource );

            MOCKPP_CHAINER_FOR_EXT ( MockResourcePathProvider, GetResourcePath, ext ) GetResourcePath_mock ( &resource );

            GetResourcePath_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "path" ) );

            MockFile file;
            File::getInstance ( &file );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &file );

            canOpenFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) );

            StoreMockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            soundManager->Sound ( "SoundConf" );

            CPPUNIT_ASSERT ( "mplayer path" == launcher.RunProcessThroughSystemCommandLine );
            CPPUNIT_ASSERT ( true == launcher.RunProcessThroughSystemBackground );

            confManager.verify();
            resource.verify();
            file.verify();
        }

        void testStopWithoutApplicationSound()
        {
            MockSmttSoundConfigurationManager confManager;
            SmartmaticSoundConfManager::getInstance ( &confManager );

            MOCKPP_CHAINER_FOR ( MockSmttSoundConfigurationManager, isUsingBeep ) isUsingBeep_mock ( &confManager );
            MOCKPP_CHAINER_FOR_EXT ( MockSmttSoundConfigurationManager, getSoundFile, ext ) getSoundFile_mock ( &confManager );
            MOCKPP_CHAINER_FOR ( MockSmttSoundConfigurationManager, getAppSound ) getAppSound_mock ( &confManager );

            isUsingBeep_mock
            .expects ( MOCKPP_NS::never() )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) );

            getSoundFile_mock
            .expects ( MOCKPP_NS::never() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "file.wav" ) );

            getAppSound_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "" ) );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<int> ( 0 ) );

            soundManager->Stop();

            confManager.verify();
            launcher.verify();
        }

        void testStopWithoutApplicationSoundCommandLine()
        {
            MockSmttSoundConfigurationManager confManager;
            SmartmaticSoundConfManager::getInstance ( &confManager );

            MOCKPP_CHAINER_FOR ( MockSmttSoundConfigurationManager, isUsingBeep ) isUsingBeep_mock ( &confManager );
            MOCKPP_CHAINER_FOR_EXT ( MockSmttSoundConfigurationManager, getSoundFile, ext ) getSoundFile_mock ( &confManager );
            MOCKPP_CHAINER_FOR ( MockSmttSoundConfigurationManager, getAppSound ) getAppSound_mock ( &confManager );

            isUsingBeep_mock
            .expects ( MOCKPP_NS::never() )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) );

            getSoundFile_mock
            .expects ( MOCKPP_NS::never() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "file.wav" ) );

            getAppSound_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "" ) );

            StoreMockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            soundManager->Stop();

            CPPUNIT_ASSERT ( "pkill -9 beep" == launcher.RunProcessThroughSystemCommandLine );
            CPPUNIT_ASSERT ( true == launcher.RunProcessThroughSystemBackground );

            confManager.verify();
        }

        void testStopWithApplicationSound()
        {
            MockSmttSoundConfigurationManager confManager;
            SmartmaticSoundConfManager::getInstance ( &confManager );

            MOCKPP_CHAINER_FOR ( MockSmttSoundConfigurationManager, isUsingBeep ) isUsingBeep_mock ( &confManager );
            MOCKPP_CHAINER_FOR_EXT ( MockSmttSoundConfigurationManager, getSoundFile, ext ) getSoundFile_mock ( &confManager );
            MOCKPP_CHAINER_FOR ( MockSmttSoundConfigurationManager, getAppSound ) getAppSound_mock ( &confManager );

            isUsingBeep_mock
            .expects ( MOCKPP_NS::never() )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) );

            getSoundFile_mock
            .expects ( MOCKPP_NS::never() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "file.wav" ) );

            getAppSound_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "mplayer" ) );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::exactly ( 2 ) )
            .will ( MOCKPP_NS::returnValue<int> ( 0 ) );

            soundManager->Stop();

            confManager.verify();
            launcher.verify();
        }

        void testStopWithApplicationSoundCommandLine()
        {
            MockSmttSoundConfigurationManager confManager;
            SmartmaticSoundConfManager::getInstance ( &confManager );

            MOCKPP_CHAINER_FOR ( MockSmttSoundConfigurationManager, isUsingBeep ) isUsingBeep_mock ( &confManager );
            MOCKPP_CHAINER_FOR_EXT ( MockSmttSoundConfigurationManager, getSoundFile, ext ) getSoundFile_mock ( &confManager );
            MOCKPP_CHAINER_FOR ( MockSmttSoundConfigurationManager, getAppSound ) getAppSound_mock ( &confManager );

            isUsingBeep_mock
            .expects ( MOCKPP_NS::never() )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) );

            getSoundFile_mock
            .expects ( MOCKPP_NS::never() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "file.wav" ) );

            getAppSound_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "aplay -q" ) );

            StoreMockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            soundManager->Stop();

            CPPUNIT_ASSERT ( "pkill -9 aplay" == launcher.RunProcessThroughSystemCommandLine );
            CPPUNIT_ASSERT ( false == launcher.RunProcessThroughSystemBackground );

            confManager.verify();
        }

        CPPUNIT_TEST_SUITE ( SmttSoundManagerTest );

        CPPUNIT_TEST ( testOverwriteUseBeepTrue );
        CPPUNIT_TEST ( testOverwriteUseBeepFalse );
        CPPUNIT_TEST ( testOverwriteGetAppSound );
        CPPUNIT_TEST ( testOverwriteGetSoundFile );

        CPPUNIT_TEST ( testSmttSoundManagerUseBeepAndNotSound );
        CPPUNIT_TEST ( testSmttSoundManagerUseBeepAndSound );

        CPPUNIT_TEST ( testSmttSoundManagerUseBeep_And_OneSound_CommanLine );
        CPPUNIT_TEST ( testSmttSoundManagerUseBeep_And_TwoSound_CommanLine );

        CPPUNIT_TEST ( testSmttSoundManagerNotUseBeepAndFileSoundNotFound );
        CPPUNIT_TEST ( testSmttSoundManagerNotUseBeepAndFileSoundFound );
        CPPUNIT_TEST ( testSmttSoundManagerNotUseBeepCommandLine );

        CPPUNIT_TEST ( testStopWithoutApplicationSound );
        CPPUNIT_TEST ( testStopWithoutApplicationSoundCommandLine );
        CPPUNIT_TEST ( testStopWithApplicationSound );
        CPPUNIT_TEST ( testStopWithApplicationSoundCommandLine );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_SOUND_MANAGER_TEST */
