#ifndef TEST_STACK_TRACE_TEST_
#define TEST_STACK_TRACE_TEST_

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <mockpp/ExpectationSegment.h>
#include <System/Runtime/ProcessLauncher.h>
#include <System/StackTraceManager.hxx>
#include "MockExitProcess.hxx"
#include "MockProcessLauncher.hxx"
#include "MockStackTrace.hxx"
#include "BasicStackTrace.hxx"
#include <signal.h>

class StackTraceTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::System::Runtime::ProcessLauncher ProcessLauncher;
        typedef Smartmatic::System::StackTraceManager StackTraceManager;
        typedef Smartmatic::System::Runtime::ExitProcess ExitProcess;

    public:

        StackTraceTest ()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testSignalSegmentationViolation()
        {
            MockStackTrace stackTrace;
            StackTraceManager::getInstance ( &stackTrace );

            MOCKPP_CHAINER_FOR ( MockStackTrace, showSigSegvError ) showSigSegvError_mock ( &stackTrace );
            MOCKPP_CHAINER_FOR ( MockStackTrace, showSigAbortError ) showSigAbortError_mock ( &stackTrace );

            showSigSegvError_mock
            .expects ( MOCKPP_NS::once() );

            showSigAbortError_mock
            .expects ( MOCKPP_NS::never() );

            StackTraceManager::getInstance()->start();

            stackTrace.emulateSignalError ( SIGSEGV );

            StackTraceManager::getInstance()->stop();

            stackTrace.verify();
        }

        void testSignalAbort()
        {
            MockStackTrace stackTrace;
            StackTraceManager::getInstance ( &stackTrace );

            MOCKPP_CHAINER_FOR ( MockStackTrace, showSigSegvError ) showSigSegvError_mock ( &stackTrace );
            MOCKPP_CHAINER_FOR ( MockStackTrace, showSigAbortError ) showSigAbortError_mock ( &stackTrace );

            showSigSegvError_mock
            .expects ( MOCKPP_NS::never() );

            showSigAbortError_mock
            .expects ( MOCKPP_NS::once() );

            StackTraceManager::getInstance()->start();

            stackTrace.emulateSignalError ( SIGABRT );

            StackTraceManager::getInstance()->stop();

            stackTrace.verify();
        }

        void testShowSignalSegmentationViolation()
        {
            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MockExitProcess exitProcess;
            ExitProcess::getInstance ( &exitProcess );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );
            MOCKPP_CHAINER_FOR ( MockExitProcess, exitProcess ) exitProcess_mock ( &exitProcess );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::once() );

            exitProcess_mock
            .expects ( MOCKPP_NS::once() );

            BasicStackTrace stackTrace;
            StackTraceManager::getInstance ( &stackTrace );

            StackTraceManager::getInstance()->start();
            stackTrace.emulateSignalError ( SIGSEGV );
            StackTraceManager::getInstance()->stop();

            launcher.verify();
            exitProcess.verify();
        }

        void testShowSignalAbort()
        {
            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MockExitProcess exitProcess;
            ExitProcess::getInstance ( &exitProcess );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );
            MOCKPP_CHAINER_FOR ( MockExitProcess, exitProcess ) exitProcess_mock ( &exitProcess );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::once() );

            exitProcess_mock
            .expects ( MOCKPP_NS::once() );

            BasicStackTrace stackTrace;
            StackTraceManager::getInstance ( &stackTrace );

            StackTraceManager::getInstance()->start();
            stackTrace.emulateSignalError ( SIGABRT );
            StackTraceManager::getInstance()->stop();

            launcher.verify();
            exitProcess.verify();
        }

        CPPUNIT_TEST_SUITE ( StackTraceTest );

        CPPUNIT_TEST ( testSignalSegmentationViolation );
        CPPUNIT_TEST ( testSignalAbort );
        CPPUNIT_TEST ( testShowSignalSegmentationViolation );
        CPPUNIT_TEST ( testShowSignalAbort );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_STACK_TRACE_TEST_ */
