#ifndef TEST_STRING_UTILS_TEST
#define TEST_STRING_UTILS_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <System/Utils/DateTimeUtils.hxx>

class DateTimeUtilsTest : public CPPUNIT_NS::TestFixture
{
    public:

        typedef Smartmatic::System::Utils::DateTimeUtils DateTimeUtils;

        DateTimeUtilsTest()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testEmptyDataTime()
        {
            DateTimeUtils util;

            std::string date = util.getDate();
            std::string time = util.getTime();

            CPPUNIT_ASSERT ( false == date.empty() );
            CPPUNIT_ASSERT ( false == time.empty() );

            CPPUNIT_ASSERT ( std::string ( "01/01/1900" ) == date );
            CPPUNIT_ASSERT ( std::string ( "00:00:00" ) == time );
        }

        void testNotValidDataTime()
        {
            std::string dateTime = "xx-yy-zz bb:cc";
            DateTimeUtils util ( dateTime );

            std::string date = util.getDate();
            std::string time = util.getTime();

            CPPUNIT_ASSERT ( false == date.empty() );
            CPPUNIT_ASSERT ( false == time.empty() );

            CPPUNIT_ASSERT ( std::string ( "01/01/1900" ) == date );
            CPPUNIT_ASSERT ( std::string ( "00:00:00" ) == time );
        }

        void testOnlyDataString()
        {
            std::string dateTime = "2013-10-05";
            DateTimeUtils util ( dateTime );

            std::string date = util.getDate();
            std::string time = util.getTime();

            CPPUNIT_ASSERT ( false == date.empty() );
            CPPUNIT_ASSERT ( false == time.empty() );
            CPPUNIT_ASSERT ( std::string ( "05/10/2013" ) == date );
            CPPUNIT_ASSERT ( std::string ( "00:00:00" ) == time );
        }

        void testOnlyTimeString()
        {
            std::string dateTime = "05:10:15";
            DateTimeUtils util ( dateTime );

            std::string date = util.getDate();
            std::string time = util.getTime();

            CPPUNIT_ASSERT ( false == date.empty() );
            CPPUNIT_ASSERT ( false == time.empty() );
            CPPUNIT_ASSERT ( std::string ( "05:10:15" ) == time );
        }

        void testFirstFullExample()
        {
            std::string dateTime = "1994-11-05T08:15:30";
            DateTimeUtils util ( dateTime );

            std::string date = util.getDate();
            std::string time = util.getTime();

            CPPUNIT_ASSERT ( false == date.empty() );
            CPPUNIT_ASSERT ( false == time.empty() );
            CPPUNIT_ASSERT ( std::string ( "05/11/1994" ) == date );
            CPPUNIT_ASSERT ( std::string ( "08:15:30" ) == time );
        }

        void testSecondFullExample()
        {
            std::string dateTime = "1994-11-05T13:15:30";
            DateTimeUtils util ( dateTime );

            std::string date = util.getDate();
            std::string time = util.getTime();

            CPPUNIT_ASSERT ( false == date.empty() );
            CPPUNIT_ASSERT ( false == time.empty() );
            CPPUNIT_ASSERT ( std::string ( "05/11/1994" ) == date );
            CPPUNIT_ASSERT ( std::string ( "13:15:30" ) == time );
        }

        void testThirdExample()
        {
            std::string dateTime = "1997-07-16T19:20:30.45";
            DateTimeUtils util ( dateTime );

            std::string date = util.getDate();
            std::string time = util.getTime();

            CPPUNIT_ASSERT ( false == date.empty() );
            CPPUNIT_ASSERT ( false == time.empty() );
            CPPUNIT_ASSERT ( std::string ( "16/07/1997" ) == date );
            CPPUNIT_ASSERT ( std::string ( "19:20:30" ) == time );
        }

        void testFourthdExample()
        {
            std::string dateTime = "2006-02-03T16:45:09";
            DateTimeUtils util ( dateTime );

            std::string date = util.getDate();
            std::string time = util.getTime();

            CPPUNIT_ASSERT ( false == date.empty() );
            CPPUNIT_ASSERT ( false == time.empty() );
            CPPUNIT_ASSERT ( std::string ( "03/02/2006" ) == date );
            CPPUNIT_ASSERT ( std::string ( "16:45:09" ) == time );
        }

        void testFifthdExample()
        {
            std::string dateTime = "2004-04-20 20:13:20.962245";
            DateTimeUtils util ( dateTime );

            std::string date = util.getDate();
            std::string time = util.getTime();

            CPPUNIT_ASSERT ( false == date.empty() );
            CPPUNIT_ASSERT ( false == time.empty() );
            CPPUNIT_ASSERT ( std::string ( "20/04/2004" ) == date );
            CPPUNIT_ASSERT ( std::string ( "20:13:20" ) == time );
        }

        void testSixthExample()
        {
            std::string dateTime = "2004/04/20 20:13:20";
            DateTimeUtils util ( dateTime );

            std::string date = util.getDate();
            std::string time = util.getTime();

            CPPUNIT_ASSERT ( false == date.empty() );
            CPPUNIT_ASSERT ( false == time.empty() );
            CPPUNIT_ASSERT ( std::string ( "20/04/2004" ) == date );
            CPPUNIT_ASSERT ( std::string ( "20:13:20" ) == time );
        }

        void test31February2012Example()
        {
            std::string dateTime = "2012/02/31";
            DateTimeUtils util ( dateTime );

            std::string date = util.getDate();

            CPPUNIT_ASSERT ( false == date.empty() );
            CPPUNIT_ASSERT ( std::string ( "02/03/2012" ) == date );
        }

        void test31February2014Example()
        {
            std::string dateTime = "2014/02/31";
            DateTimeUtils util ( dateTime );

            std::string date = util.getDate();

            CPPUNIT_ASSERT ( false == date.empty() );
            CPPUNIT_ASSERT ( std::string ( "03/03/2014" ) == date );
        }

        void testGetterDay()
        {
            std::string dateTime = "2000/02/01" ;
            DateTimeUtils util ( dateTime );

            std::string day = util.getDay();

            CPPUNIT_ASSERT ( false == day.empty() );
            CPPUNIT_ASSERT ( std::string ( "01" ) == day );
        }

        void testGetterMonth()
        {
            std::string dateTime = "2000/02/01" ;
            DateTimeUtils util ( dateTime );

            std::string month = util.getMonth();

            CPPUNIT_ASSERT ( false == month.empty() );
            CPPUNIT_ASSERT ( std::string ( "02" ) == month );
        }

        void testGetterYear()
        {
            std::string dateTime = "2000/02/01" ;
            DateTimeUtils util ( dateTime );

            std::string year = util.getYear();

            CPPUNIT_ASSERT ( false == year.empty() );
            CPPUNIT_ASSERT ( std::string ( "2000" ) == year );
        }

        void testValidDate1()
        {
            std::string dateTime = "31/02/2000" ;
            DateTimeUtils util ( dateTime );

            CPPUNIT_ASSERT ( false == util.validate() );
        }

        void testValidDate2()
        {
            std::string dateTime = "23/9/2013" ;
            DateTimeUtils util ( dateTime );

            CPPUNIT_ASSERT ( true == util.validate() );
        }

        void testValidDateSeparate1()
        {
            DateTimeUtils util ( "2013", "2", "31" );
            CPPUNIT_ASSERT ( false == util.validate() );
        }

        void testValidDateSeparate2()
        {
            DateTimeUtils util ( "23", "9", "2013" );
            CPPUNIT_ASSERT ( true == util.validate() );
        }

        void testValidateCurrentDateTime()
        {
            DateTimeUtils util ( DateTimeUtils::getCurrentDateTime() );
            CPPUNIT_ASSERT ( true == util.validate() );
        }

        CPPUNIT_TEST_SUITE ( DateTimeUtilsTest );

        CPPUNIT_TEST ( testEmptyDataTime );
        CPPUNIT_TEST ( testNotValidDataTime );
        CPPUNIT_TEST ( testOnlyDataString );
        CPPUNIT_TEST ( testOnlyTimeString );
        CPPUNIT_TEST ( testFirstFullExample );
        CPPUNIT_TEST ( testSecondFullExample );
        CPPUNIT_TEST ( testThirdExample );
        CPPUNIT_TEST ( testFourthdExample );
        CPPUNIT_TEST ( testFifthdExample );
        CPPUNIT_TEST ( testSixthExample );
        CPPUNIT_TEST ( test31February2012Example );
        CPPUNIT_TEST ( test31February2014Example );
        CPPUNIT_TEST ( testGetterDay );
        CPPUNIT_TEST ( testGetterMonth );
        CPPUNIT_TEST ( testGetterYear );
        CPPUNIT_TEST ( testValidDate1 );
        CPPUNIT_TEST ( testValidDate2 );
        CPPUNIT_TEST ( testValidDateSeparate1 );
        CPPUNIT_TEST ( testValidDateSeparate2 );
        CPPUNIT_TEST ( testValidateCurrentDateTime );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_STRING_UTILS_TEST */
