#ifndef SAFE_BUFFER_UTILS_TEST_H_
#define SAFE_BUFFER_UTILS_TEST_H_

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <System/SafeBuffer.h>
#include <System/Utils/SafeBufferUtils.hxx>

#define CR 0x0D /*CR */
#define LF 0x0A /*LF */

class SafeBufferUtilsTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::System::SafeBuffer SafeBuffer;
        typedef Smartmatic::System::Utils::SafeBufferUtils SafeBufferUtils;

    public:

        SafeBufferUtilsTest ()
        {

        }

        void setUp ()
        {

        }

        void tearDown ()
        {

        }

        void testFindEmptyDataToBuffer ()
        {
            unsigned long index = 0;
            std::string find;

            unsigned long posExpected = 0;
            unsigned long posResult = -1;

            SafeBuffer buffer ( "abcd" );
            SafeBufferUtils util ( buffer );

            CPPUNIT_ASSERT ( false == util.findData ( index, find, posResult ) );
            CPPUNIT_ASSERT ( posExpected ==  posResult );
        }

        void testFindDataNotFoundToBuffer ()
        {
            unsigned long index = 0;
            std::string find = "ba";

            unsigned long posExpected = 0;
            unsigned long posResult = -1;

            SafeBuffer buffer ( "abcd" );
            SafeBufferUtils util ( buffer );

            CPPUNIT_ASSERT ( false == util.findData ( index, find, posResult ) );
            CPPUNIT_ASSERT ( posExpected ==  posResult );
        }

        void testFindDataFoundFirstToBuffer ()
        {
            unsigned long index = 0;
            SafeBuffer find ( "ab" );

            unsigned long posExpected = 0;
            unsigned long posResult = -1;

            SafeBuffer buffer ( "abcd" );
            SafeBufferUtils util ( buffer );

            CPPUNIT_ASSERT ( true == util.findData ( index, find, posResult ) );
            CPPUNIT_ASSERT ( posExpected ==  posResult );
        }

        void testFindDataFoundCenterToBuffer ()
        {
            unsigned long index = 0;
            SafeBuffer find ( "bc" );

            unsigned long posExpected = 1;
            unsigned long posResult = -1;

            SafeBuffer buffer ( "abcd" );
            SafeBufferUtils util ( buffer );

            CPPUNIT_ASSERT ( true == util.findData ( index, find, posResult ) );
            CPPUNIT_ASSERT ( posExpected ==  posResult );
        }

        void testFindDataFoundEndToBuffer ()
        {
            unsigned long index = 0;
            SafeBuffer find ( "cd" );

            unsigned long posExpected = 2;
            unsigned long posResult = -1;

            SafeBuffer buffer ( "abcd" );
            SafeBufferUtils util ( buffer );

            CPPUNIT_ASSERT ( true == util.findData ( index, find, posResult ) );
            CPPUNIT_ASSERT ( posExpected ==  posResult );
        }

        void testFindDataIndexOutSize ()
        {
            unsigned long index = 100;
            SafeBuffer find ( "cd" );

            unsigned long posExpected = 0;
            unsigned long posResult = -1;

            SafeBuffer buffer ( "abcd" );
            SafeBufferUtils util ( buffer );

            CPPUNIT_ASSERT ( false == util.findData ( index, find, posResult ) );
            CPPUNIT_ASSERT ( posExpected ==  posResult );
        }

        void testFindEndlLineOfUnix ()
        {
            SafeBuffer buffer ( "Hello" );
            buffer.push_back ( LF );

            unsigned long index = 0;

            SafeBuffer find;
            find.push_back ( LF );

            unsigned long posExpected = 5;
            unsigned long posResult = -1;

            SafeBufferUtils util ( buffer );

            CPPUNIT_ASSERT ( true == util.findData ( index, find, posResult ) );
            CPPUNIT_ASSERT ( posExpected ==  posResult );
        }

        void testFindEndlLineOfMac ()
        {
            SafeBuffer buffer ( "Hello" );
            buffer.push_back ( CR );

            unsigned long index = 0;

            SafeBuffer find;
            find.push_back ( CR );

            unsigned long posExpected = 5;
            unsigned long posResult = -1;

            SafeBufferUtils util ( buffer );

            CPPUNIT_ASSERT ( true == util.findData ( index, find, posResult ) );
            CPPUNIT_ASSERT ( posExpected ==  posResult );
        }

        void testFindEndlLineOfWindow ()
        {
            SafeBuffer buffer ( "Hello" );
            buffer.push_back ( CR );
            buffer.push_back ( LF );

            unsigned long index = 0;

            SafeBuffer find;
            find.push_back ( CR );
            find.push_back ( LF );

            unsigned long posExpected = 5;
            unsigned long posResult = -1;

            SafeBufferUtils util ( buffer );

            CPPUNIT_ASSERT ( true == util.findData ( index, find, posResult ) );
            CPPUNIT_ASSERT ( posExpected ==  posResult );
        }

        void testSpliWindowsLineRegister ()
        {
            SafeBuffer bufferA ( "bufferA" );
            SafeBuffer bufferB ( "bufferB" );
            SafeBuffer bufferC ( "bufferC" );
            SafeBuffer bufferD ( "bufferD" );

            SafeBuffer buffer;

            buffer.AddData ( bufferA );
            buffer.push_back ( CR );
            buffer.push_back ( LF );
            buffer.AddData ( bufferB );
            buffer.push_back ( CR );
            buffer.push_back ( LF );
            buffer.AddData ( bufferC );
            buffer.push_back ( CR );
            buffer.push_back ( LF );
            buffer.AddData ( bufferD );
            buffer.push_back ( CR );
            buffer.push_back ( LF );

            SafeBufferUtils util ( buffer );

            std::vector < SafeBuffer > list = util.splitByEndLine ();

            CPPUNIT_ASSERT ( 4 == list.size () );

            std::vector < SafeBuffer >::iterator it = list.begin ();

            CPPUNIT_ASSERT ( bufferA == ( *it ) );
            ++it;

            CPPUNIT_ASSERT ( bufferB == ( *it ) );
            ++it;

            CPPUNIT_ASSERT ( bufferC == ( *it ) );
            ++it;

            CPPUNIT_ASSERT ( bufferD == ( *it ) );
        }

        void testSpliWindowsLineRegister2 ()
        {
            SafeBuffer bufferA ( "bufferA" );
            SafeBuffer bufferB ( "bufferB" );
            SafeBuffer bufferC ( "bufferC" );
            SafeBuffer bufferD ( "bufferD" );

            SafeBuffer buffer;

            buffer.AddData ( bufferA );
            buffer.push_back ( CR );
            buffer.push_back ( LF );
            buffer.AddData ( bufferB );
            buffer.push_back ( CR );
            buffer.push_back ( LF );
            buffer.AddData ( bufferC );
            buffer.push_back ( CR );
            buffer.push_back ( LF );
            buffer.AddData ( bufferD );

            SafeBufferUtils util ( buffer );

            std::vector < SafeBuffer > list = util.splitByEndLine ();

            CPPUNIT_ASSERT ( 4 == list.size () );

            std::vector < SafeBuffer >::iterator it = list.begin ();

            CPPUNIT_ASSERT ( bufferA == ( *it ) );
            ++it;

            CPPUNIT_ASSERT ( bufferB == ( *it ) );
            ++it;

            CPPUNIT_ASSERT ( bufferC == ( *it ) );
            ++it;

            CPPUNIT_ASSERT ( bufferD == ( *it ) );
        }

        void testSpliUnixLineRegister ()
        {
            SafeBuffer bufferA ( "bufferA" );
            SafeBuffer bufferB ( "bufferB" );
            SafeBuffer bufferC ( "bufferC" );
            SafeBuffer bufferD ( "bufferD" );

            SafeBuffer buffer;

            buffer.AddData ( bufferA );
            buffer.push_back ( LF );
            buffer.AddData ( bufferB );
            buffer.push_back ( LF );
            buffer.AddData ( bufferC );
            buffer.push_back ( LF );
            buffer.AddData ( bufferD );
            buffer.push_back ( LF );

            SafeBufferUtils util ( buffer );

            std::vector < SafeBuffer > list = util.splitByEndLine ();

            CPPUNIT_ASSERT ( 4 == list.size () );

            std::vector < SafeBuffer >::iterator it = list.begin ();

            CPPUNIT_ASSERT ( bufferA == ( *it ) );
            ++it;

            CPPUNIT_ASSERT ( bufferB == ( *it ) );
            ++it;

            CPPUNIT_ASSERT ( bufferC == ( *it ) );
            ++it;

            CPPUNIT_ASSERT ( bufferD == ( *it ) );
        }

        void testSpliUnixLineRegister2 ()
        {
            SafeBuffer bufferA ( "bufferA" );
            SafeBuffer bufferB ( "bufferB" );
            SafeBuffer bufferC ( "bufferC" );
            SafeBuffer bufferD ( "bufferD" );

            SafeBuffer buffer;

            buffer.AddData ( bufferA );
            buffer.push_back ( LF );
            buffer.AddData ( bufferB );
            buffer.push_back ( LF );
            buffer.AddData ( bufferC );
            buffer.push_back ( LF );
            buffer.AddData ( bufferD );

            SafeBufferUtils util ( buffer );

            std::vector < SafeBuffer > list = util.splitByEndLine ();

            CPPUNIT_ASSERT ( 4 == list.size () );

            std::vector < SafeBuffer >::iterator it = list.begin ();

            CPPUNIT_ASSERT ( bufferA == ( *it ) );
            ++it;

            CPPUNIT_ASSERT ( bufferB == ( *it ) );
            ++it;

            CPPUNIT_ASSERT ( bufferC == ( *it ) );
            ++it;

            CPPUNIT_ASSERT ( bufferD == ( *it ) );
        }

        void testSpliMacOSLineRegister ()
        {
            SafeBuffer bufferA ( "bufferA" );
            SafeBuffer bufferB ( "bufferB" );
            SafeBuffer bufferC ( "bufferC" );
            SafeBuffer bufferD ( "bufferD" );

            SafeBuffer buffer;

            buffer.AddData ( bufferA );
            buffer.push_back ( CR );
            buffer.AddData ( bufferB );
            buffer.push_back ( CR );
            buffer.AddData ( bufferC );
            buffer.push_back ( CR );
            buffer.AddData ( bufferD );
            buffer.push_back ( CR );

            SafeBufferUtils util ( buffer );

            std::vector < SafeBuffer > list = util.splitByEndLine ();

            CPPUNIT_ASSERT ( 4 == list.size () );

            std::vector < SafeBuffer >::iterator it = list.begin ();

            CPPUNIT_ASSERT ( bufferA == ( *it ) );
            ++it;

            CPPUNIT_ASSERT ( bufferB == ( *it ) );
            ++it;

            CPPUNIT_ASSERT ( bufferC == ( *it ) );
            ++it;

            CPPUNIT_ASSERT ( bufferD == ( *it ) );
        }

        void testSpliMacOSLineRegister2 ()
        {
            SafeBuffer bufferA ( "bufferA" );
            SafeBuffer bufferB ( "bufferB" );
            SafeBuffer bufferC ( "bufferC" );
            SafeBuffer bufferD ( "bufferD" );

            SafeBuffer buffer;

            buffer.AddData ( bufferA );
            buffer.push_back ( CR );
            buffer.AddData ( bufferB );
            buffer.push_back ( CR );
            buffer.AddData ( bufferC );
            buffer.push_back ( CR );
            buffer.AddData ( bufferD );

            SafeBufferUtils util ( buffer );

            std::vector < SafeBuffer > list = util.splitByEndLine ();

            CPPUNIT_ASSERT ( 4 == list.size () );

            std::vector < SafeBuffer >::iterator it = list.begin ();

            CPPUNIT_ASSERT ( bufferA == ( *it ) );
            ++it;

            CPPUNIT_ASSERT ( bufferB == ( *it ) );
            ++it;

            CPPUNIT_ASSERT ( bufferC == ( *it ) );
            ++it;

            CPPUNIT_ASSERT ( bufferD == ( *it ) );
        }

        void testSpliWithouEndLine ()
        {
            SafeBuffer buffer ( "Hello" );
            SafeBufferUtils util ( buffer );

            std::vector < SafeBuffer > list = util.splitByEndLine ();

            CPPUNIT_ASSERT ( 1 == list.size () );

            std::vector < SafeBuffer >::iterator it = list.begin ();

            CPPUNIT_ASSERT ( buffer == ( *it ) );
        }

        CPPUNIT_TEST_SUITE ( SafeBufferUtilsTest );

        CPPUNIT_TEST ( testFindEmptyDataToBuffer );
        CPPUNIT_TEST ( testFindDataNotFoundToBuffer );
        CPPUNIT_TEST ( testFindDataFoundFirstToBuffer );
        CPPUNIT_TEST ( testFindDataFoundCenterToBuffer );
        CPPUNIT_TEST ( testFindDataFoundEndToBuffer );
        CPPUNIT_TEST ( testFindDataIndexOutSize );

        CPPUNIT_TEST ( testFindEndlLineOfUnix );
        CPPUNIT_TEST ( testFindEndlLineOfMac );
        CPPUNIT_TEST ( testFindEndlLineOfWindow );

        CPPUNIT_TEST ( testSpliWindowsLineRegister );
        CPPUNIT_TEST ( testSpliWindowsLineRegister2 );
        CPPUNIT_TEST ( testSpliUnixLineRegister );
        CPPUNIT_TEST ( testSpliUnixLineRegister2 );
        CPPUNIT_TEST ( testSpliMacOSLineRegister );
        CPPUNIT_TEST ( testSpliMacOSLineRegister2 );
        CPPUNIT_TEST ( testSpliWithouEndLine );

        CPPUNIT_TEST_SUITE_END ();
};

#endif /* ECUT_MAIN */

#endif /* SAFE_BUFFER_UTILS_TEST_H_ */
