#ifndef TEST_XML_CERTIFICATE_TEST
#define TEST_XML_CERTIFICATE_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <System/XML/ExtractCertificate.hxx>
#include <System/Security/XmlSecurityC.hxx>

static std::string singleSignatureXML = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"\
                                        "<Envelope>"\
                                        " <Signature xmlns=\"http://www.w3.org/2000/09/xmldsig#\">"\
                                        "  <SignedInfo>"\
                                        "   <CanonicalizationMethod Algorithm=\"http://www.w3.org/TR/2001/REC-xml-c14n-20010315\"/>"\
                                        "    <SignatureMethod Algorithm=\"http://www.w3.org/2001/04/xmldsig-more#rsa-sha256\"/>"\
                                        "     <Reference URI=\"\">"\
                                        "      <Transforms>"\
                                        "       <Transform Algorithm=\"http://www.w3.org/2000/09/xmldsig#enveloped-signature\" />"\
                                        "      </Transforms>"\
                                        "       <DigestMethod Algorithm=\"http://www.w3.org/2001/04/xmlenc#sha256\"/>"\
                                        "        <DigestValue></DigestValue>"\
                                        "     </Reference>"\
                                        "  </SignedInfo>"\
                                        "  <SignatureValue />"\
                                        "  <KeyInfo>"\
                                        "   <KeyValue />"\
                                        "  </KeyInfo>"\
                                        " </Signature>"\
                                        "</Envelope>";

static std::string fullSignatureXML = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"\
                                      "<Envelope>"\
                                      "  <Signature xmlns=\"http://www.w3.org/2000/09/xmldsig#\">"\
                                      "	<SignedInfo xmlns=\"http://www.w3.org/2000/09/xmldsig#\">"\
                                      "		<CanonicalizationMethod Algorithm=\"http://www.w3.org/TR/2001/REC-xml-c14n-20010315\""\
                                      "			xmlns=\"http://www.w3.org/2000/09/xmldsig#\" />"\
                                      "		<SignatureMethod Algorithm=\"http://www.w3.org/2009/xmldsig11#dsa-sha256\""\
                                      "			xmlns=\"http://www.w3.org/2000/09/xmldsig#\" />"\
                                      "		<Reference URI=\"\" xmlns=\"http://www.w3.org/2000/09/xmldsig#\">"\
                                      "			<Transforms	xmlns=\"http://www.w3.org/2000/09/xmldsig#\">"\
                                      "				<Transform Algorithm=\"http://www.w3.org/2000/09/xmldsig#enveloped-signature\""\
                                      "					xmlns=\"http://www.w3.org/2000/09/xmldsig#\" />"\
                                      "			</Transforms>"\
                                      "			<DigestMethod Algorithm=\"http://www.w3.org/2001/04/xmlenc#sha256\""\
                                      "				xmlns=\"http://www.w3.org/2000/09/xmldsig#\" />"\
                                      "			<DigestValue xmlns=\"http://www.w3.org/2000/09/xmldsig#\">"\
                                      "				Oyyx+K28+cp7kuUgcnANtTBdUwg="\
                                      "			</DigestValue>"\
                                      "		</Reference>"\
                                      "	</SignedInfo>"\
                                      "	<SignatureValue xmlns=\"http://www.w3.org/2000/09/xmldsig#\">"\
                                      "		ZVzRud7G4mEZsDnBavbnZoFUmm5J2OBDkQ+IooDLn95ndGYdrq6uPQ=="\
                                      "	</SignatureValue>"\
                                      "	<KeyInfo xmlns=\"http://www.w3.org/2000/09/xmldsig#\">"\
                                      "		<X509Data xmlns=\"http://www.w3.org/2000/09/xmldsig#\">"\
                                      "			<X509Certificate xmlns=\"http://www.w3.org/2000/09/xmldsig#\">BASE64DUMMY</X509Certificate>"\
                                      "		</X509Data>"\
                                      "		<KeyValue xmlns=\"http://www.w3.org/2000/09/xmldsig#\" >"\
                                      "			<DSAKeyValue xmlns=\"http://www.w3.org/2000/09/xmldsig#\" />"\
                                      "		</KeyValue>"\
                                      "	</KeyInfo>"\
                                      "  </Signature>"\
                                      "</Envelope>";

class XmlCertificateTest : public CPPUNIT_NS::TestFixture
{
    public:

        typedef Smartmatic::System::XML::ExtractCertificate ExtractCertificate;

        XmlCertificateTest()
        {

        }

        void setUp()
        {
            Smartmatic::System::Security::XmlSecurityC::init();
        }

        void tearDown()
        {
            Smartmatic::System::Security::XmlSecurityC::clear();
        }

        void testGetCertificateToEmptyBuffer()
        {
            Smartmatic::System::SafeBuffer xml;
            Smartmatic::System::SafeBuffer result ( "NULL" );

            ExtractCertificate xmlCert ( xml );

            CPPUNIT_ASSERT ( false == xmlCert.getBase64Certificate ( result ) );
            CPPUNIT_ASSERT ( 0 == result.GetSize() );
        }

        void testGetCertificateToSingleSignatureBuffer()
        {
            Smartmatic::System::SafeBuffer xml ( singleSignatureXML );
            Smartmatic::System::SafeBuffer result ( "NULL" );

            ExtractCertificate xmlCert ( xml );

            CPPUNIT_ASSERT ( false == xmlCert.getBase64Certificate ( result ) );
            CPPUNIT_ASSERT ( 0 == result.GetSize() );
        }

        void testGetCertificateToFullSignatureBuffer()
        {
            Smartmatic::System::SafeBuffer xml ( fullSignatureXML );
            Smartmatic::System::SafeBuffer expected ( "BASE64DUMMY" );
            Smartmatic::System::SafeBuffer result;

            ExtractCertificate xmlCert ( xml );

            CPPUNIT_ASSERT ( true == xmlCert.getBase64Certificate ( result ) );
            CPPUNIT_ASSERT ( 0 == expected.GetBase64Data().compare ( result.GetBase64Data() ) );
        }

        CPPUNIT_TEST_SUITE ( XmlCertificateTest );

        CPPUNIT_TEST ( testGetCertificateToEmptyBuffer );
        CPPUNIT_TEST ( testGetCertificateToSingleSignatureBuffer );
        CPPUNIT_TEST ( testGetCertificateToFullSignatureBuffer );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_XML_CERTIFICATE_TEST */
