/**
 * @file	s-m-t-t-g-u-i-conf-manager.h
 * @brief	Declares the smtt gui conf manager class.
 */

#ifndef _S_M_T_T_G_U_I_CONFIGURATION_MANAGER_H_
#define _S_M_T_T_G_U_I_CONFIGURATION_MANAGER_H_

#include <string>
#include <list>
#include <Configuration/SmartmaticGUIConfiguration-schema.hxx>

namespace Smartmatic
{
    namespace GUI
    {
        namespace Configuration
        {

            /**
             * @class	SMTTGUIConfigurationManager
             * @brief	Manager for smttgui configurations.
             * @author	Youssef.tourkmani
             * @date	25/10/2012
             */
            class SMTTGUIConfigurationManager
            {
                public:

                    /**
                     * @fn	static SMTTGUIConfigurationManager * getInstance( SMTTGUIConfigurationManager * externManager = NULL );
                     * @brief	Gets the current instance.
                     * @author	Yadickson Soto
                     * @date	27/02/2014
                     * @param 	externManager external manager to unit test
                     * @return	instance of the class
                     */

                    static SMTTGUIConfigurationManager * getInstance ( SMTTGUIConfigurationManager * externManager = NULL );

                    /**
                     * @fn	Smartmatic::GUI::Configuration::SmartmaticGUIConfiguration * getConfiguration();
                     * @brief	Gets the configuration.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @return	null if it fails, else the configuration.
                     */

                    Smartmatic::GUI::Configuration::SmartmaticGUIConfiguration * getConfiguration ();

                    /**
                     * @fn	void SMTTGUIConfigurationManager::loadDefault();
                     * @brief	Loads the default.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     */
                    void loadDefault();

                    /**
                     * @fn	std::string SMTTGUIConfigurationManager::getSmartmaticButtonSound();
                     * @brief	Gets the smartmatic button sound.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @return	The smartmatic button sound.
                     */
                    std::string getSmartmaticButtonSound();

                    /**
                     * @fn	std::string SMTTGUIConfigurationManager::getNumericKeypadSound();
                     * @brief	Gets the numeric keypad sound.
                     * @author	Yadickson Soto
                     * @date	07/03/2013
                     * @return	The numeric keypad sound.
                     */
                    std::string getNumericKeypadSound();

                    /**
                     * @fn	std::string SMTTGUIConfigurationManager::getCancelKeypadSound();
                     * @brief	Gets the cancel keypad sound.
                     * @author	Yadickson Soto
                     * @date	07/03/2013
                     * @return	The cancel keypad sound.
                     */
                    std::string getCancelKeypadSound();

                    /**
                     * @fn	std::string SMTTGUIConfigurationManager::getAcceptKeypadSound();
                     * @brief	Gets the accept keypad sound.
                     * @author	Yadickson Soto
                     * @date	07/03/2013
                     * @return	The accept keypad sound.
                     */
                    std::string getAcceptKeypadSound();

                    /**
                     * @fn	std::string SMTTGUIConfigurationManager::getConfirmationDialogSound();
                     * @brief	Gets the confirmation dialog sound.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @return	The confirmation dialog sound.
                     */
                    std::string getConfirmationDialogSound();

                    /**
                     * @fn	std::string SMTTGUIConfigurationManager::getChooseDialogSound();
                     * @brief	Gets the choose dialog sound.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @return	The choose dialog sound.
                     */
                    std::string getChooseDialogSound();

                    /**
                     * @fn	std::string SMTTGUIConfigurationManager::getAzertyKeypadSound();
                     * @brief	Gets the azerty keypad sound.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @return	The azerty keypad sound.
                     */

                    std::string getAzertyKeypadSound();

                    /**
                     * @fn	std::string SMTTGUIConfigurationManager::getMenuSound();
                     * @brief	Gets the menu sound.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @return	The menu sound.
                     */
                    std::string getMenuSound();

                    /**
                     * @fn	bool SMTTGUIConfigurationManager::getAZERTYShowPass();
                     * @brief	Gets a zerty show pass.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @return	true if it succeeds, false if it fails.
                     */
                    bool getAZERTYShowPass();

                    /**
                     * @fn	int SMTTGUIConfigurationManager::getAllButtonsSize();
                     * @brief	Get all buttons size.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @return	The button size.
                     */
                    int getAllButtonsSize();

                    /**
                     * @fn	int SMTTGUIConfigurationManager::getMenuButtonsSize();
                     * @brief	Get menu buttons size.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @return	The button size.
                     */
                    int getMenuButtonsSize();

                    /**
                     * @fn  void getWindowSize ( int & width, int & height );
                     * @brief   Gets window size.
                     * @author  Yadickson Soto
                     * @date    27/02/2014
                     * @param   width output width value.
                     * @param   height output height value.
                     */
                    void getWindowSize ( int & width, int & height );
                    /**
                     * @fn  void getPaddings ( int & xPadding, int & yPadding );
                     * @brief   Gets window padding.
                     * @author  Yadickson Soto
                     * @date    27/02/2014
                     * @param   xPadding output x padding value.
                     * @param   yPadding output y padding value.
                     */
                    void getPaddings ( int & xPadding, int & yPadding );
                    /**
                     * @fn  void getCenterSize ( int & width, int & height );
                     * @brief   Gets window header size.
                     * @author  Yadickson Soto
                     * @date    27/02/2014
                     * @param   width output width value.
                     * @param   height output height value.
                     */
                    void getCenterSize ( int & width, int & height );
                    /**
                     * @fn  void getHeaderSize ( int & width, int & height );
                     * @brief   Gets window header size.
                     * @author  Yadickson Soto
                     * @date    27/02/2014
                     * @param   width output width value.
                     * @param   height output height value.
                     */
                    void getHeaderSize ( int & width, int & height );
                    /**
                     * @fn  void getHeaderSize ( int & width, int & height );
                     * @brief   Gets window header size.
                     * @author  Yadickson Soto
                     * @date    27/02/2014
                     * @param   width output width value.
                     * @param   height output height value.
                     */
                    void getCenterSizeWithHeader ( int & width, int & height );

                    /**
                     * @fn	Smartmatic::GUI::Configuration::EntryPassPhraseConfiguration::Value SMTTGUIConfigurationManager::getEntryConfiguration();
                     * @brief	Gets the entry configuration.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @return	value for entry configuration.
                     */
                    Smartmatic::GUI::Configuration::EntryPassPhraseConfiguration::Value getEntryConfiguration();

                    /**
                     * @fn	Smartmatic::GUI::Configuration::ButtonsQuestionConfiguration::Value SMTTGUIConfigurationManager::getButtonsQuestionConfiguration();
                     * @brief	Method getter buttons question configuration.
                     * @author	Yadickson Soto
                     * @date	17/05/2012
                     * @return	buttons question configuration.
                     */
                    Smartmatic::GUI::Configuration::ButtonsQuestionConfiguration::Value getButtonsQuestionConfiguration();
                    /**
                     * @fn	Smartmatic::GUI::Configuration::ScreenCaptureConfiguration & getScreenCaptureConfiguration();
                     * @brief	Method getter screen capture configuration.
                     * @author	Yadickson Soto
                     * @date	14/03/2013
                     * @return	screen capture configuration.
                     */
                    Smartmatic::GUI::Configuration::ScreenCaptureConfiguration & getScreenCaptureConfiguration();
                    /**
                     * @fn	Smartmatic::GUI::Configuration::ScreenCaptureType getScreenCaptureType( Smartmatic::GUI::Configuration::CaptureType type );
                     * @brief	Method getter screen capture by type.
                     * @author	Yadickson Soto
                     * @date	14/03/2013
                     * @param type type
                     * @return	screen capture type.
                     */
                    Smartmatic::GUI::Configuration::ScreenCaptureType getScreenCaptureType ( Smartmatic::GUI::Configuration::CaptureType type );
                    /**
                     * @fn	Smartmatic::GUI::Configuration::GuiThemeConfiguration getGuiThemeConfiguration ();
                     * @brief	Getter gui theme configuration components.
                     * @author	Yadickson Soto
                     * @date	10/10/2013
                     * @return	gui theme configuration components.
                     */
                    Smartmatic::GUI::Configuration::GuiThemeConfiguration getGuiThemeConfiguration ();
                    /**
                     * @fn  Smartmatic::GUI::Configuration::SmartmaticGUIMachineModelConfiguration::MachineModelType getSmartmaticGUIMachineModelConfiguration ();
                     * @brief   Getter gui machine model configuration components.
                     * @author  Eduardo Fernández
                     * @date    07/09/2017
                     * @return  gui machine model configuration components.
                     */
                    Smartmatic::GUI::Configuration::SmartmaticGUIMachineModelConfiguration::MachineModelType getSmartmaticGUIMachineModelConfiguration ();

                    /**
                     * @fn	virtual SMTTGUIConfigurationManager::~SMTTGUIConfigurationManager();
                     * @brief	Finaliser.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     */
                    virtual ~SMTTGUIConfigurationManager();

                protected:

                    /**
                     * @fn	SMTTGUIConfigurationManager::SMTTGUIConfigurationManager();
                     * @brief	Default constructor.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     */
                    SMTTGUIConfigurationManager();

                    /**
                     * @fn		virtual void initialize();
                     * @brief	Initializes this object.
                     * @author	Yadickson Soto
                     * @date	27/02/2014
                     */
                    virtual void initialize();

                private:

                    Smartmatic::GUI::Configuration::SmartmaticGUIConfiguration * configuration;  ///< The configuration
                    static SMTTGUIConfigurationManager * instance;	///< The singleton instance
            };
        }
    }
}

#endif // _S_M_T_T_G_U_I_CONFIGURATION_MANAGER_H_
