/**
 * @file ICapture.hxx
 * @brief Header interface screen capture
 * @date 14/03/2013
 * @author Yadickson Soto
 */

#ifndef ICAPTURE_HXX_
#define ICAPTURE_HXX_

#include <string>

namespace Smartmatic
{
    namespace Graphics
    {
        namespace Capture
        {

            /**
             * @class	ICapture;
             * @brief	Interface screen capture.
             * @author	Yadickson Soto
             * @date	14/03/2013
             */
            class ICapture
            {
                public:
                    /**
                     * @fn	ICapture( const std::string & execute );
                     * @brief	Class destructor.
                     * @author	Yadickson Soto
                     * @date	14/03/2013
                     */
                    explicit ICapture ( const std::string & execute );

                    /**
                     * @fn	virtual ~ICapture();
                     * @brief	Class destructor.
                     * @author	Yadickson Soto
                     * @date	14/03/2013
                     */
                    virtual ~ICapture();

                    /**
                     * @fn	void capture( const std::string& imageFullPath );
                     * @brief	Screen capture and safe to file.
                     * @author	Yadickson Soto
                     * @date	14/03/2013
                     * @param	imageFullPath	Full pathname of the image full file.
                     */
                    void capture ( const std::string& imageFullPath );

                private:

                    std::string m_execute; ///< program

                protected:

                    std::string m_command; ///< command
            };

        }
    }
}

#endif /* ICAPTURE_HXX_ */
