/**
 * @file PrintScreenManager.cpp
 * @brief Body class print screen manager
 * @date 07/04/2011
 * @author Gerardo Hernandez
 */

#include "PrintScreenManager.h"
#include "ImportCapture.hxx"
#include "ScrotCapture.hxx"
#include <Configuration/s-m-t-t-g-u-i-conf-manager.h>

using namespace Smartmatic::Graphics::Capture;
using namespace Smartmatic::GUI::Configuration;

PrintScreenManager * PrintScreenManager::instance = NULL;

PrintScreenManager::PrintScreenManager()
{
    switch ( SMTTGUIConfigurationManager::getInstance()->getScreenCaptureConfiguration().getDefault() )
    {
        default:
        case  CaptureType::CONFIGURATION_IMPORT:
            iclass = new ImportCapture();
            break;

        case CaptureType::CONFIGURATION_SCROT:
            iclass = new ScrotCapture();
            break;
    }
}

PrintScreenManager::~PrintScreenManager()
{
    delete iclass;
}

void PrintScreenManager::capture ( const std::string& imageFullPath )
{
    if (iclass)
    {
        iclass->capture ( imageFullPath );
    }
}

PrintScreenManager * PrintScreenManager::getInstance()
{
    if ( instance == NULL )
    {
        instance = new PrintScreenManager();
    }

    return instance;
}
