/**
 * @file AccessibleNameWidget.hxx
 * @brief Header Accessible Name Widget
 * @date 24/04/2013
 * @author Yadickson Soto
 */

#ifndef ACCESSIBLENAMEWIDGET_HXX_
#define ACCESSIBLENAMEWIDGET_HXX_

#include <gtkmm.h>

namespace Smartmatic
{
    namespace GUI
    {
        namespace Operation
        {

            /**
             * @class AccessibleNameWidget
             * @brief Accessible Name Widget
             * @date 24/04/2013
             * @author Yadickson Soto
             */
            class AccessibleNameWidget
            {
                public:
                    /**
                     * @fn AccessibleNameWidget( const std::string & accessibleType );
                     * @brief Class constructor
                     * @date 24/04/2013
                     * @author Yadickson Soto
                     * @param accessibleType prefix accessible type widget
                     */
                    explicit AccessibleNameWidget ( const std::string & accessibleType );
                    /**
                     * @fn AccessibleNameWidget( const std::string & accessibleType, Gtk::Widget * accessibleWidget );
                     * @brief Class constructor
                     * @date 24/04/2013
                     * @author Yadickson Soto
                     * @param accessibleType prefix accessible type widget
                     * @param accessibleWidget accessible widget
                     */
                    AccessibleNameWidget ( const std::string & accessibleType, Gtk::Widget * accessibleWidget );
                    /**
                     * @fn virtual ~AccessibleNameWidget();
                     * @brief Class constructor
                     * @date 24/04/2013
                     * @author Yadickson Soto
                     */
                    virtual ~AccessibleNameWidget();
                    /**
                     * @fn	virtual void setAccessibleName ( const std::string & name );
                     * @brief	setter accessible name method.
                     * @author	Yadickson Soto
                     * @date	24/04/2013
                     * @param name new accessible name
                     */
                    virtual void setAccessibleName ( const std::string & name );

                private:

                    std::string accessibleType; ///< type prefix name widget

                protected:

                    Gtk::Widget * accessibleWidget; ///< accessible widget
            };

        } /* namespace Operation */
    } /* namespace GUI */
} /* namespace Smartmatic */
#endif /* ACCESSIBLENAMEWIDGET_HXX_ */
