/**
 * @file WindowsManager.hxx
 * @brief Header class windows manager
 * @date 26/03/2012
 * @author Yadickson Soto
 */

#ifndef WINDOWSMANAGER_HXX_
#define WINDOWSMANAGER_HXX_

#include <vector>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace GUI
    {
        namespace Windows
        {
            class BasicWindow;
        }

        namespace Operation
        {
            /**
             * @class	WindowsManager
             * @brief	Class windows manager.
             * @author	Yadickson Soto
             * @date	26/03/2012
             */
            class WindowsManager
            {
                protected:
                    /**
                     * @fn	WindowsManager::WindowsManager();
                     * @brief	Class constructor.
                     * @author	Yadickson Soto
                     * @date	26/03/2012
                     */
                    WindowsManager();

                    static WindowsManager * instance; ///< instance class

                public:
                    /**
                     * @fn	virtual WindowsManager::~WindowsManager();
                     * @brief	Class destructor.
                     * @author	Yadickson Soto
                     * @date	26/03/2012
                     */
                    virtual ~WindowsManager();
                    /**
                     * @fn	void WindowsManager::push(Smartmatic::GUI::Windows::BasicWindow * window);
                     * @brief	Method push new window.
                     * @author	Yadickson Soto
                     * @date	26/03/2012
                     * @param	window	new window.
                     */
                    void push ( Smartmatic::GUI::Windows::BasicWindow * window );
                    /**
                     * @fn	Smartmatic::GUI::Windows::BasicWindow * WindowsManager::pop();
                     * @brief	Method pop last window.
                     * @author	Yadickson Soto
                     * @date	26/03/2012
                     * @return	last window.
                     */
                    Smartmatic::GUI::Windows::BasicWindow * pop();
                    /**
                     * @fn	Smartmatic::GUI::Windows::BasicWindow * WindowsManager::current();
                     * @brief	Method getter current window.
                     * @author	Yadickson Soto
                     * @date	26/03/2012
                     * @return	current window.
                     */
                    Smartmatic::GUI::Windows::BasicWindow * current();
                    /**
                     * @fn	static WindowsManager * WindowsManager::getInstance();
                     * @brief	Method getter instance class.
                     * @author	Yadickson Soto
                     * @date	26/03/2012
                     * @return	instance class.
                     */
                    static WindowsManager * getInstance();

                private:

                    std::vector < Smartmatic::GUI::Windows::BasicWindow * > staticWindows; ///< statics list base windows
                    static Smartmatic::Log::ISMTTLog * logger; ///< The logger
            };
        }
    }
}

#endif /* WINDOWSMANAGER_HXX_ */
