/**
 * @file ButtonsWidget.hxx
 * @brief Header class buttons widget
 * @date 17/05/2012
 * @author Yadickson Soto
 */

#ifndef BUTTONSWIDGET_HXX_
#define BUTTONSWIDGET_HXX_

#include <gtkmm.h>
#include <Widgets/smartmatic-button.h>
#include <Widgets/SmartmaticBasicEventBox.hxx>
#include <Widgets/SmartmaticBasicHBox.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace GUI
    {
        namespace Widgets
        {
            /**
             * @class	ButtonsWidget
             * @brief	Class ButtonsWidget.
             * @author	Yadickson Soto
             * @date	17/05/2012
             */
            class ButtonsWidget : public Smartmatic::GUI::Widgets::SmartmaticBasicEventBox
            {
                public:
                    /**
                     * @fn	ButtonsWidget::ButtonsWidget(bool expand = true);
                     * @brief	Class constructor.
                     * @author	Yadickson Soto
                     * @date	17/05/2012
                     * @param	expand	expand all button.
                     */
                    explicit ButtonsWidget ( bool expand = true );
                    /**
                     * @fn	ButtonsWidget::ButtonsWidget(BaseObjectType* cobject,
                     * 			const Glib::RefPtr<Gtk::Builder>& refBuilder=Gtk::Builder::create());
                     * @brief	Class constructor.
                     * @author	Yadickson Soto
                     * @date	21/05/2012
                     * @param	cobject			the cobject.
                     * @param	refBuilder	The reference builder.
                     */
                    ButtonsWidget ( BaseObjectType * cobject, const Glib::RefPtr<Gtk::Builder> & refBuilder = Gtk::Builder::create() );
                    /**
                     * @fn	virtual ButtonsWidget::~ButtonsWidget();
                     * @brief	Class destructor.
                     * @author	Yadickson Soto
                     * @date	17/05/2012
                     */
                    virtual ~ButtonsWidget();
                    /**
                     * @fn	virtual void ButtonsWidget::initialize();
                     * @brief	method initialize class.
                     * @author	Yadickson Soto
                     * @date	17/05/2012
                     */
                    virtual void initialize();
                    /**
                     * @fn	virtual void ButtonsWidget::dispose();
                     * @brief	method dispose class.
                     * @author	Yadickson Soto
                     * @date	17/05/2012
                     */
                    virtual void dispose();
                    /**
                     * @fn	sigc::signal<void> ButtonsWidget::getSignalClearButtonClicked();
                     * @brief	method getter signal clear button clicked.
                     * @author	Yadickson Soto
                     * @date	17/05/2012
                     * @return	signal clicked.
                     */
                    sigc::signal<void> getSignalClearButtonClicked();
                    /**
                     * @fn	sigc::signal<void> ButtonsWidget::getSignalAcceptButtonClicked();
                     * @brief	method getter signal accept button clicked.
                     * @author	Yadickson Soto
                     * @date	17/05/2012
                     * @return	signal clicked.
                     */
                    sigc::signal<void> getSignalAcceptButtonClicked();
                    /**
                     * @fn	sigc::signal<void> ButtonsWidget::getSignalBackButtonClicked();
                     * @brief	method getter signal back button clicked.
                     * @author	Yadickson Soto
                     * @date	17/05/2012
                     * @return	signal clicked.
                     */
                    sigc::signal<void> getSignalBackButtonClicked();
                    /**
                     * @fn	sigc::signal<void> ButtonsWidget::getSignalNullButtonClicked();
                     * @brief	method getter signal null button clicked.
                     * @author	Yadickson Soto
                     * @date	13/03/2012
                     * @return	signal clicked.
                     */
                    sigc::signal<void> getSignalNullButtonClicked();
                    /**
                     * @fn	void ButtonsWidget::setSpacing(int spacing);
                     * @brief	method set spacing.
                     * @author	Yadickson Soto
                     * @date	17/05/2012
                     * @param	spacing	spacing.
                     */
                    void setSpacing ( int spacing );
                    /**
                     * @fn	void ButtonsWidget::modifyFontSize(int size);
                     * @brief	method set font button size.
                     * @author	Yadickson Soto
                     * @date	17/05/2012
                     * @param	size	font button size.
                     */
                    void modifyFontSize ( int size );
                    /**
                     * @fn	virtual void ButtonsWidget::showButton(bool showClear, bool showAccept, bool showBack,
                     * 			bool showNull = false);
                     * @brief	method show button.
                     * @author	Yadickson Soto
                     * @date	12/03/2012
                     * @param	showClear 	flag show clear button.
                     * @param	showAccept	flag show accept button.
                     * @param	showBack		flag show back button.
                     * @param	showNull		flag show null button.
                     */
                    virtual void showButton ( bool showClear, bool showAccept, bool showBack, bool showNull = false );
                    /**
                     * @fn	virtual void setSensitiveButton ( bool sensitiveClear = false, bool sensitiveAccept = false, bool sensitiveBack = false, bool sensitiveNull = false );
                     * @brief	Sets sensitive state button.
                     * @author	Yadickson Soto
                     * @date	27/02/2014
                     * @param	sensitiveClear 	flag sensitive clear button.
                     * @param	sensitiveAccept	flag sensitive accept button.
                     * @param	sensitiveBack		flag sensitive back button.
                     * @param	sensitiveNull		flag sensitive null button.
                     */
                    virtual void setSensitiveButton ( bool sensitiveClear = false, bool sensitiveAccept = false, bool sensitiveBack = false, bool sensitiveNull = false );
                    /**
                     * @fn	virtual void ButtonsWidget::setTextClearButton(std::string text);
                     * @brief	method setter text clear button.
                     * @author	Yadickson Soto
                     * @date	21/05/2012
                     * @param	text	new text button.
                     */
                    virtual void setTextClearButton ( std::string text );
                    /**
                     * @fn	virtual void ButtonsWidget::setTextAcceptButton(std::string text);
                     * @brief	method setter text accept button.
                     * @author	Yadickson Soto
                     * @date	21/05/2012
                     * @param	text	new text button.
                     */
                    virtual void setTextAcceptButton ( std::string text );
                    /**
                     * @fn	virtual void ButtonsWidget::setTextBackButton(std::string text);
                     * @brief	method setter text back button.
                     * @author	Yadickson Soto
                     * @date	21/05/2012
                     * @param	text	new text button.
                     */
                    virtual void setTextBackButton ( std::string text );
                    /**
                     * @fn	virtual void ButtonsWidget::setTextNullButton(std::string text);
                     * @brief	method setter text null button.
                     * @author	Yadickson Soto
                     * @date	21/05/2012
                     * @param	text	new text button.
                     */
                    virtual void setTextNullButton ( std::string text );
                    /**
                     * @fn	virtual void ButtonsWidget::setSizeClearButton(int width, int height);
                     * @brief	method setter size clear button.
                     * @author	Yadickson Soto
                     * @date	21/05/2012
                     * @param	width 	new width button.
                     * @param	height	new width button.
                     */
                    virtual void setSizeClearButton ( int width, int height );
                    /**
                     * @fn	virtual void ButtonsWidget::setSizeAcceptButton(int width, int height);
                     * @brief	method setter size accept button.
                     * @author	Yadickson Soto
                     * @date	21/05/2012
                     * @param	width 	new width button.
                     * @param	height	new width button.
                     */
                    virtual void setSizeAcceptButton ( int width, int height );
                    /**
                     * @fn	virtual void ButtonsWidget::setSizeBackButton(int width, int height);
                     * @brief	method setter size back button.
                     * @author	Yadickson Soto
                     * @date	21/05/2012
                     * @param	width 	new width button.
                     * @param	height	new width button.
                     */
                    virtual void setSizeBackButton ( int width, int height );
                    /**
                     * @fn	virtual void ButtonsWidget::setSizeNullButton(int width, int height);
                     * @brief	method setter size null button.
                     * @author	Yadickson Soto
                     * @date	21/05/2012
                     * @param	width 	new width button.
                     * @param	height	new width button.
                     */
                    virtual void setSizeNullButton ( int width, int height );
                    /**
                     * @fn	void ButtonsWidget::changeButtom();
                     * @brief	method change mode buttons accept and cancel.
                     * @author	Yadickson Soto
                     * @date	21/05/2012
                     */
                    void changeButtom();
                    /**
                     * @fn	void ButtonsWidget::clearSignals();
                     * @brief	method clear signals.
                     * @author	Yadickson Soto
                     * @date	16/11/2012
                     */
                    void clearSignals();
                    /**
                     * @fn	Smartmatic::GUI::Widgets::SmartmaticButton * getClearButton();
                     * @brief	method getter clear button widget.
                     * @author	Yadickson Soto
                     * @date	24/04/2013
                     * @return	button
                     */
                    Smartmatic::GUI::Widgets::SmartmaticButton * getClearButton();
                    /**
                     * @fn	Smartmatic::GUI::Widgets::SmartmaticButton * getAcceptButton();
                     * @brief	method getter clear accept widget.
                     * @author	Yadickson Soto
                     * @date	24/04/2013
                     * @return	button
                     */
                    Smartmatic::GUI::Widgets::SmartmaticButton * getAcceptButton();
                    /**
                     * @fn	Smartmatic::GUI::Widgets::SmartmaticButton * getBackButton();
                     * @brief	method getter back button widget.
                     * @author	Yadickson Soto
                     * @date	24/04/2013
                     * @return	button
                     */
                    Smartmatic::GUI::Widgets::SmartmaticButton * getBackButton();
                    /**
                     * @fn	Smartmatic::GUI::Widgets::SmartmaticButton * getNullButton();
                     * @brief	method getter null button widget.
                     * @author	Yadickson Soto
                     * @date	24/04/2013
                     * @return	button
                     */
                    Smartmatic::GUI::Widgets::SmartmaticButton * getNullButton();
                    /**
                     * @fn	Smartmatic::GUI::Widgets::SmartmaticBasicEventBox * getEventBoxContainer();
                     * @brief	method getter event box container widget.
                     * @author	Yadickson Soto
                     * @date	24/04/2013
                     * @return	container
                     */
                    Smartmatic::GUI::Widgets::SmartmaticBasicEventBox * getEventBoxContainer();
                    /**
                     * @fn	Smartmatic::GUI::Widgets::SmartmaticBasicHBox * getHBoxContainer();
                     * @brief	method getter hbox container widget.
                     * @author	Yadickson Soto
                     * @date	24/04/2013
                     * @return	container
                     */
                    Smartmatic::GUI::Widgets::SmartmaticBasicHBox * getHBoxContainer();

                private:

                    sigc::signal<void> signalAccept; ///< signal accept
                    sigc::signal<void> signalClear; ///< signal clear
                    sigc::signal<void> signalBack; ///< signal back
                    sigc::signal<void> signalNull; ///< signal null

                    Smartmatic::GUI::Widgets::SmartmaticBasicEventBox * eventbox; ///< The main frame
                    Smartmatic::GUI::Widgets::SmartmaticBasicHBox * mainHbox; ///< The main hbox
                    static Smartmatic::Log::ISMTTLog * logger;  ///< logger

                    /**
                     * @fn	void ButtonsWidget::onAcceptClicked();
                     * @brief	method on accept clicked.
                     * @author	Yadickson Soto
                     * @date	16/11/2012
                     */
                    void onAcceptClicked();
                    /**
                     * @fn	void ButtonsWidget::onClearClicked();
                     * @brief	method on clear clicked.
                     * @author	Yadickson Soto
                     * @date	16/11/2012
                     */
                    void onClearClicked();
                    /**
                     * @fn	void ButtonsWidget::onBackClicked();
                     * @brief	method on back clicked.
                     * @author	Yadickson Soto
                     * @date	16/11/2012
                     */
                    void onBackClicked();
                    /**
                     * @fn	void ButtonsWidget::onNullClicked();
                     * @brief	method on null clicked.
                     * @author	Yadickson Soto
                     * @date	16/11/2012
                     */
                    void onNullClicked();
                    /**
                     * @fn	void ButtonsWidget::emitSignal(sigc::signal<void> signal);
                     * @brief	method emit signal.
                     * @author	Yadickson Soto
                     * @date	16/11/2012
                     * @param signal signal
                     */
                    void emitSignal ( sigc::signal<void> signal );

                protected:

                    bool expand; ///< expand
                    bool enableClicked; ///< flag enable clicked
                    Smartmatic::GUI::Widgets::SmartmaticButton * clearButton; ///< The clear button
                    Smartmatic::GUI::Widgets::SmartmaticButton * acceptButton; ///< The accept button
                    Smartmatic::GUI::Widgets::SmartmaticButton * backButton; ///< The back button
                    Smartmatic::GUI::Widgets::SmartmaticButton * nullButton; ///< The null button
            };
        }
    }
}

#endif /* BUTTONSWIDGET_HXX_ */
