/**
 * @file ISmartmaticText.hxx
 * @brief Header class smartmatic text
 * @date 03/06/2012
 * @author Yadickson Soto
 */

#ifndef ISMARTMATICTEXT_HXX_
#define ISMARTMATICTEXT_HXX_

#include <string>

namespace Smartmatic
{
    namespace GUI
    {
        namespace Widgets
        {
            /**
             * @class	ISmartmaticText
             * @brief	interface smartmatic text.
             * @author	Yadickson Soto
             * @date	03/06/2012
             */
            class ISmartmaticText

            {
                protected:
                    /**
                     * @fn	ISmartmaticText::ISmartmaticText();
                     * @brief	class constructor.
                     * @author	Yadickson Soto
                     * @date	03/06/2012
                     */
                    ISmartmaticText ();

                public:

                    /**
                     * @fn	virtual ISmartmaticText::~ISmartmaticText();
                     * @brief	class destructor.
                     * @author	Yadickson Soto
                     * @date	03/06/2012
                     */
                    virtual ~ISmartmaticText();
                    /**
                     * @fn	virtual void ISmartmaticText::setText(std::string text) = 0;
                     * @brief	Method setter text.
                     * @author	Yadickson Soto
                     * @date	03/06/2012
                     * @param	text	text.
                     */
                    virtual void setText ( std::string text ) = 0;
                    /**
                     * @fn	virtual std::string ISmartmaticText::getText() = 0;
                     * @brief	Method getter text.
                     * @author	Yadickson Soto
                     * @date	03/06/2012
                     * @return	text.
                     */
                    virtual std::string getText() = 0;
                    /**
                     * @fn	virtual void ISmartmaticText::setMax(int max);
                     * @brief	Set entry max elements.
                     * @author	Yadickson Soto
                     * @date	04/05/2012
                     * @param	max	max.
                     */
                    virtual void setMax ( int max );
                    /**
                     * @fn	virtual void ISmartmaticText::setMask(std::string mask);
                     * @brief	Set entry mask.
                     * @author	Yadickson Soto
                     * @date	04/05/2012
                     * @param	mask	mask.
                     */
                    virtual void setMask ( std::string mask );
                    /**
                     * @fn	virtual void ISmartmaticText::setRegex(std::string regex);
                     * @brief	Set entry regex.
                     * @author	Yadickson Soto
                     * @date	03/06/2012
                     * @param	regex	regular expresion.
                     */
                    virtual void setRegex ( std::string regex );
                    /**
                     * @fn	virtual void ISmartmaticText::setMandatory(bool mandatory);
                     * @brief	Set entry mandatory date.
                     * @author	Yadickson Soto
                     * @date	08/06/2012
                     * @param	mandatory	mandatory date.
                     */
                    virtual void setMandatory ( bool mandatory );
                    /**
                     * @fn	virtual bool ISmartmaticText::validate();
                     * @brief	method validate.
                     * @author	Yadickson Soto
                     * @date	03/06/2012
                     * @return	true is validate.
                     */
                    virtual bool validate();
                    /**
                     * @fn	virtual void ISmartmaticText::setBGError() = 0;
                     * @brief	method set bg error.
                     * @author	Yadickson Soto
                     * @date	03/06/2012
                     */
                    virtual void setBGError() = 0;
                    /**
                     * @fn	virtual void ISmartmaticText::setBGNormal() = 0;
                     * @brief	method set bg normal.
                     * @author	Yadickson Soto
                     * @date	03/06/2012
                     */
                    virtual void setBGNormal() = 0;
                    /**
                     * @fn	virtual void focus();
                     * @brief	Focus component
                     * @author	Yadickson Soto
                     * @date	13/09/2013
                     */
                    virtual void focus();

                protected:

                    int max; ///< max
                    std::string mask; ///< mask
                    std::string regex; ///< regex
                    bool mandatory; ///< mandatory
            };
        }
    }
}

#endif /* ISMARTMATICTEXT_HXX_ */
