/**
 * @file SmartmaticBasicCheckButton.hxx
 * @brief Header basic check button widget class
 * @date 10/10/2013
 * @author Yadickson Soto
 */

#ifndef _SMARTMATIC_BASICCHECKBUTTON_H_
#define _SMARTMATIC_BASICCHECKBUTTON_H_

#include <gtkmm.h>
#include <Operation/AccessibleNameWidget.hxx>

namespace Smartmatic
{
    namespace GUI
    {
        namespace Widgets
        {
            /**
             * @class	SmartmaticBasicCheckButton
             * @brief	Smartmatic button.
             * @author	Yadickson Soto
             * @date	10/10/2013
             */
            class SmartmaticBasicCheckButton : public Gtk::CheckButton, public Smartmatic::GUI::Operation::AccessibleNameWidget
            {
                public:
                    /**
                     * @fn	SmartmaticBasicCheckButton::SmartmaticBasicCheckButton();
                     * @brief	constructors.
                     * @author	Yadickson Soto
                     * @date	10/10/2013
                     */
                    SmartmaticBasicCheckButton();

                    /**
                     * @fn	SmartmaticBasicCheckButton(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& refBuilder=Gtk::Builder::create());
                     * @brief	Constructor.
                     * @date 10/10/2013
                     * @author Yadickson Soto
                     * @param	cobject			If non-null, the cobject.
                     * @param	refBuilder	(optional) the reference builder.
                     */
                    SmartmaticBasicCheckButton ( BaseObjectType * cobject, const Glib::RefPtr<Gtk::Builder> & refBuilder = Gtk::Builder::create() );

                    /**
                     * @fn	virtual ~SmartmaticBasicCheckButton();
                     * @brief	Class destructor.
                     * @author	Yadickson Soto
                     * @date	10/10/2013
                     */
                    virtual ~SmartmaticBasicCheckButton();

                protected:

                    /**
                     * @fn	virtual std::string getThemeConfiguration();
                     * @brief	Getter name gtk theme configuration.
                     * @author	Yadickson Soto
                     * @date	10/10/2013
                     * @return	gtk name theme configuration
                     */
                    virtual std::string getThemeConfiguration();
            };
        }
    }
}

#endif // _SMARTMATIC_BASICCHECKBUTTON_H_
