/**
 * @file SmartmaticBasicScrollContainer.hxx
 * @brief Header basic scroll container widget class
 * @date 10/10/2013
 * @author Yadickson Soto
 */

#ifndef _SMARTMATIC_SCROLLCONTAINER_H_
#define _SMARTMATIC_SCROLLCONTAINER_H_

#include <gtkmm.h>
#include <Operation/AccessibleNameWidget.hxx>

namespace Smartmatic
{
    namespace GUI
    {
        namespace Widgets
        {
            /**
             * @class	SmartmaticBasicScrollContainer
             * @brief	Smartmatic basic scroll container widget class.
             * @author	Yadickson Soto
             * @date	10/10/2013
             */
            class SmartmaticBasicScrollContainer : public Gtk::ScrolledWindow, public Smartmatic::GUI::Operation::AccessibleNameWidget
            {
                public:
                    /**
                     * @fn	SmartmaticBasicScrollContainer::SmartmaticBasicScrollContainer();
                     * @brief	constructors.
                     * @author	Yadickson Soto
                     * @date	10/10/2013
                     */
                    SmartmaticBasicScrollContainer();

                    /**
                     * @fn	SmartmaticBasicScrollContainer(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& refBuilder=Gtk::Builder::create());
                     * @brief	Constructor.
                     * @date 10/10/2013
                     * @author Yadickson Soto
                     * @param	cobject			If non-null, the cobject.
                     * @param	refBuilder	(optional) the reference builder.
                     */
                    SmartmaticBasicScrollContainer ( BaseObjectType * cobject, const Glib::RefPtr<Gtk::Builder> & refBuilder = Gtk::Builder::create() );

                    /**
                     * @fn	virtual ~SmartmaticBasicScrollContainer();
                     * @brief	Class destructor.
                     * @author	Yadickson Soto
                     * @date	10/10/2013
                     */
                    virtual ~SmartmaticBasicScrollContainer();

                protected:

                    /**
                     * @fn	virtual std::string getThemeConfiguration();
                     * @brief	Getter name gtk theme configuration.
                     * @author	Yadickson Soto
                     * @date	10/10/2013
                     * @return	gtk name theme configuration
                     */
                    virtual std::string getThemeConfiguration();
            };
        }
    }
}

#endif // _SMARTMATIC_SCROLLCONTAINER_H_
