/**
 * @file SmartmaticRadioButtonGroup.cxx
 * @brief Body class smartmatic radio button group
 * @date 21/09/2012
 * @author Yadickson Soto
 */

#include "SmartmaticRadioButtonGroup.hxx"

using namespace Smartmatic::GUI::Widgets;

SmartmaticRadioButtonGroup::SmartmaticRadioButtonGroup()
{
    emitSignal = false;
    current = NULL;
}

SmartmaticRadioButtonGroup::~SmartmaticRadioButtonGroup()
{
    emitSignal = false;
    std::list <sigc::connection>::iterator itc;

    for ( itc = connectionList.begin();
            itc != connectionList.end();
            ++itc )
    {
        ( *itc ).disconnect();
    }

    std::set <SmartmaticRadioButton *>::iterator it;

    for ( it = radioButtonList.begin();
            it != radioButtonList.end();
            ++it )
    {
        SmartmaticRadioButton * radioButton = ( *it );

        if ( radioButton )
        {
            delete radioButton;
            radioButton = NULL;
        }
    }

    connectionList.clear();
    radioButtonList.clear();
}

void SmartmaticRadioButtonGroup::addRadioButton ( SmartmaticRadioButton * radioButton, bool grouped )
{
    radioButtonList.insert ( radioButton );
    radioButton->set_active ( true );

    if ( grouped )
    {
        radioButton->set_group ( group );
    }

    sigc::connection conn = radioButton->signal_state_changed().connect ( sigc::mem_fun ( *this, &SmartmaticRadioButtonGroup::changeOption ) );
    connectionList.push_back ( conn );
    add ( radioButton );
}

SmartmaticRadioButton * SmartmaticRadioButtonGroup::getRadioButtonSelected()
{
    SmartmaticRadioButton * radioButton = NULL;
    std::set <SmartmaticRadioButton *>::iterator it;

    for ( it = radioButtonList.begin();
            it != radioButtonList.end();
            ++it )
    {
        if ( ( *it )->get_active() )
        {
            radioButton = ( *it );
            break;
        }
    }

    return radioButton;
}

sigc::signal<void, SmartmaticRadioButton *> SmartmaticRadioButtonGroup::getSignalChange()
{
    return signalChange;
}

void SmartmaticRadioButtonGroup::changeOption ( Gtk::StateType type )
{
    if ( emitSignal && type == Gtk::STATE_ACTIVE )
    {
        SmartmaticRadioButton * radioButton = getRadioButtonSelected();

        if ( radioButton && radioButton != current )
        {
            current = radioButton;
            signalChange.emit ( radioButton );
        }
    }
}

void SmartmaticRadioButtonGroup::start()
{
    emitSignal = true;
}

void SmartmaticRadioButtonGroup::clearAll()
{
    emitSignal = false;
    std::set <SmartmaticRadioButton *>::iterator it;

    for ( it = radioButtonList.begin();
            it != radioButtonList.end();
            ++it )
    {
        ( *it )->set_active ( false );
    }

    emitSignal = true;
}

SmartmaticRadioButtonGroup::GroupButton::GroupButton()
    : Gtk::RadioButtonGroup()
{
}
