/**
 * @file StepWidget.hxx
 * @brief Header class step widget
 * @date 08/03/2012
 * @author Yadickson Soto
 */

#ifndef STEPWIDGET_HXX_
#define STEPWIDGET_HXX_

#include <gtkmm.h>
#include "RefreshListener.hxx"
#include "StateListener.hxx"
#include "keyword-navigation-interface.h"
#include <Widgets/SmartmaticBasicEventBox.hxx>

namespace Smartmatic
{
    namespace GUI
    {
        namespace Widgets
        {
            /**
             * @class	StepWidget
             * @brief	Class step widget.
             * @author	Yadickson Soto
             * @date	08/03/2012
             */
            class StepWidget : public Smartmatic::GUI::Widgets::SmartmaticBasicEventBox,
                public RefreshListener,
                public keywordNavigationInterface
            {
                public:
                    /**
                     * @fn	StepWidget();
                     * @brief	Class constructor.
                     * @author	Yadickson Soto
                     * @date	08/03/2012
                     */
                    StepWidget();
                    /**
                     * @fn	virtual ~StepWidget();
                     * @brief	Class destructor.
                     * @author	Yadickson Soto
                     * @date	08/03/2012
                     */
                    virtual ~StepWidget();
                    /**
                     * @fn	virtual std::string getTitleText();
                     * @brief	virtual method getter title.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     * @return	title.
                     */
                    virtual std::string getTitleText();
                    /**
                     * @fn	void setTitleText( const std::string& titleKey );
                     * @brief	method setter title.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     * @param	titleKey	title window.
                     */
                    void setTitleText ( const std::string& titleKey );
                    /**
                     * @fn	virtual bool isTitle();
                     * @brief	virtual method getter is visible title frame.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     * @return	true is title frame visible.
                     */
                    virtual bool isTitle();
                    /**
                     * @fn	void setTitle(bool showTitle);
                     * @brief	method setter is visible title frame.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     * @param	showTitle	true is title frame visible.
                     */
                    void setTitle ( bool showTitle );
                    /**
                     * @fn	virtual bool isHelp();
                     * @brief	virtual method getter is visible help button.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     * @return	true is help button visible.
                     */
                    virtual bool isHelp();
                    /**
                     * @fn	void setHelp(bool showHelp);
                     * @brief	method setter is visible help button.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     * @param	showHelp	true is help button visible.
                     */
                    void setHelp ( bool showHelp );
                    /**
                     * @fn	virtual bool isExit();
                     * @brief	virtual method getter is visible help button.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     * @return	true is help button visible.
                     */
                    virtual bool isExit();
                    /**
                     * @fn	void setExit(bool showExit);
                     * @brief	method setter is visible exit button.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     * @param	showExit	true is exit button visible.
                     */
                    void setExit ( bool showExit );
                    /**
                     * @fn	virtual bool isHelpSensitive();
                     * @brief	virtual method getter is sensitive help button.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     * @return	true is help button is sensitive.
                     */
                    virtual bool isHelpSensitive();

                    /**
                     * @fn	void setHelpSensitive(bool helpSensitive);
                     * @brief	Sets help sensitive.
                     * @author	Youssef.tourkmani
                     * @date	29/10/2012
                     * @param	helpSensitive	true to help sensitive.
                     */
                    void setHelpSensitive ( bool helpSensitive );
                    /**
                     * @fn	virtual bool isExitSensitive();
                     * @brief	virtual method getter is sensitive help button.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     * @return	true is exit button is sensitive.
                     */
                    virtual bool isExitSensitive();

                    /**
                     * @fn	void setExitSensitive(bool exitSensitive);
                     * @brief	Sets exit sensitive.
                     * @author	Youssef.tourkmani
                     * @date	29/10/2012
                     * @param	exitSensitive	true to exit sensitive.
                     */
                    void setExitSensitive ( bool exitSensitive );
                    /**
                     * @fn	virtual bool isShowBorder();
                     * @brief	virtual method getter is show border.
                     * @author	Yadickson Soto
                     * @date	14/04/2012
                     * @return	true is show border.
                     */
                    virtual bool isShowBorder();
                    /**
                     * @fn	void setShowBorder(bool showBorder);
                     * @brief	method setter is show border.
                     * @author	Yadickson Soto
                     * @date	14/04/2012
                     * @param	showBorder	true is show border.
                     */
                    void setShowBorder ( bool showBorder );
                    /**
                     * @fn	virtual std::string getName();
                     * @brief	virtual method getter string name.
                     * @author	Yadickson Soto
                     * @date	14/04/2012
                     * @return	name.
                     */
                    virtual std::string getName();
                    /**
                     * @fn	void setName( const std::string& name );
                     * @brief	method setter string name.
                     * @author	Yadickson Soto
                     * @date	14/04/2012
                     * @param	name	name.
                     */
                    void setName ( const std::string& name );
                    /**
                     * @fn	virtual void initialize();
                     * @brief	Initializer method.
                     * @author	Yadickson Soto
                     * @date	08/03/2012
                     */
                    virtual void initialize();
                    /**
                     * @fn	virtual void dispose();
                     * @brief	virtual method stop.
                     * @author	Yadickson Soto
                     * @date	08/03/2012
                     */
                    virtual void dispose();
                    /**
                     * @fn	virtual void setWidget(Gtk::Widget * widget);
                     * @brief	widget setter method.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     * @param	widget	widget.
                     */
                    virtual void setWidget ( Gtk::Widget * widget );
                    /**
                     * @fn	void setHelpWidget(StepWidget * helpWidget);
                     * @brief	method setter help widget.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     * @param	helpWidget	help widget.
                     */
                    void setHelpWidget ( StepWidget * helpWidget );
                    /**
                     * @fn	StepWidget * getHelpWidget();
                     * @brief	method getter help widget.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     * @return	help widget.
                     */
                    StepWidget * getHelpWidget();
                    /**
                     * @fn	void setExitWidget(StepWidget * exitWidget);
                     * @brief	method setter exit widget.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     * @param	exitWidget	exit widget.
                     */
                    void setExitWidget ( StepWidget * exitWidget );
                    /**
                     * @fn	StepWidget * getExitWidget();
                     * @brief	method getter exit widget.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     * @return	exit widget.
                     */
                    StepWidget * getExitWidget();
                    /**
                     * @fn	virtual void refresh();
                     * @brief	refresh widget method.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     */
                    virtual void refresh();
                    /**
                     * @fn	void setRefreshListener(RefreshListener * refreshListener);
                     * @brief	method setter refresh listener.
                     * @author	Yadickson Soto
                     * @date	03/04/2012
                     * @param	refreshListener	object listener.
                     */
                    void setRefreshListener ( RefreshListener * refreshListener );
                    /**
                     * @fn	RefreshListener * getRefreshListener();
                     * @brief	method getter refresh listener.
                     * @author	Yadickson Soto
                     * @date	03/04/2012
                     * @return	object listener.
                     */
                    RefreshListener * getRefreshListener();
                    /**
                     * @fn	void setStateListener(StateListener * stateListener);
                     * @brief	method setter stete listener.
                     * @author	Yadickson Soto
                     * @date	03/04/2012
                     * @param	stateListener	object listener.
                     */
                    void setStateListener ( StateListener * stateListener );
                    /**
                     * @fn	StateListener * getStateListener();
                     * @brief	method getter state listener.
                     * @author	Yadickson Soto
                     * @date	03/04/2012
                     * @return	object listener.
                     */
                    StateListener * getStateListener();
                    /**
                     * @fn	sigc::signal<void> getSignalEnd();
                     * @brief	method getter signal end.
                     * @author	Yadickson Soto
                     * @date	22/04/2012
                     * @return	signal end.
                     */
                    sigc::signal<void> getSignalEnd();
                    /**
                     * @fn	sigc::signal<void> getSignalStart();
                     * @brief	method getter signal start.
                     * @author	Juan Valera
                     * @date	09/02/2017
                     * @return	signal start.
                     */
                    sigc::signal<void> getSignalStart();
                    /**
                     * @fn     sigc::signal<void> getSignalError();
                     * @brief  method getter signal error.
                     * @author manuel.arguelles
                     * @date   22/06/2022
                     * @return signal error.
                     */
                    sigc::signal<void> getSignalError();
                    /**
                     * @fn	void emit();
                     * @brief	emit signal dispatcher end.
                     * @author	Yadickson Soto
                     * @date	04/09/2013
                     */
                    void emit();
                    /**
                     * @fn     void emitError();
                     * @brief  emit signal error.
                     * @author manuel.arguelles
                     * @date   22/06/2022
                     */
                    void emitError();

                protected:

                    /**
                     * @fn	virtual void SetKey(KeysActionsCode value);
                     * @brief	Sets a key.
                     * @author	Yadickson Soto
                     * @date	08/06/2012
                     * @param	value	The value.
                     */
                    virtual void SetKey ( KeysActionsCode value );

                private:

                    sigc::signal<void> signalEnd; ///< signal end
                    sigc::signal<void> signalStart; ///< signal start
                    sigc::signal<void> signalError; ///< signal error


                    /**
                     * @fn	void onEmit();
                     * @brief	emit signal end.
                     * @author	Yadickson Soto
                     * @date	04/09/2013
                     */
                    void onEmit();

                    /**
                     * @fn     void onEmitError();
                     * @brief  emit signal error.
                     * @author manuel.arguelles
                     * @date   22/06/2022
                     */
                    void onEmitError();

                    std::string titleKey; ///< title key
                    std::string name; ///< name

                    bool showTitle; ///< flag show title
                    bool showHelp; ///< flag show help
                    bool showExit; ///< flag show exit
                    bool showBorder; ///< flag show border
                    bool helpSensitive; ///< flag help sensitive
                    bool exitSensitive; ///< flag exit sensitive
                    StepWidget * helpWidget; ///< help widget
                    StepWidget * exitWidget; ///< exit widget
                    RefreshListener * refreshListener; ///< widget to refresh
                    StateListener * stateListener; ///< widget to state
            };
        }
    }
}

#endif /* STEPWIDGET_HXX_ */
