/**
 * @file TableWidget.hxx
 * @brief Header class table widget
 * @date 13/03/2012
 * @author Yadickson Soto
 */

#ifndef TABLEWIDGET_HXX_
#define TABLEWIDGET_HXX_

#include <gtkmm.h>
#include <Widgets/ITableWidget.hxx>
#include <Widgets/SmartmaticBasicEventBox.hxx>
#include <Widgets/SmartmaticBasicTable.hxx>

namespace Smartmatic
{
    namespace GUI
    {
        namespace Widgets
        {
            /**
             * @class	TableWidget
             * @brief	Class TableWidget.
             * @author	Yadickson Soto
             * @date	13/03/2012
             */
            class TableWidget : public SmartmaticBasicEventBox, public ITableWidget
            {
                public:
                    /**
                     * @fn	TableWidget::TableWidget(Gtk::AttachOptions xAlign = Gtk::SHRINK,
                     * 			Gtk::AttachOptions yAlign = Gtk::SHRINK);
                     * @brief	Class constructor.
                     * @author	Yadickson Soto
                     * @date	13/03/2012
                     * @param	xAlign	x align.
                     * @param	yAlign	y align.
                     */
                    TableWidget ( Gtk::AttachOptions xAlign = Gtk::SHRINK, Gtk::AttachOptions yAlign = Gtk::SHRINK );
                    /**
                     * @fn	TableWidget::TableWidget(SmartmaticBasicTable * table, Gtk::AttachOptions xAlign = Gtk::SHRINK,
                     * 			Gtk::AttachOptions yAlign = Gtk::SHRINK);
                     * @brief	Class constructor.
                     * @author	Yadickson Soto
                     * @date	13/03/2012
                     * @param	table 	table.
                     * @param	xAlign	x align.
                     * @param	yAlign	y align.
                     */
                    TableWidget ( SmartmaticBasicTable * table, Gtk::AttachOptions xAlign = Gtk::SHRINK, Gtk::AttachOptions yAlign = Gtk::SHRINK );
                    /**
                     * @fn	virtual TableWidget::~TableWidget();
                     * @brief	Class destructor.
                     * @author	Yadickson Soto
                     * @date	13/03/2012
                     */
                    virtual ~TableWidget();
                    /**
                     * @fn	virtual void TableWidget::initialize();
                     * @brief	method initialize class.
                     * @author	Yadickson Soto
                     * @date	13/03/2012
                     */
                    virtual void initialize();
                    /**
                     * @fn	virtual void TableWidget::dispose();
                     * @brief	method dispose class.
                     * @author	Yadickson Soto
                     * @date	13/03/2012
                     */
                    virtual void dispose();
                    /**
                     * @fn	virtual void TableWidget::resize(unsigned int row, unsigned int column);
                     * @brief	method resize table.
                     * @author	Yadickson Soto
                     * @date	16/03/2012
                     * @param	row			row number.
                     * @param	column	column number.
                     */
                    virtual void resize ( unsigned int row, unsigned int column );
                    /**
                     * @fn	SmartmaticBasicTable * TableWidget::getTable();
                     * @brief	method getter table.
                     * @author	Yadickson Soto
                     * @date	15/03/2012
                     * @return	table.
                     */
                    SmartmaticBasicTable * getTable();
                    /**
                     * @fn	virtual void TableWidget::put( void * widget, int row, int column);
                     * @brief	method put new element in table.
                     * @author	Yadickson Soto
                     * @date	16/03/2012
                     * @param	widget	new widget.
                     * @param	row			row position.
                     * @param	column	column position.
                     */
                    virtual void put ( void * widget, int row, int column );
                    /**
                     * @fn	void TableWidget::put(Gtk::Widget * widget, int row, int column, Gtk::AttachOptions xAlign,
                     * 			Gtk::AttachOptions yAlign);
                     * @brief	method put new element in table.
                     * @author	Yadickson Soto
                     * @date	16/03/2012
                     * @param	widget	new widget.
                     * @param	row			row position.
                     * @param	column	column position.
                     * @param	xAlign	x align.
                     * @param	yAlign	y align.
                     */
                    void put ( Gtk::Widget * widget, int row, int column, Gtk::AttachOptions xAlign, Gtk::AttachOptions yAlign );
                    /**
                     * @fn	void TableWidget::put(Gtk::Widget * widget, int rowInit, int rowEnd, int colInit,
                     * 			int colEnd, Gtk::AttachOptions xAlign, Gtk::AttachOptions yAlign);
                     * @brief	method put new element in table.
                     * @author	Yadickson Soto
                     * @date	25/05/2012
                     * @param	widget 	new widget.
                     * @param	rowInit	row position.
                     * @param	rowEnd 	row position.
                     * @param	colInit	column position.
                     * @param	colEnd 	column position.
                     * @param	xAlign 	x align.
                     * @param	yAlign 	y align.
                     */
                    void put ( Gtk::Widget * widget, int rowInit, int rowEnd, int colInit, int colEnd, Gtk::AttachOptions xAlign, Gtk::AttachOptions yAlign );
                    /**
                     * @fn	void TableWidget::clear();
                     * @brief	method clear.
                     * @author	Yadickson Soto
                     * @date	09/05/2012
                     */
                    void clear();
                    /**
                     * @fn	unsigned int TableWidget::getCountElements();
                     * @brief	method getter count elements.
                     * @author	Yadickson Soto
                     * @date	09/05/2012
                     * @return	count elements.
                     */
                    unsigned int getCountElements();
                    /**
                     * @fn	virtual void TableWidget::setSpacings(int row, int column);
                     * @brief	method set spacings table.
                     * @author	Yadickson Soto
                     * @date	16/03/2012
                     * @param	row			row spacings.
                     * @param	column	column spacings.
                     */
                    virtual void setSpacings ( int row, int column );

                private:

                    SmartmaticBasicTable * table; ///< The table
                    Gtk::AttachOptions xAlign; ///< x align
                    Gtk::AttachOptions yAlign; ///< y align
            };
        }
    }
}

#endif /* TABLEWIDGET_HXX_ */
