/**
 * @file	image-selection-widget.cc
 * @brief	image selection widget class.
 */

/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
/*
 * smartmaticgui
 * Copyright (C) Juan Delgado 2011 <juan.delgado@smartmatic.com>
 *
 * smartmaticgui is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * smartmaticgui is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "image-selection-widget.h"
#include <System/IO/File.h>
#include <Widgets/SmartmaticBasicFrame.hxx>
#include <Widgets/SmartmaticBasicLabel.hxx>
#include <Widgets/SmartmaticBasicImage.hxx>

using namespace Gtk;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::System::IO;

ImageSelectionWidget::ImageSelectionWidget ( std::vector<std::string> imagesPath, std::vector<std::string> imagesCode )
    : SmartmaticBasicHBox ()
{
    std::vector<std::string>::iterator it;
    std::vector<std::string>::iterator itCode;
    itCode = imagesCode.begin();

    for ( it = imagesPath.begin(); it != imagesPath.end(); ++it )
    {
        SmartmaticBasicFrame * frame = manage ( new SmartmaticBasicFrame() );
        SmartmaticBasicEventBox * event = manage ( new SmartmaticBasicEventBox() );
        event->set_events ( Gdk::BUTTON_PRESS_MASK );
        std::string s = *it;
        std::string code = *itCode;

        if ( File::getInstance()->canOpenFile ( s ) )
        {
            Glib::RefPtr<Gdk::Pixbuf> pixbuf = Gdk::Pixbuf::create_from_file ( s );
            SmartmaticBasicImage * image = manage ( new SmartmaticBasicImage () );
            image->set ( pixbuf );
            frame->set_shadow_type ( SHADOW_NONE );
            image->show();
            event->add ( *image );
        }
        else
        {
            SmartmaticBasicLabel * label = manage ( new SmartmaticBasicLabel ( s ) );
            frame->set_shadow_type ( SHADOW_ETCHED_OUT );
            label->show();
            event->add ( *label );
        }

        event->signal_button_press_event().connect ( sigc::bind<std::string> ( sigc::mem_fun ( *this, &ImageSelectionWidget::on_image_clicked ), code ) );
        ++itCode;
        event->show();
        events.push_back ( event );
        frame->add ( *event );
        pack_start ( *frame );
    }

    if ( ( int ) imagesPath.size() == 2 )
    {
        set_spacing ( 180 );
    }
    else
    {
        set_spacing ( 30 );
    }

    set_homogeneous ( true );
    show();
}

ImageSelectionWidget::~ImageSelectionWidget()
{
}

bool ImageSelectionWidget::on_image_clicked ( GdkEventButton * event, std::string imagePath )
{
    m_clicked.emit ( imagePath );
    return false;
}

ImageSelectionWidget::type_clicked ImageSelectionWidget::clicked()
{
    return m_clicked;
}

std::vector<Smartmatic::GUI::Widgets::SmartmaticBasicEventBox *> & ImageSelectionWidget::getEventBoxs()
{
    return events;
}
