/**
 * @file smartmatic-entry-date-time.h
 * @brief Header entry date time widget class
 * @date 29/10/2012
 * @author Juan Delgado, Yadickson Soto
 */

#ifndef _SMARTMATIC_ENTRY_DATE_TIME_H_
#define _SMARTMATIC_ENTRY_DATE_TIME_H_

#include <gtkmm.h>
#include "smartmatic-entry-number.h"
#include <time.h>
#include <Widgets/SmartmaticBasicHBox.hxx>

namespace Smartmatic
{
    namespace GUI
    {
        namespace Widgets
        {

            /**
             * @class	SmartmaticEntryDateTime
             * @brief	Smartmatic entry date time.
             * @author	Youssef.tourkmani
             * @date	25/10/2012
             */
            class SmartmaticEntryDateTime: public SmartmaticBasicHBox
            {
                public:

                    /**
                     * @typedef	struct tm SmartmaticEntryDateTimeTypedef
                     * @brief	Defines an alias representing the smartmatic entry date time typedef.
                     */
                    typedef struct tm SmartmaticEntryDateTimeTypedef; ///< typedef time

                    /**
                     * @fn	SmartmaticEntryDateTime::SmartmaticEntryDateTime(bool complete, int widthEntry,
                     * 			int spacing);
                     * @brief	Constructor.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @param	complete		true to complete.
                     * @param	widthEntry	The width entry.
                     * @param	spacing			The spacing.
                     */

                    SmartmaticEntryDateTime ( bool complete, int widthEntry, int spacing );

                    /**
                     * @fn	void SmartmaticEntryDateTime::SetLabels(Glib::ustring str_year, Glib::ustring str_mon,
                     * 			Glib::ustring str_day, Glib::ustring str_hour, Glib::ustring str_min, Glib::ustring str_sec);
                     * @brief	Sets the labels.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @param	str_year	The string year.
                     * @param	str_mon 	The string mon.
                     * @param	str_day 	The string day.
                     * @param	str_hour	The string hour.
                     * @param	str_min 	The string minimum.
                     * @param	str_sec 	The string security.
                     */
                    void SetLabels ( Glib::ustring str_year, Glib::ustring str_mon,
                                     Glib::ustring str_day, Glib::ustring str_hour,
                                     Glib::ustring str_min, Glib::ustring str_sec );

                    /**
                     * @fn	void SmartmaticEntryDateTime::SetTime(SmartmaticEntryDateTimeTypedef timeFormat);
                     * @brief	Sets a time.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @param	timeFormat	The time format.
                     */
                    void SetTime ( SmartmaticEntryDateTimeTypedef timeFormat );

                    /**
                     * @fn	SmartmaticEntryDateTimeTypedef SmartmaticEntryDateTime::GetTime();
                     * @brief	Method get time.
                     * @author	Youssef.tourkmani
                     * @date	29/10/2012
                     * @return	time.
                     */
                    SmartmaticEntryDateTimeTypedef GetTime();

                    /**
                     * @fn	void SmartmaticEntryDateTime::Clear();
                     * @brief	Clears this object to its blank/initial state.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     */
                    void Clear();

                    /**
                     * @fn	void SmartmaticEntryDateTime::SetSensitive(bool isSensitive = true);
                     * @brief	Sets a sensitive.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @param	isSensitive	true if is sensitive.
                     */
                    void SetSensitive ( bool isSensitive = true );

                protected:

                    /**
                     * @fn	void SmartmaticEntryDateTime::Initialize(bool complete, int widthEntry, int spacing);
                     * @brief	Initializes this object.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @param	complete		true to complete.
                     * @param	widthEntry	The width entry.
                     * @param	spacing			The spacing.
                     */
                    void Initialize ( bool complete, int widthEntry, int spacing );

                    /**
                     * @fn	void SmartmaticEntryDateTime::SetLabels();
                     * @brief	Sets the labels.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     */
                    void SetLabels();

                    SmartmaticEntryNumber * entry_year; ///< The entry year
                    SmartmaticEntryNumber * entry_mon;  ///< The entry mon
                    SmartmaticEntryNumber * entry_day;  ///< The entry day
                    SmartmaticEntryNumber * entry_hour; ///< The entry hour
                    SmartmaticEntryNumber * entry_min;  ///< The entry minimum
                    SmartmaticEntryNumber * entry_sec;  ///< The entry security

                    Gtk::Label * label_year; ///< The label year
                    Gtk::Label * label_mon; ///< The label mon
                    Gtk::Label * label_day; ///< The label day
                    Gtk::Label * label_hour; ///< The label hour
                    Gtk::Label * label_min; ///< The label minimum
                    Gtk::Label * label_sec; ///< The label security

                    Glib::ustring str_year; ///< The string year
                    Glib::ustring str_mon;  ///< The string mon
                    Glib::ustring str_day;  ///< The string day
                    Glib::ustring str_hour; ///< The string hour
                    Glib::ustring str_min;  ///< The string minimum
                    Glib::ustring str_sec;  ///< The string security
            };
        }
    }
}

#endif // _SMARTMATIC_ENTRY_DATE_TIME_H_
