/**
 * @file	smartmatic-entry-hours.h
 * @brief	Declares the smartmatic entry hours class.
 * @date 30/10/2012
 * @author Yadickson Soto
 */
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
/*
 * smartmaticgui
 * Copyright (C) Juan Delgado 2011 <juan.delgado@smartmatic.com>
 *
 * smartmaticgui is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * smartmaticgui is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _SMARTMATIC_ENTRY_HOURS_H_

#define _SMARTMATIC_ENTRY_HOURS_H_

#include <gtkmm.h>
#include "smartmatic-entry-number.h"
#include <locale.h>
#include <time.h>
#include <Widgets/SmartmaticBasicHBox.hxx>

namespace Smartmatic
{
    namespace GUI
    {
        namespace Widgets
        {

            /**
             * @class	SmartmaticEntryHours
             * @brief	Smartmatic entry hours.
             * @author	Youssef.tourkmani
             * @date	25/10/2012
             */
            class SmartmaticEntryHours: public SmartmaticBasicHBox
            {
                public:

                    /**
                     * @fn	SmartmaticEntryHours::SmartmaticEntryHours();
                     * @brief	Constructor.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     */
                    SmartmaticEntryHours();

                    /**
                     * @fn	void SmartmaticEntryHours::SetSensitive(bool isSensitive = true);
                     * @brief	Sets a sensitive.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @param	isSensitive	true if is sensitive.
                    */
                    void SetSensitive ( bool isSensitive = true );

                    /**
                     * @fn	int SmartmaticEntryHours::getHours();
                     * @brief	Gets the hours.
                     * @author	Youssef.tourkmani
                     * @date	29/10/2012
                     * @return	The hours.
                     */
                    int getHours();

                    /**
                     * @fn	int SmartmaticEntryHours::getMins();
                     * @brief	Gets the mins.
                     * @author	Youssef.tourkmani
                     * @date	29/10/2012
                     * @return	The mins.
                     */
                    int getMins();

                    /**
                     * @fn	int SmartmaticEntryHours::getSecs();
                     * @brief	return the seconds.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @return	The seconds.
                     */
                    int getSecs();

                    /**
                     * @fn	void SmartmaticEntryHours::SetLabels(Glib::ustring str_hour,Glib::ustring str_min,
                     * 			Glib::ustring str_sec);
                     * @brief	Sets the labels.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @param	str_hour	The string hour.
                     * @param	str_min 	The string minimum.
                     * @param	str_sec 	The string security.
                     */
                    void SetLabels ( Glib::ustring str_hour, Glib::ustring str_min, Glib::ustring str_sec );

                    /**
                     * @fn	void SmartmaticEntryHours::Initialize(int hours, int mins, int secs);
                     * @brief	Initializes this object.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     *
                     * @param	hours	The hours.
                     * @param	mins 	The minutes.
                     * @param	secs 	The seconds.
                     */
                    void Initialize ( int hours, int mins, int secs );

                    /**
                     * @fn	bool SmartmaticEntryHours::CheckFields();
                     * @brief	Determines if we can check fields.
                     * @author	Youssef.tourkmani
                     * @date	25/10/2012
                     * @return	true if it succeeds, false if it fails.
                     */
                    bool CheckFields();

                    /**
                     * @typedef	sigc::signal<void, bool> fields_complete
                     * @brief	Defines an alias representing the fields complete.
                     */
                    typedef sigc::signal<void, bool> fields_complete;

                    /**
                     * @fn	fields_complete SmartmaticEntryHours::fields_complete_signal();
                     * @brief	Gets the fields complete signal.
                     * @author	Youssef.tourkmani
                     * @date	25/10/2012
                     * @return	.
                     */
                    fields_complete fields_complete_signal();

                protected:
                    fields_complete m_fields_complete;   ///< The ballot clicked

                    SmartmaticEntryNumber * entry_hour; ///< The entry hour
                    SmartmaticEntryNumber * entry_min;  ///< The entry minimum
                    SmartmaticEntryNumber * entry_sec;  ///< The entry security


                    Gtk::Label * label_hour; ///< The label hour
                    Gtk::Label * label_min; ///< The label minimum
                    Gtk::Label * label_sec; ///< The label security

                    Glib::ustring str_hour; ///< The string hour
                    Glib::ustring str_min;  ///< The string minimum
                    Glib::ustring str_sec;  ///< The string security

                    /**
                     * @fn	void SmartmaticEntryHours::TextInserted();
                     * @brief	Text inserted.
                     * @author	Youssef.tourkmani
                     * @date	25/10/2012
                     */
                    void TextInserted();


            };
        }
    }
}

#endif // _SMARTMATIC_ENTRY_HOURS_H_
