/**
 * @file smartmatic-label.cc
 * @brief Body label widget class
 * @date 29/10/2012
 * @author Juan Delgado, Yadickson Soto
 */

#include "smartmatic-label.h"

using namespace Smartmatic::GUI::Widgets;

SmartmaticLabel::SmartmaticLabel()
    : SmartmaticBasicLabel()
{
    Initialize();
}

SmartmaticLabel::SmartmaticLabel ( BaseObjectType * cobject, const Glib::RefPtr<Gtk::Builder> & refBuilder )
    : SmartmaticBasicLabel ( cobject, refBuilder )
{
    Initialize();
}

SmartmaticLabel::~SmartmaticLabel() { }

void SmartmaticLabel::on_size_allocate ( Gtk::Allocation & allocation )
{
    if ( !isRecursive )
    {
        Label::on_size_allocate ( allocation );

        if ( customWrapMode )
        {
            set_alignment ( 0.0, 0.5 );
            set_padding ( 0, 0 );
            int width = allocation.get_width();
            Pango::Rectangle rec, dummy;
            Glib::RefPtr<Pango::Layout> layout;
            layout = get_layout();
            layout->get_pixel_extents ( dummy, rec );

            if ( rec.get_width() <= width )
            {
                set_alignment ( 0.5, 0.5 );
                set_line_wrap ( false );
            }
            else
            {
                set_line_wrap ( true );
                set_line_wrap_mode ( Pango::WRAP_WORD_CHAR );
                set_justify ( Gtk::JUSTIFY_CENTER );
                Pango::Rectangle rec1, dummy1;
                Glib::RefPtr<Pango::Layout> layout1;
                layout1 = get_layout();
                layout1->get_pixel_extents ( dummy1, rec1 );
                int paddingLabel = ( width - rec1.get_width() ) / 2;

                if ( paddingLabel > 0 )
                {
                    set_padding ( paddingLabel, 0 );
                }

                isRecursive = true;
            }
        }
    }
    else
    {
        isRecursive = false;
    }
}

void SmartmaticLabel::SetCustomWrapMode()
{
    customWrapMode = true;
}

void SmartmaticLabel::Initialize()
{
    customWrapMode = false;
    isRecursive = false;
}

void SmartmaticLabel::SetSize ( int size )
{
    Pango::FontDescription font = get_style()->get_font();
    font.set_size ( size * Pango::SCALE );
    modify_font ( font );
}

void SmartmaticLabel::SetBold ( bool bold )
{
    Pango::FontDescription font = get_style()->get_font();

    if ( bold )
    {
        font.set_weight ( Pango::WEIGHT_BOLD );
    }
    else
    {
        font.set_weight ( Pango::WEIGHT_NORMAL );
    }

    modify_font ( font );
}

void SmartmaticLabel::SetAutoWrap ( Label & label, int width, int height )
{
    label.set_size_request ( width, height );
    Pango::Rectangle rec, dummy;
    Glib::RefPtr<Pango::Layout> layout;
    layout = label.get_layout();
    layout->get_pixel_extents ( dummy, rec );

    if ( rec.get_width() < width )
    {
        label.set_alignment ( 0.5, 0.5 );
    }
    else
    {
        label.set_line_wrap ( true );
        label.set_justify ( Gtk::JUSTIFY_CENTER );
        Pango::Rectangle rec1, dummy1;
        Glib::RefPtr<Pango::Layout> layout1;
        layout1 = label.get_layout();
        layout1->get_pixel_extents ( dummy1, rec1 );
        int paddingLabel = ( width - rec1.get_width() ) / 2;
        label.set_padding ( paddingLabel, 0 );
    }
}
