/**
 * @file	wizard-widget-base.h
 * @brief	Declares the wizard widget base class.
 */
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
/*
 * smartmaticgui
 * Copyright (C) Juan Delgado 2011 <juan.delgado@smartmatic.com>
 *
 * smartmaticgui is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * smartmaticgui is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _WIZARD_WIDGET_BASE_H_
#define _WIZARD_WIDGET_BASE_H_

#include <gtkmm.h>
#include <Widgets/StepWidget.hxx>

namespace Smartmatic
{
    namespace GUI
    {
        namespace Widgets
        {

            /**
             * @class	WizardWidgetBase
             * @brief	Wizard widget base.
             * @author	Youssef.tourkmani
             * @date	25/10/2012
             */
            class WizardWidgetBase: public Smartmatic::GUI::Widgets::StepWidget
            {
                public:

                    /**
                     * @fn	WizardWidgetBase::WizardWidgetBase();
                     * @brief	Class constructor.
                     * @author	Yadickson Soto
                     * @date	22/02/2012
                     */
                    WizardWidgetBase();

                    /**
                     * @fn	virtual WizardWidgetBase::~WizardWidgetBase();
                     * @brief	Class destructor.
                     * @author	Yadickson Soto
                     * @date	22/02/2012
                     */
                    virtual ~WizardWidgetBase();

                    /**
                     * @typedef	sigc::signal<void> type_done_signal
                     * @brief	Defines an alias representing the type done signal.
                     */
                    typedef sigc::signal<void> type_done_signal;

                    /**
                     * @typedef sigc::signal<void, std::string> type_play_audio_signal
                     * @brief   Defines an alias representing the type play audio signal.
                     */
                    typedef sigc::signal<void, std::string> type_play_audio_signal;

                    /**
                     * @fn	type_done_signal WizardWidgetBase::on_stop_signal_emit();
                     * @brief	Executes the stop signal emit action.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @return	signal
                     */

                    type_done_signal on_stop_signal_emit();

                    /**
                     * @fn	type_done_signal WizardWidgetBase::on_cancel_signal_emit();
                     * @brief	Executes the cancel signal emit action.
                     * @author	Yadickson Soto
                     * @date	14/10/2013
                     * @return	signal
                     */

                    type_done_signal on_cancel_signal_emit();

                    /**
                     * @fn	type_done_signal WizardWidgetBase::on_disable_close_signal_emit();
                     * @brief	Executes the disable close signal emit action.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @return	.
                     */
                    type_done_signal on_disable_close_signal_emit();

                    /**
                     * @fn  type_play_audio_signal WizardWidgetBase::on_play_audio_signal_emit();
                     * @brief   Executes the play audio signal emit action.
                     * @author  eduardo.fernandez
                     * @date    18/11/2017
                     * @return  .
                     */
                    type_play_audio_signal on_play_audio_signal_emit();

                    /**
                     * @fn	virtual bool WizardWidgetBase::StopWizard();
                     * @brief	Method getter is stop wizard.
                     * @author	Yadickson Soto
                     * @date	22/02/2012
                     * @return	true is stop wizard.
                     */
                    virtual bool StopWizard();

                    /**
                     * @fn	virtual bool WizardWidgetBase::isEnabledButtonExitWizard();
                     * @brief	Method getter is enabled button exit wizard.
                     * @author	Yadickson Soto
                     * @date	22/02/2012
                     * @return	true is enabled button exit wizard.
                     */
                    virtual bool isEnabledButtonExitWizard();

                protected:

                    type_done_signal       m_stop_signal; ///< The stop signal
                    type_done_signal       m_cancel_signal; ///< The cancel signal
                    type_done_signal       m_disable_close_signal; ///< The stop signal
                    type_play_audio_signal m_play_audio_signal; ///< The play audio signal
            };
        }
    }
}

#endif // _WIZARD_WIDGET_BASE_H_
