/**
 * @file basic-window.h
 * @brief Header class basic window
 * @date 26/03/2012
 * @author Yadickson Soto
 */

#ifndef _BASIC_WINDOW_H_
#define _BASIC_WINDOW_H_

#include <gtkmm.h>
#include <string>
#include <list>
#include "Widgets/keyword-navigation-interface.h"
#include "Configuration/label-configuration.h"
#include "Widgets/exit-button-listener.h"
#include "Widgets/help-button-listener.h"
#include <Configuration/position-window-schema.hxx>
#include <Operation/AccessibleNameWidget.hxx>
#include <Widgets/SmartmaticBasicImage.hxx>
#include <Widgets/SmartmaticBasicLabel.hxx>
#include <Widgets/SmartmaticBasicEventBox.hxx>
#include <Widgets/SmartmaticBasicFrame.hxx>
#include <Widgets/SmartmaticBasicHBox.hxx>
#include <Widgets/SmartmaticBasicVBox.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace GUI
    {
        namespace Widgets
        {
            class HelpExitButtons;
            class StepWidget;
        }

        namespace Windows
        {
            /**
             * @class	BasicWindow
             * @brief	class basic window.
             * @author	Yadickson Soto
             * @date	26/03/2012
             */
            class BasicWindow: public Gtk::Window,
                public Smartmatic::GUI::Widgets::ExitButtonListener,
                public Smartmatic::GUI::Widgets::HelpButtonListener,
                public Smartmatic::GUI::Operation::AccessibleNameWidget
            {
                public:

                    /**
                     * @fn	BasicWindow(bool useHeaderFrame=true, bool useTitleFrame = false, bool isModal = true,
                     * 			Gtk::WindowType type = Gtk::WINDOW_TOPLEVEL);
                     * @brief	Constructor.
                     * @author	Youssef.tourkmani
                     * @date	29/10/2012
                     * @param	useTitleFrame 	(optional) the use title frame.
                     * @param	type						(optional) the type.
                     */
                    BasicWindow ( bool useTitleFrame = false, Gtk::WindowType type = Gtk::WINDOW_TOPLEVEL );
                    /**
                     * @fn	virtual ~BasicWindow ();
                     * @brief	Class destructor.
                     * @author	Yadickson Soto
                     * @date	27/04/2011
                     */
                    virtual ~BasicWindow ();
                    /**
                     * @fn	virtual void ShowDialog();
                     * @brief	Method  show the dialog.
                     * @author	Yadickson Soto
                     * @date	27/04/2011
                     */
                    virtual void ShowDialog();
                    /**
                     * @fn	virtual void QuitDialog();
                     * @brief	Method quit dialog.
                     * @author	Yadickson Soto
                     * @date	27/04/2011
                     */
                    virtual void QuitDialog();
                    /**
                     * @fn	void getWindowSize (int& width, int& height);
                     * @brief	Method getter window size.
                     * @author	Yadickson Soto
                     * @date	27/04/2011
                     * @param	width 	result width.
                     * @param	height	result height.
                     */
                    void getWindowSize ( int & width, int & height );
                    /**
                     * @fn	void getContentSize (int& width, int& height);
                     * @brief	Gets a principal size.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @param	width 	The width.
                     * @param	height	The height.
                     */
                    void getContentSize ( int & width, int & height );
                    /**
                     * @fn	void setPosition(int x, int y);
                     * @brief	Method set position window.
                     * @author	Yadickson Soto
                     * @date	27/04/2011
                     * @param	x	position x.
                     * @param	y	position y.
                     */
                    void setPosition ( int x, int y );
                    /**
                     * @fn	void setPosition( Smartmatic::GUI::Configuration::PositionConfiguration & position );
                     * @brief	Method set position window.
                     * @author	Yadickson Soto
                     * @date	27/04/2011
                     * @param	position	new position.
                     */
                    void setPosition ( Smartmatic::GUI::Configuration::PositionConfiguration & position );
                    /**
                     * @fn	void showTitle();
                     * @brief	Method show title.
                     * @author	Yadickson Soto
                     * @date	27/04/2011
                     */
                    void showTitle();
                    /**
                     * @fn	void hideTitle();
                     * @brief	Method hide title.
                     * @author	Yadickson Soto
                     * @date	27/04/2011
                     */
                    void hideTitle();
                    /**
                     * @fn	void getTitleSize (int& width, int& height);
                     * @brief	Gets a title size.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @param	width 	The width.
                     * @param	height	The height.
                     */
                    void getTitleSize ( int & width, int & height );
                    /**
                     * @fn	void setTitleLabelConfiguration(Smartmatic::GUI::Configuration::LabelConfiguration lblConfig);
                     * @brief	Method set title label configuration.
                     * @author	Yadickson Soto
                     * @date	28/03/2012
                     * @param	lblConfig	label configuration.
                     */
                    void setTitleLabelConfiguration ( Smartmatic::GUI::Configuration::LabelConfiguration lblConfig );
                    /**
                     * @fn	void setTitleText(std::string title);
                     * @brief	Method set title test.
                     * @author	Yadickson Soto
                     * @date	28/03/2012
                     * @param	title	new text.
                     */
                    void setTitleText ( std::string title );
                    /**
                     * @fn	void setTitleColor(Gdk::Color & color);
                     * @brief	Method set title color.
                     * @author	Yadickson Soto
                     * @date	28/03/2012
                     * @param	color	new title color.
                     */
                    void setTitleColor ( Gdk::Color & color );
                    /**
                     * @fn	void showTitleImage();
                     * @brief	Method show title image.
                     * @author	Yadickson Soto
                     * @date	28/03/2012
                     */
                    void showTitleImage();
                    /**
                     * @fn	void hideTitleImage();
                     * @brief	Method hide title image.
                     * @author	Yadickson Soto
                     * @date	28/03/2012
                     */
                    void hideTitleImage();
                    /**
                     * @fn	void setTitleImage(std::string image);
                     * @brief	Method setter title image.
                     * @author	Yadickson Soto
                     * @date	28/03/2012
                     * @param	image	new title image.
                     */
                    void setTitleImage ( std::string image );
                    /**
                     * @fn	void showTitleHelp();
                     * @brief	Method show title help.
                     * @author	Yadickson Soto
                     * @date	28/03/2012
                     */
                    void showTitleHelp();
                    /**
                     * @fn	void hideTitleHelp();
                     * @brief	Method hide title help.
                     * @author	Yadickson Soto
                     * @date	28/03/2012
                     */
                    void hideTitleHelp();
                    /**
                     * @fn	void setTitleHelp(Gtk::Widget * widget);
                     * @brief	Method setter title help.
                     * @author	Yadickson Soto
                     * @date	28/03/2012
                     * @param	widget	new title help.
                     */
                    void setTitleHelp ( Gtk::Widget * widget );
                    /**
                     * @fn	virtual void setTitle(Gtk::Widget * widget);
                     * @brief	Method view widget in title area.
                     * @author	Yadickson Soto
                     * @date	28/03/2012
                     * @param	widget	widget to view.
                     */
                    virtual void setTitle ( Gtk::Widget * widget );
                    /**
                     * @fn	virtual void setWidget(Gtk::Widget * widget);
                     * @brief	Method view widget in client area.
                     * @author	Yadickson Soto
                     * @date	28/03/2012
                     * @param	widget	widget to view.
                     */
                    virtual void setWidget ( Gtk::Widget * widget );
                    /**
                     * @fn	virtual void setExitButtonSensitive (bool sensitive);
                     * @brief	Sets exit button sensitive.
                     * @author	Youssef.tourkmani
                     * @date	30/10/2012
                     * @param	sensitive	true to sensitive.
                     */
                    virtual void setExitButtonSensitive ( bool sensitive );
                    /**
                     * @fn	virtual void setExitButtonVisible (bool visible);
                     * @brief	Sets exit button visible.
                     * @author	Youssef.tourkmani
                     * @date	30/10/2012
                     * @param	visible	true to show, false to hide.
                     */
                    virtual void setExitButtonVisible ( bool visible );
                    /**
                     * @fn	virtual void setHelpButtonSensitive (bool sensitive);
                     * @brief	Sets help button sensitive.
                     * @author	Youssef.tourkmani
                     * @date	30/10/2012
                     * @param	sensitive	true to sensitive.
                     */
                    virtual void setHelpButtonSensitive ( bool sensitive );
                    /**
                     * @fn	virtual void setHelpButtonVisible (bool visible);
                     * @brief	Sets help button visible.
                     * @author	Youssef.tourkmani
                     * @date	30/10/2012
                     * @param	visible	true to show, false to hide.
                     */
                    virtual void setHelpButtonVisible ( bool visible );
                    /**
                     * @fn	virtual void setBorderVisible(bool visible);
                     * @brief	Method view all border.
                     * @author	Yadickson Soto
                     * @date	28/03/2012
                     * @param	visible	true to show, false to hide.
                     */
                    virtual void setBorderVisible ( bool visible );
                    /**
                     * @fn	virtual void enableHelpButton();
                     * @brief	Method enable help button.
                     * @author	Yadickson Soto
                     * @date	28/03/2012
                     */
                    virtual void enableHelpButton();
                    /**
                     * @fn	virtual void disableHelpButton();
                     * @brief	Method disable help button.
                     * @author	Yadickson Soto
                     * @date	28/03/2012
                     */
                    virtual void disableHelpButton();
                    /**
                     * @fn	virtual void enableExitButton();
                     * @brief	Method enable exit button.
                     * @author	Yadickson Soto
                     * @date	28/03/2012
                     */
                    virtual void enableExitButton();
                    /**
                     * @fn	virtual void disableExitButton();
                     * @brief	Method disable exit button.
                     * @author	Yadickson Soto
                     * @date	28/03/2012
                     */
                    virtual void disableExitButton();
                    /**
                     * @fn	void pushStepWidget(Smartmatic::GUI::Widgets::StepWidget * widget, bool force = false);
                     * @brief	Method push new widget.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     * @param	widget	new widget.
                     * @param	force 	force push.
                     */
                    void pushStepWidget ( Smartmatic::GUI::Widgets::StepWidget * widget, bool force = false );
                    /**
                     * @fn	Smartmatic::GUI::Widgets::StepWidget * popPushStepWidget(Smartmatic::GUI::Widgets::StepWidget * widget,
                     * 			bool force = false);
                     * @brief	Method pop and push new widget.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     * @param	widget	new widget.
                     * @param	force 	force push.
                     * @return	last widget.
                     */
                    Smartmatic::GUI::Widgets::StepWidget * popPushStepWidget ( Smartmatic::GUI::Widgets::StepWidget * widget, bool force = false );
                    /**
                     * @fn	Smartmatic::GUI::Widgets::StepWidget * popStepWidget(bool force = false);
                     * @brief	Method pop last widget.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     * @param	force	force push.
                     * @return	last widget.
                     */
                    Smartmatic::GUI::Widgets::StepWidget * popStepWidget ( bool force = false );
                    /**
                     * @fn	void setStepWidget(Smartmatic::GUI::Widgets::StepWidget * widget);
                     * @brief	Method set step windget.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     * @param	widget	set step widget.
                     */
                    void setStepWidget ( Smartmatic::GUI::Widgets::StepWidget * widget );
                    /**
                     * @fn	virtual void refreshTitleText();
                     * @brief	Method refresh title text.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     */
                    virtual void refreshTitleText();
                    /**
                     * @fn	virtual void refreshHelpButton();
                     * @brief	Method refresh help button.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     */
                    virtual void refreshHelpButton();
                    /**
                     * @fn	virtual void refreshExitButton();
                     * @brief	Method refresh exit button.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     */
                    virtual void refreshExitButton();
                    /**
                     * @fn	virtual void refreshStepWidget();
                     * @brief	Method refresh step widget.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     */
                    virtual void refreshStepWidget();
                    /**
                     * @fn	void setKeywordNavigation(Smartmatic::GUI::Widgets::keywordNavigationInterface * keywordInterface);
                     * @brief	Method setter current keyword.
                     * @author	Yadickson Soto
                     * @date	08/06/2012
                     * @param	keywordInterface	current keyword.
                     */
                    void setKeywordNavigation ( Smartmatic::GUI::Widgets::keywordNavigationInterface * keywordInterface );
                    /**
                     * @fn	void setBlockPopPush(bool blockState = false);
                     * @brief	Method setter block push pop.
                     * @author	Yadickson Soto
                     * @date	08/06/2012
                     * @param	blockState	block state.
                     */
                    void setBlockPopPush ( bool blockState = false );

                protected:
                    /**
                     * @fn	virtual bool key_pressed(GdkEventKey *event);
                     * @brief	Key pressed.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @param	event	If non-null, the event.
                     * @return	true if it succeeds, false if it fails.
                     */
                    virtual bool key_pressed ( GdkEventKey * event );
                    /**
                     * @fn	Gtk::Frame& getTitleFrame();
                     * @brief	Gets the title frame.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @return	The title frame.
                     */
                    Gtk::Frame & getTitleFrame();
                    /**
                     * @fn	Gtk::Frame& getClientAreaFrame();
                     * @brief	Gets the client area frame.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @return	The client area frame.
                     */
                    Gtk::Frame & getClientAreaFrame();
                    /**
                     * @fn	virtual bool on_delete_event( GdkEventAny* G_GNUC_UNUSED );
                     * @brief	Raises the delete event.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @param	G_GNUC_UNUSED	If non-null, the gnuc unused.
                     * @return	true if it succeeds, false if it fails.
                     */
                    virtual bool on_delete_event ( GdkEventAny * G_GNUC_UNUSED );
                    /**
                     * @fn	void initialize();
                     * @brief	Method initialize class.
                     * @author	Yadickson Soto
                     * @date	27/03/2012
                     */
                    void initialize();
                    /**
                     * @fn	virtual void dispose();
                     * @brief	Method dispose class.
                     * @author	Yadickson Soto
                     * @date	27/03/2012
                     */
                    virtual void dispose();
                    /**
                     * @fn	virtual void ShowHelp();
                     * @brief	Method show menu.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     */
                    virtual void ShowHelp();
                    /**
                     * @fn	virtual void ShowExit();
                     * @brief	Method show exit.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     */
                    virtual void ShowExit();
                    /**
                     * @fn	virtual void Exit();
                     * @brief	Method exit window clicked.
                     * @author	Yadickson Soto
                     * @date	30/03/2012
                     */
                    virtual void Exit();
                    /**
                     * @fn	virtual void CloseHelp();
                     * @brief	Method close help.
                     * @author	Juan Valera
                     * @date	09/02/2017
                     */
                    virtual void CloseHelp();
                    /**
                     * @fn	int getCountStepWidget();
                     * @brief	Method getter count step widget.
                     * @author	Yadickson Soto
                     * @date	11/04/2012
                     * @return	count step widget.
                     */
                    int getCountStepWidget();
                    /**
                     * @fn	Smartmatic::GUI::Widgets::StepWidget * getCurrentWidget();
                     * @brief	Method getter current step widget.
                     * @author	Yadickson Soto
                     * @date	11/04/2012
                     * @return	current step widget.
                     */
                    Smartmatic::GUI::Widgets::StepWidget * getCurrentWidget();

                private:
                    /**
                     * @fn	void resizeComponents();
                     * @brief	Method resize components.
                     * @author	Yadickson Soto
                     * @date	27/04/2012
                     */
                    void resizeComponents();

                    Glib::Mutex mutex; ///< lock show widget

                    Smartmatic::GUI::Widgets::HelpExitButtons * helpExitButtons; ///< help exit buttons
                    Smartmatic::GUI::Widgets::StepWidget * currentWidget; ///< current widget

                    bool blockState; ///< block pusp pop state
                    int formheight; ///< form height
                    int formwidth; ///< form width
                    bool useTitleFrame; ///< flag show title frame

                    std::vector<Smartmatic::GUI::Widgets::KeysActionsCode> validKeys;   ///< The valid keys

                    Smartmatic::GUI::Widgets::SmartmaticBasicVBox * mainVbox; ///< main frame
                    Smartmatic::GUI::Widgets::SmartmaticBasicHBox * titleHbox; ///< title hbox
                    Smartmatic::GUI::Widgets::SmartmaticBasicEventBox * titleHelpEventbox; ///< title help
                    Smartmatic::GUI::Widgets::SmartmaticBasicFrame * titleFrame;	///< The title frame
                    Smartmatic::GUI::Widgets::SmartmaticBasicFrame * clientArea;	///< The client area
                    Smartmatic::GUI::Widgets::SmartmaticBasicImage * titleImage;	///< The title image
                    Smartmatic::GUI::Widgets::SmartmaticBasicLabel * titleLabel; ///< title label
                    Smartmatic::GUI::Widgets::SmartmaticBasicEventBox * titleeventbox;  ///< The title event box
                    Smartmatic::GUI::Widgets::SmartmaticBasicEventBox * clientAreaEventBox; ///< The client area event box
                    Smartmatic::GUI::Widgets::keywordNavigationInterface * keywordInterface; ///< The keyword interface

                    std::list < Smartmatic::GUI::Widgets::StepWidget * > stepWidgetList; ///< widget list
                    Smartmatic::GUI::Widgets::KeysActionsCode keyCode; ///< key press
                    static Smartmatic::Log::ISMTTLog * logger; ///< The logger
            };
        }
    }
}
#endif /* _BASIC_FORM_H_ */
