/**
 * @file    LogImpl.h
 * @brief   Declares the log implementation class.
 * @date 08-03-2011
 * @author gerardohernandez
 */

#ifndef LOGIMPL_H_
#define LOGIMPL_H_

#include "ISMTTLog.h"
#include "log4cxx/spi/loggingevent.h"


namespace Smartmatic
{
    namespace Log
    {
        /**
         * @class   LogImpl
         * @brief   Implementation of the ISMTTLog.
         * @author  Fsilva
         * @date    28/04/2011
         *              @see ISMTTLog
         */
        class LogImpl : public ISMTTLog, public log4cxx::Logger
        {

            private:

                log4cxx::LoggerPtr loggerError; ///< The logger with the error level
                log4cxx::LoggerPtr loggerInfo;  ///< The logger with the info level
                log4cxx::LoggerPtr loggerWarn;  ///< The logger with the warning level
                log4cxx::LogString currentName; ///< The current name of the log string
                std::string domain; ///< The domain

                /**
                 * @fn  void LogImpl::doLog ( const log4cxx::LevelPtr & level, const std::string & messageCode );
                 * @brief   Executes the log operation.
                 * @author  Fsilva
                 * @date    27/04/2011
                 * @param   level               The level.
                 * @param   messageCode The message code.
                 */
                void doLog ( const log4cxx::LevelPtr & level, const std::string & messageCode );

            public:

                /**
                 * @fn  LogImpl::LogImpl ( log4cxx::LoggerPtr loggerInfoArg,log4cxx::LoggerPtr loggerErrorArg,
                 *          log4cxx::LoggerPtr loggerWarnArg, log4cxx::helpers::Pool& pool,
                 *          const log4cxx::LogString& name, std::string domain = "" );
                 * @brief   Constructor.
                 * @author  Fsilva
                 * @date    27/04/2011
                 * @param   loggerInfoArg   The logger information argument.
                 * @param   loggerErrorArg  The logger error argument.
                 * @param   loggerWarnArg   The logger warning argument.
                 * @param   pool                        The pool.
                 * @param   name                        The name.
                 * @param   domain                  The domain.
                 */
                LogImpl ( log4cxx::LoggerPtr loggerInfoArg, log4cxx::LoggerPtr loggerErrorArg, log4cxx::LoggerPtr loggerWarnArg,
                          log4cxx::helpers::Pool & pool, const log4cxx::LogString & name, std::string domain = "" );

                /**
                 * @fn  void LogImpl::Debug ( const std::string & messageCode );
                 * @brief   Log the Debug message.
                 * @author  Fsilva
                 * @date    27/04/2011
                 * @param   messageCode The message code.
                 */
                void Debug ( const std::string & messageCode );

                /**
                 * @fn  void LogImpl::Audit ( const std::string & messageCode );
                 * @brief   Log the Audit message.
                 * @author  Fsilva
                 * @date    27/04/2011
                 * @param   messageCode The message code.
                 */
                void Audit ( const std::string & messageCode );

                /**
                 * @fn  void LogImpl::Error ( const std::string & messageCode );
                 * @brief   Log the error message.
                 * @author  Fsilva
                 * @date    27/04/2011
                 * @param   messageCode The message code.
                 */
                void Error ( const std::string & messageCode );
        };
    }
}

#endif /* LOGIMPL_H_ */
