/**
 * @file    SMTTLogManager.cpp
 * @brief   Declares the smtt log manager class.
 * @date 8/07/2011
 * @author gerardohernandez
 */

#include "SMTTLogManager.h"
#include "LogImpl.h"
#include <log4cxx/logmanager.h>
#include <log4cxx/xml/domconfigurator.h>

using namespace Smartmatic::Log;
using namespace log4cxx;
using namespace log4cxx::xml;
using namespace log4cxx::rolling;
using namespace log4cxx::helpers;

#define LOG_CONF_FILENAME "log4-configuration.xml" ///< file name logger

SMTTLogManager * SMTTLogManager::instance = NULL;

ISMTTLog * SMTTLogManager::GetLogger ( const std::string & name, const std::string & domain )
{
    LoggerPtr loggerError = LogManager::getLogger ( name );
    LoggerPtr loggerInfo = LogManager::getLogger ( name );
    LoggerPtr loggerWarn = LogManager::getLogger ( name );
    Pool * pool = new Pool ();
    return new LogImpl ( loggerInfo, loggerError, loggerWarn, *pool, name, domain );
}

SMTTLogManager::SMTTLogManager ()
    : fullFilePath(LOG_CONF_FILENAME)
{
}

SMTTLogManager::~SMTTLogManager ()
{
    instance = NULL;
}

void SMTTLogManager::Reconfigure ()
{
    DOMConfigurator::configure ( fullFilePath );
}

void SMTTLogManager::shutdown ()
{
    LogManager::shutdown ();
}

const std::string & SMTTLogManager::getConfigFile ()
{
    return fullFilePath;
}

void SMTTLogManager::setConfigFile ( const std::string & fileName )
{
    fullFilePath = fileName;
}

SMTTLogManager * SMTTLogManager::getInstance ()
{
    if ( instance == NULL )
    {
        instance = new SMTTLogManager ();
    }

    return instance;
}
