/**
 * @file    SMTTLogManager.h
 *
 * @brief   Declares the smtt log manager class.
 */

#ifndef _SMTTLOGMANAGER_H_
#define _SMTTLOGMANAGER_H_

#include <string>

namespace Smartmatic
{
    namespace Log
    {
        /**
         * @class ISMTTLog
         * @brief forward declaration of the class.
         */
        class ISMTTLog;
    }
}

namespace Smartmatic
{
    namespace Log
    {
        /**
         * @class   SMTTLogManager
         * @brief   Manage the state and functions about Loggers and logs.
         * @author  Fsilva
         * @date    28/04/2011
         */
        class SMTTLogManager
        {
            protected:
                /**
                 * @fn SMTTLogManager ();
                 * @brief	Class constructor
                 * @author	Yadickson Soto
                 * @date	15-11-2013
                 */
                SMTTLogManager ();

            public:

                /**
                 * @fn virtual ~SMTTLogManager ();
                 * @brief	Destroy
                 * @author	Yadickson Soto
                 * @date	15-11-2013
                 */
                virtual ~SMTTLogManager ();

                /**
                 * @fn  static ISMTTLog * SMTTLogManager::GetLogger ( const std::string & name, const std::string & domain );
                 * @brief   Gets a logger.
                 * @author  Fsilva
                 * @date    27/04/2011
                 * @param   name        The name.
                 * @param   domain  The domain.
                 * @return  null if it fails, else the logger.
                 */
                static ISMTTLog * GetLogger ( const std::string & name, const std::string & domain );

                /**
                 * @fn  void SMTTLogManager::Reconfigure ();
                 * @brief   Reconfigure the logger.
                 * @author  Yadickson Soto yadickson.soto@smartmatic.com
                 * @date    27/05/2011
                 */
                void Reconfigure ();

                /**
                 * @fn  void SMTTLogManager::shutdown ();
                 * @brief   Shutdown the logger.
                 * @author  Yadickson Soto yadickson.soto@smartmatic.com
                 * @date    27/05/2011
                 */
                void shutdown ();

                /**
                 * @fn  const std::string & getConfigFile ();
                 * @brief   Gets configuration file.
                 * @author  Youssef.tourkmani
                 * @date    24/10/2012
                 * @return  The configuration file.
                 */
                const std::string & getConfigFile ();

                /**
                 * @fn  void setConfigFile ( const std::string & fileName );
                 * @brief   Configures the logger file.
                 * @author  Yadickson Soto
                 * @date    15/11/2013
                 * @param   fileName    Filename of the file.
                 */
                void setConfigFile ( const std::string & fileName );

                /**
                 * @fn	static SMTTLogManager * getInstance ();
                 * @brief	Getter method instance of class.
                 * @author	Yadickson Soto
                 * @date	15/11/2013
                 * @return	instance of class.
                 */
                static SMTTLogManager * getInstance ();

            private:

                std::string fullFilePath; ///< full file path configure
                static SMTTLogManager * instance; ///< instance of class
        };
    }
}

#endif // _SMTTLOGMANAGER_H_
