/**
 * @file DynamicPathRollingFileAppender.hxx
 * @brief Header class DynamicPathRollingFileAppender
 * @date 15/07/2011
 * @author Yadickson Soto yadickson.soto@smartmatic.com
 */

#ifndef DYNAMICPATHROLLINGFILEAPPENDER_HXX_
#define DYNAMICPATHROLLINGFILEAPPENDER_HXX_

#include <log4cxx/rollingfileappender.h>
#include <Log/BasePathInterface.hxx>

namespace log4cxx
{
    /**
     * @class   DynamicPathRollingFileAppender
     * @brief   This class allows the extension of the class log4cxx::RollingFileAppender.
     * @author  Yadickson Soto yadickson.soto@smartmatic.com
     * @date    15/07/2011
     */
    class DynamicPathRollingFileAppender : public log4cxx::RollingFileAppender
    {
        public:
            /**
             * @fn  DynamicPathRollingFileAppender::DynamicPathRollingFileAppender ();
             * @brief   Constructor class.
             * @author  Yadickson Soto yadickson.soto@smartmatic.com
             * @date    15/07/2011
             */
           DynamicPathRollingFileAppender ();

            /**
             * @fn  virtual DynamicPathRollingFileAppender::~DynamicPathRollingFileAppender ();
             * @brief   Destroy.
             * @author  Yadickson Soto yadickson.soto@smartmatic.com
             * @date    15/07/2011
             */
            virtual ~DynamicPathRollingFileAppender ();

            /**
             * @fn  virtual void DynamicPathRollingFileAppender::setFile ( const log4cxx::LogString& file,
             *          bool append, bool bufferedIO, size_t bufferSize, log4cxx::helpers::Pool& p );
             * @brief   Virtual method set file name.
             * @author  Yadickson Soto yadickson.soto@smartmatic.com
             * @date    15/07/2011
             * @param   file                file name of config file logger.
             * @param   append          flag method.
             * @param   bufferedIO  flag method.
             * @param   bufferSize  size of buffer.
             * @param   p                       object for synchronize.
             */
            virtual void setFile ( const log4cxx::LogString & file,
                                   bool append,
                                   bool bufferedIO,
                                   size_t bufferSize,
                                   log4cxx::helpers::Pool & p );

            /**
             * @fn  virtual void DynamicPathRollingFileAppender::setOption ( const log4cxx::LogString & option,
             *          const log4cxx::LogString & value );
             * @brief   Virtual method set option config.
             * @author  Yadickson Soto yadickson.soto@smartmatic.com
             * @date    15/07/2011
             * @param   option  option name of config file logger.
             * @param   value   value of option.
             */
            virtual void setOption ( const log4cxx::LogString & option, const log4cxx::LogString & value );

            /**
             * @fn  virtual void DynamicPathRollingFileAppender::append ( const log4cxx::spi::LoggingEventPtr& event,
             *          log4cxx::helpers::Pool& p );
             * @brief   Virtual method set append log.
             * @author  Yadickson Soto yadickson.soto@smartmatic.com
             * @date    15/07/2011
             * @param   event   object container data line.
             * @param   p           object for synchronize.
             */
            virtual void append ( const log4cxx::spi::LoggingEventPtr & event, log4cxx::helpers::Pool & p );

            /**
             * @fn  static void DynamicPathRollingFileAppender::putBasePathInterface ( Smartmatic::Log::BasePathInterface * iBasePath );
             * @brief   Method set base path interface logger.
             * @author  Yadickson Soto yadickson.soto@smartmatic.com
             * @date    15/07/2011
             * @param   iBasePath   base path interface
             *                                  @see Smartmatic::Log::BasePathInterface.
             */
            static void putBasePathInterface ( Smartmatic::Log::BasePathInterface * iBasePath );

            /**
             * @fn  static std::map <int, bool> & DynamicPathRollingFileAppender::getStateChangeMap ();
             * @brief   Method getter state change map.
             * @author  Yadickson Soto yadickson.soto@smartmatic.com
             * @date    15/07/2011
             * @return  state change map.
             */
            static std::map <int, bool> & getStateChangeMap ();

            DECLARE_LOG4CXX_OBJECT ( DynamicPathRollingFileAppender )
            BEGIN_LOG4CXX_CAST_MAP ()
            LOG4CXX_CAST_ENTRY ( DynamicPathRollingFileAppender )
            LOG4CXX_CAST_ENTRY_CHAIN ( RollingFileAppender )
            END_LOG4CXX_CAST_MAP ()

        private:

            static std::map <std::string, Smartmatic::Log::BasePathInterface * > iBasePathMap; ///< state change map

            log4cxx::LogString file; ///< file name logger
            log4cxx::LogString cryptoType; ///< crypto type config
            log4cxx::LogString basePathType; ///< base path type

            bool appendFlag; ///< append flag logger file
            bool bufferedIO; ///< buffer io flag logger file
            size_t bufferSize; ///< buffer size logger file
            bool createFile;  ///< flag for create logger file
            bool forceClose; ///< flag for force close logger file
    };

    LOG4CXX_PTR_DEF ( DynamicPathRollingFileAppender ); ///< create pointer of class DynamicPathRollingFileAppender
}

#endif /* DYNAMICPATHROLLINGFILEAPPENDER_HXX_ */
